/**
 *                                                                            
 * Copyright (c) 2011, 2016 - Loetz GmbH&Co.KG (69115 Heidelberg, Germany)
 *                                                                            
 * All rights reserved. This program and the accompanying materials           
 * are made available under the terms of the Eclipse Public License 2.0        
 * which accompanies this distribution, and is available at                  
 * https://www.eclipse.org/legal/epl-2.0/                                 
 *                                 
 * SPDX-License-Identifier: EPL-2.0                                 
 *                                                                            
 * Contributors:   
 * Christophe Loetz (Loetz GmbH&Co.KG) - initial implementation 
 */
package org.eclipse.osbp.xtext.table.ide.contentassist.antlr;

import com.google.inject.Inject;
import java.util.HashMap;
import java.util.Map;
import org.eclipse.osbp.xtext.table.ide.contentassist.antlr.internal.InternalTableDSLParser;
import org.eclipse.osbp.xtext.table.services.TableDSLGrammarAccess;
import org.eclipse.xtext.AbstractElement;
import org.eclipse.xtext.ide.editor.contentassist.antlr.AbstractContentAssistParser;

public class TableDSLParser extends AbstractContentAssistParser {

	@Inject
	private TableDSLGrammarAccess grammarAccess;

	private Map<AbstractElement, String> nameMappings;

	@Override
	protected InternalTableDSLParser createParser() {
		InternalTableDSLParser result = new InternalTableDSLParser(null);
		result.setGrammarAccess(grammarAccess);
		return result;
	}

	@Override
	protected String getRuleName(AbstractElement element) {
		if (nameMappings == null) {
			nameMappings = new HashMap<AbstractElement, String>() {
				private static final long serialVersionUID = 1L;
				{
					put(grammarAccess.getTableOptionAccess().getAlternatives(), "rule__TableOption__Alternatives");
					put(grammarAccess.getTableSelectionAccess().getAlternatives_2(), "rule__TableSelection__Alternatives_2");
					put(grammarAccess.getTableValueElementAccess().getAlternatives(), "rule__TableValueElement__Alternatives");
					put(grammarAccess.getTableIntervalAccess().getAlternatives(), "rule__TableInterval__Alternatives");
					put(grammarAccess.getTableLookupAccess().getAlternatives(), "rule__TableLookup__Alternatives");
					put(grammarAccess.getTableRangeElementAccess().getAlternatives(), "rule__TableRangeElement__Alternatives");
					put(grammarAccess.getPropertyStyleAccess().getAlternatives(), "rule__PropertyStyle__Alternatives");
					put(grammarAccess.getStyleConfigAccess().getAlternatives(), "rule__StyleConfig__Alternatives");
					put(grammarAccess.getLIntAccess().getAlternatives_0(), "rule__LInt__Alternatives_0");
					put(grammarAccess.getXImportDeclarationAccess().getAlternatives_2(), "rule__XImportDeclaration__Alternatives_2");
					put(grammarAccess.getXImportDeclarationAccess().getAlternatives_2_0_3(), "rule__XImportDeclaration__Alternatives_2_0_3");
					put(grammarAccess.getXAnnotationAccess().getAlternatives_3_1(), "rule__XAnnotation__Alternatives_3_1");
					put(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getAlternatives(), "rule__XAnnotationElementValueOrCommaList__Alternatives");
					put(grammarAccess.getXAnnotationElementValueAccess().getAlternatives(), "rule__XAnnotationElementValue__Alternatives");
					put(grammarAccess.getXAnnotationOrExpressionAccess().getAlternatives(), "rule__XAnnotationOrExpression__Alternatives");
					put(grammarAccess.getXAssignmentAccess().getAlternatives(), "rule__XAssignment__Alternatives");
					put(grammarAccess.getOpMultiAssignAccess().getAlternatives(), "rule__OpMultiAssign__Alternatives");
					put(grammarAccess.getOpEqualityAccess().getAlternatives(), "rule__OpEquality__Alternatives");
					put(grammarAccess.getXRelationalExpressionAccess().getAlternatives_1(), "rule__XRelationalExpression__Alternatives_1");
					put(grammarAccess.getOpCompareAccess().getAlternatives(), "rule__OpCompare__Alternatives");
					put(grammarAccess.getOpOtherAccess().getAlternatives(), "rule__OpOther__Alternatives");
					put(grammarAccess.getOpOtherAccess().getAlternatives_5_1(), "rule__OpOther__Alternatives_5_1");
					put(grammarAccess.getOpOtherAccess().getAlternatives_6_1(), "rule__OpOther__Alternatives_6_1");
					put(grammarAccess.getOpAddAccess().getAlternatives(), "rule__OpAdd__Alternatives");
					put(grammarAccess.getOpMultiAccess().getAlternatives(), "rule__OpMulti__Alternatives");
					put(grammarAccess.getXUnaryOperationAccess().getAlternatives(), "rule__XUnaryOperation__Alternatives");
					put(grammarAccess.getOpUnaryAccess().getAlternatives(), "rule__OpUnary__Alternatives");
					put(grammarAccess.getOpPostfixAccess().getAlternatives(), "rule__OpPostfix__Alternatives");
					put(grammarAccess.getXMemberFeatureCallAccess().getAlternatives_1(), "rule__XMemberFeatureCall__Alternatives_1");
					put(grammarAccess.getXMemberFeatureCallAccess().getAlternatives_1_0_0_0_1(), "rule__XMemberFeatureCall__Alternatives_1_0_0_0_1");
					put(grammarAccess.getXMemberFeatureCallAccess().getAlternatives_1_1_0_0_1(), "rule__XMemberFeatureCall__Alternatives_1_1_0_0_1");
					put(grammarAccess.getXMemberFeatureCallAccess().getAlternatives_1_1_3_1(), "rule__XMemberFeatureCall__Alternatives_1_1_3_1");
					put(grammarAccess.getXPrimaryExpressionAccess().getAlternatives(), "rule__XPrimaryExpression__Alternatives");
					put(grammarAccess.getXLiteralAccess().getAlternatives(), "rule__XLiteral__Alternatives");
					put(grammarAccess.getXCollectionLiteralAccess().getAlternatives(), "rule__XCollectionLiteral__Alternatives");
					put(grammarAccess.getXSwitchExpressionAccess().getAlternatives_2(), "rule__XSwitchExpression__Alternatives_2");
					put(grammarAccess.getXCasePartAccess().getAlternatives_3(), "rule__XCasePart__Alternatives_3");
					put(grammarAccess.getXExpressionOrVarDeclarationAccess().getAlternatives(), "rule__XExpressionOrVarDeclaration__Alternatives");
					put(grammarAccess.getXVariableDeclarationAccess().getAlternatives_1(), "rule__XVariableDeclaration__Alternatives_1");
					put(grammarAccess.getXVariableDeclarationAccess().getAlternatives_2(), "rule__XVariableDeclaration__Alternatives_2");
					put(grammarAccess.getXFeatureCallAccess().getAlternatives_3_1(), "rule__XFeatureCall__Alternatives_3_1");
					put(grammarAccess.getFeatureCallIDAccess().getAlternatives(), "rule__FeatureCallID__Alternatives");
					put(grammarAccess.getIdOrSuperAccess().getAlternatives(), "rule__IdOrSuper__Alternatives");
					put(grammarAccess.getXConstructorCallAccess().getAlternatives_4_1(), "rule__XConstructorCall__Alternatives_4_1");
					put(grammarAccess.getXBooleanLiteralAccess().getAlternatives_1(), "rule__XBooleanLiteral__Alternatives_1");
					put(grammarAccess.getXTryCatchFinallyExpressionAccess().getAlternatives_3(), "rule__XTryCatchFinallyExpression__Alternatives_3");
					put(grammarAccess.getNumberAccess().getAlternatives(), "rule__Number__Alternatives");
					put(grammarAccess.getNumberAccess().getAlternatives_1_0(), "rule__Number__Alternatives_1_0");
					put(grammarAccess.getNumberAccess().getAlternatives_1_1_1(), "rule__Number__Alternatives_1_1_1");
					put(grammarAccess.getJvmTypeReferenceAccess().getAlternatives(), "rule__JvmTypeReference__Alternatives");
					put(grammarAccess.getJvmArgumentTypeReferenceAccess().getAlternatives(), "rule__JvmArgumentTypeReference__Alternatives");
					put(grammarAccess.getJvmWildcardTypeReferenceAccess().getAlternatives_2(), "rule__JvmWildcardTypeReference__Alternatives_2");
					put(grammarAccess.getStyleCompareAccess().getAlternatives(), "rule__StyleCompare__Alternatives");
					put(grammarAccess.getTrendIconEnumAccess().getAlternatives(), "rule__TrendIconEnum__Alternatives");
					put(grammarAccess.getRowHeaderModeAccess().getAlternatives(), "rule__RowHeaderMode__Alternatives");
					put(grammarAccess.getAxisEnumAccess().getAlternatives(), "rule__AxisEnum__Alternatives");
					put(grammarAccess.getTableModelAccess().getGroup(), "rule__TableModel__Group__0");
					put(grammarAccess.getTablePackageAccess().getGroup(), "rule__TablePackage__Group__0");
					put(grammarAccess.getTablePackageAccess().getGroup_3(), "rule__TablePackage__Group_3__0");
					put(grammarAccess.getTableAccess().getGroup(), "rule__Table__Group__0");
					put(grammarAccess.getTableAccess().getGroup_3(), "rule__Table__Group_3__0");
					put(grammarAccess.getTableSelectionAccess().getGroup(), "rule__TableSelection__Group__0");
					put(grammarAccess.getTableSelectionAccess().getGroup_3_1(), "rule__TableSelection__Group_3_1__0");
					put(grammarAccess.getTableSelectionAccess().getGroup_3_4(), "rule__TableSelection__Group_3_4__0");
					put(grammarAccess.getTableSelectionAccess().getGroup_4(), "rule__TableSelection__Group_4__0");
					put(grammarAccess.getTableTableAccess().getGroup(), "rule__TableTable__Group__0");
					put(grammarAccess.getTableTableAccess().getGroup_2_2(), "rule__TableTable__Group_2_2__0");
					put(grammarAccess.getTableTableAccess().getGroup_2_5(), "rule__TableTable__Group_2_5__0");
					put(grammarAccess.getTableTableAccess().getGroup_3(), "rule__TableTable__Group_3__0");
					put(grammarAccess.getTablePreorderAccess().getGroup(), "rule__TablePreorder__Group__0");
					put(grammarAccess.getTableValueAccess().getGroup(), "rule__TableValue__Group__0");
					put(grammarAccess.getTableValueAccess().getGroup_3_1(), "rule__TableValue__Group_3_1__0");
					put(grammarAccess.getTableValueAccess().getGroup_3_3(), "rule__TableValue__Group_3_3__0");
					put(grammarAccess.getTableValueAccess().getGroup_4_0(), "rule__TableValue__Group_4_0__0");
					put(grammarAccess.getTableValueAccess().getGroup_4_1(), "rule__TableValue__Group_4_1__0");
					put(grammarAccess.getTableFormatterAccess().getGroup(), "rule__TableFormatter__Group__0");
					put(grammarAccess.getTableImageAccess().getGroup(), "rule__TableImage__Group__0");
					put(grammarAccess.getTableImageAccess().getGroup_3_2(), "rule__TableImage__Group_3_2__0");
					put(grammarAccess.getTableTooltipPatternAccess().getGroup(), "rule__TableTooltipPattern__Group__0");
					put(grammarAccess.getTableTaskAccess().getGroup(), "rule__TableTask__Group__0");
					put(grammarAccess.getTableAllColumnsAccess().getGroup(), "rule__TableAllColumns__Group__0");
					put(grammarAccess.getTableOrdinalAccess().getGroup(), "rule__TableOrdinal__Group__0");
					put(grammarAccess.getTableColumnAccess().getGroup(), "rule__TableColumn__Group__0");
					put(grammarAccess.getTableMeasureAccess().getGroup(), "rule__TableMeasure__Group__0");
					put(grammarAccess.getTableDerivedAccess().getGroup(), "rule__TableDerived__Group__0");
					put(grammarAccess.getTableHierarchyAccess().getGroup(), "rule__TableHierarchy__Group__0");
					put(grammarAccess.getTableAttributeAccess().getGroup(), "rule__TableAttribute__Group__0");
					put(grammarAccess.getTableAggregationAccess().getGroup(), "rule__TableAggregation__Group__0");
					put(grammarAccess.getTableNumberIntervalAccess().getGroup(), "rule__TableNumberInterval__Group__0");
					put(grammarAccess.getTableIntIntervalAccess().getGroup(), "rule__TableIntInterval__Group__0");
					put(grammarAccess.getTableDateDayIntervalAccess().getGroup(), "rule__TableDateDayInterval__Group__0");
					put(grammarAccess.getTableIntLookupAccess().getGroup(), "rule__TableIntLookup__Group__0");
					put(grammarAccess.getTableNumberLookupAccess().getGroup(), "rule__TableNumberLookup__Group__0");
					put(grammarAccess.getTableStringLookupAccess().getGroup(), "rule__TableStringLookup__Group__0");
					put(grammarAccess.getTableDateDayLookupAccess().getGroup(), "rule__TableDateDayLookup__Group__0");
					put(grammarAccess.getTableDatamartAccess().getGroup(), "rule__TableDatamart__Group__0");
					put(grammarAccess.getTableDatamartAccess().getGroup_2(), "rule__TableDatamart__Group_2__0");
					put(grammarAccess.getTableAxisAccess().getGroup(), "rule__TableAxis__Group__0");
					put(grammarAccess.getTableAxisAccess().getGroup_2_0(), "rule__TableAxis__Group_2_0__0");
					put(grammarAccess.getTableAxisAccess().getGroup_3(), "rule__TableAxis__Group_3__0");
					put(grammarAccess.getTableAxisAccess().getGroup_4(), "rule__TableAxis__Group_4__0");
					put(grammarAccess.getTableTextColorAccess().getGroup(), "rule__TableTextColor__Group__0");
					put(grammarAccess.getTableCellColorAccess().getGroup(), "rule__TableCellColor__Group__0");
					put(grammarAccess.getTableIconAccess().getGroup(), "rule__TableIcon__Group__0");
					put(grammarAccess.getTableTrendAccess().getGroup(), "rule__TableTrend__Group__0");
					put(grammarAccess.getTableTooltipAccess().getGroup(), "rule__TableTooltip__Group__0");
					put(grammarAccess.getTableGridAccess().getGroup(), "rule__TableGrid__Group__0");
					put(grammarAccess.getPropertyAccess().getGroup(), "rule__Property__Group__0");
					put(grammarAccess.getTableDtoDatasourceAccess().getGroup(), "rule__TableDtoDatasource__Group__0");
					put(grammarAccess.getTableDtoDatasourceAccess().getGroup_2(), "rule__TableDtoDatasource__Group_2__0");
					put(grammarAccess.getNestedFieldAccess().getGroup(), "rule__NestedField__Group__0");
					put(grammarAccess.getNestedPathAccess().getGroup(), "rule__NestedPath__Group__0");
					put(grammarAccess.getPropertyButtonStyleAccess().getGroup(), "rule__PropertyButtonStyle__Group__0");
					put(grammarAccess.getPropertyHtmlStyleAccess().getGroup(), "rule__PropertyHtmlStyle__Group__0");
					put(grammarAccess.getPropertyBooleanStyleAccess().getGroup(), "rule__PropertyBooleanStyle__Group__0");
					put(grammarAccess.getPropertyDateStyleAccess().getGroup(), "rule__PropertyDateStyle__Group__0");
					put(grammarAccess.getPropertyNumberStyleAccess().getGroup(), "rule__PropertyNumberStyle__Group__0");
					put(grammarAccess.getPropertyProgressbarStyleAccess().getGroup(), "rule__PropertyProgressbarStyle__Group__0");
					put(grammarAccess.getGridPropIndicatorStyleAccess().getGroup(), "rule__GridPropIndicatorStyle__Group__0");
					put(grammarAccess.getPropertyQuantityStyleAccess().getGroup(), "rule__PropertyQuantityStyle__Group__0");
					put(grammarAccess.getPropertyQuantityStyleAccess().getGroup_6(), "rule__PropertyQuantityStyle__Group_6__0");
					put(grammarAccess.getPropertyPriceStyleAccess().getGroup(), "rule__PropertyPriceStyle__Group__0");
					put(grammarAccess.getPropertyPriceStyleAccess().getGroup_6(), "rule__PropertyPriceStyle__Group_6__0");
					put(grammarAccess.getPropertyTextStyleAccess().getGroup(), "rule__PropertyTextStyle__Group__0");
					put(grammarAccess.getPropertyBlobImageStyleAccess().getGroup(), "rule__PropertyBlobImageStyle__Group__0");
					put(grammarAccess.getPropertyImageStyleAccess().getGroup(), "rule__PropertyImageStyle__Group__0");
					put(grammarAccess.getPropertyImageStyleAccess().getGroup_2(), "rule__PropertyImageStyle__Group_2__0");
					put(grammarAccess.getNumericToResourceStyleConfigAccess().getGroup(), "rule__NumericToResourceStyleConfig__Group__0");
					put(grammarAccess.getStringToResourceStyleConfigAccess().getGroup(), "rule__StringToResourceStyleConfig__Group__0");
					put(grammarAccess.getLIntAccess().getGroup(), "rule__LInt__Group__0");
					put(grammarAccess.getLDoubleAccess().getGroup(), "rule__LDouble__Group__0");
					put(grammarAccess.getLDoubleAccess().getGroup_1(), "rule__LDouble__Group_1__0");
					put(grammarAccess.getSignedNumberAccess().getGroup(), "rule__SignedNumber__Group__0");
					put(grammarAccess.getSignedIntAccess().getGroup(), "rule__SignedInt__Group__0");
					put(grammarAccess.getXImportDeclarationAccess().getGroup(), "rule__XImportDeclaration__Group__0");
					put(grammarAccess.getXImportDeclarationAccess().getGroup_2_0(), "rule__XImportDeclaration__Group_2_0__0");
					put(grammarAccess.getXImportDeclarationAccess().getGroup_2_3(), "rule__XImportDeclaration__Group_2_3__0");
					put(grammarAccess.getXAnnotationAccess().getGroup(), "rule__XAnnotation__Group__0");
					put(grammarAccess.getXAnnotationAccess().getGroup_3(), "rule__XAnnotation__Group_3__0");
					put(grammarAccess.getXAnnotationAccess().getGroup_3_1_0(), "rule__XAnnotation__Group_3_1_0__0");
					put(grammarAccess.getXAnnotationAccess().getGroup_3_1_0_1(), "rule__XAnnotation__Group_3_1_0_1__0");
					put(grammarAccess.getXAnnotationElementValuePairAccess().getGroup(), "rule__XAnnotationElementValuePair__Group__0");
					put(grammarAccess.getXAnnotationElementValuePairAccess().getGroup_0(), "rule__XAnnotationElementValuePair__Group_0__0");
					put(grammarAccess.getXAnnotationElementValuePairAccess().getGroup_0_0(), "rule__XAnnotationElementValuePair__Group_0_0__0");
					put(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getGroup_0(), "rule__XAnnotationElementValueOrCommaList__Group_0__0");
					put(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getGroup_0_0(), "rule__XAnnotationElementValueOrCommaList__Group_0_0__0");
					put(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getGroup_0_0_0(), "rule__XAnnotationElementValueOrCommaList__Group_0_0_0__0");
					put(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getGroup_0_1(), "rule__XAnnotationElementValueOrCommaList__Group_0_1__0");
					put(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getGroup_0_1_1(), "rule__XAnnotationElementValueOrCommaList__Group_0_1_1__0");
					put(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getGroup_1(), "rule__XAnnotationElementValueOrCommaList__Group_1__0");
					put(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getGroup_1_1(), "rule__XAnnotationElementValueOrCommaList__Group_1_1__0");
					put(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getGroup_1_1_1(), "rule__XAnnotationElementValueOrCommaList__Group_1_1_1__0");
					put(grammarAccess.getXAnnotationElementValueAccess().getGroup_0(), "rule__XAnnotationElementValue__Group_0__0");
					put(grammarAccess.getXAnnotationElementValueAccess().getGroup_0_0(), "rule__XAnnotationElementValue__Group_0_0__0");
					put(grammarAccess.getXAnnotationElementValueAccess().getGroup_0_0_0(), "rule__XAnnotationElementValue__Group_0_0_0__0");
					put(grammarAccess.getXAnnotationElementValueAccess().getGroup_0_1(), "rule__XAnnotationElementValue__Group_0_1__0");
					put(grammarAccess.getXAnnotationElementValueAccess().getGroup_0_1_1(), "rule__XAnnotationElementValue__Group_0_1_1__0");
					put(grammarAccess.getXAssignmentAccess().getGroup_0(), "rule__XAssignment__Group_0__0");
					put(grammarAccess.getXAssignmentAccess().getGroup_1(), "rule__XAssignment__Group_1__0");
					put(grammarAccess.getXAssignmentAccess().getGroup_1_1(), "rule__XAssignment__Group_1_1__0");
					put(grammarAccess.getXAssignmentAccess().getGroup_1_1_0(), "rule__XAssignment__Group_1_1_0__0");
					put(grammarAccess.getXAssignmentAccess().getGroup_1_1_0_0(), "rule__XAssignment__Group_1_1_0_0__0");
					put(grammarAccess.getOpMultiAssignAccess().getGroup_5(), "rule__OpMultiAssign__Group_5__0");
					put(grammarAccess.getOpMultiAssignAccess().getGroup_6(), "rule__OpMultiAssign__Group_6__0");
					put(grammarAccess.getXOrExpressionAccess().getGroup(), "rule__XOrExpression__Group__0");
					put(grammarAccess.getXOrExpressionAccess().getGroup_1(), "rule__XOrExpression__Group_1__0");
					put(grammarAccess.getXOrExpressionAccess().getGroup_1_0(), "rule__XOrExpression__Group_1_0__0");
					put(grammarAccess.getXOrExpressionAccess().getGroup_1_0_0(), "rule__XOrExpression__Group_1_0_0__0");
					put(grammarAccess.getXAndExpressionAccess().getGroup(), "rule__XAndExpression__Group__0");
					put(grammarAccess.getXAndExpressionAccess().getGroup_1(), "rule__XAndExpression__Group_1__0");
					put(grammarAccess.getXAndExpressionAccess().getGroup_1_0(), "rule__XAndExpression__Group_1_0__0");
					put(grammarAccess.getXAndExpressionAccess().getGroup_1_0_0(), "rule__XAndExpression__Group_1_0_0__0");
					put(grammarAccess.getXEqualityExpressionAccess().getGroup(), "rule__XEqualityExpression__Group__0");
					put(grammarAccess.getXEqualityExpressionAccess().getGroup_1(), "rule__XEqualityExpression__Group_1__0");
					put(grammarAccess.getXEqualityExpressionAccess().getGroup_1_0(), "rule__XEqualityExpression__Group_1_0__0");
					put(grammarAccess.getXEqualityExpressionAccess().getGroup_1_0_0(), "rule__XEqualityExpression__Group_1_0_0__0");
					put(grammarAccess.getXRelationalExpressionAccess().getGroup(), "rule__XRelationalExpression__Group__0");
					put(grammarAccess.getXRelationalExpressionAccess().getGroup_1_0(), "rule__XRelationalExpression__Group_1_0__0");
					put(grammarAccess.getXRelationalExpressionAccess().getGroup_1_0_0(), "rule__XRelationalExpression__Group_1_0_0__0");
					put(grammarAccess.getXRelationalExpressionAccess().getGroup_1_0_0_0(), "rule__XRelationalExpression__Group_1_0_0_0__0");
					put(grammarAccess.getXRelationalExpressionAccess().getGroup_1_1(), "rule__XRelationalExpression__Group_1_1__0");
					put(grammarAccess.getXRelationalExpressionAccess().getGroup_1_1_0(), "rule__XRelationalExpression__Group_1_1_0__0");
					put(grammarAccess.getXRelationalExpressionAccess().getGroup_1_1_0_0(), "rule__XRelationalExpression__Group_1_1_0_0__0");
					put(grammarAccess.getOpCompareAccess().getGroup_1(), "rule__OpCompare__Group_1__0");
					put(grammarAccess.getXOtherOperatorExpressionAccess().getGroup(), "rule__XOtherOperatorExpression__Group__0");
					put(grammarAccess.getXOtherOperatorExpressionAccess().getGroup_1(), "rule__XOtherOperatorExpression__Group_1__0");
					put(grammarAccess.getXOtherOperatorExpressionAccess().getGroup_1_0(), "rule__XOtherOperatorExpression__Group_1_0__0");
					put(grammarAccess.getXOtherOperatorExpressionAccess().getGroup_1_0_0(), "rule__XOtherOperatorExpression__Group_1_0_0__0");
					put(grammarAccess.getOpOtherAccess().getGroup_2(), "rule__OpOther__Group_2__0");
					put(grammarAccess.getOpOtherAccess().getGroup_5(), "rule__OpOther__Group_5__0");
					put(grammarAccess.getOpOtherAccess().getGroup_5_1_0(), "rule__OpOther__Group_5_1_0__0");
					put(grammarAccess.getOpOtherAccess().getGroup_5_1_0_0(), "rule__OpOther__Group_5_1_0_0__0");
					put(grammarAccess.getOpOtherAccess().getGroup_6(), "rule__OpOther__Group_6__0");
					put(grammarAccess.getOpOtherAccess().getGroup_6_1_0(), "rule__OpOther__Group_6_1_0__0");
					put(grammarAccess.getOpOtherAccess().getGroup_6_1_0_0(), "rule__OpOther__Group_6_1_0_0__0");
					put(grammarAccess.getXAdditiveExpressionAccess().getGroup(), "rule__XAdditiveExpression__Group__0");
					put(grammarAccess.getXAdditiveExpressionAccess().getGroup_1(), "rule__XAdditiveExpression__Group_1__0");
					put(grammarAccess.getXAdditiveExpressionAccess().getGroup_1_0(), "rule__XAdditiveExpression__Group_1_0__0");
					put(grammarAccess.getXAdditiveExpressionAccess().getGroup_1_0_0(), "rule__XAdditiveExpression__Group_1_0_0__0");
					put(grammarAccess.getXMultiplicativeExpressionAccess().getGroup(), "rule__XMultiplicativeExpression__Group__0");
					put(grammarAccess.getXMultiplicativeExpressionAccess().getGroup_1(), "rule__XMultiplicativeExpression__Group_1__0");
					put(grammarAccess.getXMultiplicativeExpressionAccess().getGroup_1_0(), "rule__XMultiplicativeExpression__Group_1_0__0");
					put(grammarAccess.getXMultiplicativeExpressionAccess().getGroup_1_0_0(), "rule__XMultiplicativeExpression__Group_1_0_0__0");
					put(grammarAccess.getXUnaryOperationAccess().getGroup_0(), "rule__XUnaryOperation__Group_0__0");
					put(grammarAccess.getXCastedExpressionAccess().getGroup(), "rule__XCastedExpression__Group__0");
					put(grammarAccess.getXCastedExpressionAccess().getGroup_1(), "rule__XCastedExpression__Group_1__0");
					put(grammarAccess.getXCastedExpressionAccess().getGroup_1_0(), "rule__XCastedExpression__Group_1_0__0");
					put(grammarAccess.getXCastedExpressionAccess().getGroup_1_0_0(), "rule__XCastedExpression__Group_1_0_0__0");
					put(grammarAccess.getXPostfixOperationAccess().getGroup(), "rule__XPostfixOperation__Group__0");
					put(grammarAccess.getXPostfixOperationAccess().getGroup_1(), "rule__XPostfixOperation__Group_1__0");
					put(grammarAccess.getXPostfixOperationAccess().getGroup_1_0(), "rule__XPostfixOperation__Group_1_0__0");
					put(grammarAccess.getXMemberFeatureCallAccess().getGroup(), "rule__XMemberFeatureCall__Group__0");
					put(grammarAccess.getXMemberFeatureCallAccess().getGroup_1_0(), "rule__XMemberFeatureCall__Group_1_0__0");
					put(grammarAccess.getXMemberFeatureCallAccess().getGroup_1_0_0(), "rule__XMemberFeatureCall__Group_1_0_0__0");
					put(grammarAccess.getXMemberFeatureCallAccess().getGroup_1_0_0_0(), "rule__XMemberFeatureCall__Group_1_0_0_0__0");
					put(grammarAccess.getXMemberFeatureCallAccess().getGroup_1_1(), "rule__XMemberFeatureCall__Group_1_1__0");
					put(grammarAccess.getXMemberFeatureCallAccess().getGroup_1_1_0(), "rule__XMemberFeatureCall__Group_1_1_0__0");
					put(grammarAccess.getXMemberFeatureCallAccess().getGroup_1_1_0_0(), "rule__XMemberFeatureCall__Group_1_1_0_0__0");
					put(grammarAccess.getXMemberFeatureCallAccess().getGroup_1_1_1(), "rule__XMemberFeatureCall__Group_1_1_1__0");
					put(grammarAccess.getXMemberFeatureCallAccess().getGroup_1_1_1_2(), "rule__XMemberFeatureCall__Group_1_1_1_2__0");
					put(grammarAccess.getXMemberFeatureCallAccess().getGroup_1_1_3(), "rule__XMemberFeatureCall__Group_1_1_3__0");
					put(grammarAccess.getXMemberFeatureCallAccess().getGroup_1_1_3_1_1(), "rule__XMemberFeatureCall__Group_1_1_3_1_1__0");
					put(grammarAccess.getXMemberFeatureCallAccess().getGroup_1_1_3_1_1_1(), "rule__XMemberFeatureCall__Group_1_1_3_1_1_1__0");
					put(grammarAccess.getXSetLiteralAccess().getGroup(), "rule__XSetLiteral__Group__0");
					put(grammarAccess.getXSetLiteralAccess().getGroup_3(), "rule__XSetLiteral__Group_3__0");
					put(grammarAccess.getXSetLiteralAccess().getGroup_3_1(), "rule__XSetLiteral__Group_3_1__0");
					put(grammarAccess.getXListLiteralAccess().getGroup(), "rule__XListLiteral__Group__0");
					put(grammarAccess.getXListLiteralAccess().getGroup_3(), "rule__XListLiteral__Group_3__0");
					put(grammarAccess.getXListLiteralAccess().getGroup_3_1(), "rule__XListLiteral__Group_3_1__0");
					put(grammarAccess.getXClosureAccess().getGroup(), "rule__XClosure__Group__0");
					put(grammarAccess.getXClosureAccess().getGroup_0(), "rule__XClosure__Group_0__0");
					put(grammarAccess.getXClosureAccess().getGroup_0_0(), "rule__XClosure__Group_0_0__0");
					put(grammarAccess.getXClosureAccess().getGroup_1(), "rule__XClosure__Group_1__0");
					put(grammarAccess.getXClosureAccess().getGroup_1_0(), "rule__XClosure__Group_1_0__0");
					put(grammarAccess.getXClosureAccess().getGroup_1_0_0(), "rule__XClosure__Group_1_0_0__0");
					put(grammarAccess.getXClosureAccess().getGroup_1_0_0_1(), "rule__XClosure__Group_1_0_0_1__0");
					put(grammarAccess.getXExpressionInClosureAccess().getGroup(), "rule__XExpressionInClosure__Group__0");
					put(grammarAccess.getXExpressionInClosureAccess().getGroup_1(), "rule__XExpressionInClosure__Group_1__0");
					put(grammarAccess.getXShortClosureAccess().getGroup(), "rule__XShortClosure__Group__0");
					put(grammarAccess.getXShortClosureAccess().getGroup_0(), "rule__XShortClosure__Group_0__0");
					put(grammarAccess.getXShortClosureAccess().getGroup_0_0(), "rule__XShortClosure__Group_0_0__0");
					put(grammarAccess.getXShortClosureAccess().getGroup_0_0_1(), "rule__XShortClosure__Group_0_0_1__0");
					put(grammarAccess.getXShortClosureAccess().getGroup_0_0_1_1(), "rule__XShortClosure__Group_0_0_1_1__0");
					put(grammarAccess.getXParenthesizedExpressionAccess().getGroup(), "rule__XParenthesizedExpression__Group__0");
					put(grammarAccess.getXIfExpressionAccess().getGroup(), "rule__XIfExpression__Group__0");
					put(grammarAccess.getXIfExpressionAccess().getGroup_6(), "rule__XIfExpression__Group_6__0");
					put(grammarAccess.getXSwitchExpressionAccess().getGroup(), "rule__XSwitchExpression__Group__0");
					put(grammarAccess.getXSwitchExpressionAccess().getGroup_2_0(), "rule__XSwitchExpression__Group_2_0__0");
					put(grammarAccess.getXSwitchExpressionAccess().getGroup_2_0_0(), "rule__XSwitchExpression__Group_2_0_0__0");
					put(grammarAccess.getXSwitchExpressionAccess().getGroup_2_0_0_0(), "rule__XSwitchExpression__Group_2_0_0_0__0");
					put(grammarAccess.getXSwitchExpressionAccess().getGroup_2_1(), "rule__XSwitchExpression__Group_2_1__0");
					put(grammarAccess.getXSwitchExpressionAccess().getGroup_2_1_0(), "rule__XSwitchExpression__Group_2_1_0__0");
					put(grammarAccess.getXSwitchExpressionAccess().getGroup_2_1_0_0(), "rule__XSwitchExpression__Group_2_1_0_0__0");
					put(grammarAccess.getXSwitchExpressionAccess().getGroup_5(), "rule__XSwitchExpression__Group_5__0");
					put(grammarAccess.getXCasePartAccess().getGroup(), "rule__XCasePart__Group__0");
					put(grammarAccess.getXCasePartAccess().getGroup_2(), "rule__XCasePart__Group_2__0");
					put(grammarAccess.getXCasePartAccess().getGroup_3_0(), "rule__XCasePart__Group_3_0__0");
					put(grammarAccess.getXForLoopExpressionAccess().getGroup(), "rule__XForLoopExpression__Group__0");
					put(grammarAccess.getXForLoopExpressionAccess().getGroup_0(), "rule__XForLoopExpression__Group_0__0");
					put(grammarAccess.getXForLoopExpressionAccess().getGroup_0_0(), "rule__XForLoopExpression__Group_0_0__0");
					put(grammarAccess.getXBasicForLoopExpressionAccess().getGroup(), "rule__XBasicForLoopExpression__Group__0");
					put(grammarAccess.getXBasicForLoopExpressionAccess().getGroup_3(), "rule__XBasicForLoopExpression__Group_3__0");
					put(grammarAccess.getXBasicForLoopExpressionAccess().getGroup_3_1(), "rule__XBasicForLoopExpression__Group_3_1__0");
					put(grammarAccess.getXBasicForLoopExpressionAccess().getGroup_7(), "rule__XBasicForLoopExpression__Group_7__0");
					put(grammarAccess.getXBasicForLoopExpressionAccess().getGroup_7_1(), "rule__XBasicForLoopExpression__Group_7_1__0");
					put(grammarAccess.getXWhileExpressionAccess().getGroup(), "rule__XWhileExpression__Group__0");
					put(grammarAccess.getXDoWhileExpressionAccess().getGroup(), "rule__XDoWhileExpression__Group__0");
					put(grammarAccess.getXBlockExpressionAccess().getGroup(), "rule__XBlockExpression__Group__0");
					put(grammarAccess.getXBlockExpressionAccess().getGroup_2(), "rule__XBlockExpression__Group_2__0");
					put(grammarAccess.getXVariableDeclarationAccess().getGroup(), "rule__XVariableDeclaration__Group__0");
					put(grammarAccess.getXVariableDeclarationAccess().getGroup_2_0(), "rule__XVariableDeclaration__Group_2_0__0");
					put(grammarAccess.getXVariableDeclarationAccess().getGroup_2_0_0(), "rule__XVariableDeclaration__Group_2_0_0__0");
					put(grammarAccess.getXVariableDeclarationAccess().getGroup_3(), "rule__XVariableDeclaration__Group_3__0");
					put(grammarAccess.getJvmFormalParameterAccess().getGroup(), "rule__JvmFormalParameter__Group__0");
					put(grammarAccess.getFullJvmFormalParameterAccess().getGroup(), "rule__FullJvmFormalParameter__Group__0");
					put(grammarAccess.getXFeatureCallAccess().getGroup(), "rule__XFeatureCall__Group__0");
					put(grammarAccess.getXFeatureCallAccess().getGroup_1(), "rule__XFeatureCall__Group_1__0");
					put(grammarAccess.getXFeatureCallAccess().getGroup_1_2(), "rule__XFeatureCall__Group_1_2__0");
					put(grammarAccess.getXFeatureCallAccess().getGroup_3(), "rule__XFeatureCall__Group_3__0");
					put(grammarAccess.getXFeatureCallAccess().getGroup_3_1_1(), "rule__XFeatureCall__Group_3_1_1__0");
					put(grammarAccess.getXFeatureCallAccess().getGroup_3_1_1_1(), "rule__XFeatureCall__Group_3_1_1_1__0");
					put(grammarAccess.getXConstructorCallAccess().getGroup(), "rule__XConstructorCall__Group__0");
					put(grammarAccess.getXConstructorCallAccess().getGroup_3(), "rule__XConstructorCall__Group_3__0");
					put(grammarAccess.getXConstructorCallAccess().getGroup_3_2(), "rule__XConstructorCall__Group_3_2__0");
					put(grammarAccess.getXConstructorCallAccess().getGroup_4(), "rule__XConstructorCall__Group_4__0");
					put(grammarAccess.getXConstructorCallAccess().getGroup_4_1_1(), "rule__XConstructorCall__Group_4_1_1__0");
					put(grammarAccess.getXConstructorCallAccess().getGroup_4_1_1_1(), "rule__XConstructorCall__Group_4_1_1_1__0");
					put(grammarAccess.getXBooleanLiteralAccess().getGroup(), "rule__XBooleanLiteral__Group__0");
					put(grammarAccess.getXNullLiteralAccess().getGroup(), "rule__XNullLiteral__Group__0");
					put(grammarAccess.getXNumberLiteralAccess().getGroup(), "rule__XNumberLiteral__Group__0");
					put(grammarAccess.getXStringLiteralAccess().getGroup(), "rule__XStringLiteral__Group__0");
					put(grammarAccess.getXTypeLiteralAccess().getGroup(), "rule__XTypeLiteral__Group__0");
					put(grammarAccess.getXThrowExpressionAccess().getGroup(), "rule__XThrowExpression__Group__0");
					put(grammarAccess.getXReturnExpressionAccess().getGroup(), "rule__XReturnExpression__Group__0");
					put(grammarAccess.getXTryCatchFinallyExpressionAccess().getGroup(), "rule__XTryCatchFinallyExpression__Group__0");
					put(grammarAccess.getXTryCatchFinallyExpressionAccess().getGroup_3_0(), "rule__XTryCatchFinallyExpression__Group_3_0__0");
					put(grammarAccess.getXTryCatchFinallyExpressionAccess().getGroup_3_0_1(), "rule__XTryCatchFinallyExpression__Group_3_0_1__0");
					put(grammarAccess.getXTryCatchFinallyExpressionAccess().getGroup_3_1(), "rule__XTryCatchFinallyExpression__Group_3_1__0");
					put(grammarAccess.getXSynchronizedExpressionAccess().getGroup(), "rule__XSynchronizedExpression__Group__0");
					put(grammarAccess.getXSynchronizedExpressionAccess().getGroup_0(), "rule__XSynchronizedExpression__Group_0__0");
					put(grammarAccess.getXSynchronizedExpressionAccess().getGroup_0_0(), "rule__XSynchronizedExpression__Group_0_0__0");
					put(grammarAccess.getXCatchClauseAccess().getGroup(), "rule__XCatchClause__Group__0");
					put(grammarAccess.getQualifiedNameAccess().getGroup(), "rule__QualifiedName__Group__0");
					put(grammarAccess.getQualifiedNameAccess().getGroup_1(), "rule__QualifiedName__Group_1__0");
					put(grammarAccess.getNumberAccess().getGroup_1(), "rule__Number__Group_1__0");
					put(grammarAccess.getNumberAccess().getGroup_1_1(), "rule__Number__Group_1_1__0");
					put(grammarAccess.getStaticQualifierAccess().getGroup(), "rule__StaticQualifier__Group__0");
					put(grammarAccess.getJvmTypeReferenceAccess().getGroup_0(), "rule__JvmTypeReference__Group_0__0");
					put(grammarAccess.getJvmTypeReferenceAccess().getGroup_0_1(), "rule__JvmTypeReference__Group_0_1__0");
					put(grammarAccess.getJvmTypeReferenceAccess().getGroup_0_1_0(), "rule__JvmTypeReference__Group_0_1_0__0");
					put(grammarAccess.getArrayBracketsAccess().getGroup(), "rule__ArrayBrackets__Group__0");
					put(grammarAccess.getXFunctionTypeRefAccess().getGroup(), "rule__XFunctionTypeRef__Group__0");
					put(grammarAccess.getXFunctionTypeRefAccess().getGroup_0(), "rule__XFunctionTypeRef__Group_0__0");
					put(grammarAccess.getXFunctionTypeRefAccess().getGroup_0_1(), "rule__XFunctionTypeRef__Group_0_1__0");
					put(grammarAccess.getXFunctionTypeRefAccess().getGroup_0_1_1(), "rule__XFunctionTypeRef__Group_0_1_1__0");
					put(grammarAccess.getJvmParameterizedTypeReferenceAccess().getGroup(), "rule__JvmParameterizedTypeReference__Group__0");
					put(grammarAccess.getJvmParameterizedTypeReferenceAccess().getGroup_1(), "rule__JvmParameterizedTypeReference__Group_1__0");
					put(grammarAccess.getJvmParameterizedTypeReferenceAccess().getGroup_1_2(), "rule__JvmParameterizedTypeReference__Group_1_2__0");
					put(grammarAccess.getJvmParameterizedTypeReferenceAccess().getGroup_1_4(), "rule__JvmParameterizedTypeReference__Group_1_4__0");
					put(grammarAccess.getJvmParameterizedTypeReferenceAccess().getGroup_1_4_0(), "rule__JvmParameterizedTypeReference__Group_1_4_0__0");
					put(grammarAccess.getJvmParameterizedTypeReferenceAccess().getGroup_1_4_0_0(), "rule__JvmParameterizedTypeReference__Group_1_4_0_0__0");
					put(grammarAccess.getJvmParameterizedTypeReferenceAccess().getGroup_1_4_2(), "rule__JvmParameterizedTypeReference__Group_1_4_2__0");
					put(grammarAccess.getJvmParameterizedTypeReferenceAccess().getGroup_1_4_2_2(), "rule__JvmParameterizedTypeReference__Group_1_4_2_2__0");
					put(grammarAccess.getJvmWildcardTypeReferenceAccess().getGroup(), "rule__JvmWildcardTypeReference__Group__0");
					put(grammarAccess.getJvmWildcardTypeReferenceAccess().getGroup_2_0(), "rule__JvmWildcardTypeReference__Group_2_0__0");
					put(grammarAccess.getJvmWildcardTypeReferenceAccess().getGroup_2_1(), "rule__JvmWildcardTypeReference__Group_2_1__0");
					put(grammarAccess.getJvmUpperBoundAccess().getGroup(), "rule__JvmUpperBound__Group__0");
					put(grammarAccess.getJvmUpperBoundAndedAccess().getGroup(), "rule__JvmUpperBoundAnded__Group__0");
					put(grammarAccess.getJvmLowerBoundAccess().getGroup(), "rule__JvmLowerBound__Group__0");
					put(grammarAccess.getJvmLowerBoundAndedAccess().getGroup(), "rule__JvmLowerBoundAnded__Group__0");
					put(grammarAccess.getJvmTypeParameterAccess().getGroup(), "rule__JvmTypeParameter__Group__0");
					put(grammarAccess.getJvmTypeParameterAccess().getGroup_1(), "rule__JvmTypeParameter__Group_1__0");
					put(grammarAccess.getQualifiedNameWithWildcardAccess().getGroup(), "rule__QualifiedNameWithWildcard__Group__0");
					put(grammarAccess.getQualifiedNameInStaticImportAccess().getGroup(), "rule__QualifiedNameInStaticImport__Group__0");
					put(grammarAccess.getTableModelAccess().getImportSectionAssignment_0(), "rule__TableModel__ImportSectionAssignment_0");
					put(grammarAccess.getTableModelAccess().getPackagesAssignment_1(), "rule__TableModel__PackagesAssignment_1");
					put(grammarAccess.getTablePackageAccess().getNameAssignment_2(), "rule__TablePackage__NameAssignment_2");
					put(grammarAccess.getTablePackageAccess().getTablesAssignment_3_1(), "rule__TablePackage__TablesAssignment_3_1");
					put(grammarAccess.getTableAccess().getNameAssignment_2(), "rule__Table__NameAssignment_2");
					put(grammarAccess.getTableAccess().getDescriptionAssignment_3_0(), "rule__Table__DescriptionAssignment_3_0");
					put(grammarAccess.getTableAccess().getDescriptionValueAssignment_3_1(), "rule__Table__DescriptionValueAssignment_3_1");
					put(grammarAccess.getTableAccess().getTabletypeAssignment_5(), "rule__Table__TabletypeAssignment_5");
					put(grammarAccess.getTableSelectionAccess().getMultiSelectionAssignment_2_0(), "rule__TableSelection__MultiSelectionAssignment_2_0");
					put(grammarAccess.getTableSelectionAccess().getSelectalwaysAssignment_3_0(), "rule__TableSelection__SelectalwaysAssignment_3_0");
					put(grammarAccess.getTableSelectionAccess().getHeaderModeAssignment_3_1_1(), "rule__TableSelection__HeaderModeAssignment_3_1_1");
					put(grammarAccess.getTableSelectionAccess().getFilteringAssignment_3_2(), "rule__TableSelection__FilteringAssignment_3_2");
					put(grammarAccess.getTableSelectionAccess().getEmbeddedAssignment_3_3(), "rule__TableSelection__EmbeddedAssignment_3_3");
					put(grammarAccess.getTableSelectionAccess().getToolbarAssignment_3_4_1(), "rule__TableSelection__ToolbarAssignment_3_4_1");
					put(grammarAccess.getTableSelectionAccess().getSourceAssignment_4_1(), "rule__TableSelection__SourceAssignment_4_1");
					put(grammarAccess.getTableTableAccess().getSelectalwaysAssignment_2_0(), "rule__TableTable__SelectalwaysAssignment_2_0");
					put(grammarAccess.getTableTableAccess().getSelectByIdAssignment_2_1(), "rule__TableTable__SelectByIdAssignment_2_1");
					put(grammarAccess.getTableTableAccess().getHeaderModeAssignment_2_2_1(), "rule__TableTable__HeaderModeAssignment_2_2_1");
					put(grammarAccess.getTableTableAccess().getFilteringAssignment_2_3(), "rule__TableTable__FilteringAssignment_2_3");
					put(grammarAccess.getTableTableAccess().getEmbeddedAssignment_2_4(), "rule__TableTable__EmbeddedAssignment_2_4");
					put(grammarAccess.getTableTableAccess().getToolbarAssignment_2_5_1(), "rule__TableTable__ToolbarAssignment_2_5_1");
					put(grammarAccess.getTableTableAccess().getSourceAssignment_3_1(), "rule__TableTable__SourceAssignment_3_1");
					put(grammarAccess.getTablePreorderAccess().getColumnAssignment_2(), "rule__TablePreorder__ColumnAssignment_2");
					put(grammarAccess.getTablePreorderAccess().getAscendingAssignment_3(), "rule__TablePreorder__AscendingAssignment_3");
					put(grammarAccess.getTableValueAccess().getColumnAssignment_2(), "rule__TableValue__ColumnAssignment_2");
					put(grammarAccess.getTableValueAccess().getCollapsedAssignment_3_0(), "rule__TableValue__CollapsedAssignment_3_0");
					put(grammarAccess.getTableValueAccess().getIconNameAssignment_3_1_1(), "rule__TableValue__IconNameAssignment_3_1_1");
					put(grammarAccess.getTableValueAccess().getFormatterAssignment_3_2(), "rule__TableValue__FormatterAssignment_3_2");
					put(grammarAccess.getTableValueAccess().getHasImageAssignment_3_3_0(), "rule__TableValue__HasImageAssignment_3_3_0");
					put(grammarAccess.getTableValueAccess().getImageAssignment_3_3_1(), "rule__TableValue__ImageAssignment_3_3_1");
					put(grammarAccess.getTableValueAccess().getTooltipPatternAssignment_3_4(), "rule__TableValue__TooltipPatternAssignment_3_4");
					put(grammarAccess.getTableValueAccess().getHideLabelIntervalAssignment_4_0_1(), "rule__TableValue__HideLabelIntervalAssignment_4_0_1");
					put(grammarAccess.getTableValueAccess().getIntervalsAssignment_4_0_3(), "rule__TableValue__IntervalsAssignment_4_0_3");
					put(grammarAccess.getTableValueAccess().getHideLabelLookupAssignment_4_1_1(), "rule__TableValue__HideLabelLookupAssignment_4_1_1");
					put(grammarAccess.getTableValueAccess().getLookupsAssignment_4_1_3(), "rule__TableValue__LookupsAssignment_4_1_3");
					put(grammarAccess.getTableFormatterAccess().getFormatAssignment_2(), "rule__TableFormatter__FormatAssignment_2");
					put(grammarAccess.getTableImageAccess().getImagePathPatternAssignment_2(), "rule__TableImage__ImagePathPatternAssignment_2");
					put(grammarAccess.getTableImageAccess().getHasParameterAssignment_3_0(), "rule__TableImage__HasParameterAssignment_3_0");
					put(grammarAccess.getTableImageAccess().getHideImageLabelAssignment_3_1(), "rule__TableImage__HideImageLabelAssignment_3_1");
					put(grammarAccess.getTableImageAccess().getResizeAssignment_3_2_0(), "rule__TableImage__ResizeAssignment_3_2_0");
					put(grammarAccess.getTableImageAccess().getResizeStringAssignment_3_2_1(), "rule__TableImage__ResizeStringAssignment_3_2_1");
					put(grammarAccess.getTableTooltipPatternAccess().getTooltipPatternAssignment_2(), "rule__TableTooltipPattern__TooltipPatternAssignment_2");
					put(grammarAccess.getTableOrdinalAccess().getValueRefAssignment_1(), "rule__TableOrdinal__ValueRefAssignment_1");
					put(grammarAccess.getTableColumnAccess().getValueRefAssignment_1(), "rule__TableColumn__ValueRefAssignment_1");
					put(grammarAccess.getTableMeasureAccess().getValueRefAssignment_1(), "rule__TableMeasure__ValueRefAssignment_1");
					put(grammarAccess.getTableDerivedAccess().getValueRefAssignment_1(), "rule__TableDerived__ValueRefAssignment_1");
					put(grammarAccess.getTableHierarchyAccess().getValueRefAssignment_1(), "rule__TableHierarchy__ValueRefAssignment_1");
					put(grammarAccess.getTableAttributeAccess().getValueRefAssignment_2(), "rule__TableAttribute__ValueRefAssignment_2");
					put(grammarAccess.getTableAggregationAccess().getValueRefAssignment_1(), "rule__TableAggregation__ValueRefAssignment_1");
					put(grammarAccess.getTableNumberIntervalAccess().getNumberIntervalValueAssignment_2(), "rule__TableNumberInterval__NumberIntervalValueAssignment_2");
					put(grammarAccess.getTableNumberIntervalAccess().getNumberRangeAssignment_3(), "rule__TableNumberInterval__NumberRangeAssignment_3");
					put(grammarAccess.getTableIntIntervalAccess().getIntIntervalValueAssignment_2(), "rule__TableIntInterval__IntIntervalValueAssignment_2");
					put(grammarAccess.getTableIntIntervalAccess().getIntRangeAssignment_3(), "rule__TableIntInterval__IntRangeAssignment_3");
					put(grammarAccess.getTableDateDayIntervalAccess().getDateIntervalValueAssignment_2(), "rule__TableDateDayInterval__DateIntervalValueAssignment_2");
					put(grammarAccess.getTableDateDayIntervalAccess().getDateRangeAssignment_3(), "rule__TableDateDayInterval__DateRangeAssignment_3");
					put(grammarAccess.getTableIntLookupAccess().getLookupValueAssignment_2(), "rule__TableIntLookup__LookupValueAssignment_2");
					put(grammarAccess.getTableIntLookupAccess().getDiscreteAssignment_3(), "rule__TableIntLookup__DiscreteAssignment_3");
					put(grammarAccess.getTableNumberLookupAccess().getLookupValueAssignment_2(), "rule__TableNumberLookup__LookupValueAssignment_2");
					put(grammarAccess.getTableNumberLookupAccess().getDiscreteAssignment_3(), "rule__TableNumberLookup__DiscreteAssignment_3");
					put(grammarAccess.getTableStringLookupAccess().getLookupValueAssignment_2(), "rule__TableStringLookup__LookupValueAssignment_2");
					put(grammarAccess.getTableStringLookupAccess().getDiscreteAssignment_3(), "rule__TableStringLookup__DiscreteAssignment_3");
					put(grammarAccess.getTableDateDayLookupAccess().getLookupValueAssignment_2(), "rule__TableDateDayLookup__LookupValueAssignment_2");
					put(grammarAccess.getTableDateDayLookupAccess().getDiscreteAssignment_3(), "rule__TableDateDayLookup__DiscreteAssignment_3");
					put(grammarAccess.getTableDatamartAccess().getDatamartRefAssignment_1(), "rule__TableDatamart__DatamartRefAssignment_1");
					put(grammarAccess.getTableDatamartAccess().getElementsAssignment_2_1(), "rule__TableDatamart__ElementsAssignment_2_1");
					put(grammarAccess.getTableEventAccess().getSourceAssignment(), "rule__TableEvent__SourceAssignment");
					put(grammarAccess.getTableAxisAccess().getAxisAssignment_1(), "rule__TableAxis__AxisAssignment_1");
					put(grammarAccess.getTableAxisAccess().getHasRowHeightAssignment_2_0_0(), "rule__TableAxis__HasRowHeightAssignment_2_0_0");
					put(grammarAccess.getTableAxisAccess().getRowHeightAssignment_2_0_1(), "rule__TableAxis__RowHeightAssignment_2_0_1");
					put(grammarAccess.getTableAxisAccess().getPreOrderAssignment_2_1(), "rule__TableAxis__PreOrderAssignment_2_1");
					put(grammarAccess.getTableAxisAccess().getHasDetailsAssignment_3_0(), "rule__TableAxis__HasDetailsAssignment_3_0");
					put(grammarAccess.getTableAxisAccess().getValuesAssignment_3_2(), "rule__TableAxis__ValuesAssignment_3_2");
					put(grammarAccess.getTableAxisAccess().getHasEventsAssignment_4_0(), "rule__TableAxis__HasEventsAssignment_4_0");
					put(grammarAccess.getTableAxisAccess().getEventsAssignment_4_2(), "rule__TableAxis__EventsAssignment_4_2");
					put(grammarAccess.getTableTextColorAccess().getRgbAssignment_1(), "rule__TableTextColor__RgbAssignment_1");
					put(grammarAccess.getTableCellColorAccess().getRgbAssignment_1(), "rule__TableCellColor__RgbAssignment_1");
					put(grammarAccess.getTableIconAccess().getIconAssignment_1(), "rule__TableIcon__IconAssignment_1");
					put(grammarAccess.getTableTrendAccess().getIconAssignment_1(), "rule__TableTrend__IconAssignment_1");
					put(grammarAccess.getTableTooltipAccess().getTooltipAssignment_1(), "rule__TableTooltip__TooltipAssignment_1");
					put(grammarAccess.getTableGridAccess().getSourceAssignment_3(), "rule__TableGrid__SourceAssignment_3");
					put(grammarAccess.getPropertyAccess().getEditableAssignment_0(), "rule__Property__EditableAssignment_0");
					put(grammarAccess.getPropertyAccess().getPathAssignment_2(), "rule__Property__PathAssignment_2");
					put(grammarAccess.getPropertyAccess().getStyleAssignment_4(), "rule__Property__StyleAssignment_4");
					put(grammarAccess.getTableDtoDatasourceAccess().getDtoSourceAssignment_1(), "rule__TableDtoDatasource__DtoSourceAssignment_1");
					put(grammarAccess.getTableDtoDatasourceAccess().getPropertiesAssignment_2_1(), "rule__TableDtoDatasource__PropertiesAssignment_2_1");
					put(grammarAccess.getNestedFieldAccess().getFieldAssignment_1(), "rule__NestedField__FieldAssignment_1");
					put(grammarAccess.getNestedFieldAccess().getPathAssignment_2(), "rule__NestedField__PathAssignment_2");
					put(grammarAccess.getNestedPathAccess().getFieldAssignment_2(), "rule__NestedPath__FieldAssignment_2");
					put(grammarAccess.getNestedPathAccess().getPathAssignment_3(), "rule__NestedPath__PathAssignment_3");
					put(grammarAccess.getPropertyButtonStyleAccess().getEventTopicAssignment_3(), "rule__PropertyButtonStyle__EventTopicAssignment_3");
					put(grammarAccess.getPropertyDateStyleAccess().getDateFormatAssignment_3(), "rule__PropertyDateStyle__DateFormatAssignment_3");
					put(grammarAccess.getPropertyNumberStyleAccess().getNumberFormatAssignment_3(), "rule__PropertyNumberStyle__NumberFormatAssignment_3");
					put(grammarAccess.getPropertyProgressbarStyleAccess().getMaxValueAssignment_3(), "rule__PropertyProgressbarStyle__MaxValueAssignment_3");
					put(grammarAccess.getGridPropIndicatorStyleAccess().getGreenStartsAssignment_3(), "rule__GridPropIndicatorStyle__GreenStartsAssignment_3");
					put(grammarAccess.getGridPropIndicatorStyleAccess().getRedEndsAssignment_5(), "rule__GridPropIndicatorStyle__RedEndsAssignment_5");
					put(grammarAccess.getPropertyQuantityStyleAccess().getHtmlPatternAssignment_2(), "rule__PropertyQuantityStyle__HtmlPatternAssignment_2");
					put(grammarAccess.getPropertyQuantityStyleAccess().getValuePropertyPathAssignment_5(), "rule__PropertyQuantityStyle__ValuePropertyPathAssignment_5");
					put(grammarAccess.getPropertyQuantityStyleAccess().getValueNumberFormatAssignment_6_2(), "rule__PropertyQuantityStyle__ValueNumberFormatAssignment_6_2");
					put(grammarAccess.getPropertyQuantityStyleAccess().getUomPropertyPathAssignment_9(), "rule__PropertyQuantityStyle__UomPropertyPathAssignment_9");
					put(grammarAccess.getPropertyPriceStyleAccess().getHtmlPatternAssignment_2(), "rule__PropertyPriceStyle__HtmlPatternAssignment_2");
					put(grammarAccess.getPropertyPriceStyleAccess().getValuePropertyPathAssignment_5(), "rule__PropertyPriceStyle__ValuePropertyPathAssignment_5");
					put(grammarAccess.getPropertyPriceStyleAccess().getValueNumberFormatAssignment_6_2(), "rule__PropertyPriceStyle__ValueNumberFormatAssignment_6_2");
					put(grammarAccess.getPropertyPriceStyleAccess().getCurrencyPropertyPathAssignment_9(), "rule__PropertyPriceStyle__CurrencyPropertyPathAssignment_9");
					put(grammarAccess.getPropertyImageStyleAccess().getEventTopicAssignment_2_1(), "rule__PropertyImageStyle__EventTopicAssignment_2_1");
					put(grammarAccess.getPropertyImageStyleAccess().getConfigsAssignment_4(), "rule__PropertyImageStyle__ConfigsAssignment_4");
					put(grammarAccess.getNumericToResourceStyleConfigAccess().getCompareAssignment_1(), "rule__NumericToResourceStyleConfig__CompareAssignment_1");
					put(grammarAccess.getNumericToResourceStyleConfigAccess().getValueAssignment_2(), "rule__NumericToResourceStyleConfig__ValueAssignment_2");
					put(grammarAccess.getNumericToResourceStyleConfigAccess().getResourceThemePathAssignment_4(), "rule__NumericToResourceStyleConfig__ResourceThemePathAssignment_4");
					put(grammarAccess.getStringToResourceStyleConfigAccess().getCompareAssignment_1(), "rule__StringToResourceStyleConfig__CompareAssignment_1");
					put(grammarAccess.getStringToResourceStyleConfigAccess().getValueAssignment_2(), "rule__StringToResourceStyleConfig__ValueAssignment_2");
					put(grammarAccess.getStringToResourceStyleConfigAccess().getResourceThemePathAssignment_4(), "rule__StringToResourceStyleConfig__ResourceThemePathAssignment_4");
					put(grammarAccess.getXImportDeclarationAccess().getStaticAssignment_2_0_0(), "rule__XImportDeclaration__StaticAssignment_2_0_0");
					put(grammarAccess.getXImportDeclarationAccess().getExtensionAssignment_2_0_1(), "rule__XImportDeclaration__ExtensionAssignment_2_0_1");
					put(grammarAccess.getXImportDeclarationAccess().getImportedTypeAssignment_2_0_2(), "rule__XImportDeclaration__ImportedTypeAssignment_2_0_2");
					put(grammarAccess.getXImportDeclarationAccess().getWildcardAssignment_2_0_3_0(), "rule__XImportDeclaration__WildcardAssignment_2_0_3_0");
					put(grammarAccess.getXImportDeclarationAccess().getMemberNameAssignment_2_0_3_1(), "rule__XImportDeclaration__MemberNameAssignment_2_0_3_1");
					put(grammarAccess.getXImportDeclarationAccess().getImportedTypeAssignment_2_1(), "rule__XImportDeclaration__ImportedTypeAssignment_2_1");
					put(grammarAccess.getXImportDeclarationAccess().getImportedNamespaceAssignment_2_2(), "rule__XImportDeclaration__ImportedNamespaceAssignment_2_2");
					put(grammarAccess.getXImportDeclarationAccess().getFqnImportAssignment_2_3_0(), "rule__XImportDeclaration__FqnImportAssignment_2_3_0");
					put(grammarAccess.getXImportDeclarationAccess().getImportedFullyQualifiedNameAssignment_2_3_1(), "rule__XImportDeclaration__ImportedFullyQualifiedNameAssignment_2_3_1");
					put(grammarAccess.getXAnnotationAccess().getAnnotationTypeAssignment_2(), "rule__XAnnotation__AnnotationTypeAssignment_2");
					put(grammarAccess.getXAnnotationAccess().getElementValuePairsAssignment_3_1_0_0(), "rule__XAnnotation__ElementValuePairsAssignment_3_1_0_0");
					put(grammarAccess.getXAnnotationAccess().getElementValuePairsAssignment_3_1_0_1_1(), "rule__XAnnotation__ElementValuePairsAssignment_3_1_0_1_1");
					put(grammarAccess.getXAnnotationAccess().getValueAssignment_3_1_1(), "rule__XAnnotation__ValueAssignment_3_1_1");
					put(grammarAccess.getXAnnotationElementValuePairAccess().getElementAssignment_0_0_0(), "rule__XAnnotationElementValuePair__ElementAssignment_0_0_0");
					put(grammarAccess.getXAnnotationElementValuePairAccess().getValueAssignment_1(), "rule__XAnnotationElementValuePair__ValueAssignment_1");
					put(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getElementsAssignment_0_1_0(), "rule__XAnnotationElementValueOrCommaList__ElementsAssignment_0_1_0");
					put(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getElementsAssignment_0_1_1_1(), "rule__XAnnotationElementValueOrCommaList__ElementsAssignment_0_1_1_1");
					put(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getElementsAssignment_1_1_1_1(), "rule__XAnnotationElementValueOrCommaList__ElementsAssignment_1_1_1_1");
					put(grammarAccess.getXAnnotationElementValueAccess().getElementsAssignment_0_1_0(), "rule__XAnnotationElementValue__ElementsAssignment_0_1_0");
					put(grammarAccess.getXAnnotationElementValueAccess().getElementsAssignment_0_1_1_1(), "rule__XAnnotationElementValue__ElementsAssignment_0_1_1_1");
					put(grammarAccess.getXAssignmentAccess().getFeatureAssignment_0_1(), "rule__XAssignment__FeatureAssignment_0_1");
					put(grammarAccess.getXAssignmentAccess().getValueAssignment_0_3(), "rule__XAssignment__ValueAssignment_0_3");
					put(grammarAccess.getXAssignmentAccess().getFeatureAssignment_1_1_0_0_1(), "rule__XAssignment__FeatureAssignment_1_1_0_0_1");
					put(grammarAccess.getXAssignmentAccess().getRightOperandAssignment_1_1_1(), "rule__XAssignment__RightOperandAssignment_1_1_1");
					put(grammarAccess.getXOrExpressionAccess().getFeatureAssignment_1_0_0_1(), "rule__XOrExpression__FeatureAssignment_1_0_0_1");
					put(grammarAccess.getXOrExpressionAccess().getRightOperandAssignment_1_1(), "rule__XOrExpression__RightOperandAssignment_1_1");
					put(grammarAccess.getXAndExpressionAccess().getFeatureAssignment_1_0_0_1(), "rule__XAndExpression__FeatureAssignment_1_0_0_1");
					put(grammarAccess.getXAndExpressionAccess().getRightOperandAssignment_1_1(), "rule__XAndExpression__RightOperandAssignment_1_1");
					put(grammarAccess.getXEqualityExpressionAccess().getFeatureAssignment_1_0_0_1(), "rule__XEqualityExpression__FeatureAssignment_1_0_0_1");
					put(grammarAccess.getXEqualityExpressionAccess().getRightOperandAssignment_1_1(), "rule__XEqualityExpression__RightOperandAssignment_1_1");
					put(grammarAccess.getXRelationalExpressionAccess().getTypeAssignment_1_0_1(), "rule__XRelationalExpression__TypeAssignment_1_0_1");
					put(grammarAccess.getXRelationalExpressionAccess().getFeatureAssignment_1_1_0_0_1(), "rule__XRelationalExpression__FeatureAssignment_1_1_0_0_1");
					put(grammarAccess.getXRelationalExpressionAccess().getRightOperandAssignment_1_1_1(), "rule__XRelationalExpression__RightOperandAssignment_1_1_1");
					put(grammarAccess.getXOtherOperatorExpressionAccess().getFeatureAssignment_1_0_0_1(), "rule__XOtherOperatorExpression__FeatureAssignment_1_0_0_1");
					put(grammarAccess.getXOtherOperatorExpressionAccess().getRightOperandAssignment_1_1(), "rule__XOtherOperatorExpression__RightOperandAssignment_1_1");
					put(grammarAccess.getXAdditiveExpressionAccess().getFeatureAssignment_1_0_0_1(), "rule__XAdditiveExpression__FeatureAssignment_1_0_0_1");
					put(grammarAccess.getXAdditiveExpressionAccess().getRightOperandAssignment_1_1(), "rule__XAdditiveExpression__RightOperandAssignment_1_1");
					put(grammarAccess.getXMultiplicativeExpressionAccess().getFeatureAssignment_1_0_0_1(), "rule__XMultiplicativeExpression__FeatureAssignment_1_0_0_1");
					put(grammarAccess.getXMultiplicativeExpressionAccess().getRightOperandAssignment_1_1(), "rule__XMultiplicativeExpression__RightOperandAssignment_1_1");
					put(grammarAccess.getXUnaryOperationAccess().getFeatureAssignment_0_1(), "rule__XUnaryOperation__FeatureAssignment_0_1");
					put(grammarAccess.getXUnaryOperationAccess().getOperandAssignment_0_2(), "rule__XUnaryOperation__OperandAssignment_0_2");
					put(grammarAccess.getXCastedExpressionAccess().getTypeAssignment_1_1(), "rule__XCastedExpression__TypeAssignment_1_1");
					put(grammarAccess.getXPostfixOperationAccess().getFeatureAssignment_1_0_1(), "rule__XPostfixOperation__FeatureAssignment_1_0_1");
					put(grammarAccess.getXMemberFeatureCallAccess().getExplicitStaticAssignment_1_0_0_0_1_1(), "rule__XMemberFeatureCall__ExplicitStaticAssignment_1_0_0_0_1_1");
					put(grammarAccess.getXMemberFeatureCallAccess().getFeatureAssignment_1_0_0_0_2(), "rule__XMemberFeatureCall__FeatureAssignment_1_0_0_0_2");
					put(grammarAccess.getXMemberFeatureCallAccess().getValueAssignment_1_0_1(), "rule__XMemberFeatureCall__ValueAssignment_1_0_1");
					put(grammarAccess.getXMemberFeatureCallAccess().getNullSafeAssignment_1_1_0_0_1_1(), "rule__XMemberFeatureCall__NullSafeAssignment_1_1_0_0_1_1");
					put(grammarAccess.getXMemberFeatureCallAccess().getExplicitStaticAssignment_1_1_0_0_1_2(), "rule__XMemberFeatureCall__ExplicitStaticAssignment_1_1_0_0_1_2");
					put(grammarAccess.getXMemberFeatureCallAccess().getTypeArgumentsAssignment_1_1_1_1(), "rule__XMemberFeatureCall__TypeArgumentsAssignment_1_1_1_1");
					put(grammarAccess.getXMemberFeatureCallAccess().getTypeArgumentsAssignment_1_1_1_2_1(), "rule__XMemberFeatureCall__TypeArgumentsAssignment_1_1_1_2_1");
					put(grammarAccess.getXMemberFeatureCallAccess().getFeatureAssignment_1_1_2(), "rule__XMemberFeatureCall__FeatureAssignment_1_1_2");
					put(grammarAccess.getXMemberFeatureCallAccess().getExplicitOperationCallAssignment_1_1_3_0(), "rule__XMemberFeatureCall__ExplicitOperationCallAssignment_1_1_3_0");
					put(grammarAccess.getXMemberFeatureCallAccess().getMemberCallArgumentsAssignment_1_1_3_1_0(), "rule__XMemberFeatureCall__MemberCallArgumentsAssignment_1_1_3_1_0");
					put(grammarAccess.getXMemberFeatureCallAccess().getMemberCallArgumentsAssignment_1_1_3_1_1_0(), "rule__XMemberFeatureCall__MemberCallArgumentsAssignment_1_1_3_1_1_0");
					put(grammarAccess.getXMemberFeatureCallAccess().getMemberCallArgumentsAssignment_1_1_3_1_1_1_1(), "rule__XMemberFeatureCall__MemberCallArgumentsAssignment_1_1_3_1_1_1_1");
					put(grammarAccess.getXMemberFeatureCallAccess().getMemberCallArgumentsAssignment_1_1_4(), "rule__XMemberFeatureCall__MemberCallArgumentsAssignment_1_1_4");
					put(grammarAccess.getXSetLiteralAccess().getElementsAssignment_3_0(), "rule__XSetLiteral__ElementsAssignment_3_0");
					put(grammarAccess.getXSetLiteralAccess().getElementsAssignment_3_1_1(), "rule__XSetLiteral__ElementsAssignment_3_1_1");
					put(grammarAccess.getXListLiteralAccess().getElementsAssignment_3_0(), "rule__XListLiteral__ElementsAssignment_3_0");
					put(grammarAccess.getXListLiteralAccess().getElementsAssignment_3_1_1(), "rule__XListLiteral__ElementsAssignment_3_1_1");
					put(grammarAccess.getXClosureAccess().getDeclaredFormalParametersAssignment_1_0_0_0(), "rule__XClosure__DeclaredFormalParametersAssignment_1_0_0_0");
					put(grammarAccess.getXClosureAccess().getDeclaredFormalParametersAssignment_1_0_0_1_1(), "rule__XClosure__DeclaredFormalParametersAssignment_1_0_0_1_1");
					put(grammarAccess.getXClosureAccess().getExplicitSyntaxAssignment_1_0_1(), "rule__XClosure__ExplicitSyntaxAssignment_1_0_1");
					put(grammarAccess.getXClosureAccess().getExpressionAssignment_2(), "rule__XClosure__ExpressionAssignment_2");
					put(grammarAccess.getXExpressionInClosureAccess().getExpressionsAssignment_1_0(), "rule__XExpressionInClosure__ExpressionsAssignment_1_0");
					put(grammarAccess.getXShortClosureAccess().getDeclaredFormalParametersAssignment_0_0_1_0(), "rule__XShortClosure__DeclaredFormalParametersAssignment_0_0_1_0");
					put(grammarAccess.getXShortClosureAccess().getDeclaredFormalParametersAssignment_0_0_1_1_1(), "rule__XShortClosure__DeclaredFormalParametersAssignment_0_0_1_1_1");
					put(grammarAccess.getXShortClosureAccess().getExplicitSyntaxAssignment_0_0_2(), "rule__XShortClosure__ExplicitSyntaxAssignment_0_0_2");
					put(grammarAccess.getXShortClosureAccess().getExpressionAssignment_1(), "rule__XShortClosure__ExpressionAssignment_1");
					put(grammarAccess.getXIfExpressionAccess().getIfAssignment_3(), "rule__XIfExpression__IfAssignment_3");
					put(grammarAccess.getXIfExpressionAccess().getThenAssignment_5(), "rule__XIfExpression__ThenAssignment_5");
					put(grammarAccess.getXIfExpressionAccess().getElseAssignment_6_1(), "rule__XIfExpression__ElseAssignment_6_1");
					put(grammarAccess.getXSwitchExpressionAccess().getDeclaredParamAssignment_2_0_0_0_1(), "rule__XSwitchExpression__DeclaredParamAssignment_2_0_0_0_1");
					put(grammarAccess.getXSwitchExpressionAccess().getSwitchAssignment_2_0_1(), "rule__XSwitchExpression__SwitchAssignment_2_0_1");
					put(grammarAccess.getXSwitchExpressionAccess().getDeclaredParamAssignment_2_1_0_0_0(), "rule__XSwitchExpression__DeclaredParamAssignment_2_1_0_0_0");
					put(grammarAccess.getXSwitchExpressionAccess().getSwitchAssignment_2_1_1(), "rule__XSwitchExpression__SwitchAssignment_2_1_1");
					put(grammarAccess.getXSwitchExpressionAccess().getCasesAssignment_4(), "rule__XSwitchExpression__CasesAssignment_4");
					put(grammarAccess.getXSwitchExpressionAccess().getDefaultAssignment_5_2(), "rule__XSwitchExpression__DefaultAssignment_5_2");
					put(grammarAccess.getXCasePartAccess().getTypeGuardAssignment_1(), "rule__XCasePart__TypeGuardAssignment_1");
					put(grammarAccess.getXCasePartAccess().getCaseAssignment_2_1(), "rule__XCasePart__CaseAssignment_2_1");
					put(grammarAccess.getXCasePartAccess().getThenAssignment_3_0_1(), "rule__XCasePart__ThenAssignment_3_0_1");
					put(grammarAccess.getXCasePartAccess().getFallThroughAssignment_3_1(), "rule__XCasePart__FallThroughAssignment_3_1");
					put(grammarAccess.getXForLoopExpressionAccess().getDeclaredParamAssignment_0_0_3(), "rule__XForLoopExpression__DeclaredParamAssignment_0_0_3");
					put(grammarAccess.getXForLoopExpressionAccess().getForExpressionAssignment_1(), "rule__XForLoopExpression__ForExpressionAssignment_1");
					put(grammarAccess.getXForLoopExpressionAccess().getEachExpressionAssignment_3(), "rule__XForLoopExpression__EachExpressionAssignment_3");
					put(grammarAccess.getXBasicForLoopExpressionAccess().getInitExpressionsAssignment_3_0(), "rule__XBasicForLoopExpression__InitExpressionsAssignment_3_0");
					put(grammarAccess.getXBasicForLoopExpressionAccess().getInitExpressionsAssignment_3_1_1(), "rule__XBasicForLoopExpression__InitExpressionsAssignment_3_1_1");
					put(grammarAccess.getXBasicForLoopExpressionAccess().getExpressionAssignment_5(), "rule__XBasicForLoopExpression__ExpressionAssignment_5");
					put(grammarAccess.getXBasicForLoopExpressionAccess().getUpdateExpressionsAssignment_7_0(), "rule__XBasicForLoopExpression__UpdateExpressionsAssignment_7_0");
					put(grammarAccess.getXBasicForLoopExpressionAccess().getUpdateExpressionsAssignment_7_1_1(), "rule__XBasicForLoopExpression__UpdateExpressionsAssignment_7_1_1");
					put(grammarAccess.getXBasicForLoopExpressionAccess().getEachExpressionAssignment_9(), "rule__XBasicForLoopExpression__EachExpressionAssignment_9");
					put(grammarAccess.getXWhileExpressionAccess().getPredicateAssignment_3(), "rule__XWhileExpression__PredicateAssignment_3");
					put(grammarAccess.getXWhileExpressionAccess().getBodyAssignment_5(), "rule__XWhileExpression__BodyAssignment_5");
					put(grammarAccess.getXDoWhileExpressionAccess().getBodyAssignment_2(), "rule__XDoWhileExpression__BodyAssignment_2");
					put(grammarAccess.getXDoWhileExpressionAccess().getPredicateAssignment_5(), "rule__XDoWhileExpression__PredicateAssignment_5");
					put(grammarAccess.getXBlockExpressionAccess().getExpressionsAssignment_2_0(), "rule__XBlockExpression__ExpressionsAssignment_2_0");
					put(grammarAccess.getXVariableDeclarationAccess().getWriteableAssignment_1_0(), "rule__XVariableDeclaration__WriteableAssignment_1_0");
					put(grammarAccess.getXVariableDeclarationAccess().getTypeAssignment_2_0_0_0(), "rule__XVariableDeclaration__TypeAssignment_2_0_0_0");
					put(grammarAccess.getXVariableDeclarationAccess().getNameAssignment_2_0_0_1(), "rule__XVariableDeclaration__NameAssignment_2_0_0_1");
					put(grammarAccess.getXVariableDeclarationAccess().getNameAssignment_2_1(), "rule__XVariableDeclaration__NameAssignment_2_1");
					put(grammarAccess.getXVariableDeclarationAccess().getRightAssignment_3_1(), "rule__XVariableDeclaration__RightAssignment_3_1");
					put(grammarAccess.getJvmFormalParameterAccess().getParameterTypeAssignment_0(), "rule__JvmFormalParameter__ParameterTypeAssignment_0");
					put(grammarAccess.getJvmFormalParameterAccess().getNameAssignment_1(), "rule__JvmFormalParameter__NameAssignment_1");
					put(grammarAccess.getFullJvmFormalParameterAccess().getParameterTypeAssignment_0(), "rule__FullJvmFormalParameter__ParameterTypeAssignment_0");
					put(grammarAccess.getFullJvmFormalParameterAccess().getNameAssignment_1(), "rule__FullJvmFormalParameter__NameAssignment_1");
					put(grammarAccess.getXFeatureCallAccess().getTypeArgumentsAssignment_1_1(), "rule__XFeatureCall__TypeArgumentsAssignment_1_1");
					put(grammarAccess.getXFeatureCallAccess().getTypeArgumentsAssignment_1_2_1(), "rule__XFeatureCall__TypeArgumentsAssignment_1_2_1");
					put(grammarAccess.getXFeatureCallAccess().getFeatureAssignment_2(), "rule__XFeatureCall__FeatureAssignment_2");
					put(grammarAccess.getXFeatureCallAccess().getExplicitOperationCallAssignment_3_0(), "rule__XFeatureCall__ExplicitOperationCallAssignment_3_0");
					put(grammarAccess.getXFeatureCallAccess().getFeatureCallArgumentsAssignment_3_1_0(), "rule__XFeatureCall__FeatureCallArgumentsAssignment_3_1_0");
					put(grammarAccess.getXFeatureCallAccess().getFeatureCallArgumentsAssignment_3_1_1_0(), "rule__XFeatureCall__FeatureCallArgumentsAssignment_3_1_1_0");
					put(grammarAccess.getXFeatureCallAccess().getFeatureCallArgumentsAssignment_3_1_1_1_1(), "rule__XFeatureCall__FeatureCallArgumentsAssignment_3_1_1_1_1");
					put(grammarAccess.getXFeatureCallAccess().getFeatureCallArgumentsAssignment_4(), "rule__XFeatureCall__FeatureCallArgumentsAssignment_4");
					put(grammarAccess.getXConstructorCallAccess().getConstructorAssignment_2(), "rule__XConstructorCall__ConstructorAssignment_2");
					put(grammarAccess.getXConstructorCallAccess().getTypeArgumentsAssignment_3_1(), "rule__XConstructorCall__TypeArgumentsAssignment_3_1");
					put(grammarAccess.getXConstructorCallAccess().getTypeArgumentsAssignment_3_2_1(), "rule__XConstructorCall__TypeArgumentsAssignment_3_2_1");
					put(grammarAccess.getXConstructorCallAccess().getExplicitConstructorCallAssignment_4_0(), "rule__XConstructorCall__ExplicitConstructorCallAssignment_4_0");
					put(grammarAccess.getXConstructorCallAccess().getArgumentsAssignment_4_1_0(), "rule__XConstructorCall__ArgumentsAssignment_4_1_0");
					put(grammarAccess.getXConstructorCallAccess().getArgumentsAssignment_4_1_1_0(), "rule__XConstructorCall__ArgumentsAssignment_4_1_1_0");
					put(grammarAccess.getXConstructorCallAccess().getArgumentsAssignment_4_1_1_1_1(), "rule__XConstructorCall__ArgumentsAssignment_4_1_1_1_1");
					put(grammarAccess.getXConstructorCallAccess().getArgumentsAssignment_5(), "rule__XConstructorCall__ArgumentsAssignment_5");
					put(grammarAccess.getXBooleanLiteralAccess().getIsTrueAssignment_1_1(), "rule__XBooleanLiteral__IsTrueAssignment_1_1");
					put(grammarAccess.getXNumberLiteralAccess().getValueAssignment_1(), "rule__XNumberLiteral__ValueAssignment_1");
					put(grammarAccess.getXStringLiteralAccess().getValueAssignment_1(), "rule__XStringLiteral__ValueAssignment_1");
					put(grammarAccess.getXTypeLiteralAccess().getTypeAssignment_3(), "rule__XTypeLiteral__TypeAssignment_3");
					put(grammarAccess.getXTypeLiteralAccess().getArrayDimensionsAssignment_4(), "rule__XTypeLiteral__ArrayDimensionsAssignment_4");
					put(grammarAccess.getXThrowExpressionAccess().getExpressionAssignment_2(), "rule__XThrowExpression__ExpressionAssignment_2");
					put(grammarAccess.getXReturnExpressionAccess().getExpressionAssignment_2(), "rule__XReturnExpression__ExpressionAssignment_2");
					put(grammarAccess.getXTryCatchFinallyExpressionAccess().getExpressionAssignment_2(), "rule__XTryCatchFinallyExpression__ExpressionAssignment_2");
					put(grammarAccess.getXTryCatchFinallyExpressionAccess().getCatchClausesAssignment_3_0_0(), "rule__XTryCatchFinallyExpression__CatchClausesAssignment_3_0_0");
					put(grammarAccess.getXTryCatchFinallyExpressionAccess().getFinallyExpressionAssignment_3_0_1_1(), "rule__XTryCatchFinallyExpression__FinallyExpressionAssignment_3_0_1_1");
					put(grammarAccess.getXTryCatchFinallyExpressionAccess().getFinallyExpressionAssignment_3_1_1(), "rule__XTryCatchFinallyExpression__FinallyExpressionAssignment_3_1_1");
					put(grammarAccess.getXSynchronizedExpressionAccess().getParamAssignment_1(), "rule__XSynchronizedExpression__ParamAssignment_1");
					put(grammarAccess.getXSynchronizedExpressionAccess().getExpressionAssignment_3(), "rule__XSynchronizedExpression__ExpressionAssignment_3");
					put(grammarAccess.getXCatchClauseAccess().getDeclaredParamAssignment_2(), "rule__XCatchClause__DeclaredParamAssignment_2");
					put(grammarAccess.getXCatchClauseAccess().getExpressionAssignment_4(), "rule__XCatchClause__ExpressionAssignment_4");
					put(grammarAccess.getXFunctionTypeRefAccess().getParamTypesAssignment_0_1_0(), "rule__XFunctionTypeRef__ParamTypesAssignment_0_1_0");
					put(grammarAccess.getXFunctionTypeRefAccess().getParamTypesAssignment_0_1_1_1(), "rule__XFunctionTypeRef__ParamTypesAssignment_0_1_1_1");
					put(grammarAccess.getXFunctionTypeRefAccess().getReturnTypeAssignment_2(), "rule__XFunctionTypeRef__ReturnTypeAssignment_2");
					put(grammarAccess.getJvmParameterizedTypeReferenceAccess().getTypeAssignment_0(), "rule__JvmParameterizedTypeReference__TypeAssignment_0");
					put(grammarAccess.getJvmParameterizedTypeReferenceAccess().getArgumentsAssignment_1_1(), "rule__JvmParameterizedTypeReference__ArgumentsAssignment_1_1");
					put(grammarAccess.getJvmParameterizedTypeReferenceAccess().getArgumentsAssignment_1_2_1(), "rule__JvmParameterizedTypeReference__ArgumentsAssignment_1_2_1");
					put(grammarAccess.getJvmParameterizedTypeReferenceAccess().getTypeAssignment_1_4_1(), "rule__JvmParameterizedTypeReference__TypeAssignment_1_4_1");
					put(grammarAccess.getJvmParameterizedTypeReferenceAccess().getArgumentsAssignment_1_4_2_1(), "rule__JvmParameterizedTypeReference__ArgumentsAssignment_1_4_2_1");
					put(grammarAccess.getJvmParameterizedTypeReferenceAccess().getArgumentsAssignment_1_4_2_2_1(), "rule__JvmParameterizedTypeReference__ArgumentsAssignment_1_4_2_2_1");
					put(grammarAccess.getJvmWildcardTypeReferenceAccess().getConstraintsAssignment_2_0_0(), "rule__JvmWildcardTypeReference__ConstraintsAssignment_2_0_0");
					put(grammarAccess.getJvmWildcardTypeReferenceAccess().getConstraintsAssignment_2_0_1(), "rule__JvmWildcardTypeReference__ConstraintsAssignment_2_0_1");
					put(grammarAccess.getJvmWildcardTypeReferenceAccess().getConstraintsAssignment_2_1_0(), "rule__JvmWildcardTypeReference__ConstraintsAssignment_2_1_0");
					put(grammarAccess.getJvmWildcardTypeReferenceAccess().getConstraintsAssignment_2_1_1(), "rule__JvmWildcardTypeReference__ConstraintsAssignment_2_1_1");
					put(grammarAccess.getJvmUpperBoundAccess().getTypeReferenceAssignment_1(), "rule__JvmUpperBound__TypeReferenceAssignment_1");
					put(grammarAccess.getJvmUpperBoundAndedAccess().getTypeReferenceAssignment_1(), "rule__JvmUpperBoundAnded__TypeReferenceAssignment_1");
					put(grammarAccess.getJvmLowerBoundAccess().getTypeReferenceAssignment_1(), "rule__JvmLowerBound__TypeReferenceAssignment_1");
					put(grammarAccess.getJvmLowerBoundAndedAccess().getTypeReferenceAssignment_1(), "rule__JvmLowerBoundAnded__TypeReferenceAssignment_1");
					put(grammarAccess.getJvmTypeParameterAccess().getNameAssignment_0(), "rule__JvmTypeParameter__NameAssignment_0");
					put(grammarAccess.getJvmTypeParameterAccess().getConstraintsAssignment_1_0(), "rule__JvmTypeParameter__ConstraintsAssignment_1_0");
					put(grammarAccess.getJvmTypeParameterAccess().getConstraintsAssignment_1_1(), "rule__JvmTypeParameter__ConstraintsAssignment_1_1");
					put(grammarAccess.getXImportSectionAccess().getImportDeclarationsAssignment(), "rule__XImportSection__ImportDeclarationsAssignment");
					put(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), "rule__TableSelection__UnorderedGroup_3");
					put(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), "rule__TableTable__UnorderedGroup_2");
					put(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), "rule__TableValue__UnorderedGroup_3");
					put(grammarAccess.getTableValueAccess().getUnorderedGroup_4(), "rule__TableValue__UnorderedGroup_4");
					put(grammarAccess.getTableImageAccess().getUnorderedGroup_3(), "rule__TableImage__UnorderedGroup_3");
					put(grammarAccess.getTableAxisAccess().getUnorderedGroup_2(), "rule__TableAxis__UnorderedGroup_2");
				}
			};
		}
		return nameMappings.get(element);
	}
			
	@Override
	protected String[] getInitialHiddenTokens() {
		return new String[] { "RULE_WS", "RULE_ML_COMMENT", "RULE_SL_COMMENT" };
	}

	public TableDSLGrammarAccess getGrammarAccess() {
		return this.grammarAccess;
	}

	public void setGrammarAccess(TableDSLGrammarAccess grammarAccess) {
		this.grammarAccess = grammarAccess;
	}
}
