/**
 *                                                                            
 * Copyright (c) 2011, 2016 - Loetz GmbH&Co.KG (69115 Heidelberg, Germany)
 *                                                                            
 * All rights reserved. This program and the accompanying materials           
 * are made available under the terms of the Eclipse Public License 2.0        
 * which accompanies this distribution, and is available at                  
 * https://www.eclipse.org/legal/epl-2.0/                                 
 *                                 
 * SPDX-License-Identifier: EPL-2.0                                 
 *                                                                            
 * Contributors:   
 * Christophe Loetz (Loetz GmbH&Co.KG) - initial implementation 
 */
package org.eclipse.osbp.xtext.table.serializer;

import com.google.inject.Inject;
import java.util.Set;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.osbp.infogrid.model.gridsource.CxGridNestedField;
import org.eclipse.osbp.infogrid.model.gridsource.CxGridNestedPath;
import org.eclipse.osbp.infogrid.model.gridsource.CxGridProperty;
import org.eclipse.osbp.infogrid.model.gridsource.CxGridSourcePackage;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridPropBlobImageStyle;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridPropBooleanStyle;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridPropButtonStyle;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridPropDateStyle;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridPropHtmlStyle;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridPropImageStyle;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridPropIndicatorStyle;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridPropNumberStyle;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridPropPriceStyle;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridPropProgressbarStyle;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridPropQuantityStyle;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridPropTextStyle;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridStyleConfigNumericToResource;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridStyleConfigStringToResource;
import org.eclipse.osbp.infogrid.model.gridsource.style.CxGridStylePackage;
import org.eclipse.osbp.xtext.oxtype.oxtype.OXImportDeclaration;
import org.eclipse.osbp.xtext.oxtype.oxtype.OXtypePackage;
import org.eclipse.osbp.xtext.oxtype.serializer.OXtypeSemanticSequencer;
import org.eclipse.osbp.xtext.table.Table;
import org.eclipse.osbp.xtext.table.TableAggregation;
import org.eclipse.osbp.xtext.table.TableAllColumns;
import org.eclipse.osbp.xtext.table.TableAttribute;
import org.eclipse.osbp.xtext.table.TableAxis;
import org.eclipse.osbp.xtext.table.TableCellColor;
import org.eclipse.osbp.xtext.table.TableColumn;
import org.eclipse.osbp.xtext.table.TableDSLPackage;
import org.eclipse.osbp.xtext.table.TableDatamart;
import org.eclipse.osbp.xtext.table.TableDateDayInterval;
import org.eclipse.osbp.xtext.table.TableDateDayLookup;
import org.eclipse.osbp.xtext.table.TableDerived;
import org.eclipse.osbp.xtext.table.TableDtoDatasource;
import org.eclipse.osbp.xtext.table.TableEvent;
import org.eclipse.osbp.xtext.table.TableFormatter;
import org.eclipse.osbp.xtext.table.TableGrid;
import org.eclipse.osbp.xtext.table.TableHierarchy;
import org.eclipse.osbp.xtext.table.TableIcon;
import org.eclipse.osbp.xtext.table.TableImage;
import org.eclipse.osbp.xtext.table.TableIntInterval;
import org.eclipse.osbp.xtext.table.TableIntLookup;
import org.eclipse.osbp.xtext.table.TableMeasure;
import org.eclipse.osbp.xtext.table.TableModel;
import org.eclipse.osbp.xtext.table.TableNumberInterval;
import org.eclipse.osbp.xtext.table.TableNumberLookup;
import org.eclipse.osbp.xtext.table.TableOrdinal;
import org.eclipse.osbp.xtext.table.TablePackage;
import org.eclipse.osbp.xtext.table.TablePreorder;
import org.eclipse.osbp.xtext.table.TableSelection;
import org.eclipse.osbp.xtext.table.TableStringLookup;
import org.eclipse.osbp.xtext.table.TableTable;
import org.eclipse.osbp.xtext.table.TableTask;
import org.eclipse.osbp.xtext.table.TableTextColor;
import org.eclipse.osbp.xtext.table.TableTooltip;
import org.eclipse.osbp.xtext.table.TableTooltipPattern;
import org.eclipse.osbp.xtext.table.TableTrend;
import org.eclipse.osbp.xtext.table.TableValue;
import org.eclipse.osbp.xtext.table.services.TableDSLGrammarAccess;
import org.eclipse.xtext.Action;
import org.eclipse.xtext.Parameter;
import org.eclipse.xtext.ParserRule;
import org.eclipse.xtext.common.types.JvmFormalParameter;
import org.eclipse.xtext.common.types.JvmGenericArrayTypeReference;
import org.eclipse.xtext.common.types.JvmInnerTypeReference;
import org.eclipse.xtext.common.types.JvmLowerBound;
import org.eclipse.xtext.common.types.JvmParameterizedTypeReference;
import org.eclipse.xtext.common.types.JvmTypeParameter;
import org.eclipse.xtext.common.types.JvmUpperBound;
import org.eclipse.xtext.common.types.JvmWildcardTypeReference;
import org.eclipse.xtext.common.types.TypesPackage;
import org.eclipse.xtext.serializer.ISerializationContext;
import org.eclipse.xtext.serializer.acceptor.SequenceFeeder;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService.ValueTransient;
import org.eclipse.xtext.xbase.XAssignment;
import org.eclipse.xtext.xbase.XBasicForLoopExpression;
import org.eclipse.xtext.xbase.XBinaryOperation;
import org.eclipse.xtext.xbase.XBlockExpression;
import org.eclipse.xtext.xbase.XBooleanLiteral;
import org.eclipse.xtext.xbase.XCasePart;
import org.eclipse.xtext.xbase.XCastedExpression;
import org.eclipse.xtext.xbase.XCatchClause;
import org.eclipse.xtext.xbase.XClosure;
import org.eclipse.xtext.xbase.XConstructorCall;
import org.eclipse.xtext.xbase.XDoWhileExpression;
import org.eclipse.xtext.xbase.XFeatureCall;
import org.eclipse.xtext.xbase.XForLoopExpression;
import org.eclipse.xtext.xbase.XIfExpression;
import org.eclipse.xtext.xbase.XInstanceOfExpression;
import org.eclipse.xtext.xbase.XListLiteral;
import org.eclipse.xtext.xbase.XMemberFeatureCall;
import org.eclipse.xtext.xbase.XNullLiteral;
import org.eclipse.xtext.xbase.XNumberLiteral;
import org.eclipse.xtext.xbase.XPostfixOperation;
import org.eclipse.xtext.xbase.XReturnExpression;
import org.eclipse.xtext.xbase.XSetLiteral;
import org.eclipse.xtext.xbase.XStringLiteral;
import org.eclipse.xtext.xbase.XSwitchExpression;
import org.eclipse.xtext.xbase.XSynchronizedExpression;
import org.eclipse.xtext.xbase.XThrowExpression;
import org.eclipse.xtext.xbase.XTryCatchFinallyExpression;
import org.eclipse.xtext.xbase.XTypeLiteral;
import org.eclipse.xtext.xbase.XUnaryOperation;
import org.eclipse.xtext.xbase.XVariableDeclaration;
import org.eclipse.xtext.xbase.XWhileExpression;
import org.eclipse.xtext.xbase.XbasePackage;
import org.eclipse.xtext.xbase.annotations.xAnnotations.XAnnotation;
import org.eclipse.xtext.xbase.annotations.xAnnotations.XAnnotationElementValuePair;
import org.eclipse.xtext.xbase.annotations.xAnnotations.XAnnotationsPackage;
import org.eclipse.xtext.xtype.XFunctionTypeRef;
import org.eclipse.xtext.xtype.XImportSection;
import org.eclipse.xtext.xtype.XtypePackage;

@SuppressWarnings("all")
public class TableDSLSemanticSequencer extends OXtypeSemanticSequencer {

	@Inject
	private TableDSLGrammarAccess grammarAccess;
	
	@Override
	public void sequence(ISerializationContext context, EObject semanticObject) {
		EPackage epackage = semanticObject.eClass().getEPackage();
		ParserRule rule = context.getParserRule();
		Action action = context.getAssignedAction();
		Set<Parameter> parameters = context.getEnabledBooleanParameters();
		if (epackage == CxGridSourcePackage.eINSTANCE)
			switch (semanticObject.eClass().getClassifierID()) {
			case CxGridSourcePackage.CX_GRID_NESTED_FIELD:
				sequence_NestedField(context, (CxGridNestedField) semanticObject); 
				return; 
			case CxGridSourcePackage.CX_GRID_NESTED_PATH:
				sequence_NestedPath(context, (CxGridNestedPath) semanticObject); 
				return; 
			case CxGridSourcePackage.CX_GRID_PROPERTY:
				sequence_Property(context, (CxGridProperty) semanticObject); 
				return; 
			}
		else if (epackage == OXtypePackage.eINSTANCE)
			switch (semanticObject.eClass().getClassifierID()) {
			case OXtypePackage.OX_IMPORT_DECLARATION:
				sequence_XImportDeclaration(context, (OXImportDeclaration) semanticObject); 
				return; 
			}
		else if (epackage == CxGridStylePackage.eINSTANCE)
			switch (semanticObject.eClass().getClassifierID()) {
			case CxGridStylePackage.CX_GRID_PROP_BLOB_IMAGE_STYLE:
				sequence_PropertyBlobImageStyle(context, (CxGridPropBlobImageStyle) semanticObject); 
				return; 
			case CxGridStylePackage.CX_GRID_PROP_BOOLEAN_STYLE:
				sequence_PropertyBooleanStyle(context, (CxGridPropBooleanStyle) semanticObject); 
				return; 
			case CxGridStylePackage.CX_GRID_PROP_BUTTON_STYLE:
				sequence_PropertyButtonStyle(context, (CxGridPropButtonStyle) semanticObject); 
				return; 
			case CxGridStylePackage.CX_GRID_PROP_DATE_STYLE:
				sequence_PropertyDateStyle(context, (CxGridPropDateStyle) semanticObject); 
				return; 
			case CxGridStylePackage.CX_GRID_PROP_HTML_STYLE:
				sequence_PropertyHtmlStyle(context, (CxGridPropHtmlStyle) semanticObject); 
				return; 
			case CxGridStylePackage.CX_GRID_PROP_IMAGE_STYLE:
				sequence_PropertyImageStyle(context, (CxGridPropImageStyle) semanticObject); 
				return; 
			case CxGridStylePackage.CX_GRID_PROP_INDICATOR_STYLE:
				sequence_GridPropIndicatorStyle(context, (CxGridPropIndicatorStyle) semanticObject); 
				return; 
			case CxGridStylePackage.CX_GRID_PROP_NUMBER_STYLE:
				sequence_PropertyNumberStyle(context, (CxGridPropNumberStyle) semanticObject); 
				return; 
			case CxGridStylePackage.CX_GRID_PROP_PRICE_STYLE:
				sequence_PropertyPriceStyle(context, (CxGridPropPriceStyle) semanticObject); 
				return; 
			case CxGridStylePackage.CX_GRID_PROP_PROGRESSBAR_STYLE:
				sequence_PropertyProgressbarStyle(context, (CxGridPropProgressbarStyle) semanticObject); 
				return; 
			case CxGridStylePackage.CX_GRID_PROP_QUANTITY_STYLE:
				sequence_PropertyQuantityStyle(context, (CxGridPropQuantityStyle) semanticObject); 
				return; 
			case CxGridStylePackage.CX_GRID_PROP_TEXT_STYLE:
				sequence_PropertyTextStyle(context, (CxGridPropTextStyle) semanticObject); 
				return; 
			case CxGridStylePackage.CX_GRID_STYLE_CONFIG_NUMERIC_TO_RESOURCE:
				sequence_NumericToResourceStyleConfig(context, (CxGridStyleConfigNumericToResource) semanticObject); 
				return; 
			case CxGridStylePackage.CX_GRID_STYLE_CONFIG_STRING_TO_RESOURCE:
				sequence_StringToResourceStyleConfig(context, (CxGridStyleConfigStringToResource) semanticObject); 
				return; 
			}
		else if (epackage == TableDSLPackage.eINSTANCE)
			switch (semanticObject.eClass().getClassifierID()) {
			case TableDSLPackage.TABLE:
				sequence_Table(context, (Table) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_AGGREGATION:
				sequence_TableAggregation(context, (TableAggregation) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_ALL_COLUMNS:
				sequence_TableAllColumns(context, (TableAllColumns) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_ATTRIBUTE:
				sequence_TableAttribute(context, (TableAttribute) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_AXIS:
				sequence_TableAxis(context, (TableAxis) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_CELL_COLOR:
				sequence_TableCellColor(context, (TableCellColor) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_COLUMN:
				sequence_TableColumn(context, (TableColumn) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_DATAMART:
				sequence_TableDatamart(context, (TableDatamart) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_DATE_DAY_INTERVAL:
				sequence_TableDateDayInterval(context, (TableDateDayInterval) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_DATE_DAY_LOOKUP:
				sequence_TableDateDayLookup(context, (TableDateDayLookup) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_DERIVED:
				sequence_TableDerived(context, (TableDerived) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_DTO_DATASOURCE:
				sequence_TableDtoDatasource(context, (TableDtoDatasource) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_EVENT:
				sequence_TableEvent(context, (TableEvent) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_FORMATTER:
				sequence_TableFormatter(context, (TableFormatter) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_GRID:
				sequence_TableGrid(context, (TableGrid) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_HIERARCHY:
				sequence_TableHierarchy(context, (TableHierarchy) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_ICON:
				sequence_TableIcon(context, (TableIcon) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_IMAGE:
				sequence_TableImage(context, (TableImage) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_INT_INTERVAL:
				sequence_TableIntInterval(context, (TableIntInterval) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_INT_LOOKUP:
				sequence_TableIntLookup(context, (TableIntLookup) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_MEASURE:
				sequence_TableMeasure(context, (TableMeasure) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_MODEL:
				sequence_TableModel(context, (TableModel) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_NUMBER_INTERVAL:
				sequence_TableNumberInterval(context, (TableNumberInterval) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_NUMBER_LOOKUP:
				sequence_TableNumberLookup(context, (TableNumberLookup) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_ORDINAL:
				sequence_TableOrdinal(context, (TableOrdinal) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_PACKAGE:
				sequence_TablePackage(context, (TablePackage) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_PREORDER:
				sequence_TablePreorder(context, (TablePreorder) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_SELECTION:
				sequence_TableSelection(context, (TableSelection) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_STRING_LOOKUP:
				sequence_TableStringLookup(context, (TableStringLookup) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_TABLE:
				sequence_TableTable(context, (TableTable) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_TASK:
				sequence_TableTask(context, (TableTask) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_TEXT_COLOR:
				sequence_TableTextColor(context, (TableTextColor) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_TOOLTIP:
				sequence_TableTooltip(context, (TableTooltip) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_TOOLTIP_PATTERN:
				sequence_TableTooltipPattern(context, (TableTooltipPattern) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_TREND:
				sequence_TableTrend(context, (TableTrend) semanticObject); 
				return; 
			case TableDSLPackage.TABLE_VALUE:
				sequence_TableValue(context, (TableValue) semanticObject); 
				return; 
			}
		else if (epackage == TypesPackage.eINSTANCE)
			switch (semanticObject.eClass().getClassifierID()) {
			case TypesPackage.JVM_FORMAL_PARAMETER:
				if (rule == grammarAccess.getFullJvmFormalParameterRule()) {
					sequence_FullJvmFormalParameter(context, (JvmFormalParameter) semanticObject); 
					return; 
				}
				else if (rule == grammarAccess.getJvmFormalParameterRule()) {
					sequence_JvmFormalParameter(context, (JvmFormalParameter) semanticObject); 
					return; 
				}
				else break;
			case TypesPackage.JVM_GENERIC_ARRAY_TYPE_REFERENCE:
				sequence_JvmTypeReference(context, (JvmGenericArrayTypeReference) semanticObject); 
				return; 
			case TypesPackage.JVM_INNER_TYPE_REFERENCE:
				sequence_JvmParameterizedTypeReference(context, (JvmInnerTypeReference) semanticObject); 
				return; 
			case TypesPackage.JVM_LOWER_BOUND:
				if (rule == grammarAccess.getJvmLowerBoundAndedRule()) {
					sequence_JvmLowerBoundAnded(context, (JvmLowerBound) semanticObject); 
					return; 
				}
				else if (rule == grammarAccess.getJvmLowerBoundRule()) {
					sequence_JvmLowerBound(context, (JvmLowerBound) semanticObject); 
					return; 
				}
				else break;
			case TypesPackage.JVM_PARAMETERIZED_TYPE_REFERENCE:
				if (action == grammarAccess.getJvmParameterizedTypeReferenceAccess().getJvmInnerTypeReferenceOuterAction_1_4_0_0_0()) {
					sequence_JvmParameterizedTypeReference_JvmInnerTypeReference_1_4_0_0_0(context, (JvmParameterizedTypeReference) semanticObject); 
					return; 
				}
				else if (rule == grammarAccess.getJvmTypeReferenceRule()
						|| action == grammarAccess.getJvmTypeReferenceAccess().getJvmGenericArrayTypeReferenceComponentTypeAction_0_1_0_0()
						|| rule == grammarAccess.getJvmParameterizedTypeReferenceRule()
						|| rule == grammarAccess.getJvmArgumentTypeReferenceRule()) {
					sequence_JvmParameterizedTypeReference(context, (JvmParameterizedTypeReference) semanticObject); 
					return; 
				}
				else break;
			case TypesPackage.JVM_TYPE_PARAMETER:
				sequence_JvmTypeParameter(context, (JvmTypeParameter) semanticObject); 
				return; 
			case TypesPackage.JVM_UPPER_BOUND:
				if (rule == grammarAccess.getJvmUpperBoundAndedRule()) {
					sequence_JvmUpperBoundAnded(context, (JvmUpperBound) semanticObject); 
					return; 
				}
				else if (rule == grammarAccess.getJvmUpperBoundRule()) {
					sequence_JvmUpperBound(context, (JvmUpperBound) semanticObject); 
					return; 
				}
				else break;
			case TypesPackage.JVM_WILDCARD_TYPE_REFERENCE:
				sequence_JvmWildcardTypeReference(context, (JvmWildcardTypeReference) semanticObject); 
				return; 
			}
		else if (epackage == XAnnotationsPackage.eINSTANCE)
			switch (semanticObject.eClass().getClassifierID()) {
			case XAnnotationsPackage.XANNOTATION:
				sequence_XAnnotation(context, (XAnnotation) semanticObject); 
				return; 
			case XAnnotationsPackage.XANNOTATION_ELEMENT_VALUE_PAIR:
				sequence_XAnnotationElementValuePair(context, (XAnnotationElementValuePair) semanticObject); 
				return; 
			}
		else if (epackage == XbasePackage.eINSTANCE)
			switch (semanticObject.eClass().getClassifierID()) {
			case XbasePackage.XASSIGNMENT:
				sequence_XAssignment_XMemberFeatureCall(context, (XAssignment) semanticObject); 
				return; 
			case XbasePackage.XBASIC_FOR_LOOP_EXPRESSION:
				sequence_XBasicForLoopExpression(context, (XBasicForLoopExpression) semanticObject); 
				return; 
			case XbasePackage.XBINARY_OPERATION:
				sequence_XAdditiveExpression_XAndExpression_XAssignment_XEqualityExpression_XMultiplicativeExpression_XOrExpression_XOtherOperatorExpression_XRelationalExpression(context, (XBinaryOperation) semanticObject); 
				return; 
			case XbasePackage.XBLOCK_EXPRESSION:
				if (rule == grammarAccess.getXAnnotationElementValueOrCommaListRule()
						|| action == grammarAccess.getXAnnotationElementValueOrCommaListAccess().getXListLiteralElementsAction_1_1_0()
						|| rule == grammarAccess.getXAnnotationElementValueRule()
						|| rule == grammarAccess.getXAnnotationOrExpressionRule()
						|| rule == grammarAccess.getXExpressionRule()
						|| rule == grammarAccess.getXAssignmentRule()
						|| action == grammarAccess.getXAssignmentAccess().getXBinaryOperationLeftOperandAction_1_1_0_0_0()
						|| rule == grammarAccess.getXOrExpressionRule()
						|| action == grammarAccess.getXOrExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXAndExpressionRule()
						|| action == grammarAccess.getXAndExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXEqualityExpressionRule()
						|| action == grammarAccess.getXEqualityExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXRelationalExpressionRule()
						|| action == grammarAccess.getXRelationalExpressionAccess().getXInstanceOfExpressionExpressionAction_1_0_0_0_0()
						|| action == grammarAccess.getXRelationalExpressionAccess().getXBinaryOperationLeftOperandAction_1_1_0_0_0()
						|| rule == grammarAccess.getXOtherOperatorExpressionRule()
						|| action == grammarAccess.getXOtherOperatorExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXAdditiveExpressionRule()
						|| action == grammarAccess.getXAdditiveExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXMultiplicativeExpressionRule()
						|| action == grammarAccess.getXMultiplicativeExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXUnaryOperationRule()
						|| rule == grammarAccess.getXCastedExpressionRule()
						|| action == grammarAccess.getXCastedExpressionAccess().getXCastedExpressionTargetAction_1_0_0_0()
						|| rule == grammarAccess.getXPostfixOperationRule()
						|| action == grammarAccess.getXPostfixOperationAccess().getXPostfixOperationOperandAction_1_0_0()
						|| rule == grammarAccess.getXMemberFeatureCallRule()
						|| action == grammarAccess.getXMemberFeatureCallAccess().getXAssignmentAssignableAction_1_0_0_0_0()
						|| action == grammarAccess.getXMemberFeatureCallAccess().getXMemberFeatureCallMemberCallTargetAction_1_1_0_0_0()
						|| rule == grammarAccess.getXPrimaryExpressionRule()
						|| rule == grammarAccess.getXParenthesizedExpressionRule()
						|| rule == grammarAccess.getXBlockExpressionRule()
						|| rule == grammarAccess.getXExpressionOrVarDeclarationRule()) {
					sequence_XBlockExpression(context, (XBlockExpression) semanticObject); 
					return; 
				}
				else if (rule == grammarAccess.getXExpressionInClosureRule()) {
					sequence_XExpressionInClosure(context, (XBlockExpression) semanticObject); 
					return; 
				}
				else break;
			case XbasePackage.XBOOLEAN_LITERAL:
				sequence_XBooleanLiteral(context, (XBooleanLiteral) semanticObject); 
				return; 
			case XbasePackage.XCASE_PART:
				sequence_XCasePart(context, (XCasePart) semanticObject); 
				return; 
			case XbasePackage.XCASTED_EXPRESSION:
				sequence_XCastedExpression(context, (XCastedExpression) semanticObject); 
				return; 
			case XbasePackage.XCATCH_CLAUSE:
				sequence_XCatchClause(context, (XCatchClause) semanticObject); 
				return; 
			case XbasePackage.XCLOSURE:
				if (rule == grammarAccess.getXAnnotationElementValueOrCommaListRule()
						|| action == grammarAccess.getXAnnotationElementValueOrCommaListAccess().getXListLiteralElementsAction_1_1_0()
						|| rule == grammarAccess.getXAnnotationElementValueRule()
						|| rule == grammarAccess.getXAnnotationOrExpressionRule()
						|| rule == grammarAccess.getXExpressionRule()
						|| rule == grammarAccess.getXAssignmentRule()
						|| action == grammarAccess.getXAssignmentAccess().getXBinaryOperationLeftOperandAction_1_1_0_0_0()
						|| rule == grammarAccess.getXOrExpressionRule()
						|| action == grammarAccess.getXOrExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXAndExpressionRule()
						|| action == grammarAccess.getXAndExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXEqualityExpressionRule()
						|| action == grammarAccess.getXEqualityExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXRelationalExpressionRule()
						|| action == grammarAccess.getXRelationalExpressionAccess().getXInstanceOfExpressionExpressionAction_1_0_0_0_0()
						|| action == grammarAccess.getXRelationalExpressionAccess().getXBinaryOperationLeftOperandAction_1_1_0_0_0()
						|| rule == grammarAccess.getXOtherOperatorExpressionRule()
						|| action == grammarAccess.getXOtherOperatorExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXAdditiveExpressionRule()
						|| action == grammarAccess.getXAdditiveExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXMultiplicativeExpressionRule()
						|| action == grammarAccess.getXMultiplicativeExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXUnaryOperationRule()
						|| rule == grammarAccess.getXCastedExpressionRule()
						|| action == grammarAccess.getXCastedExpressionAccess().getXCastedExpressionTargetAction_1_0_0_0()
						|| rule == grammarAccess.getXPostfixOperationRule()
						|| action == grammarAccess.getXPostfixOperationAccess().getXPostfixOperationOperandAction_1_0_0()
						|| rule == grammarAccess.getXMemberFeatureCallRule()
						|| action == grammarAccess.getXMemberFeatureCallAccess().getXAssignmentAssignableAction_1_0_0_0_0()
						|| action == grammarAccess.getXMemberFeatureCallAccess().getXMemberFeatureCallMemberCallTargetAction_1_1_0_0_0()
						|| rule == grammarAccess.getXPrimaryExpressionRule()
						|| rule == grammarAccess.getXLiteralRule()
						|| rule == grammarAccess.getXClosureRule()
						|| rule == grammarAccess.getXParenthesizedExpressionRule()
						|| rule == grammarAccess.getXExpressionOrVarDeclarationRule()) {
					sequence_XClosure(context, (XClosure) semanticObject); 
					return; 
				}
				else if (rule == grammarAccess.getXShortClosureRule()) {
					sequence_XShortClosure(context, (XClosure) semanticObject); 
					return; 
				}
				else break;
			case XbasePackage.XCONSTRUCTOR_CALL:
				sequence_XConstructorCall(context, (XConstructorCall) semanticObject); 
				return; 
			case XbasePackage.XDO_WHILE_EXPRESSION:
				sequence_XDoWhileExpression(context, (XDoWhileExpression) semanticObject); 
				return; 
			case XbasePackage.XFEATURE_CALL:
				sequence_XFeatureCall(context, (XFeatureCall) semanticObject); 
				return; 
			case XbasePackage.XFOR_LOOP_EXPRESSION:
				sequence_XForLoopExpression(context, (XForLoopExpression) semanticObject); 
				return; 
			case XbasePackage.XIF_EXPRESSION:
				sequence_XIfExpression(context, (XIfExpression) semanticObject); 
				return; 
			case XbasePackage.XINSTANCE_OF_EXPRESSION:
				sequence_XRelationalExpression(context, (XInstanceOfExpression) semanticObject); 
				return; 
			case XbasePackage.XLIST_LITERAL:
				if (rule == grammarAccess.getXAnnotationElementValueOrCommaListRule()) {
					sequence_XAnnotationElementValueOrCommaList_XListLiteral(context, (XListLiteral) semanticObject); 
					return; 
				}
				else if (rule == grammarAccess.getXAnnotationElementValueRule()) {
					sequence_XAnnotationElementValue_XListLiteral(context, (XListLiteral) semanticObject); 
					return; 
				}
				else if (action == grammarAccess.getXAnnotationElementValueOrCommaListAccess().getXListLiteralElementsAction_1_1_0()
						|| rule == grammarAccess.getXAnnotationOrExpressionRule()
						|| rule == grammarAccess.getXExpressionRule()
						|| rule == grammarAccess.getXAssignmentRule()
						|| action == grammarAccess.getXAssignmentAccess().getXBinaryOperationLeftOperandAction_1_1_0_0_0()
						|| rule == grammarAccess.getXOrExpressionRule()
						|| action == grammarAccess.getXOrExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXAndExpressionRule()
						|| action == grammarAccess.getXAndExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXEqualityExpressionRule()
						|| action == grammarAccess.getXEqualityExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXRelationalExpressionRule()
						|| action == grammarAccess.getXRelationalExpressionAccess().getXInstanceOfExpressionExpressionAction_1_0_0_0_0()
						|| action == grammarAccess.getXRelationalExpressionAccess().getXBinaryOperationLeftOperandAction_1_1_0_0_0()
						|| rule == grammarAccess.getXOtherOperatorExpressionRule()
						|| action == grammarAccess.getXOtherOperatorExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXAdditiveExpressionRule()
						|| action == grammarAccess.getXAdditiveExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXMultiplicativeExpressionRule()
						|| action == grammarAccess.getXMultiplicativeExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0()
						|| rule == grammarAccess.getXUnaryOperationRule()
						|| rule == grammarAccess.getXCastedExpressionRule()
						|| action == grammarAccess.getXCastedExpressionAccess().getXCastedExpressionTargetAction_1_0_0_0()
						|| rule == grammarAccess.getXPostfixOperationRule()
						|| action == grammarAccess.getXPostfixOperationAccess().getXPostfixOperationOperandAction_1_0_0()
						|| rule == grammarAccess.getXMemberFeatureCallRule()
						|| action == grammarAccess.getXMemberFeatureCallAccess().getXAssignmentAssignableAction_1_0_0_0_0()
						|| action == grammarAccess.getXMemberFeatureCallAccess().getXMemberFeatureCallMemberCallTargetAction_1_1_0_0_0()
						|| rule == grammarAccess.getXPrimaryExpressionRule()
						|| rule == grammarAccess.getXLiteralRule()
						|| rule == grammarAccess.getXCollectionLiteralRule()
						|| rule == grammarAccess.getXListLiteralRule()
						|| rule == grammarAccess.getXParenthesizedExpressionRule()
						|| rule == grammarAccess.getXExpressionOrVarDeclarationRule()) {
					sequence_XListLiteral(context, (XListLiteral) semanticObject); 
					return; 
				}
				else break;
			case XbasePackage.XMEMBER_FEATURE_CALL:
				sequence_XMemberFeatureCall(context, (XMemberFeatureCall) semanticObject); 
				return; 
			case XbasePackage.XNULL_LITERAL:
				sequence_XNullLiteral(context, (XNullLiteral) semanticObject); 
				return; 
			case XbasePackage.XNUMBER_LITERAL:
				sequence_XNumberLiteral(context, (XNumberLiteral) semanticObject); 
				return; 
			case XbasePackage.XPOSTFIX_OPERATION:
				sequence_XPostfixOperation(context, (XPostfixOperation) semanticObject); 
				return; 
			case XbasePackage.XRETURN_EXPRESSION:
				sequence_XReturnExpression(context, (XReturnExpression) semanticObject); 
				return; 
			case XbasePackage.XSET_LITERAL:
				sequence_XSetLiteral(context, (XSetLiteral) semanticObject); 
				return; 
			case XbasePackage.XSTRING_LITERAL:
				sequence_XStringLiteral(context, (XStringLiteral) semanticObject); 
				return; 
			case XbasePackage.XSWITCH_EXPRESSION:
				sequence_XSwitchExpression(context, (XSwitchExpression) semanticObject); 
				return; 
			case XbasePackage.XSYNCHRONIZED_EXPRESSION:
				sequence_XSynchronizedExpression(context, (XSynchronizedExpression) semanticObject); 
				return; 
			case XbasePackage.XTHROW_EXPRESSION:
				sequence_XThrowExpression(context, (XThrowExpression) semanticObject); 
				return; 
			case XbasePackage.XTRY_CATCH_FINALLY_EXPRESSION:
				sequence_XTryCatchFinallyExpression(context, (XTryCatchFinallyExpression) semanticObject); 
				return; 
			case XbasePackage.XTYPE_LITERAL:
				sequence_XTypeLiteral(context, (XTypeLiteral) semanticObject); 
				return; 
			case XbasePackage.XUNARY_OPERATION:
				sequence_XUnaryOperation(context, (XUnaryOperation) semanticObject); 
				return; 
			case XbasePackage.XVARIABLE_DECLARATION:
				sequence_XVariableDeclaration(context, (XVariableDeclaration) semanticObject); 
				return; 
			case XbasePackage.XWHILE_EXPRESSION:
				sequence_XWhileExpression(context, (XWhileExpression) semanticObject); 
				return; 
			}
		else if (epackage == XtypePackage.eINSTANCE)
			switch (semanticObject.eClass().getClassifierID()) {
			case XtypePackage.XFUNCTION_TYPE_REF:
				sequence_XFunctionTypeRef(context, (XFunctionTypeRef) semanticObject); 
				return; 
			case XtypePackage.XIMPORT_SECTION:
				sequence_XImportSection(context, (XImportSection) semanticObject); 
				return; 
			}
		if (errorAcceptor != null)
			errorAcceptor.accept(diagnosticProvider.createInvalidContextOrTypeDiagnostic(semanticObject, context));
	}
	
	/**
	 * Contexts:
	 *     PropertyStyle returns CxGridPropIndicatorStyle
	 *     GridPropIndicatorStyle returns CxGridPropIndicatorStyle
	 *
	 * Constraint:
	 *     (greenStarts=LDouble redEnds=LDouble)
	 */
	protected void sequence_GridPropIndicatorStyle(ISerializationContext context, CxGridPropIndicatorStyle semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, CxGridStylePackage.Literals.CX_GRID_PROP_INDICATOR_STYLE__GREEN_STARTS) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CxGridStylePackage.Literals.CX_GRID_PROP_INDICATOR_STYLE__GREEN_STARTS));
			if (transientValues.isValueTransient(semanticObject, CxGridStylePackage.Literals.CX_GRID_PROP_INDICATOR_STYLE__RED_ENDS) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CxGridStylePackage.Literals.CX_GRID_PROP_INDICATOR_STYLE__RED_ENDS));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getGridPropIndicatorStyleAccess().getGreenStartsLDoubleParserRuleCall_3_0(), semanticObject.getGreenStarts());
		feeder.accept(grammarAccess.getGridPropIndicatorStyleAccess().getRedEndsLDoubleParserRuleCall_5_0(), semanticObject.getRedEnds());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     NestedField returns CxGridNestedField
	 *
	 * Constraint:
	 *     (field=[JvmOperation|ID] path=NestedPath?)
	 */
	protected void sequence_NestedField(ISerializationContext context, CxGridNestedField semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     NestedPath returns CxGridNestedPath
	 *
	 * Constraint:
	 *     (field=[JvmOperation|ID] path=NestedPath?)
	 */
	protected void sequence_NestedPath(ISerializationContext context, CxGridNestedPath semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     StyleConfig returns CxGridStyleConfigNumericToResource
	 *     NumericToResourceStyleConfig returns CxGridStyleConfigNumericToResource
	 *
	 * Constraint:
	 *     (compare=StyleCompare value=LDouble resourceThemePath=THEME_RESOURCE)
	 */
	protected void sequence_NumericToResourceStyleConfig(ISerializationContext context, CxGridStyleConfigNumericToResource semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, CxGridStylePackage.Literals.CX_GRID_STYLE_CONFIG_NUMERIC_TO_RESOURCE__COMPARE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CxGridStylePackage.Literals.CX_GRID_STYLE_CONFIG_NUMERIC_TO_RESOURCE__COMPARE));
			if (transientValues.isValueTransient(semanticObject, CxGridStylePackage.Literals.CX_GRID_STYLE_CONFIG_NUMERIC_TO_RESOURCE__VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CxGridStylePackage.Literals.CX_GRID_STYLE_CONFIG_NUMERIC_TO_RESOURCE__VALUE));
			if (transientValues.isValueTransient(semanticObject, CxGridStylePackage.Literals.CX_GRID_STYLE_CONFIG_NUMERIC_TO_RESOURCE__RESOURCE_THEME_PATH) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CxGridStylePackage.Literals.CX_GRID_STYLE_CONFIG_NUMERIC_TO_RESOURCE__RESOURCE_THEME_PATH));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getNumericToResourceStyleConfigAccess().getCompareStyleCompareEnumRuleCall_1_0(), semanticObject.getCompare());
		feeder.accept(grammarAccess.getNumericToResourceStyleConfigAccess().getValueLDoubleParserRuleCall_2_0(), semanticObject.getValue());
		feeder.accept(grammarAccess.getNumericToResourceStyleConfigAccess().getResourceThemePathTHEME_RESOURCETerminalRuleCall_4_0(), semanticObject.getResourceThemePath());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     PropertyStyle returns CxGridPropBlobImageStyle
	 *     PropertyBlobImageStyle returns CxGridPropBlobImageStyle
	 *
	 * Constraint:
	 *     {CxGridPropBlobImageStyle}
	 */
	protected void sequence_PropertyBlobImageStyle(ISerializationContext context, CxGridPropBlobImageStyle semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     PropertyStyle returns CxGridPropBooleanStyle
	 *     PropertyBooleanStyle returns CxGridPropBooleanStyle
	 *
	 * Constraint:
	 *     {CxGridPropBooleanStyle}
	 */
	protected void sequence_PropertyBooleanStyle(ISerializationContext context, CxGridPropBooleanStyle semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     PropertyStyle returns CxGridPropButtonStyle
	 *     PropertyButtonStyle returns CxGridPropButtonStyle
	 *
	 * Constraint:
	 *     eventTopic=STRING
	 */
	protected void sequence_PropertyButtonStyle(ISerializationContext context, CxGridPropButtonStyle semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, CxGridStylePackage.Literals.CX_GRID_EVENT_TOPIC_ABLE__EVENT_TOPIC) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CxGridStylePackage.Literals.CX_GRID_EVENT_TOPIC_ABLE__EVENT_TOPIC));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getPropertyButtonStyleAccess().getEventTopicSTRINGTerminalRuleCall_3_0(), semanticObject.getEventTopic());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     PropertyStyle returns CxGridPropDateStyle
	 *     PropertyDateStyle returns CxGridPropDateStyle
	 *
	 * Constraint:
	 *     dateFormat=STRING
	 */
	protected void sequence_PropertyDateStyle(ISerializationContext context, CxGridPropDateStyle semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, CxGridStylePackage.Literals.CX_GRID_PROP_DATE_STYLE__DATE_FORMAT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CxGridStylePackage.Literals.CX_GRID_PROP_DATE_STYLE__DATE_FORMAT));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getPropertyDateStyleAccess().getDateFormatSTRINGTerminalRuleCall_3_0(), semanticObject.getDateFormat());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     PropertyStyle returns CxGridPropHtmlStyle
	 *     PropertyHtmlStyle returns CxGridPropHtmlStyle
	 *
	 * Constraint:
	 *     {CxGridPropHtmlStyle}
	 */
	protected void sequence_PropertyHtmlStyle(ISerializationContext context, CxGridPropHtmlStyle semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     PropertyStyle returns CxGridPropImageStyle
	 *     PropertyImageStyle returns CxGridPropImageStyle
	 *
	 * Constraint:
	 *     (eventTopic=STRING? configs+=StyleConfig*)
	 */
	protected void sequence_PropertyImageStyle(ISerializationContext context, CxGridPropImageStyle semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     PropertyStyle returns CxGridPropNumberStyle
	 *     PropertyNumberStyle returns CxGridPropNumberStyle
	 *
	 * Constraint:
	 *     numberFormat=STRING
	 */
	protected void sequence_PropertyNumberStyle(ISerializationContext context, CxGridPropNumberStyle semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, CxGridStylePackage.Literals.CX_GRID_PROP_NUMBER_STYLE__NUMBER_FORMAT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CxGridStylePackage.Literals.CX_GRID_PROP_NUMBER_STYLE__NUMBER_FORMAT));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getPropertyNumberStyleAccess().getNumberFormatSTRINGTerminalRuleCall_3_0(), semanticObject.getNumberFormat());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     PropertyPriceStyle returns CxGridPropPriceStyle
	 *
	 * Constraint:
	 *     (htmlPattern=STRING? valuePropertyPath=NestedField valueNumberFormat=STRING? currencyPropertyPath=NestedField)
	 */
	protected void sequence_PropertyPriceStyle(ISerializationContext context, CxGridPropPriceStyle semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     PropertyStyle returns CxGridPropProgressbarStyle
	 *     PropertyProgressbarStyle returns CxGridPropProgressbarStyle
	 *
	 * Constraint:
	 *     maxValue=LDouble
	 */
	protected void sequence_PropertyProgressbarStyle(ISerializationContext context, CxGridPropProgressbarStyle semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, CxGridStylePackage.Literals.CX_GRID_PROP_PROGRESSBAR_STYLE__MAX_VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CxGridStylePackage.Literals.CX_GRID_PROP_PROGRESSBAR_STYLE__MAX_VALUE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getPropertyProgressbarStyleAccess().getMaxValueLDoubleParserRuleCall_3_0(), semanticObject.getMaxValue());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     PropertyQuantityStyle returns CxGridPropQuantityStyle
	 *
	 * Constraint:
	 *     (htmlPattern=STRING? valuePropertyPath=NestedField valueNumberFormat=STRING? uomPropertyPath=NestedField)
	 */
	protected void sequence_PropertyQuantityStyle(ISerializationContext context, CxGridPropQuantityStyle semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     PropertyStyle returns CxGridPropTextStyle
	 *     PropertyTextStyle returns CxGridPropTextStyle
	 *
	 * Constraint:
	 *     {CxGridPropTextStyle}
	 */
	protected void sequence_PropertyTextStyle(ISerializationContext context, CxGridPropTextStyle semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     Property returns CxGridProperty
	 *
	 * Constraint:
	 *     (editable?='editable'? path=NestedField style=PropertyStyle)
	 */
	protected void sequence_Property(ISerializationContext context, CxGridProperty semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     StyleConfig returns CxGridStyleConfigStringToResource
	 *     StringToResourceStyleConfig returns CxGridStyleConfigStringToResource
	 *
	 * Constraint:
	 *     (compare=StyleCompare value=STRING resourceThemePath=THEME_RESOURCE)
	 */
	protected void sequence_StringToResourceStyleConfig(ISerializationContext context, CxGridStyleConfigStringToResource semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, CxGridStylePackage.Literals.CX_GRID_STYLE_CONFIG_STRING_TO_RESOURCE__COMPARE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CxGridStylePackage.Literals.CX_GRID_STYLE_CONFIG_STRING_TO_RESOURCE__COMPARE));
			if (transientValues.isValueTransient(semanticObject, CxGridStylePackage.Literals.CX_GRID_STYLE_CONFIG_STRING_TO_RESOURCE__VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CxGridStylePackage.Literals.CX_GRID_STYLE_CONFIG_STRING_TO_RESOURCE__VALUE));
			if (transientValues.isValueTransient(semanticObject, CxGridStylePackage.Literals.CX_GRID_STYLE_CONFIG_STRING_TO_RESOURCE__RESOURCE_THEME_PATH) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, CxGridStylePackage.Literals.CX_GRID_STYLE_CONFIG_STRING_TO_RESOURCE__RESOURCE_THEME_PATH));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getStringToResourceStyleConfigAccess().getCompareStyleCompareEnumRuleCall_1_0(), semanticObject.getCompare());
		feeder.accept(grammarAccess.getStringToResourceStyleConfigAccess().getValueSTRINGTerminalRuleCall_2_0(), semanticObject.getValue());
		feeder.accept(grammarAccess.getStringToResourceStyleConfigAccess().getResourceThemePathTHEME_RESOURCETerminalRuleCall_4_0(), semanticObject.getResourceThemePath());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableValueElement returns TableAggregation
	 *     TableAggregation returns TableAggregation
	 *
	 * Constraint:
	 *     valueRef=[DatamartSetAggregationFunction|ID]
	 */
	protected void sequence_TableAggregation(ISerializationContext context, TableAggregation semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_AGGREGATION__VALUE_REF) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_AGGREGATION__VALUE_REF));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableAggregationAccess().getValueRefDatamartSetAggregationFunctionIDTerminalRuleCall_1_0_1(), semanticObject.eGet(TableDSLPackage.Literals.TABLE_AGGREGATION__VALUE_REF, false));
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableValueElement returns TableAllColumns
	 *     TableAllColumns returns TableAllColumns
	 *
	 * Constraint:
	 *     {TableAllColumns}
	 */
	protected void sequence_TableAllColumns(ISerializationContext context, TableAllColumns semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     TableValueElement returns TableAttribute
	 *     TableAttribute returns TableAttribute
	 *
	 * Constraint:
	 *     valueRef=[DatamartAttribute|ID]
	 */
	protected void sequence_TableAttribute(ISerializationContext context, TableAttribute semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_ATTRIBUTE__VALUE_REF) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_ATTRIBUTE__VALUE_REF));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableAttributeAccess().getValueRefDatamartAttributeIDTerminalRuleCall_2_0_1(), semanticObject.eGet(TableDSLPackage.Literals.TABLE_ATTRIBUTE__VALUE_REF, false));
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableElement returns TableAxis
	 *     TableAxis returns TableAxis
	 *
	 * Constraint:
	 *     (
	 *         axis=AxisEnum 
	 *         (preOrder=TablePreorder? (hasRowHeight?='rowheight' rowHeight=Number)?)+ 
	 *         (hasDetails?='details' values+=TableValue*)? 
	 *         (hasEvents?='notifyOnSelect' events+=TableEvent*)?
	 *     )
	 */
	protected void sequence_TableAxis(ISerializationContext context, TableAxis semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     TableRangeElement returns TableCellColor
	 *     TableCellColor returns TableCellColor
	 *
	 * Constraint:
	 *     rgb=STRING
	 */
	protected void sequence_TableCellColor(ISerializationContext context, TableCellColor semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_CELL_COLOR__RGB) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_CELL_COLOR__RGB));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableCellColorAccess().getRgbSTRINGTerminalRuleCall_1_0(), semanticObject.getRgb());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableValueElement returns TableColumn
	 *     TableColumn returns TableColumn
	 *
	 * Constraint:
	 *     valueRef=[DatamartColumn|ID]
	 */
	protected void sequence_TableColumn(ISerializationContext context, TableColumn semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_COLUMN__VALUE_REF) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_COLUMN__VALUE_REF));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableColumnAccess().getValueRefDatamartColumnIDTerminalRuleCall_1_0_1(), semanticObject.eGet(TableDSLPackage.Literals.TABLE_COLUMN__VALUE_REF, false));
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableDatamart returns TableDatamart
	 *
	 * Constraint:
	 *     (datamartRef=[DatamartDefinition|ID] elements+=TableElement*)
	 */
	protected void sequence_TableDatamart(ISerializationContext context, TableDatamart semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     TableInterval returns TableDateDayInterval
	 *     TableDateDayInterval returns TableDateDayInterval
	 *
	 * Constraint:
	 *     (dateIntervalValue=SignedInt dateRange=TableRangeElement)
	 */
	protected void sequence_TableDateDayInterval(ISerializationContext context, TableDateDayInterval semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_DATE_DAY_INTERVAL__DATE_INTERVAL_VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_DATE_DAY_INTERVAL__DATE_INTERVAL_VALUE));
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_DATE_DAY_INTERVAL__DATE_RANGE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_DATE_DAY_INTERVAL__DATE_RANGE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableDateDayIntervalAccess().getDateIntervalValueSignedIntParserRuleCall_2_0(), semanticObject.getDateIntervalValue());
		feeder.accept(grammarAccess.getTableDateDayIntervalAccess().getDateRangeTableRangeElementParserRuleCall_3_0(), semanticObject.getDateRange());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableLookup returns TableDateDayLookup
	 *     TableDateDayLookup returns TableDateDayLookup
	 *
	 * Constraint:
	 *     (lookupValue=SignedInt discrete=TableRangeElement)
	 */
	protected void sequence_TableDateDayLookup(ISerializationContext context, TableDateDayLookup semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_DATE_DAY_LOOKUP__LOOKUP_VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_DATE_DAY_LOOKUP__LOOKUP_VALUE));
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_DATE_DAY_LOOKUP__DISCRETE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_DATE_DAY_LOOKUP__DISCRETE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableDateDayLookupAccess().getLookupValueSignedIntParserRuleCall_2_0(), semanticObject.getLookupValue());
		feeder.accept(grammarAccess.getTableDateDayLookupAccess().getDiscreteTableRangeElementParserRuleCall_3_0(), semanticObject.getDiscrete());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableValueElement returns TableDerived
	 *     TableDerived returns TableDerived
	 *
	 * Constraint:
	 *     valueRef=[DatamartDerivedMeasure|ID]
	 */
	protected void sequence_TableDerived(ISerializationContext context, TableDerived semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_DERIVED__VALUE_REF) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_DERIVED__VALUE_REF));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableDerivedAccess().getValueRefDatamartDerivedMeasureIDTerminalRuleCall_1_0_1(), semanticObject.eGet(TableDSLPackage.Literals.TABLE_DERIVED__VALUE_REF, false));
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableDtoDatasource returns TableDtoDatasource
	 *
	 * Constraint:
	 *     (dtoSource=[LDto|ID] properties+=Property*)
	 */
	protected void sequence_TableDtoDatasource(ISerializationContext context, TableDtoDatasource semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     TableEvent returns TableEvent
	 *
	 * Constraint:
	 *     source=TableValueElement
	 */
	protected void sequence_TableEvent(ISerializationContext context, TableEvent semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_EVENT__SOURCE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_EVENT__SOURCE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableEventAccess().getSourceTableValueElementParserRuleCall_0(), semanticObject.getSource());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableFormatter returns TableFormatter
	 *
	 * Constraint:
	 *     format=STRING
	 */
	protected void sequence_TableFormatter(ISerializationContext context, TableFormatter semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_FORMATTER__FORMAT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_FORMATTER__FORMAT));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableFormatterAccess().getFormatSTRINGTerminalRuleCall_2_0(), semanticObject.getFormat());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableOption returns TableGrid
	 *     TableGrid returns TableGrid
	 *
	 * Constraint:
	 *     source=TableDtoDatasource
	 */
	protected void sequence_TableGrid(ISerializationContext context, TableGrid semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_GRID__SOURCE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_GRID__SOURCE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableGridAccess().getSourceTableDtoDatasourceParserRuleCall_3_0(), semanticObject.getSource());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableValueElement returns TableHierarchy
	 *     TableHierarchy returns TableHierarchy
	 *
	 * Constraint:
	 *     valueRef=[CubeLevel|ID]
	 */
	protected void sequence_TableHierarchy(ISerializationContext context, TableHierarchy semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_HIERARCHY__VALUE_REF) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_HIERARCHY__VALUE_REF));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableHierarchyAccess().getValueRefCubeLevelIDTerminalRuleCall_1_0_1(), semanticObject.eGet(TableDSLPackage.Literals.TABLE_HIERARCHY__VALUE_REF, false));
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableRangeElement returns TableIcon
	 *     TableIcon returns TableIcon
	 *
	 * Constraint:
	 *     icon=STRING
	 */
	protected void sequence_TableIcon(ISerializationContext context, TableIcon semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_ICON__ICON) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_ICON__ICON));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableIconAccess().getIconSTRINGTerminalRuleCall_1_0(), semanticObject.getIcon());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableImage returns TableImage
	 *
	 * Constraint:
	 *     (imagePathPattern=STRING ((hasParameter?='dynamic' | hideImageLabel?='hidelabel')? (resize?='resize' resizeString=STRING)?)+)
	 */
	protected void sequence_TableImage(ISerializationContext context, TableImage semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     TableInterval returns TableIntInterval
	 *     TableIntInterval returns TableIntInterval
	 *
	 * Constraint:
	 *     (intIntervalValue=SignedInt intRange=TableRangeElement)
	 */
	protected void sequence_TableIntInterval(ISerializationContext context, TableIntInterval semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_INT_INTERVAL__INT_INTERVAL_VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_INT_INTERVAL__INT_INTERVAL_VALUE));
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_INT_INTERVAL__INT_RANGE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_INT_INTERVAL__INT_RANGE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableIntIntervalAccess().getIntIntervalValueSignedIntParserRuleCall_2_0(), semanticObject.getIntIntervalValue());
		feeder.accept(grammarAccess.getTableIntIntervalAccess().getIntRangeTableRangeElementParserRuleCall_3_0(), semanticObject.getIntRange());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableLookup returns TableIntLookup
	 *     TableIntLookup returns TableIntLookup
	 *
	 * Constraint:
	 *     (lookupValue=SignedInt discrete=TableRangeElement)
	 */
	protected void sequence_TableIntLookup(ISerializationContext context, TableIntLookup semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_INT_LOOKUP__LOOKUP_VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_INT_LOOKUP__LOOKUP_VALUE));
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_INT_LOOKUP__DISCRETE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_INT_LOOKUP__DISCRETE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableIntLookupAccess().getLookupValueSignedIntParserRuleCall_2_0(), semanticObject.getLookupValue());
		feeder.accept(grammarAccess.getTableIntLookupAccess().getDiscreteTableRangeElementParserRuleCall_3_0(), semanticObject.getDiscrete());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableValueElement returns TableMeasure
	 *     TableMeasure returns TableMeasure
	 *
	 * Constraint:
	 *     valueRef=[DatamartMeasure|ID]
	 */
	protected void sequence_TableMeasure(ISerializationContext context, TableMeasure semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_MEASURE__VALUE_REF) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_MEASURE__VALUE_REF));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableMeasureAccess().getValueRefDatamartMeasureIDTerminalRuleCall_1_0_1(), semanticObject.eGet(TableDSLPackage.Literals.TABLE_MEASURE__VALUE_REF, false));
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableModel returns TableModel
	 *
	 * Constraint:
	 *     ((importSection=XImportSection packages+=TablePackage+) | packages+=TablePackage+)?
	 */
	protected void sequence_TableModel(ISerializationContext context, TableModel semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     TableInterval returns TableNumberInterval
	 *     TableNumberInterval returns TableNumberInterval
	 *
	 * Constraint:
	 *     (numberIntervalValue=SignedNumber numberRange=TableRangeElement)
	 */
	protected void sequence_TableNumberInterval(ISerializationContext context, TableNumberInterval semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_NUMBER_INTERVAL__NUMBER_INTERVAL_VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_NUMBER_INTERVAL__NUMBER_INTERVAL_VALUE));
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_NUMBER_INTERVAL__NUMBER_RANGE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_NUMBER_INTERVAL__NUMBER_RANGE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableNumberIntervalAccess().getNumberIntervalValueSignedNumberParserRuleCall_2_0(), semanticObject.getNumberIntervalValue());
		feeder.accept(grammarAccess.getTableNumberIntervalAccess().getNumberRangeTableRangeElementParserRuleCall_3_0(), semanticObject.getNumberRange());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableLookup returns TableNumberLookup
	 *     TableNumberLookup returns TableNumberLookup
	 *
	 * Constraint:
	 *     (lookupValue=SignedNumber discrete=TableRangeElement)
	 */
	protected void sequence_TableNumberLookup(ISerializationContext context, TableNumberLookup semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_NUMBER_LOOKUP__LOOKUP_VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_NUMBER_LOOKUP__LOOKUP_VALUE));
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_NUMBER_LOOKUP__DISCRETE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_NUMBER_LOOKUP__DISCRETE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableNumberLookupAccess().getLookupValueSignedNumberParserRuleCall_2_0(), semanticObject.getLookupValue());
		feeder.accept(grammarAccess.getTableNumberLookupAccess().getDiscreteTableRangeElementParserRuleCall_3_0(), semanticObject.getDiscrete());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableValueElement returns TableOrdinal
	 *     TableOrdinal returns TableOrdinal
	 *
	 * Constraint:
	 *     valueRef=Number
	 */
	protected void sequence_TableOrdinal(ISerializationContext context, TableOrdinal semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_ORDINAL__VALUE_REF) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_ORDINAL__VALUE_REF));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableOrdinalAccess().getValueRefNumberParserRuleCall_1_0(), semanticObject.getValueRef());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TablePackage returns TablePackage
	 *
	 * Constraint:
	 *     (name=QualifiedName tables+=Table*)
	 */
	protected void sequence_TablePackage(ISerializationContext context, TablePackage semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     TablePreorder returns TablePreorder
	 *
	 * Constraint:
	 *     (column=TableValueElement ascending?='ascending'?)
	 */
	protected void sequence_TablePreorder(ISerializationContext context, TablePreorder semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     TableOption returns TableSelection
	 *     TableSelection returns TableSelection
	 *
	 * Constraint:
	 *     (
	 *         multiSelection?='multiple'? 
	 *         (selectalways?='alwaysSelected' | headerMode=RowHeaderMode | filtering?='filtering' | embedded?='embedded' | toolbar=[ActionToolbar|ID])* 
	 *         source=TableDatamart?
	 *     )
	 */
	protected void sequence_TableSelection(ISerializationContext context, TableSelection semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     TableLookup returns TableStringLookup
	 *     TableStringLookup returns TableStringLookup
	 *
	 * Constraint:
	 *     (lookupValue=STRING discrete=TableRangeElement)
	 */
	protected void sequence_TableStringLookup(ISerializationContext context, TableStringLookup semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_STRING_LOOKUP__LOOKUP_VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_STRING_LOOKUP__LOOKUP_VALUE));
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_STRING_LOOKUP__DISCRETE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_STRING_LOOKUP__DISCRETE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableStringLookupAccess().getLookupValueSTRINGTerminalRuleCall_2_0(), semanticObject.getLookupValue());
		feeder.accept(grammarAccess.getTableStringLookupAccess().getDiscreteTableRangeElementParserRuleCall_3_0(), semanticObject.getDiscrete());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableOption returns TableTable
	 *     TableTable returns TableTable
	 *
	 * Constraint:
	 *     (
	 *         (
	 *             selectalways?='alwaysSelected' | 
	 *             selectById?='selectById' | 
	 *             headerMode=RowHeaderMode | 
	 *             filtering?='filtering' | 
	 *             embedded?='embedded' | 
	 *             toolbar=[ActionToolbar|ID]
	 *         )* 
	 *         source=TableDatamart?
	 *     )
	 */
	protected void sequence_TableTable(ISerializationContext context, TableTable semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     TableValueElement returns TableTask
	 *     TableTask returns TableTask
	 *
	 * Constraint:
	 *     {TableTask}
	 */
	protected void sequence_TableTask(ISerializationContext context, TableTask semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     TableRangeElement returns TableTextColor
	 *     TableTextColor returns TableTextColor
	 *
	 * Constraint:
	 *     rgb=STRING
	 */
	protected void sequence_TableTextColor(ISerializationContext context, TableTextColor semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_TEXT_COLOR__RGB) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_TEXT_COLOR__RGB));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableTextColorAccess().getRgbSTRINGTerminalRuleCall_1_0(), semanticObject.getRgb());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableTooltipPattern returns TableTooltipPattern
	 *
	 * Constraint:
	 *     tooltipPattern=TRANSLATABLESTRING
	 */
	protected void sequence_TableTooltipPattern(ISerializationContext context, TableTooltipPattern semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_TOOLTIP_PATTERN__TOOLTIP_PATTERN) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_TOOLTIP_PATTERN__TOOLTIP_PATTERN));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableTooltipPatternAccess().getTooltipPatternTRANSLATABLESTRINGParserRuleCall_2_0(), semanticObject.getTooltipPattern());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableRangeElement returns TableTooltip
	 *     TableTooltip returns TableTooltip
	 *
	 * Constraint:
	 *     tooltip=TRANSLATABLESTRING
	 */
	protected void sequence_TableTooltip(ISerializationContext context, TableTooltip semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_TOOLTIP__TOOLTIP) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_TOOLTIP__TOOLTIP));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableTooltipAccess().getTooltipTRANSLATABLESTRINGParserRuleCall_1_0(), semanticObject.getTooltip());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableRangeElement returns TableTrend
	 *     TableTrend returns TableTrend
	 *
	 * Constraint:
	 *     icon=TrendIconEnum
	 */
	protected void sequence_TableTrend(ISerializationContext context, TableTrend semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, TableDSLPackage.Literals.TABLE_TREND__ICON) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, TableDSLPackage.Literals.TABLE_TREND__ICON));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getTableTrendAccess().getIconTrendIconEnumEnumRuleCall_1_0(), semanticObject.getIcon());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     TableValue returns TableValue
	 *
	 * Constraint:
	 *     (
	 *         column=TableValueElement 
	 *         (
	 *             (collapsed?='collapse' | iconName=STRING | formatter=TableFormatter | tooltipPattern=TableTooltipPattern)? 
	 *             (hasImage?='image' image=TableImage)?
	 *         )+ 
	 *         hideLabelInterval?='hidelabel'? 
	 *         ((intervals+=TableInterval | hideLabelLookup?='hidelabel' | lookups+=TableLookup)? hideLabelInterval?='hidelabel'?)*
	 *     )
	 */
	protected void sequence_TableValue(ISerializationContext context, TableValue semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     Table returns Table
	 *
	 * Constraint:
	 *     (name=ID (description?='describedBy' descriptionValue=TRANSLATABLESTRING)? tabletype=TableOption)
	 */
	protected void sequence_Table(ISerializationContext context, Table semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
}
