/**
 *                                                                            
 * Copyright (c) 2011, 2016 - Loetz GmbH&Co.KG (69115 Heidelberg, Germany)
 *                                                                            
 * All rights reserved. This program and the accompanying materials           
 * are made available under the terms of the Eclipse Public License 2.0        
 * which accompanies this distribution, and is available at                  
 * https://www.eclipse.org/legal/epl-2.0/                                 
 *                                 
 * SPDX-License-Identifier: EPL-2.0                                 
 *                                                                            
 * Contributors:   
 * Christophe Loetz (Loetz GmbH&Co.KG) - initial implementation 
 */
package org.eclipse.osbp.xtext.table.parser.antlr.internal;

import org.eclipse.xtext.*;
import org.eclipse.xtext.parser.*;
import org.eclipse.xtext.parser.impl.*;
import org.eclipse.emf.ecore.util.EcoreUtil;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.common.util.Enumerator;
import org.eclipse.xtext.parser.antlr.AbstractInternalAntlrParser;
import org.eclipse.xtext.parser.antlr.XtextTokenStream;
import org.eclipse.xtext.parser.antlr.XtextTokenStream.HiddenTokens;
import org.eclipse.xtext.parser.antlr.AntlrDatatypeRuleToken;
import org.eclipse.osbp.xtext.table.services.TableDSLGrammarAccess;



import org.antlr.runtime.*;
import java.util.Stack;
import java.util.List;
import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
@SuppressWarnings("all")
public class InternalTableDSLParser extends AbstractInternalAntlrParser {
    public static final String[] tokenNames = new String[] {
        "<invalid>", "<EOR>", "<DOWN>", "<UP>", "RULE_ID", "RULE_STRING", "RULE_THEME_RESOURCE", "RULE_INT", "RULE_HEX", "RULE_DECIMAL", "RULE_EVENT_TOPIC", "RULE_ML_COMMENT", "RULE_SL_COMMENT", "RULE_WS", "RULE_ANY_OTHER", "'package'", "'{'", "'}'", "'table'", "'describedBy'", "'as'", "'selection'", "'multiple'", "'single'", "'alwaysSelected'", "'rowHeader'", "'filtering'", "'embedded'", "'toolbar'", "'using'", "'readOnly'", "'selectById'", "'preorder'", "'ascending'", "'value'", "'collapse'", "'icon'", "'image'", "'intervals'", "'hidelabel'", "'lookups'", "'formatter'", "'path'", "'dynamic'", "'resize'", "'tooltipPattern'", "'taskId'", "'allColumns'", "'ordinal'", "'column'", "'measure'", "'derived'", "'level'", "'property'", "'aggregation'", "'upToNumber'", "'upToInteger'", "'daysInPast'", "'integer'", "'number'", "'string'", "'datamart'", "'axis'", "'rowheight'", "'details'", "'notifyOnSelect'", "'textcolor'", "'cellcolor'", "'trend'", "'tooltip'", "'editable'", "'prop'", "'style'", "'dto'", "'.'", "'buttonStyle'", "'eventTopic'", "'htmlStyle'", "'boolStyle'", "'dateStyle'", "'format'", "'numberStyle'", "'progressbarStyle'", "'max'", "'indicatorStyle'", "'greenFrom'", "'redUntil'", "'textStyle'", "'blobImageStyle'", "'imageStyle'", "'then'", "'+'", "'-'", "'import'", "'static'", "'extension'", "'*'", "'ns'", "';'", "'@'", "'('", "','", "')'", "'='", "'#'", "'['", "']'", "'+='", "'-='", "'*='", "'/='", "'%='", "'<'", "'>'", "'>='", "'||'", "'&&'", "'=='", "'!='", "'==='", "'!=='", "'instanceof'", "'->'", "'..<'", "'..'", "'=>'", "'<>'", "'?:'", "'**'", "'/'", "'%'", "'!'", "'++'", "'--'", "'::'", "'?.'", "'|'", "'if'", "'else'", "'switch'", "':'", "'default'", "'case'", "'for'", "'while'", "'do'", "'var'", "'val'", "'extends'", "'super'", "'new'", "'false'", "'true'", "'null'", "'typeof'", "'throw'", "'return'", "'try'", "'finally'", "'synchronized'", "'catch'", "'?'", "'&'", "'equal'", "'greater equal'", "'greater than'", "'lower equal'", "'lower than'", "'not equal'", "'rising'", "'bad-rising'", "'sloping'", "'good-sloping'", "'stagnating'", "'hidden'", "'explicit'", "'indexed'", "'columns'", "'rows'", "'pages'", "'sections'", "'chapters'"
    };
    public static final int T__144=144;
    public static final int T__143=143;
    public static final int T__146=146;
    public static final int RULE_HEX=8;
    public static final int T__50=50;
    public static final int T__145=145;
    public static final int T__140=140;
    public static final int T__142=142;
    public static final int T__141=141;
    public static final int T__59=59;
    public static final int T__55=55;
    public static final int T__56=56;
    public static final int T__57=57;
    public static final int T__58=58;
    public static final int T__51=51;
    public static final int T__137=137;
    public static final int T__52=52;
    public static final int T__136=136;
    public static final int T__53=53;
    public static final int T__139=139;
    public static final int T__54=54;
    public static final int T__138=138;
    public static final int T__133=133;
    public static final int T__132=132;
    public static final int T__60=60;
    public static final int T__135=135;
    public static final int T__61=61;
    public static final int T__134=134;
    public static final int RULE_ID=4;
    public static final int T__131=131;
    public static final int T__130=130;
    public static final int RULE_EVENT_TOPIC=10;
    public static final int RULE_INT=7;
    public static final int T__66=66;
    public static final int RULE_ML_COMMENT=11;
    public static final int T__67=67;
    public static final int T__129=129;
    public static final int T__68=68;
    public static final int T__69=69;
    public static final int T__62=62;
    public static final int T__126=126;
    public static final int T__63=63;
    public static final int T__125=125;
    public static final int T__64=64;
    public static final int T__128=128;
    public static final int T__65=65;
    public static final int T__127=127;
    public static final int T__166=166;
    public static final int T__165=165;
    public static final int T__168=168;
    public static final int T__167=167;
    public static final int T__162=162;
    public static final int T__161=161;
    public static final int T__164=164;
    public static final int T__163=163;
    public static final int T__160=160;
    public static final int T__37=37;
    public static final int T__38=38;
    public static final int T__39=39;
    public static final int T__33=33;
    public static final int T__34=34;
    public static final int T__35=35;
    public static final int T__36=36;
    public static final int T__159=159;
    public static final int T__30=30;
    public static final int T__158=158;
    public static final int T__31=31;
    public static final int T__32=32;
    public static final int T__155=155;
    public static final int T__154=154;
    public static final int T__157=157;
    public static final int T__156=156;
    public static final int T__151=151;
    public static final int T__150=150;
    public static final int T__153=153;
    public static final int T__152=152;
    public static final int T__48=48;
    public static final int T__49=49;
    public static final int T__44=44;
    public static final int T__45=45;
    public static final int T__46=46;
    public static final int T__47=47;
    public static final int RULE_THEME_RESOURCE=6;
    public static final int T__40=40;
    public static final int T__148=148;
    public static final int T__41=41;
    public static final int T__147=147;
    public static final int T__42=42;
    public static final int T__43=43;
    public static final int T__149=149;
    public static final int T__91=91;
    public static final int T__100=100;
    public static final int T__92=92;
    public static final int T__93=93;
    public static final int T__102=102;
    public static final int T__94=94;
    public static final int T__101=101;
    public static final int T__90=90;
    public static final int T__180=180;
    public static final int T__181=181;
    public static final int T__19=19;
    public static final int T__15=15;
    public static final int T__16=16;
    public static final int T__17=17;
    public static final int T__18=18;
    public static final int T__99=99;
    public static final int T__95=95;
    public static final int T__96=96;
    public static final int T__97=97;
    public static final int T__98=98;
    public static final int T__177=177;
    public static final int T__176=176;
    public static final int T__179=179;
    public static final int T__178=178;
    public static final int T__173=173;
    public static final int T__172=172;
    public static final int T__175=175;
    public static final int T__174=174;
    public static final int T__171=171;
    public static final int T__170=170;
    public static final int RULE_DECIMAL=9;
    public static final int T__26=26;
    public static final int T__27=27;
    public static final int T__28=28;
    public static final int T__29=29;
    public static final int T__22=22;
    public static final int T__23=23;
    public static final int T__24=24;
    public static final int T__25=25;
    public static final int T__169=169;
    public static final int T__20=20;
    public static final int T__21=21;
    public static final int T__122=122;
    public static final int T__70=70;
    public static final int T__121=121;
    public static final int T__71=71;
    public static final int T__124=124;
    public static final int T__72=72;
    public static final int T__123=123;
    public static final int T__120=120;
    public static final int RULE_STRING=5;
    public static final int RULE_SL_COMMENT=12;
    public static final int T__77=77;
    public static final int T__119=119;
    public static final int T__78=78;
    public static final int T__118=118;
    public static final int T__79=79;
    public static final int T__73=73;
    public static final int T__115=115;
    public static final int EOF=-1;
    public static final int T__74=74;
    public static final int T__114=114;
    public static final int T__75=75;
    public static final int T__117=117;
    public static final int T__76=76;
    public static final int T__116=116;
    public static final int T__80=80;
    public static final int T__111=111;
    public static final int T__81=81;
    public static final int T__110=110;
    public static final int T__82=82;
    public static final int T__113=113;
    public static final int T__83=83;
    public static final int T__112=112;
    public static final int RULE_WS=13;
    public static final int RULE_ANY_OTHER=14;
    public static final int T__88=88;
    public static final int T__108=108;
    public static final int T__89=89;
    public static final int T__107=107;
    public static final int T__109=109;
    public static final int T__84=84;
    public static final int T__104=104;
    public static final int T__85=85;
    public static final int T__103=103;
    public static final int T__86=86;
    public static final int T__106=106;
    public static final int T__87=87;
    public static final int T__105=105;

    // delegates
    // delegators


        public InternalTableDSLParser(TokenStream input) {
            this(input, new RecognizerSharedState());
        }
        public InternalTableDSLParser(TokenStream input, RecognizerSharedState state) {
            super(input, state);
             
        }
        

    public String[] getTokenNames() { return InternalTableDSLParser.tokenNames; }
    public String getGrammarFileName() { return "InternalTableDSL.g"; }



     	private TableDSLGrammarAccess grammarAccess;

        public InternalTableDSLParser(TokenStream input, TableDSLGrammarAccess grammarAccess) {
            this(input);
            this.grammarAccess = grammarAccess;
            registerRules(grammarAccess.getGrammar());
        }

        @Override
        protected String getFirstRuleName() {
        	return "TableModel";
       	}

       	@Override
       	protected TableDSLGrammarAccess getGrammarAccess() {
       		return grammarAccess;
       	}




    // $ANTLR start "entryRuleTableModel"
    // InternalTableDSL.g:65:1: entryRuleTableModel returns [EObject current=null] : iv_ruleTableModel= ruleTableModel EOF ;
    public final EObject entryRuleTableModel() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableModel = null;


        try {
            // InternalTableDSL.g:65:51: (iv_ruleTableModel= ruleTableModel EOF )
            // InternalTableDSL.g:66:2: iv_ruleTableModel= ruleTableModel EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableModelRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableModel=ruleTableModel();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableModel; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableModel"


    // $ANTLR start "ruleTableModel"
    // InternalTableDSL.g:72:1: ruleTableModel returns [EObject current=null] : ( ( (lv_importSection_0_0= ruleXImportSection ) )? ( (lv_packages_1_0= ruleTablePackage ) )* ) ;
    public final EObject ruleTableModel() throws RecognitionException {
        EObject current = null;

        EObject lv_importSection_0_0 = null;

        EObject lv_packages_1_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:78:2: ( ( ( (lv_importSection_0_0= ruleXImportSection ) )? ( (lv_packages_1_0= ruleTablePackage ) )* ) )
            // InternalTableDSL.g:79:2: ( ( (lv_importSection_0_0= ruleXImportSection ) )? ( (lv_packages_1_0= ruleTablePackage ) )* )
            {
            // InternalTableDSL.g:79:2: ( ( (lv_importSection_0_0= ruleXImportSection ) )? ( (lv_packages_1_0= ruleTablePackage ) )* )
            // InternalTableDSL.g:80:3: ( (lv_importSection_0_0= ruleXImportSection ) )? ( (lv_packages_1_0= ruleTablePackage ) )*
            {
            // InternalTableDSL.g:80:3: ( (lv_importSection_0_0= ruleXImportSection ) )?
            int alt1=2;
            int LA1_0 = input.LA(1);

            if ( (LA1_0==93) ) {
                alt1=1;
            }
            switch (alt1) {
                case 1 :
                    // InternalTableDSL.g:81:4: (lv_importSection_0_0= ruleXImportSection )
                    {
                    // InternalTableDSL.g:81:4: (lv_importSection_0_0= ruleXImportSection )
                    // InternalTableDSL.g:82:5: lv_importSection_0_0= ruleXImportSection
                    {
                    if ( state.backtracking==0 ) {

                      					newCompositeNode(grammarAccess.getTableModelAccess().getImportSectionXImportSectionParserRuleCall_0_0());
                      				
                    }
                    pushFollow(FOLLOW_3);
                    lv_importSection_0_0=ruleXImportSection();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					if (current==null) {
                      						current = createModelElementForParent(grammarAccess.getTableModelRule());
                      					}
                      					set(
                      						current,
                      						"importSection",
                      						lv_importSection_0_0,
                      						"org.eclipse.xtext.xbase.Xtype.XImportSection");
                      					afterParserOrEnumRuleCall();
                      				
                    }

                    }


                    }
                    break;

            }

            // InternalTableDSL.g:99:3: ( (lv_packages_1_0= ruleTablePackage ) )*
            loop2:
            do {
                int alt2=2;
                int LA2_0 = input.LA(1);

                if ( (LA2_0==15) ) {
                    alt2=1;
                }


                switch (alt2) {
            	case 1 :
            	    // InternalTableDSL.g:100:4: (lv_packages_1_0= ruleTablePackage )
            	    {
            	    // InternalTableDSL.g:100:4: (lv_packages_1_0= ruleTablePackage )
            	    // InternalTableDSL.g:101:5: lv_packages_1_0= ruleTablePackage
            	    {
            	    if ( state.backtracking==0 ) {

            	      					newCompositeNode(grammarAccess.getTableModelAccess().getPackagesTablePackageParserRuleCall_1_0());
            	      				
            	    }
            	    pushFollow(FOLLOW_3);
            	    lv_packages_1_0=ruleTablePackage();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      					if (current==null) {
            	      						current = createModelElementForParent(grammarAccess.getTableModelRule());
            	      					}
            	      					add(
            	      						current,
            	      						"packages",
            	      						lv_packages_1_0,
            	      						"org.eclipse.osbp.xtext.table.TableDSL.TablePackage");
            	      					afterParserOrEnumRuleCall();
            	      				
            	    }

            	    }


            	    }
            	    break;

            	default :
            	    break loop2;
                }
            } while (true);


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableModel"


    // $ANTLR start "entryRuleTablePackage"
    // InternalTableDSL.g:122:1: entryRuleTablePackage returns [EObject current=null] : iv_ruleTablePackage= ruleTablePackage EOF ;
    public final EObject entryRuleTablePackage() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTablePackage = null;


        try {
            // InternalTableDSL.g:122:53: (iv_ruleTablePackage= ruleTablePackage EOF )
            // InternalTableDSL.g:123:2: iv_ruleTablePackage= ruleTablePackage EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTablePackageRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTablePackage=ruleTablePackage();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTablePackage; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTablePackage"


    // $ANTLR start "ruleTablePackage"
    // InternalTableDSL.g:129:1: ruleTablePackage returns [EObject current=null] : ( () otherlv_1= 'package' ( (lv_name_2_0= ruleQualifiedName ) ) (otherlv_3= '{' ( (lv_tables_4_0= ruleTable ) )* otherlv_5= '}' )? ) ;
    public final EObject ruleTablePackage() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_3=null;
        Token otherlv_5=null;
        AntlrDatatypeRuleToken lv_name_2_0 = null;

        EObject lv_tables_4_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:135:2: ( ( () otherlv_1= 'package' ( (lv_name_2_0= ruleQualifiedName ) ) (otherlv_3= '{' ( (lv_tables_4_0= ruleTable ) )* otherlv_5= '}' )? ) )
            // InternalTableDSL.g:136:2: ( () otherlv_1= 'package' ( (lv_name_2_0= ruleQualifiedName ) ) (otherlv_3= '{' ( (lv_tables_4_0= ruleTable ) )* otherlv_5= '}' )? )
            {
            // InternalTableDSL.g:136:2: ( () otherlv_1= 'package' ( (lv_name_2_0= ruleQualifiedName ) ) (otherlv_3= '{' ( (lv_tables_4_0= ruleTable ) )* otherlv_5= '}' )? )
            // InternalTableDSL.g:137:3: () otherlv_1= 'package' ( (lv_name_2_0= ruleQualifiedName ) ) (otherlv_3= '{' ( (lv_tables_4_0= ruleTable ) )* otherlv_5= '}' )?
            {
            // InternalTableDSL.g:137:3: ()
            // InternalTableDSL.g:138:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTablePackageAccess().getTablePackageAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,15,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTablePackageAccess().getPackageKeyword_1());
              		
            }
            // InternalTableDSL.g:148:3: ( (lv_name_2_0= ruleQualifiedName ) )
            // InternalTableDSL.g:149:4: (lv_name_2_0= ruleQualifiedName )
            {
            // InternalTableDSL.g:149:4: (lv_name_2_0= ruleQualifiedName )
            // InternalTableDSL.g:150:5: lv_name_2_0= ruleQualifiedName
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTablePackageAccess().getNameQualifiedNameParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_5);
            lv_name_2_0=ruleQualifiedName();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTablePackageRule());
              					}
              					set(
              						current,
              						"name",
              						lv_name_2_0,
              						"org.eclipse.xtext.xbase.Xbase.QualifiedName");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:167:3: (otherlv_3= '{' ( (lv_tables_4_0= ruleTable ) )* otherlv_5= '}' )?
            int alt4=2;
            int LA4_0 = input.LA(1);

            if ( (LA4_0==16) ) {
                alt4=1;
            }
            switch (alt4) {
                case 1 :
                    // InternalTableDSL.g:168:4: otherlv_3= '{' ( (lv_tables_4_0= ruleTable ) )* otherlv_5= '}'
                    {
                    otherlv_3=(Token)match(input,16,FOLLOW_6); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_3, grammarAccess.getTablePackageAccess().getLeftCurlyBracketKeyword_3_0());
                      			
                    }
                    // InternalTableDSL.g:172:4: ( (lv_tables_4_0= ruleTable ) )*
                    loop3:
                    do {
                        int alt3=2;
                        int LA3_0 = input.LA(1);

                        if ( (LA3_0==18) ) {
                            alt3=1;
                        }


                        switch (alt3) {
                    	case 1 :
                    	    // InternalTableDSL.g:173:5: (lv_tables_4_0= ruleTable )
                    	    {
                    	    // InternalTableDSL.g:173:5: (lv_tables_4_0= ruleTable )
                    	    // InternalTableDSL.g:174:6: lv_tables_4_0= ruleTable
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      						newCompositeNode(grammarAccess.getTablePackageAccess().getTablesTableParserRuleCall_3_1_0());
                    	      					
                    	    }
                    	    pushFollow(FOLLOW_6);
                    	    lv_tables_4_0=ruleTable();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      						if (current==null) {
                    	      							current = createModelElementForParent(grammarAccess.getTablePackageRule());
                    	      						}
                    	      						add(
                    	      							current,
                    	      							"tables",
                    	      							lv_tables_4_0,
                    	      							"org.eclipse.osbp.xtext.table.TableDSL.Table");
                    	      						afterParserOrEnumRuleCall();
                    	      					
                    	    }

                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop3;
                        }
                    } while (true);

                    otherlv_5=(Token)match(input,17,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_5, grammarAccess.getTablePackageAccess().getRightCurlyBracketKeyword_3_2());
                      			
                    }

                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTablePackage"


    // $ANTLR start "entryRuleTable"
    // InternalTableDSL.g:200:1: entryRuleTable returns [EObject current=null] : iv_ruleTable= ruleTable EOF ;
    public final EObject entryRuleTable() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTable = null;


        try {
            // InternalTableDSL.g:200:46: (iv_ruleTable= ruleTable EOF )
            // InternalTableDSL.g:201:2: iv_ruleTable= ruleTable EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTable=ruleTable();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTable; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTable"


    // $ANTLR start "ruleTable"
    // InternalTableDSL.g:207:1: ruleTable returns [EObject current=null] : ( () otherlv_1= 'table' ( (lv_name_2_0= RULE_ID ) ) ( ( (lv_description_3_0= 'describedBy' ) ) ( (lv_descriptionValue_4_0= ruleTRANSLATABLESTRING ) ) )? otherlv_5= 'as' ( (lv_tabletype_6_0= ruleTableOption ) ) ) ;
    public final EObject ruleTable() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token lv_name_2_0=null;
        Token lv_description_3_0=null;
        Token otherlv_5=null;
        AntlrDatatypeRuleToken lv_descriptionValue_4_0 = null;

        EObject lv_tabletype_6_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:213:2: ( ( () otherlv_1= 'table' ( (lv_name_2_0= RULE_ID ) ) ( ( (lv_description_3_0= 'describedBy' ) ) ( (lv_descriptionValue_4_0= ruleTRANSLATABLESTRING ) ) )? otherlv_5= 'as' ( (lv_tabletype_6_0= ruleTableOption ) ) ) )
            // InternalTableDSL.g:214:2: ( () otherlv_1= 'table' ( (lv_name_2_0= RULE_ID ) ) ( ( (lv_description_3_0= 'describedBy' ) ) ( (lv_descriptionValue_4_0= ruleTRANSLATABLESTRING ) ) )? otherlv_5= 'as' ( (lv_tabletype_6_0= ruleTableOption ) ) )
            {
            // InternalTableDSL.g:214:2: ( () otherlv_1= 'table' ( (lv_name_2_0= RULE_ID ) ) ( ( (lv_description_3_0= 'describedBy' ) ) ( (lv_descriptionValue_4_0= ruleTRANSLATABLESTRING ) ) )? otherlv_5= 'as' ( (lv_tabletype_6_0= ruleTableOption ) ) )
            // InternalTableDSL.g:215:3: () otherlv_1= 'table' ( (lv_name_2_0= RULE_ID ) ) ( ( (lv_description_3_0= 'describedBy' ) ) ( (lv_descriptionValue_4_0= ruleTRANSLATABLESTRING ) ) )? otherlv_5= 'as' ( (lv_tabletype_6_0= ruleTableOption ) )
            {
            // InternalTableDSL.g:215:3: ()
            // InternalTableDSL.g:216:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableAccess().getTableAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,18,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableAccess().getTableKeyword_1());
              		
            }
            // InternalTableDSL.g:226:3: ( (lv_name_2_0= RULE_ID ) )
            // InternalTableDSL.g:227:4: (lv_name_2_0= RULE_ID )
            {
            // InternalTableDSL.g:227:4: (lv_name_2_0= RULE_ID )
            // InternalTableDSL.g:228:5: lv_name_2_0= RULE_ID
            {
            lv_name_2_0=(Token)match(input,RULE_ID,FOLLOW_7); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(lv_name_2_0, grammarAccess.getTableAccess().getNameIDTerminalRuleCall_2_0());
              				
            }
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableRule());
              					}
              					setWithLastConsumed(
              						current,
              						"name",
              						lv_name_2_0,
              						"org.eclipse.xtext.xbase.Xtype.ID");
              				
            }

            }


            }

            // InternalTableDSL.g:244:3: ( ( (lv_description_3_0= 'describedBy' ) ) ( (lv_descriptionValue_4_0= ruleTRANSLATABLESTRING ) ) )?
            int alt5=2;
            int LA5_0 = input.LA(1);

            if ( (LA5_0==19) ) {
                alt5=1;
            }
            switch (alt5) {
                case 1 :
                    // InternalTableDSL.g:245:4: ( (lv_description_3_0= 'describedBy' ) ) ( (lv_descriptionValue_4_0= ruleTRANSLATABLESTRING ) )
                    {
                    // InternalTableDSL.g:245:4: ( (lv_description_3_0= 'describedBy' ) )
                    // InternalTableDSL.g:246:5: (lv_description_3_0= 'describedBy' )
                    {
                    // InternalTableDSL.g:246:5: (lv_description_3_0= 'describedBy' )
                    // InternalTableDSL.g:247:6: lv_description_3_0= 'describedBy'
                    {
                    lv_description_3_0=(Token)match(input,19,FOLLOW_8); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						newLeafNode(lv_description_3_0, grammarAccess.getTableAccess().getDescriptionDescribedByKeyword_3_0_0());
                      					
                    }
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElement(grammarAccess.getTableRule());
                      						}
                      						setWithLastConsumed(current, "description", true, "describedBy");
                      					
                    }

                    }


                    }

                    // InternalTableDSL.g:259:4: ( (lv_descriptionValue_4_0= ruleTRANSLATABLESTRING ) )
                    // InternalTableDSL.g:260:5: (lv_descriptionValue_4_0= ruleTRANSLATABLESTRING )
                    {
                    // InternalTableDSL.g:260:5: (lv_descriptionValue_4_0= ruleTRANSLATABLESTRING )
                    // InternalTableDSL.g:261:6: lv_descriptionValue_4_0= ruleTRANSLATABLESTRING
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getTableAccess().getDescriptionValueTRANSLATABLESTRINGParserRuleCall_3_1_0());
                      					
                    }
                    pushFollow(FOLLOW_9);
                    lv_descriptionValue_4_0=ruleTRANSLATABLESTRING();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getTableRule());
                      						}
                      						set(
                      							current,
                      							"descriptionValue",
                      							lv_descriptionValue_4_0,
                      							"org.eclipse.osbp.xtext.table.TableDSL.TRANSLATABLESTRING");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }


                    }
                    break;

            }

            otherlv_5=(Token)match(input,20,FOLLOW_10); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_5, grammarAccess.getTableAccess().getAsKeyword_4());
              		
            }
            // InternalTableDSL.g:283:3: ( (lv_tabletype_6_0= ruleTableOption ) )
            // InternalTableDSL.g:284:4: (lv_tabletype_6_0= ruleTableOption )
            {
            // InternalTableDSL.g:284:4: (lv_tabletype_6_0= ruleTableOption )
            // InternalTableDSL.g:285:5: lv_tabletype_6_0= ruleTableOption
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableAccess().getTabletypeTableOptionParserRuleCall_5_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_tabletype_6_0=ruleTableOption();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableRule());
              					}
              					set(
              						current,
              						"tabletype",
              						lv_tabletype_6_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.TableOption");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTable"


    // $ANTLR start "entryRuleTableOption"
    // InternalTableDSL.g:306:1: entryRuleTableOption returns [EObject current=null] : iv_ruleTableOption= ruleTableOption EOF ;
    public final EObject entryRuleTableOption() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableOption = null;


        try {
            // InternalTableDSL.g:306:52: (iv_ruleTableOption= ruleTableOption EOF )
            // InternalTableDSL.g:307:2: iv_ruleTableOption= ruleTableOption EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableOptionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableOption=ruleTableOption();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableOption; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableOption"


    // $ANTLR start "ruleTableOption"
    // InternalTableDSL.g:313:1: ruleTableOption returns [EObject current=null] : (this_TableSelection_0= ruleTableSelection | this_TableTable_1= ruleTableTable | this_TableGrid_2= ruleTableGrid ) ;
    public final EObject ruleTableOption() throws RecognitionException {
        EObject current = null;

        EObject this_TableSelection_0 = null;

        EObject this_TableTable_1 = null;

        EObject this_TableGrid_2 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:319:2: ( (this_TableSelection_0= ruleTableSelection | this_TableTable_1= ruleTableTable | this_TableGrid_2= ruleTableGrid ) )
            // InternalTableDSL.g:320:2: (this_TableSelection_0= ruleTableSelection | this_TableTable_1= ruleTableTable | this_TableGrid_2= ruleTableGrid )
            {
            // InternalTableDSL.g:320:2: (this_TableSelection_0= ruleTableSelection | this_TableTable_1= ruleTableTable | this_TableGrid_2= ruleTableGrid )
            int alt6=3;
            switch ( input.LA(1) ) {
            case 21:
                {
                alt6=1;
                }
                break;
            case 30:
                {
                alt6=2;
                }
                break;
            case 70:
                {
                alt6=3;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 6, 0, input);

                throw nvae;
            }

            switch (alt6) {
                case 1 :
                    // InternalTableDSL.g:321:3: this_TableSelection_0= ruleTableSelection
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableOptionAccess().getTableSelectionParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableSelection_0=ruleTableSelection();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableSelection_0;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:330:3: this_TableTable_1= ruleTableTable
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableOptionAccess().getTableTableParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableTable_1=ruleTableTable();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableTable_1;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:339:3: this_TableGrid_2= ruleTableGrid
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableOptionAccess().getTableGridParserRuleCall_2());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableGrid_2=ruleTableGrid();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableGrid_2;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableOption"


    // $ANTLR start "entryRuleTableSelection"
    // InternalTableDSL.g:351:1: entryRuleTableSelection returns [EObject current=null] : iv_ruleTableSelection= ruleTableSelection EOF ;
    public final EObject entryRuleTableSelection() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableSelection = null;


        try {
            // InternalTableDSL.g:351:55: (iv_ruleTableSelection= ruleTableSelection EOF )
            // InternalTableDSL.g:352:2: iv_ruleTableSelection= ruleTableSelection EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableSelectionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableSelection=ruleTableSelection();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableSelection; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableSelection"


    // $ANTLR start "ruleTableSelection"
    // InternalTableDSL.g:358:1: ruleTableSelection returns [EObject current=null] : ( () otherlv_1= 'selection' ( ( (lv_multiSelection_2_0= 'multiple' ) ) | otherlv_3= 'single' ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) ) ) )* ) ) ) (otherlv_12= 'using' ( (lv_source_13_0= ruleTableDatamart ) ) )? ) ;
    public final EObject ruleTableSelection() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token lv_multiSelection_2_0=null;
        Token otherlv_3=null;
        Token lv_selectalways_5_0=null;
        Token otherlv_6=null;
        Token lv_filtering_8_0=null;
        Token lv_embedded_9_0=null;
        Token otherlv_10=null;
        Token otherlv_11=null;
        Token otherlv_12=null;
        Enumerator lv_headerMode_7_0 = null;

        EObject lv_source_13_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:364:2: ( ( () otherlv_1= 'selection' ( ( (lv_multiSelection_2_0= 'multiple' ) ) | otherlv_3= 'single' ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) ) ) )* ) ) ) (otherlv_12= 'using' ( (lv_source_13_0= ruleTableDatamart ) ) )? ) )
            // InternalTableDSL.g:365:2: ( () otherlv_1= 'selection' ( ( (lv_multiSelection_2_0= 'multiple' ) ) | otherlv_3= 'single' ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) ) ) )* ) ) ) (otherlv_12= 'using' ( (lv_source_13_0= ruleTableDatamart ) ) )? )
            {
            // InternalTableDSL.g:365:2: ( () otherlv_1= 'selection' ( ( (lv_multiSelection_2_0= 'multiple' ) ) | otherlv_3= 'single' ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) ) ) )* ) ) ) (otherlv_12= 'using' ( (lv_source_13_0= ruleTableDatamart ) ) )? )
            // InternalTableDSL.g:366:3: () otherlv_1= 'selection' ( ( (lv_multiSelection_2_0= 'multiple' ) ) | otherlv_3= 'single' ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) ) ) )* ) ) ) (otherlv_12= 'using' ( (lv_source_13_0= ruleTableDatamart ) ) )?
            {
            // InternalTableDSL.g:366:3: ()
            // InternalTableDSL.g:367:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableSelectionAccess().getTableSelectionAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,21,FOLLOW_11); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableSelectionAccess().getSelectionKeyword_1());
              		
            }
            // InternalTableDSL.g:377:3: ( ( (lv_multiSelection_2_0= 'multiple' ) ) | otherlv_3= 'single' )
            int alt7=2;
            int LA7_0 = input.LA(1);

            if ( (LA7_0==22) ) {
                alt7=1;
            }
            else if ( (LA7_0==23) ) {
                alt7=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 7, 0, input);

                throw nvae;
            }
            switch (alt7) {
                case 1 :
                    // InternalTableDSL.g:378:4: ( (lv_multiSelection_2_0= 'multiple' ) )
                    {
                    // InternalTableDSL.g:378:4: ( (lv_multiSelection_2_0= 'multiple' ) )
                    // InternalTableDSL.g:379:5: (lv_multiSelection_2_0= 'multiple' )
                    {
                    // InternalTableDSL.g:379:5: (lv_multiSelection_2_0= 'multiple' )
                    // InternalTableDSL.g:380:6: lv_multiSelection_2_0= 'multiple'
                    {
                    lv_multiSelection_2_0=(Token)match(input,22,FOLLOW_12); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						newLeafNode(lv_multiSelection_2_0, grammarAccess.getTableSelectionAccess().getMultiSelectionMultipleKeyword_2_0_0());
                      					
                    }
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElement(grammarAccess.getTableSelectionRule());
                      						}
                      						setWithLastConsumed(current, "multiSelection", true, "multiple");
                      					
                    }

                    }


                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:393:4: otherlv_3= 'single'
                    {
                    otherlv_3=(Token)match(input,23,FOLLOW_12); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_3, grammarAccess.getTableSelectionAccess().getSingleKeyword_2_1());
                      			
                    }

                    }
                    break;

            }

            // InternalTableDSL.g:398:3: ( ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) ) ) )* ) ) )
            // InternalTableDSL.g:399:4: ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) ) ) )* ) )
            {
            // InternalTableDSL.g:399:4: ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) ) ) )* ) )
            // InternalTableDSL.g:400:5: ( ( ({...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) ) ) )* )
            {
            getUnorderedGroupHelper().enter(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3());
            // InternalTableDSL.g:403:5: ( ( ({...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) ) ) )* )
            // InternalTableDSL.g:404:6: ( ({...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) ) ) )*
            {
            // InternalTableDSL.g:404:6: ( ({...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) ) ) )*
            loop8:
            do {
                int alt8=6;
                int LA8_0 = input.LA(1);

                if ( LA8_0 == 24 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 0) ) {
                    alt8=1;
                }
                else if ( LA8_0 == 25 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 1) ) {
                    alt8=2;
                }
                else if ( LA8_0 == 26 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 2) ) {
                    alt8=3;
                }
                else if ( LA8_0 == 27 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 3) ) {
                    alt8=4;
                }
                else if ( LA8_0 == 28 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 4) ) {
                    alt8=5;
                }


                switch (alt8) {
            	case 1 :
            	    // InternalTableDSL.g:405:4: ({...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:405:4: ({...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) ) )
            	    // InternalTableDSL.g:406:5: {...}? => ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 0) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableSelection", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 0)");
            	    }
            	    // InternalTableDSL.g:406:111: ( ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) ) )
            	    // InternalTableDSL.g:407:6: ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 0);
            	    // InternalTableDSL.g:410:9: ({...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) ) )
            	    // InternalTableDSL.g:410:10: {...}? => ( (lv_selectalways_5_0= 'alwaysSelected' ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableSelection", "true");
            	    }
            	    // InternalTableDSL.g:410:19: ( (lv_selectalways_5_0= 'alwaysSelected' ) )
            	    // InternalTableDSL.g:410:20: (lv_selectalways_5_0= 'alwaysSelected' )
            	    {
            	    // InternalTableDSL.g:410:20: (lv_selectalways_5_0= 'alwaysSelected' )
            	    // InternalTableDSL.g:411:10: lv_selectalways_5_0= 'alwaysSelected'
            	    {
            	    lv_selectalways_5_0=(Token)match(input,24,FOLLOW_12); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      										newLeafNode(lv_selectalways_5_0, grammarAccess.getTableSelectionAccess().getSelectalwaysAlwaysSelectedKeyword_3_0_0());
            	      									
            	    }
            	    if ( state.backtracking==0 ) {

            	      										if (current==null) {
            	      											current = createModelElement(grammarAccess.getTableSelectionRule());
            	      										}
            	      										setWithLastConsumed(current, "selectalways", true, "alwaysSelected");
            	      									
            	    }

            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3());

            	    }


            	    }


            	    }
            	    break;
            	case 2 :
            	    // InternalTableDSL.g:428:4: ({...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:428:4: ({...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) ) )
            	    // InternalTableDSL.g:429:5: {...}? => ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 1) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableSelection", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 1)");
            	    }
            	    // InternalTableDSL.g:429:111: ( ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) ) )
            	    // InternalTableDSL.g:430:6: ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 1);
            	    // InternalTableDSL.g:433:9: ({...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) ) )
            	    // InternalTableDSL.g:433:10: {...}? => (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableSelection", "true");
            	    }
            	    // InternalTableDSL.g:433:19: (otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) ) )
            	    // InternalTableDSL.g:433:20: otherlv_6= 'rowHeader' ( (lv_headerMode_7_0= ruleRowHeaderMode ) )
            	    {
            	    otherlv_6=(Token)match(input,25,FOLLOW_13); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      									newLeafNode(otherlv_6, grammarAccess.getTableSelectionAccess().getRowHeaderKeyword_3_1_0());
            	      								
            	    }
            	    // InternalTableDSL.g:437:9: ( (lv_headerMode_7_0= ruleRowHeaderMode ) )
            	    // InternalTableDSL.g:438:10: (lv_headerMode_7_0= ruleRowHeaderMode )
            	    {
            	    // InternalTableDSL.g:438:10: (lv_headerMode_7_0= ruleRowHeaderMode )
            	    // InternalTableDSL.g:439:11: lv_headerMode_7_0= ruleRowHeaderMode
            	    {
            	    if ( state.backtracking==0 ) {

            	      											newCompositeNode(grammarAccess.getTableSelectionAccess().getHeaderModeRowHeaderModeEnumRuleCall_3_1_1_0());
            	      										
            	    }
            	    pushFollow(FOLLOW_12);
            	    lv_headerMode_7_0=ruleRowHeaderMode();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      											if (current==null) {
            	      												current = createModelElementForParent(grammarAccess.getTableSelectionRule());
            	      											}
            	      											set(
            	      												current,
            	      												"headerMode",
            	      												lv_headerMode_7_0,
            	      												"org.eclipse.osbp.xtext.table.TableDSL.RowHeaderMode");
            	      											afterParserOrEnumRuleCall();
            	      										
            	    }

            	    }


            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3());

            	    }


            	    }


            	    }
            	    break;
            	case 3 :
            	    // InternalTableDSL.g:462:4: ({...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:462:4: ({...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) ) )
            	    // InternalTableDSL.g:463:5: {...}? => ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 2) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableSelection", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 2)");
            	    }
            	    // InternalTableDSL.g:463:111: ( ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) ) )
            	    // InternalTableDSL.g:464:6: ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 2);
            	    // InternalTableDSL.g:467:9: ({...}? => ( (lv_filtering_8_0= 'filtering' ) ) )
            	    // InternalTableDSL.g:467:10: {...}? => ( (lv_filtering_8_0= 'filtering' ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableSelection", "true");
            	    }
            	    // InternalTableDSL.g:467:19: ( (lv_filtering_8_0= 'filtering' ) )
            	    // InternalTableDSL.g:467:20: (lv_filtering_8_0= 'filtering' )
            	    {
            	    // InternalTableDSL.g:467:20: (lv_filtering_8_0= 'filtering' )
            	    // InternalTableDSL.g:468:10: lv_filtering_8_0= 'filtering'
            	    {
            	    lv_filtering_8_0=(Token)match(input,26,FOLLOW_12); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      										newLeafNode(lv_filtering_8_0, grammarAccess.getTableSelectionAccess().getFilteringFilteringKeyword_3_2_0());
            	      									
            	    }
            	    if ( state.backtracking==0 ) {

            	      										if (current==null) {
            	      											current = createModelElement(grammarAccess.getTableSelectionRule());
            	      										}
            	      										setWithLastConsumed(current, "filtering", true, "filtering");
            	      									
            	    }

            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3());

            	    }


            	    }


            	    }
            	    break;
            	case 4 :
            	    // InternalTableDSL.g:485:4: ({...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:485:4: ({...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) ) )
            	    // InternalTableDSL.g:486:5: {...}? => ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 3) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableSelection", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 3)");
            	    }
            	    // InternalTableDSL.g:486:111: ( ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) ) )
            	    // InternalTableDSL.g:487:6: ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 3);
            	    // InternalTableDSL.g:490:9: ({...}? => ( (lv_embedded_9_0= 'embedded' ) ) )
            	    // InternalTableDSL.g:490:10: {...}? => ( (lv_embedded_9_0= 'embedded' ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableSelection", "true");
            	    }
            	    // InternalTableDSL.g:490:19: ( (lv_embedded_9_0= 'embedded' ) )
            	    // InternalTableDSL.g:490:20: (lv_embedded_9_0= 'embedded' )
            	    {
            	    // InternalTableDSL.g:490:20: (lv_embedded_9_0= 'embedded' )
            	    // InternalTableDSL.g:491:10: lv_embedded_9_0= 'embedded'
            	    {
            	    lv_embedded_9_0=(Token)match(input,27,FOLLOW_12); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      										newLeafNode(lv_embedded_9_0, grammarAccess.getTableSelectionAccess().getEmbeddedEmbeddedKeyword_3_3_0());
            	      									
            	    }
            	    if ( state.backtracking==0 ) {

            	      										if (current==null) {
            	      											current = createModelElement(grammarAccess.getTableSelectionRule());
            	      										}
            	      										setWithLastConsumed(current, "embedded", true, "embedded");
            	      									
            	    }

            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3());

            	    }


            	    }


            	    }
            	    break;
            	case 5 :
            	    // InternalTableDSL.g:508:4: ({...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:508:4: ({...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) ) )
            	    // InternalTableDSL.g:509:5: {...}? => ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 4) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableSelection", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 4)");
            	    }
            	    // InternalTableDSL.g:509:111: ( ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) ) )
            	    // InternalTableDSL.g:510:6: ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3(), 4);
            	    // InternalTableDSL.g:513:9: ({...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) ) )
            	    // InternalTableDSL.g:513:10: {...}? => (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableSelection", "true");
            	    }
            	    // InternalTableDSL.g:513:19: (otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) ) )
            	    // InternalTableDSL.g:513:20: otherlv_10= 'toolbar' ( (otherlv_11= RULE_ID ) )
            	    {
            	    otherlv_10=(Token)match(input,28,FOLLOW_4); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      									newLeafNode(otherlv_10, grammarAccess.getTableSelectionAccess().getToolbarKeyword_3_4_0());
            	      								
            	    }
            	    // InternalTableDSL.g:517:9: ( (otherlv_11= RULE_ID ) )
            	    // InternalTableDSL.g:518:10: (otherlv_11= RULE_ID )
            	    {
            	    // InternalTableDSL.g:518:10: (otherlv_11= RULE_ID )
            	    // InternalTableDSL.g:519:11: otherlv_11= RULE_ID
            	    {
            	    if ( state.backtracking==0 ) {

            	      											if (current==null) {
            	      												current = createModelElement(grammarAccess.getTableSelectionRule());
            	      											}
            	      										
            	    }
            	    otherlv_11=(Token)match(input,RULE_ID,FOLLOW_12); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      											newLeafNode(otherlv_11, grammarAccess.getTableSelectionAccess().getToolbarActionToolbarCrossReference_3_4_1_0());
            	      										
            	    }

            	    }


            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3());

            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop8;
                }
            } while (true);


            }


            }

            getUnorderedGroupHelper().leave(grammarAccess.getTableSelectionAccess().getUnorderedGroup_3());

            }

            // InternalTableDSL.g:543:3: (otherlv_12= 'using' ( (lv_source_13_0= ruleTableDatamart ) ) )?
            int alt9=2;
            int LA9_0 = input.LA(1);

            if ( (LA9_0==29) ) {
                alt9=1;
            }
            switch (alt9) {
                case 1 :
                    // InternalTableDSL.g:544:4: otherlv_12= 'using' ( (lv_source_13_0= ruleTableDatamart ) )
                    {
                    otherlv_12=(Token)match(input,29,FOLLOW_14); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_12, grammarAccess.getTableSelectionAccess().getUsingKeyword_4_0());
                      			
                    }
                    // InternalTableDSL.g:548:4: ( (lv_source_13_0= ruleTableDatamart ) )
                    // InternalTableDSL.g:549:5: (lv_source_13_0= ruleTableDatamart )
                    {
                    // InternalTableDSL.g:549:5: (lv_source_13_0= ruleTableDatamart )
                    // InternalTableDSL.g:550:6: lv_source_13_0= ruleTableDatamart
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getTableSelectionAccess().getSourceTableDatamartParserRuleCall_4_1_0());
                      					
                    }
                    pushFollow(FOLLOW_2);
                    lv_source_13_0=ruleTableDatamart();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getTableSelectionRule());
                      						}
                      						set(
                      							current,
                      							"source",
                      							lv_source_13_0,
                      							"org.eclipse.osbp.xtext.table.TableDSL.TableDatamart");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableSelection"


    // $ANTLR start "entryRuleTableTable"
    // InternalTableDSL.g:572:1: entryRuleTableTable returns [EObject current=null] : iv_ruleTableTable= ruleTableTable EOF ;
    public final EObject entryRuleTableTable() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableTable = null;


        try {
            // InternalTableDSL.g:572:51: (iv_ruleTableTable= ruleTableTable EOF )
            // InternalTableDSL.g:573:2: iv_ruleTableTable= ruleTableTable EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableTableRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableTable=ruleTableTable();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableTable; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableTable"


    // $ANTLR start "ruleTableTable"
    // InternalTableDSL.g:579:1: ruleTableTable returns [EObject current=null] : ( () otherlv_1= 'readOnly' ( ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) ) ) )* ) ) ) (otherlv_11= 'using' ( (lv_source_12_0= ruleTableDatamart ) ) )? ) ;
    public final EObject ruleTableTable() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token lv_selectalways_3_0=null;
        Token lv_selectById_4_0=null;
        Token otherlv_5=null;
        Token lv_filtering_7_0=null;
        Token lv_embedded_8_0=null;
        Token otherlv_9=null;
        Token otherlv_10=null;
        Token otherlv_11=null;
        Enumerator lv_headerMode_6_0 = null;

        EObject lv_source_12_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:585:2: ( ( () otherlv_1= 'readOnly' ( ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) ) ) )* ) ) ) (otherlv_11= 'using' ( (lv_source_12_0= ruleTableDatamart ) ) )? ) )
            // InternalTableDSL.g:586:2: ( () otherlv_1= 'readOnly' ( ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) ) ) )* ) ) ) (otherlv_11= 'using' ( (lv_source_12_0= ruleTableDatamart ) ) )? )
            {
            // InternalTableDSL.g:586:2: ( () otherlv_1= 'readOnly' ( ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) ) ) )* ) ) ) (otherlv_11= 'using' ( (lv_source_12_0= ruleTableDatamart ) ) )? )
            // InternalTableDSL.g:587:3: () otherlv_1= 'readOnly' ( ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) ) ) )* ) ) ) (otherlv_11= 'using' ( (lv_source_12_0= ruleTableDatamart ) ) )?
            {
            // InternalTableDSL.g:587:3: ()
            // InternalTableDSL.g:588:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableTableAccess().getTableTableAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,30,FOLLOW_15); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableTableAccess().getReadOnlyKeyword_1());
              		
            }
            // InternalTableDSL.g:598:3: ( ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) ) ) )* ) ) )
            // InternalTableDSL.g:599:4: ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) ) ) )* ) )
            {
            // InternalTableDSL.g:599:4: ( ( ( ({...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) ) ) )* ) )
            // InternalTableDSL.g:600:5: ( ( ({...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) ) ) )* )
            {
            getUnorderedGroupHelper().enter(grammarAccess.getTableTableAccess().getUnorderedGroup_2());
            // InternalTableDSL.g:603:5: ( ( ({...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) ) ) )* )
            // InternalTableDSL.g:604:6: ( ({...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) ) ) )*
            {
            // InternalTableDSL.g:604:6: ( ({...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) ) ) )*
            loop10:
            do {
                int alt10=7;
                int LA10_0 = input.LA(1);

                if ( LA10_0 == 24 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 0) ) {
                    alt10=1;
                }
                else if ( LA10_0 == 31 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 1) ) {
                    alt10=2;
                }
                else if ( LA10_0 == 25 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 2) ) {
                    alt10=3;
                }
                else if ( LA10_0 == 26 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 3) ) {
                    alt10=4;
                }
                else if ( LA10_0 == 27 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 4) ) {
                    alt10=5;
                }
                else if ( LA10_0 == 28 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 5) ) {
                    alt10=6;
                }


                switch (alt10) {
            	case 1 :
            	    // InternalTableDSL.g:605:4: ({...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:605:4: ({...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) ) )
            	    // InternalTableDSL.g:606:5: {...}? => ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 0) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableTable", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 0)");
            	    }
            	    // InternalTableDSL.g:606:107: ( ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) ) )
            	    // InternalTableDSL.g:607:6: ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 0);
            	    // InternalTableDSL.g:610:9: ({...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) ) )
            	    // InternalTableDSL.g:610:10: {...}? => ( (lv_selectalways_3_0= 'alwaysSelected' ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableTable", "true");
            	    }
            	    // InternalTableDSL.g:610:19: ( (lv_selectalways_3_0= 'alwaysSelected' ) )
            	    // InternalTableDSL.g:610:20: (lv_selectalways_3_0= 'alwaysSelected' )
            	    {
            	    // InternalTableDSL.g:610:20: (lv_selectalways_3_0= 'alwaysSelected' )
            	    // InternalTableDSL.g:611:10: lv_selectalways_3_0= 'alwaysSelected'
            	    {
            	    lv_selectalways_3_0=(Token)match(input,24,FOLLOW_15); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      										newLeafNode(lv_selectalways_3_0, grammarAccess.getTableTableAccess().getSelectalwaysAlwaysSelectedKeyword_2_0_0());
            	      									
            	    }
            	    if ( state.backtracking==0 ) {

            	      										if (current==null) {
            	      											current = createModelElement(grammarAccess.getTableTableRule());
            	      										}
            	      										setWithLastConsumed(current, "selectalways", true, "alwaysSelected");
            	      									
            	    }

            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableTableAccess().getUnorderedGroup_2());

            	    }


            	    }


            	    }
            	    break;
            	case 2 :
            	    // InternalTableDSL.g:628:4: ({...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:628:4: ({...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) ) )
            	    // InternalTableDSL.g:629:5: {...}? => ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 1) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableTable", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 1)");
            	    }
            	    // InternalTableDSL.g:629:107: ( ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) ) )
            	    // InternalTableDSL.g:630:6: ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 1);
            	    // InternalTableDSL.g:633:9: ({...}? => ( (lv_selectById_4_0= 'selectById' ) ) )
            	    // InternalTableDSL.g:633:10: {...}? => ( (lv_selectById_4_0= 'selectById' ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableTable", "true");
            	    }
            	    // InternalTableDSL.g:633:19: ( (lv_selectById_4_0= 'selectById' ) )
            	    // InternalTableDSL.g:633:20: (lv_selectById_4_0= 'selectById' )
            	    {
            	    // InternalTableDSL.g:633:20: (lv_selectById_4_0= 'selectById' )
            	    // InternalTableDSL.g:634:10: lv_selectById_4_0= 'selectById'
            	    {
            	    lv_selectById_4_0=(Token)match(input,31,FOLLOW_15); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      										newLeafNode(lv_selectById_4_0, grammarAccess.getTableTableAccess().getSelectByIdSelectByIdKeyword_2_1_0());
            	      									
            	    }
            	    if ( state.backtracking==0 ) {

            	      										if (current==null) {
            	      											current = createModelElement(grammarAccess.getTableTableRule());
            	      										}
            	      										setWithLastConsumed(current, "selectById", true, "selectById");
            	      									
            	    }

            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableTableAccess().getUnorderedGroup_2());

            	    }


            	    }


            	    }
            	    break;
            	case 3 :
            	    // InternalTableDSL.g:651:4: ({...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:651:4: ({...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) ) )
            	    // InternalTableDSL.g:652:5: {...}? => ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 2) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableTable", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 2)");
            	    }
            	    // InternalTableDSL.g:652:107: ( ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) ) )
            	    // InternalTableDSL.g:653:6: ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 2);
            	    // InternalTableDSL.g:656:9: ({...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) ) )
            	    // InternalTableDSL.g:656:10: {...}? => (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableTable", "true");
            	    }
            	    // InternalTableDSL.g:656:19: (otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) ) )
            	    // InternalTableDSL.g:656:20: otherlv_5= 'rowHeader' ( (lv_headerMode_6_0= ruleRowHeaderMode ) )
            	    {
            	    otherlv_5=(Token)match(input,25,FOLLOW_13); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      									newLeafNode(otherlv_5, grammarAccess.getTableTableAccess().getRowHeaderKeyword_2_2_0());
            	      								
            	    }
            	    // InternalTableDSL.g:660:9: ( (lv_headerMode_6_0= ruleRowHeaderMode ) )
            	    // InternalTableDSL.g:661:10: (lv_headerMode_6_0= ruleRowHeaderMode )
            	    {
            	    // InternalTableDSL.g:661:10: (lv_headerMode_6_0= ruleRowHeaderMode )
            	    // InternalTableDSL.g:662:11: lv_headerMode_6_0= ruleRowHeaderMode
            	    {
            	    if ( state.backtracking==0 ) {

            	      											newCompositeNode(grammarAccess.getTableTableAccess().getHeaderModeRowHeaderModeEnumRuleCall_2_2_1_0());
            	      										
            	    }
            	    pushFollow(FOLLOW_15);
            	    lv_headerMode_6_0=ruleRowHeaderMode();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      											if (current==null) {
            	      												current = createModelElementForParent(grammarAccess.getTableTableRule());
            	      											}
            	      											set(
            	      												current,
            	      												"headerMode",
            	      												lv_headerMode_6_0,
            	      												"org.eclipse.osbp.xtext.table.TableDSL.RowHeaderMode");
            	      											afterParserOrEnumRuleCall();
            	      										
            	    }

            	    }


            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableTableAccess().getUnorderedGroup_2());

            	    }


            	    }


            	    }
            	    break;
            	case 4 :
            	    // InternalTableDSL.g:685:4: ({...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:685:4: ({...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) ) )
            	    // InternalTableDSL.g:686:5: {...}? => ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 3) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableTable", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 3)");
            	    }
            	    // InternalTableDSL.g:686:107: ( ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) ) )
            	    // InternalTableDSL.g:687:6: ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 3);
            	    // InternalTableDSL.g:690:9: ({...}? => ( (lv_filtering_7_0= 'filtering' ) ) )
            	    // InternalTableDSL.g:690:10: {...}? => ( (lv_filtering_7_0= 'filtering' ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableTable", "true");
            	    }
            	    // InternalTableDSL.g:690:19: ( (lv_filtering_7_0= 'filtering' ) )
            	    // InternalTableDSL.g:690:20: (lv_filtering_7_0= 'filtering' )
            	    {
            	    // InternalTableDSL.g:690:20: (lv_filtering_7_0= 'filtering' )
            	    // InternalTableDSL.g:691:10: lv_filtering_7_0= 'filtering'
            	    {
            	    lv_filtering_7_0=(Token)match(input,26,FOLLOW_15); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      										newLeafNode(lv_filtering_7_0, grammarAccess.getTableTableAccess().getFilteringFilteringKeyword_2_3_0());
            	      									
            	    }
            	    if ( state.backtracking==0 ) {

            	      										if (current==null) {
            	      											current = createModelElement(grammarAccess.getTableTableRule());
            	      										}
            	      										setWithLastConsumed(current, "filtering", true, "filtering");
            	      									
            	    }

            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableTableAccess().getUnorderedGroup_2());

            	    }


            	    }


            	    }
            	    break;
            	case 5 :
            	    // InternalTableDSL.g:708:4: ({...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:708:4: ({...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) ) )
            	    // InternalTableDSL.g:709:5: {...}? => ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 4) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableTable", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 4)");
            	    }
            	    // InternalTableDSL.g:709:107: ( ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) ) )
            	    // InternalTableDSL.g:710:6: ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 4);
            	    // InternalTableDSL.g:713:9: ({...}? => ( (lv_embedded_8_0= 'embedded' ) ) )
            	    // InternalTableDSL.g:713:10: {...}? => ( (lv_embedded_8_0= 'embedded' ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableTable", "true");
            	    }
            	    // InternalTableDSL.g:713:19: ( (lv_embedded_8_0= 'embedded' ) )
            	    // InternalTableDSL.g:713:20: (lv_embedded_8_0= 'embedded' )
            	    {
            	    // InternalTableDSL.g:713:20: (lv_embedded_8_0= 'embedded' )
            	    // InternalTableDSL.g:714:10: lv_embedded_8_0= 'embedded'
            	    {
            	    lv_embedded_8_0=(Token)match(input,27,FOLLOW_15); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      										newLeafNode(lv_embedded_8_0, grammarAccess.getTableTableAccess().getEmbeddedEmbeddedKeyword_2_4_0());
            	      									
            	    }
            	    if ( state.backtracking==0 ) {

            	      										if (current==null) {
            	      											current = createModelElement(grammarAccess.getTableTableRule());
            	      										}
            	      										setWithLastConsumed(current, "embedded", true, "embedded");
            	      									
            	    }

            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableTableAccess().getUnorderedGroup_2());

            	    }


            	    }


            	    }
            	    break;
            	case 6 :
            	    // InternalTableDSL.g:731:4: ({...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:731:4: ({...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) ) )
            	    // InternalTableDSL.g:732:5: {...}? => ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 5) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableTable", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 5)");
            	    }
            	    // InternalTableDSL.g:732:107: ( ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) ) )
            	    // InternalTableDSL.g:733:6: ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableTableAccess().getUnorderedGroup_2(), 5);
            	    // InternalTableDSL.g:736:9: ({...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) ) )
            	    // InternalTableDSL.g:736:10: {...}? => (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableTable", "true");
            	    }
            	    // InternalTableDSL.g:736:19: (otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) ) )
            	    // InternalTableDSL.g:736:20: otherlv_9= 'toolbar' ( (otherlv_10= RULE_ID ) )
            	    {
            	    otherlv_9=(Token)match(input,28,FOLLOW_4); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      									newLeafNode(otherlv_9, grammarAccess.getTableTableAccess().getToolbarKeyword_2_5_0());
            	      								
            	    }
            	    // InternalTableDSL.g:740:9: ( (otherlv_10= RULE_ID ) )
            	    // InternalTableDSL.g:741:10: (otherlv_10= RULE_ID )
            	    {
            	    // InternalTableDSL.g:741:10: (otherlv_10= RULE_ID )
            	    // InternalTableDSL.g:742:11: otherlv_10= RULE_ID
            	    {
            	    if ( state.backtracking==0 ) {

            	      											if (current==null) {
            	      												current = createModelElement(grammarAccess.getTableTableRule());
            	      											}
            	      										
            	    }
            	    otherlv_10=(Token)match(input,RULE_ID,FOLLOW_15); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      											newLeafNode(otherlv_10, grammarAccess.getTableTableAccess().getToolbarActionToolbarCrossReference_2_5_1_0());
            	      										
            	    }

            	    }


            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableTableAccess().getUnorderedGroup_2());

            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop10;
                }
            } while (true);


            }


            }

            getUnorderedGroupHelper().leave(grammarAccess.getTableTableAccess().getUnorderedGroup_2());

            }

            // InternalTableDSL.g:766:3: (otherlv_11= 'using' ( (lv_source_12_0= ruleTableDatamart ) ) )?
            int alt11=2;
            int LA11_0 = input.LA(1);

            if ( (LA11_0==29) ) {
                alt11=1;
            }
            switch (alt11) {
                case 1 :
                    // InternalTableDSL.g:767:4: otherlv_11= 'using' ( (lv_source_12_0= ruleTableDatamart ) )
                    {
                    otherlv_11=(Token)match(input,29,FOLLOW_14); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_11, grammarAccess.getTableTableAccess().getUsingKeyword_3_0());
                      			
                    }
                    // InternalTableDSL.g:771:4: ( (lv_source_12_0= ruleTableDatamart ) )
                    // InternalTableDSL.g:772:5: (lv_source_12_0= ruleTableDatamart )
                    {
                    // InternalTableDSL.g:772:5: (lv_source_12_0= ruleTableDatamart )
                    // InternalTableDSL.g:773:6: lv_source_12_0= ruleTableDatamart
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getTableTableAccess().getSourceTableDatamartParserRuleCall_3_1_0());
                      					
                    }
                    pushFollow(FOLLOW_2);
                    lv_source_12_0=ruleTableDatamart();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getTableTableRule());
                      						}
                      						set(
                      							current,
                      							"source",
                      							lv_source_12_0,
                      							"org.eclipse.osbp.xtext.table.TableDSL.TableDatamart");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableTable"


    // $ANTLR start "entryRuleTablePreorder"
    // InternalTableDSL.g:795:1: entryRuleTablePreorder returns [EObject current=null] : iv_ruleTablePreorder= ruleTablePreorder EOF ;
    public final EObject entryRuleTablePreorder() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTablePreorder = null;


        try {
            // InternalTableDSL.g:795:54: (iv_ruleTablePreorder= ruleTablePreorder EOF )
            // InternalTableDSL.g:796:2: iv_ruleTablePreorder= ruleTablePreorder EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTablePreorderRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTablePreorder=ruleTablePreorder();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTablePreorder; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTablePreorder"


    // $ANTLR start "ruleTablePreorder"
    // InternalTableDSL.g:802:1: ruleTablePreorder returns [EObject current=null] : ( () otherlv_1= 'preorder' ( (lv_column_2_0= ruleTableValueElement ) ) ( (lv_ascending_3_0= 'ascending' ) )? ) ;
    public final EObject ruleTablePreorder() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token lv_ascending_3_0=null;
        EObject lv_column_2_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:808:2: ( ( () otherlv_1= 'preorder' ( (lv_column_2_0= ruleTableValueElement ) ) ( (lv_ascending_3_0= 'ascending' ) )? ) )
            // InternalTableDSL.g:809:2: ( () otherlv_1= 'preorder' ( (lv_column_2_0= ruleTableValueElement ) ) ( (lv_ascending_3_0= 'ascending' ) )? )
            {
            // InternalTableDSL.g:809:2: ( () otherlv_1= 'preorder' ( (lv_column_2_0= ruleTableValueElement ) ) ( (lv_ascending_3_0= 'ascending' ) )? )
            // InternalTableDSL.g:810:3: () otherlv_1= 'preorder' ( (lv_column_2_0= ruleTableValueElement ) ) ( (lv_ascending_3_0= 'ascending' ) )?
            {
            // InternalTableDSL.g:810:3: ()
            // InternalTableDSL.g:811:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTablePreorderAccess().getTablePreorderAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,32,FOLLOW_16); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTablePreorderAccess().getPreorderKeyword_1());
              		
            }
            // InternalTableDSL.g:821:3: ( (lv_column_2_0= ruleTableValueElement ) )
            // InternalTableDSL.g:822:4: (lv_column_2_0= ruleTableValueElement )
            {
            // InternalTableDSL.g:822:4: (lv_column_2_0= ruleTableValueElement )
            // InternalTableDSL.g:823:5: lv_column_2_0= ruleTableValueElement
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTablePreorderAccess().getColumnTableValueElementParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_17);
            lv_column_2_0=ruleTableValueElement();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTablePreorderRule());
              					}
              					set(
              						current,
              						"column",
              						lv_column_2_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.TableValueElement");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:840:3: ( (lv_ascending_3_0= 'ascending' ) )?
            int alt12=2;
            int LA12_0 = input.LA(1);

            if ( (LA12_0==33) ) {
                alt12=1;
            }
            switch (alt12) {
                case 1 :
                    // InternalTableDSL.g:841:4: (lv_ascending_3_0= 'ascending' )
                    {
                    // InternalTableDSL.g:841:4: (lv_ascending_3_0= 'ascending' )
                    // InternalTableDSL.g:842:5: lv_ascending_3_0= 'ascending'
                    {
                    lv_ascending_3_0=(Token)match(input,33,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					newLeafNode(lv_ascending_3_0, grammarAccess.getTablePreorderAccess().getAscendingAscendingKeyword_3_0());
                      				
                    }
                    if ( state.backtracking==0 ) {

                      					if (current==null) {
                      						current = createModelElement(grammarAccess.getTablePreorderRule());
                      					}
                      					setWithLastConsumed(current, "ascending", true, "ascending");
                      				
                    }

                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTablePreorder"


    // $ANTLR start "entryRuleTableValue"
    // InternalTableDSL.g:858:1: entryRuleTableValue returns [EObject current=null] : iv_ruleTableValue= ruleTableValue EOF ;
    public final EObject entryRuleTableValue() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableValue = null;


        try {
            // InternalTableDSL.g:858:51: (iv_ruleTableValue= ruleTableValue EOF )
            // InternalTableDSL.g:859:2: iv_ruleTableValue= ruleTableValue EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableValueRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableValue=ruleTableValue();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableValue; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableValue"


    // $ANTLR start "ruleTableValue"
    // InternalTableDSL.g:865:1: ruleTableValue returns [EObject current=null] : ( () otherlv_1= 'value' ( (lv_column_2_0= ruleTableValueElement ) ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) ) ) )* ) ) ) ( ( ( ( ({...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) ) ) | ({...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) ) ) )* ) ) ) ) ;
    public final EObject ruleTableValue() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token lv_collapsed_4_0=null;
        Token otherlv_5=null;
        Token lv_iconName_6_0=null;
        Token lv_hasImage_8_0=null;
        Token otherlv_12=null;
        Token lv_hideLabelInterval_13_0=null;
        Token otherlv_14=null;
        Token otherlv_16=null;
        Token otherlv_17=null;
        Token lv_hideLabelLookup_18_0=null;
        Token otherlv_19=null;
        Token otherlv_21=null;
        EObject lv_column_2_0 = null;

        EObject lv_formatter_7_0 = null;

        EObject lv_image_9_0 = null;

        EObject lv_tooltipPattern_10_0 = null;

        EObject lv_intervals_15_0 = null;

        EObject lv_lookups_20_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:871:2: ( ( () otherlv_1= 'value' ( (lv_column_2_0= ruleTableValueElement ) ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) ) ) )* ) ) ) ( ( ( ( ({...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) ) ) | ({...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) ) ) )* ) ) ) ) )
            // InternalTableDSL.g:872:2: ( () otherlv_1= 'value' ( (lv_column_2_0= ruleTableValueElement ) ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) ) ) )* ) ) ) ( ( ( ( ({...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) ) ) | ({...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) ) ) )* ) ) ) )
            {
            // InternalTableDSL.g:872:2: ( () otherlv_1= 'value' ( (lv_column_2_0= ruleTableValueElement ) ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) ) ) )* ) ) ) ( ( ( ( ({...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) ) ) | ({...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) ) ) )* ) ) ) )
            // InternalTableDSL.g:873:3: () otherlv_1= 'value' ( (lv_column_2_0= ruleTableValueElement ) ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) ) ) )* ) ) ) ( ( ( ( ({...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) ) ) | ({...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) ) ) )* ) ) )
            {
            // InternalTableDSL.g:873:3: ()
            // InternalTableDSL.g:874:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableValueAccess().getTableValueAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,34,FOLLOW_16); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableValueAccess().getValueKeyword_1());
              		
            }
            // InternalTableDSL.g:884:3: ( (lv_column_2_0= ruleTableValueElement ) )
            // InternalTableDSL.g:885:4: (lv_column_2_0= ruleTableValueElement )
            {
            // InternalTableDSL.g:885:4: (lv_column_2_0= ruleTableValueElement )
            // InternalTableDSL.g:886:5: lv_column_2_0= ruleTableValueElement
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableValueAccess().getColumnTableValueElementParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_18);
            lv_column_2_0=ruleTableValueElement();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableValueRule());
              					}
              					set(
              						current,
              						"column",
              						lv_column_2_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.TableValueElement");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:903:3: ( ( ( ( ({...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) ) ) )* ) ) )
            // InternalTableDSL.g:904:4: ( ( ( ({...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) ) ) )* ) )
            {
            // InternalTableDSL.g:904:4: ( ( ( ({...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) ) ) )* ) )
            // InternalTableDSL.g:905:5: ( ( ({...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) ) ) )* )
            {
            getUnorderedGroupHelper().enter(grammarAccess.getTableValueAccess().getUnorderedGroup_3());
            // InternalTableDSL.g:908:5: ( ( ({...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) ) ) )* )
            // InternalTableDSL.g:909:6: ( ({...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) ) ) )*
            {
            // InternalTableDSL.g:909:6: ( ({...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) ) ) | ({...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) ) ) )*
            loop13:
            do {
                int alt13=6;
                int LA13_0 = input.LA(1);

                if ( LA13_0 == 35 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 0) ) {
                    alt13=1;
                }
                else if ( LA13_0 == 36 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 1) ) {
                    alt13=2;
                }
                else if ( LA13_0 == 41 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 2) ) {
                    alt13=3;
                }
                else if ( LA13_0 == 37 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 3) ) {
                    alt13=4;
                }
                else if ( LA13_0 == 45 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 4) ) {
                    alt13=5;
                }


                switch (alt13) {
            	case 1 :
            	    // InternalTableDSL.g:910:4: ({...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:910:4: ({...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) ) )
            	    // InternalTableDSL.g:911:5: {...}? => ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 0) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableValue", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 0)");
            	    }
            	    // InternalTableDSL.g:911:107: ( ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) ) )
            	    // InternalTableDSL.g:912:6: ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 0);
            	    // InternalTableDSL.g:915:9: ({...}? => ( (lv_collapsed_4_0= 'collapse' ) ) )
            	    // InternalTableDSL.g:915:10: {...}? => ( (lv_collapsed_4_0= 'collapse' ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableValue", "true");
            	    }
            	    // InternalTableDSL.g:915:19: ( (lv_collapsed_4_0= 'collapse' ) )
            	    // InternalTableDSL.g:915:20: (lv_collapsed_4_0= 'collapse' )
            	    {
            	    // InternalTableDSL.g:915:20: (lv_collapsed_4_0= 'collapse' )
            	    // InternalTableDSL.g:916:10: lv_collapsed_4_0= 'collapse'
            	    {
            	    lv_collapsed_4_0=(Token)match(input,35,FOLLOW_18); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      										newLeafNode(lv_collapsed_4_0, grammarAccess.getTableValueAccess().getCollapsedCollapseKeyword_3_0_0());
            	      									
            	    }
            	    if ( state.backtracking==0 ) {

            	      										if (current==null) {
            	      											current = createModelElement(grammarAccess.getTableValueRule());
            	      										}
            	      										setWithLastConsumed(current, "collapsed", true, "collapse");
            	      									
            	    }

            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableValueAccess().getUnorderedGroup_3());

            	    }


            	    }


            	    }
            	    break;
            	case 2 :
            	    // InternalTableDSL.g:933:4: ({...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:933:4: ({...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) ) )
            	    // InternalTableDSL.g:934:5: {...}? => ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 1) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableValue", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 1)");
            	    }
            	    // InternalTableDSL.g:934:107: ( ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) ) )
            	    // InternalTableDSL.g:935:6: ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 1);
            	    // InternalTableDSL.g:938:9: ({...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) ) )
            	    // InternalTableDSL.g:938:10: {...}? => (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableValue", "true");
            	    }
            	    // InternalTableDSL.g:938:19: (otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) ) )
            	    // InternalTableDSL.g:938:20: otherlv_5= 'icon' ( (lv_iconName_6_0= RULE_STRING ) )
            	    {
            	    otherlv_5=(Token)match(input,36,FOLLOW_8); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      									newLeafNode(otherlv_5, grammarAccess.getTableValueAccess().getIconKeyword_3_1_0());
            	      								
            	    }
            	    // InternalTableDSL.g:942:9: ( (lv_iconName_6_0= RULE_STRING ) )
            	    // InternalTableDSL.g:943:10: (lv_iconName_6_0= RULE_STRING )
            	    {
            	    // InternalTableDSL.g:943:10: (lv_iconName_6_0= RULE_STRING )
            	    // InternalTableDSL.g:944:11: lv_iconName_6_0= RULE_STRING
            	    {
            	    lv_iconName_6_0=(Token)match(input,RULE_STRING,FOLLOW_18); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      											newLeafNode(lv_iconName_6_0, grammarAccess.getTableValueAccess().getIconNameSTRINGTerminalRuleCall_3_1_1_0());
            	      										
            	    }
            	    if ( state.backtracking==0 ) {

            	      											if (current==null) {
            	      												current = createModelElement(grammarAccess.getTableValueRule());
            	      											}
            	      											setWithLastConsumed(
            	      												current,
            	      												"iconName",
            	      												lv_iconName_6_0,
            	      												"org.eclipse.xtext.xbase.Xtype.STRING");
            	      										
            	    }

            	    }


            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableValueAccess().getUnorderedGroup_3());

            	    }


            	    }


            	    }
            	    break;
            	case 3 :
            	    // InternalTableDSL.g:966:4: ({...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:966:4: ({...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) ) )
            	    // InternalTableDSL.g:967:5: {...}? => ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 2) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableValue", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 2)");
            	    }
            	    // InternalTableDSL.g:967:107: ( ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) ) )
            	    // InternalTableDSL.g:968:6: ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 2);
            	    // InternalTableDSL.g:971:9: ({...}? => ( (lv_formatter_7_0= ruleTableFormatter ) ) )
            	    // InternalTableDSL.g:971:10: {...}? => ( (lv_formatter_7_0= ruleTableFormatter ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableValue", "true");
            	    }
            	    // InternalTableDSL.g:971:19: ( (lv_formatter_7_0= ruleTableFormatter ) )
            	    // InternalTableDSL.g:971:20: (lv_formatter_7_0= ruleTableFormatter )
            	    {
            	    // InternalTableDSL.g:971:20: (lv_formatter_7_0= ruleTableFormatter )
            	    // InternalTableDSL.g:972:10: lv_formatter_7_0= ruleTableFormatter
            	    {
            	    if ( state.backtracking==0 ) {

            	      										newCompositeNode(grammarAccess.getTableValueAccess().getFormatterTableFormatterParserRuleCall_3_2_0());
            	      									
            	    }
            	    pushFollow(FOLLOW_18);
            	    lv_formatter_7_0=ruleTableFormatter();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      										if (current==null) {
            	      											current = createModelElementForParent(grammarAccess.getTableValueRule());
            	      										}
            	      										set(
            	      											current,
            	      											"formatter",
            	      											lv_formatter_7_0,
            	      											"org.eclipse.osbp.xtext.table.TableDSL.TableFormatter");
            	      										afterParserOrEnumRuleCall();
            	      									
            	    }

            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableValueAccess().getUnorderedGroup_3());

            	    }


            	    }


            	    }
            	    break;
            	case 4 :
            	    // InternalTableDSL.g:994:4: ({...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:994:4: ({...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) ) )
            	    // InternalTableDSL.g:995:5: {...}? => ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 3) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableValue", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 3)");
            	    }
            	    // InternalTableDSL.g:995:107: ( ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) ) )
            	    // InternalTableDSL.g:996:6: ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 3);
            	    // InternalTableDSL.g:999:9: ({...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) ) )
            	    // InternalTableDSL.g:999:10: {...}? => ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableValue", "true");
            	    }
            	    // InternalTableDSL.g:999:19: ( ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) ) )
            	    // InternalTableDSL.g:999:20: ( (lv_hasImage_8_0= 'image' ) ) ( (lv_image_9_0= ruleTableImage ) )
            	    {
            	    // InternalTableDSL.g:999:20: ( (lv_hasImage_8_0= 'image' ) )
            	    // InternalTableDSL.g:1000:10: (lv_hasImage_8_0= 'image' )
            	    {
            	    // InternalTableDSL.g:1000:10: (lv_hasImage_8_0= 'image' )
            	    // InternalTableDSL.g:1001:11: lv_hasImage_8_0= 'image'
            	    {
            	    lv_hasImage_8_0=(Token)match(input,37,FOLLOW_19); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      											newLeafNode(lv_hasImage_8_0, grammarAccess.getTableValueAccess().getHasImageImageKeyword_3_3_0_0());
            	      										
            	    }
            	    if ( state.backtracking==0 ) {

            	      											if (current==null) {
            	      												current = createModelElement(grammarAccess.getTableValueRule());
            	      											}
            	      											setWithLastConsumed(current, "hasImage", true, "image");
            	      										
            	    }

            	    }


            	    }

            	    // InternalTableDSL.g:1013:9: ( (lv_image_9_0= ruleTableImage ) )
            	    // InternalTableDSL.g:1014:10: (lv_image_9_0= ruleTableImage )
            	    {
            	    // InternalTableDSL.g:1014:10: (lv_image_9_0= ruleTableImage )
            	    // InternalTableDSL.g:1015:11: lv_image_9_0= ruleTableImage
            	    {
            	    if ( state.backtracking==0 ) {

            	      											newCompositeNode(grammarAccess.getTableValueAccess().getImageTableImageParserRuleCall_3_3_1_0());
            	      										
            	    }
            	    pushFollow(FOLLOW_18);
            	    lv_image_9_0=ruleTableImage();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      											if (current==null) {
            	      												current = createModelElementForParent(grammarAccess.getTableValueRule());
            	      											}
            	      											set(
            	      												current,
            	      												"image",
            	      												lv_image_9_0,
            	      												"org.eclipse.osbp.xtext.table.TableDSL.TableImage");
            	      											afterParserOrEnumRuleCall();
            	      										
            	    }

            	    }


            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableValueAccess().getUnorderedGroup_3());

            	    }


            	    }


            	    }
            	    break;
            	case 5 :
            	    // InternalTableDSL.g:1038:4: ({...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:1038:4: ({...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) ) )
            	    // InternalTableDSL.g:1039:5: {...}? => ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 4) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableValue", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 4)");
            	    }
            	    // InternalTableDSL.g:1039:107: ( ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) ) )
            	    // InternalTableDSL.g:1040:6: ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableValueAccess().getUnorderedGroup_3(), 4);
            	    // InternalTableDSL.g:1043:9: ({...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) ) )
            	    // InternalTableDSL.g:1043:10: {...}? => ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableValue", "true");
            	    }
            	    // InternalTableDSL.g:1043:19: ( (lv_tooltipPattern_10_0= ruleTableTooltipPattern ) )
            	    // InternalTableDSL.g:1043:20: (lv_tooltipPattern_10_0= ruleTableTooltipPattern )
            	    {
            	    // InternalTableDSL.g:1043:20: (lv_tooltipPattern_10_0= ruleTableTooltipPattern )
            	    // InternalTableDSL.g:1044:10: lv_tooltipPattern_10_0= ruleTableTooltipPattern
            	    {
            	    if ( state.backtracking==0 ) {

            	      										newCompositeNode(grammarAccess.getTableValueAccess().getTooltipPatternTableTooltipPatternParserRuleCall_3_4_0());
            	      									
            	    }
            	    pushFollow(FOLLOW_18);
            	    lv_tooltipPattern_10_0=ruleTableTooltipPattern();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      										if (current==null) {
            	      											current = createModelElementForParent(grammarAccess.getTableValueRule());
            	      										}
            	      										set(
            	      											current,
            	      											"tooltipPattern",
            	      											lv_tooltipPattern_10_0,
            	      											"org.eclipse.osbp.xtext.table.TableDSL.TableTooltipPattern");
            	      										afterParserOrEnumRuleCall();
            	      									
            	    }

            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableValueAccess().getUnorderedGroup_3());

            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop13;
                }
            } while (true);


            }


            }

            getUnorderedGroupHelper().leave(grammarAccess.getTableValueAccess().getUnorderedGroup_3());

            }

            // InternalTableDSL.g:1073:3: ( ( ( ( ({...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) ) ) | ({...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) ) ) )* ) ) )
            // InternalTableDSL.g:1074:4: ( ( ( ({...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) ) ) | ({...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) ) ) )* ) )
            {
            // InternalTableDSL.g:1074:4: ( ( ( ({...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) ) ) | ({...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) ) ) )* ) )
            // InternalTableDSL.g:1075:5: ( ( ({...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) ) ) | ({...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) ) ) )* )
            {
            getUnorderedGroupHelper().enter(grammarAccess.getTableValueAccess().getUnorderedGroup_4());
            // InternalTableDSL.g:1078:5: ( ( ({...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) ) ) | ({...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) ) ) )* )
            // InternalTableDSL.g:1079:6: ( ({...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) ) ) | ({...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) ) ) )*
            {
            // InternalTableDSL.g:1079:6: ( ({...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) ) ) | ({...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) ) ) )*
            loop18:
            do {
                int alt18=3;
                int LA18_0 = input.LA(1);

                if ( LA18_0 == 38 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_4(), 0) ) {
                    alt18=1;
                }
                else if ( LA18_0 == 40 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_4(), 1) ) {
                    alt18=2;
                }


                switch (alt18) {
            	case 1 :
            	    // InternalTableDSL.g:1080:4: ({...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) ) )
            	    {
            	    // InternalTableDSL.g:1080:4: ({...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) ) )
            	    // InternalTableDSL.g:1081:5: {...}? => ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_4(), 0) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableValue", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_4(), 0)");
            	    }
            	    // InternalTableDSL.g:1081:107: ( ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) ) )
            	    // InternalTableDSL.g:1082:6: ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableValueAccess().getUnorderedGroup_4(), 0);
            	    // InternalTableDSL.g:1085:9: ({...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' ) )
            	    // InternalTableDSL.g:1085:10: {...}? => (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableValue", "true");
            	    }
            	    // InternalTableDSL.g:1085:19: (otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}' )
            	    // InternalTableDSL.g:1085:20: otherlv_12= 'intervals' ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )? otherlv_14= '{' ( (lv_intervals_15_0= ruleTableInterval ) )* otherlv_16= '}'
            	    {
            	    otherlv_12=(Token)match(input,38,FOLLOW_20); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      									newLeafNode(otherlv_12, grammarAccess.getTableValueAccess().getIntervalsKeyword_4_0_0());
            	      								
            	    }
            	    // InternalTableDSL.g:1089:9: ( (lv_hideLabelInterval_13_0= 'hidelabel' ) )?
            	    int alt14=2;
            	    int LA14_0 = input.LA(1);

            	    if ( (LA14_0==39) ) {
            	        alt14=1;
            	    }
            	    switch (alt14) {
            	        case 1 :
            	            // InternalTableDSL.g:1090:10: (lv_hideLabelInterval_13_0= 'hidelabel' )
            	            {
            	            // InternalTableDSL.g:1090:10: (lv_hideLabelInterval_13_0= 'hidelabel' )
            	            // InternalTableDSL.g:1091:11: lv_hideLabelInterval_13_0= 'hidelabel'
            	            {
            	            lv_hideLabelInterval_13_0=(Token)match(input,39,FOLLOW_21); if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              											newLeafNode(lv_hideLabelInterval_13_0, grammarAccess.getTableValueAccess().getHideLabelIntervalHidelabelKeyword_4_0_1_0());
            	              										
            	            }
            	            if ( state.backtracking==0 ) {

            	              											if (current==null) {
            	              												current = createModelElement(grammarAccess.getTableValueRule());
            	              											}
            	              											setWithLastConsumed(current, "hideLabelInterval", true, "hidelabel");
            	              										
            	            }

            	            }


            	            }
            	            break;

            	    }

            	    otherlv_14=(Token)match(input,16,FOLLOW_22); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      									newLeafNode(otherlv_14, grammarAccess.getTableValueAccess().getLeftCurlyBracketKeyword_4_0_2());
            	      								
            	    }
            	    // InternalTableDSL.g:1107:9: ( (lv_intervals_15_0= ruleTableInterval ) )*
            	    loop15:
            	    do {
            	        int alt15=2;
            	        int LA15_0 = input.LA(1);

            	        if ( ((LA15_0>=55 && LA15_0<=57)) ) {
            	            alt15=1;
            	        }


            	        switch (alt15) {
            	    	case 1 :
            	    	    // InternalTableDSL.g:1108:10: (lv_intervals_15_0= ruleTableInterval )
            	    	    {
            	    	    // InternalTableDSL.g:1108:10: (lv_intervals_15_0= ruleTableInterval )
            	    	    // InternalTableDSL.g:1109:11: lv_intervals_15_0= ruleTableInterval
            	    	    {
            	    	    if ( state.backtracking==0 ) {

            	    	      											newCompositeNode(grammarAccess.getTableValueAccess().getIntervalsTableIntervalParserRuleCall_4_0_3_0());
            	    	      										
            	    	    }
            	    	    pushFollow(FOLLOW_22);
            	    	    lv_intervals_15_0=ruleTableInterval();

            	    	    state._fsp--;
            	    	    if (state.failed) return current;
            	    	    if ( state.backtracking==0 ) {

            	    	      											if (current==null) {
            	    	      												current = createModelElementForParent(grammarAccess.getTableValueRule());
            	    	      											}
            	    	      											add(
            	    	      												current,
            	    	      												"intervals",
            	    	      												lv_intervals_15_0,
            	    	      												"org.eclipse.osbp.xtext.table.TableDSL.TableInterval");
            	    	      											afterParserOrEnumRuleCall();
            	    	      										
            	    	    }

            	    	    }


            	    	    }
            	    	    break;

            	    	default :
            	    	    break loop15;
            	        }
            	    } while (true);

            	    otherlv_16=(Token)match(input,17,FOLLOW_23); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      									newLeafNode(otherlv_16, grammarAccess.getTableValueAccess().getRightCurlyBracketKeyword_4_0_4());
            	      								
            	    }

            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableValueAccess().getUnorderedGroup_4());

            	    }


            	    }


            	    }
            	    break;
            	case 2 :
            	    // InternalTableDSL.g:1136:4: ({...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) ) )
            	    {
            	    // InternalTableDSL.g:1136:4: ({...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) ) )
            	    // InternalTableDSL.g:1137:5: {...}? => ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_4(), 1) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableValue", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableValueAccess().getUnorderedGroup_4(), 1)");
            	    }
            	    // InternalTableDSL.g:1137:107: ( ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) ) )
            	    // InternalTableDSL.g:1138:6: ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableValueAccess().getUnorderedGroup_4(), 1);
            	    // InternalTableDSL.g:1141:9: ({...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' ) )
            	    // InternalTableDSL.g:1141:10: {...}? => (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableValue", "true");
            	    }
            	    // InternalTableDSL.g:1141:19: (otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}' )
            	    // InternalTableDSL.g:1141:20: otherlv_17= 'lookups' ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )? otherlv_19= '{' ( (lv_lookups_20_0= ruleTableLookup ) )* otherlv_21= '}'
            	    {
            	    otherlv_17=(Token)match(input,40,FOLLOW_20); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      									newLeafNode(otherlv_17, grammarAccess.getTableValueAccess().getLookupsKeyword_4_1_0());
            	      								
            	    }
            	    // InternalTableDSL.g:1145:9: ( (lv_hideLabelLookup_18_0= 'hidelabel' ) )?
            	    int alt16=2;
            	    int LA16_0 = input.LA(1);

            	    if ( (LA16_0==39) ) {
            	        alt16=1;
            	    }
            	    switch (alt16) {
            	        case 1 :
            	            // InternalTableDSL.g:1146:10: (lv_hideLabelLookup_18_0= 'hidelabel' )
            	            {
            	            // InternalTableDSL.g:1146:10: (lv_hideLabelLookup_18_0= 'hidelabel' )
            	            // InternalTableDSL.g:1147:11: lv_hideLabelLookup_18_0= 'hidelabel'
            	            {
            	            lv_hideLabelLookup_18_0=(Token)match(input,39,FOLLOW_21); if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              											newLeafNode(lv_hideLabelLookup_18_0, grammarAccess.getTableValueAccess().getHideLabelLookupHidelabelKeyword_4_1_1_0());
            	              										
            	            }
            	            if ( state.backtracking==0 ) {

            	              											if (current==null) {
            	              												current = createModelElement(grammarAccess.getTableValueRule());
            	              											}
            	              											setWithLastConsumed(current, "hideLabelLookup", true, "hidelabel");
            	              										
            	            }

            	            }


            	            }
            	            break;

            	    }

            	    otherlv_19=(Token)match(input,16,FOLLOW_24); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      									newLeafNode(otherlv_19, grammarAccess.getTableValueAccess().getLeftCurlyBracketKeyword_4_1_2());
            	      								
            	    }
            	    // InternalTableDSL.g:1163:9: ( (lv_lookups_20_0= ruleTableLookup ) )*
            	    loop17:
            	    do {
            	        int alt17=2;
            	        int LA17_0 = input.LA(1);

            	        if ( ((LA17_0>=57 && LA17_0<=60)) ) {
            	            alt17=1;
            	        }


            	        switch (alt17) {
            	    	case 1 :
            	    	    // InternalTableDSL.g:1164:10: (lv_lookups_20_0= ruleTableLookup )
            	    	    {
            	    	    // InternalTableDSL.g:1164:10: (lv_lookups_20_0= ruleTableLookup )
            	    	    // InternalTableDSL.g:1165:11: lv_lookups_20_0= ruleTableLookup
            	    	    {
            	    	    if ( state.backtracking==0 ) {

            	    	      											newCompositeNode(grammarAccess.getTableValueAccess().getLookupsTableLookupParserRuleCall_4_1_3_0());
            	    	      										
            	    	    }
            	    	    pushFollow(FOLLOW_24);
            	    	    lv_lookups_20_0=ruleTableLookup();

            	    	    state._fsp--;
            	    	    if (state.failed) return current;
            	    	    if ( state.backtracking==0 ) {

            	    	      											if (current==null) {
            	    	      												current = createModelElementForParent(grammarAccess.getTableValueRule());
            	    	      											}
            	    	      											add(
            	    	      												current,
            	    	      												"lookups",
            	    	      												lv_lookups_20_0,
            	    	      												"org.eclipse.osbp.xtext.table.TableDSL.TableLookup");
            	    	      											afterParserOrEnumRuleCall();
            	    	      										
            	    	    }

            	    	    }


            	    	    }
            	    	    break;

            	    	default :
            	    	    break loop17;
            	        }
            	    } while (true);

            	    otherlv_21=(Token)match(input,17,FOLLOW_23); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      									newLeafNode(otherlv_21, grammarAccess.getTableValueAccess().getRightCurlyBracketKeyword_4_1_4());
            	      								
            	    }

            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableValueAccess().getUnorderedGroup_4());

            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop18;
                }
            } while (true);


            }


            }

            getUnorderedGroupHelper().leave(grammarAccess.getTableValueAccess().getUnorderedGroup_4());

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableValue"


    // $ANTLR start "entryRuleTableFormatter"
    // InternalTableDSL.g:1203:1: entryRuleTableFormatter returns [EObject current=null] : iv_ruleTableFormatter= ruleTableFormatter EOF ;
    public final EObject entryRuleTableFormatter() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableFormatter = null;


        try {
            // InternalTableDSL.g:1203:55: (iv_ruleTableFormatter= ruleTableFormatter EOF )
            // InternalTableDSL.g:1204:2: iv_ruleTableFormatter= ruleTableFormatter EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableFormatterRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableFormatter=ruleTableFormatter();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableFormatter; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableFormatter"


    // $ANTLR start "ruleTableFormatter"
    // InternalTableDSL.g:1210:1: ruleTableFormatter returns [EObject current=null] : ( () otherlv_1= 'formatter' ( (lv_format_2_0= RULE_STRING ) ) ) ;
    public final EObject ruleTableFormatter() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token lv_format_2_0=null;


        	enterRule();

        try {
            // InternalTableDSL.g:1216:2: ( ( () otherlv_1= 'formatter' ( (lv_format_2_0= RULE_STRING ) ) ) )
            // InternalTableDSL.g:1217:2: ( () otherlv_1= 'formatter' ( (lv_format_2_0= RULE_STRING ) ) )
            {
            // InternalTableDSL.g:1217:2: ( () otherlv_1= 'formatter' ( (lv_format_2_0= RULE_STRING ) ) )
            // InternalTableDSL.g:1218:3: () otherlv_1= 'formatter' ( (lv_format_2_0= RULE_STRING ) )
            {
            // InternalTableDSL.g:1218:3: ()
            // InternalTableDSL.g:1219:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableFormatterAccess().getTableFormatterAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,41,FOLLOW_8); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableFormatterAccess().getFormatterKeyword_1());
              		
            }
            // InternalTableDSL.g:1229:3: ( (lv_format_2_0= RULE_STRING ) )
            // InternalTableDSL.g:1230:4: (lv_format_2_0= RULE_STRING )
            {
            // InternalTableDSL.g:1230:4: (lv_format_2_0= RULE_STRING )
            // InternalTableDSL.g:1231:5: lv_format_2_0= RULE_STRING
            {
            lv_format_2_0=(Token)match(input,RULE_STRING,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(lv_format_2_0, grammarAccess.getTableFormatterAccess().getFormatSTRINGTerminalRuleCall_2_0());
              				
            }
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableFormatterRule());
              					}
              					setWithLastConsumed(
              						current,
              						"format",
              						lv_format_2_0,
              						"org.eclipse.xtext.xbase.Xtype.STRING");
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableFormatter"


    // $ANTLR start "entryRuleTableImage"
    // InternalTableDSL.g:1251:1: entryRuleTableImage returns [EObject current=null] : iv_ruleTableImage= ruleTableImage EOF ;
    public final EObject entryRuleTableImage() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableImage = null;


        try {
            // InternalTableDSL.g:1251:51: (iv_ruleTableImage= ruleTableImage EOF )
            // InternalTableDSL.g:1252:2: iv_ruleTableImage= ruleTableImage EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableImageRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableImage=ruleTableImage();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableImage; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableImage"


    // $ANTLR start "ruleTableImage"
    // InternalTableDSL.g:1258:1: ruleTableImage returns [EObject current=null] : ( () otherlv_1= 'path' ( (lv_imagePathPattern_2_0= RULE_STRING ) ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) ) ) )* ) ) ) ) ;
    public final EObject ruleTableImage() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token lv_imagePathPattern_2_0=null;
        Token lv_hasParameter_4_0=null;
        Token lv_hideImageLabel_5_0=null;
        Token lv_resize_6_0=null;
        Token lv_resizeString_7_0=null;


        	enterRule();

        try {
            // InternalTableDSL.g:1264:2: ( ( () otherlv_1= 'path' ( (lv_imagePathPattern_2_0= RULE_STRING ) ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) ) ) )* ) ) ) ) )
            // InternalTableDSL.g:1265:2: ( () otherlv_1= 'path' ( (lv_imagePathPattern_2_0= RULE_STRING ) ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) ) ) )* ) ) ) )
            {
            // InternalTableDSL.g:1265:2: ( () otherlv_1= 'path' ( (lv_imagePathPattern_2_0= RULE_STRING ) ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) ) ) )* ) ) ) )
            // InternalTableDSL.g:1266:3: () otherlv_1= 'path' ( (lv_imagePathPattern_2_0= RULE_STRING ) ) ( ( ( ( ({...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) ) ) )* ) ) )
            {
            // InternalTableDSL.g:1266:3: ()
            // InternalTableDSL.g:1267:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableImageAccess().getTableImageAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,42,FOLLOW_8); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableImageAccess().getPathKeyword_1());
              		
            }
            // InternalTableDSL.g:1277:3: ( (lv_imagePathPattern_2_0= RULE_STRING ) )
            // InternalTableDSL.g:1278:4: (lv_imagePathPattern_2_0= RULE_STRING )
            {
            // InternalTableDSL.g:1278:4: (lv_imagePathPattern_2_0= RULE_STRING )
            // InternalTableDSL.g:1279:5: lv_imagePathPattern_2_0= RULE_STRING
            {
            lv_imagePathPattern_2_0=(Token)match(input,RULE_STRING,FOLLOW_25); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(lv_imagePathPattern_2_0, grammarAccess.getTableImageAccess().getImagePathPatternSTRINGTerminalRuleCall_2_0());
              				
            }
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableImageRule());
              					}
              					setWithLastConsumed(
              						current,
              						"imagePathPattern",
              						lv_imagePathPattern_2_0,
              						"org.eclipse.xtext.xbase.Xtype.STRING");
              				
            }

            }


            }

            // InternalTableDSL.g:1295:3: ( ( ( ( ({...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) ) ) )* ) ) )
            // InternalTableDSL.g:1296:4: ( ( ( ({...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) ) ) )* ) )
            {
            // InternalTableDSL.g:1296:4: ( ( ( ({...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) ) ) )* ) )
            // InternalTableDSL.g:1297:5: ( ( ({...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) ) ) )* )
            {
            getUnorderedGroupHelper().enter(grammarAccess.getTableImageAccess().getUnorderedGroup_3());
            // InternalTableDSL.g:1300:5: ( ( ({...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) ) ) )* )
            // InternalTableDSL.g:1301:6: ( ({...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) ) ) )*
            {
            // InternalTableDSL.g:1301:6: ( ({...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) ) ) | ({...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) ) ) )*
            loop19:
            do {
                int alt19=4;
                int LA19_0 = input.LA(1);

                if ( LA19_0 == 43 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableImageAccess().getUnorderedGroup_3(), 0) ) {
                    alt19=1;
                }
                else if ( LA19_0 == 39 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableImageAccess().getUnorderedGroup_3(), 1) ) {
                    alt19=2;
                }
                else if ( LA19_0 == 44 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableImageAccess().getUnorderedGroup_3(), 2) ) {
                    alt19=3;
                }


                switch (alt19) {
            	case 1 :
            	    // InternalTableDSL.g:1302:4: ({...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:1302:4: ({...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) ) )
            	    // InternalTableDSL.g:1303:5: {...}? => ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableImageAccess().getUnorderedGroup_3(), 0) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableImage", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableImageAccess().getUnorderedGroup_3(), 0)");
            	    }
            	    // InternalTableDSL.g:1303:107: ( ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) ) )
            	    // InternalTableDSL.g:1304:6: ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableImageAccess().getUnorderedGroup_3(), 0);
            	    // InternalTableDSL.g:1307:9: ({...}? => ( (lv_hasParameter_4_0= 'dynamic' ) ) )
            	    // InternalTableDSL.g:1307:10: {...}? => ( (lv_hasParameter_4_0= 'dynamic' ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableImage", "true");
            	    }
            	    // InternalTableDSL.g:1307:19: ( (lv_hasParameter_4_0= 'dynamic' ) )
            	    // InternalTableDSL.g:1307:20: (lv_hasParameter_4_0= 'dynamic' )
            	    {
            	    // InternalTableDSL.g:1307:20: (lv_hasParameter_4_0= 'dynamic' )
            	    // InternalTableDSL.g:1308:10: lv_hasParameter_4_0= 'dynamic'
            	    {
            	    lv_hasParameter_4_0=(Token)match(input,43,FOLLOW_25); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      										newLeafNode(lv_hasParameter_4_0, grammarAccess.getTableImageAccess().getHasParameterDynamicKeyword_3_0_0());
            	      									
            	    }
            	    if ( state.backtracking==0 ) {

            	      										if (current==null) {
            	      											current = createModelElement(grammarAccess.getTableImageRule());
            	      										}
            	      										setWithLastConsumed(current, "hasParameter", true, "dynamic");
            	      									
            	    }

            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableImageAccess().getUnorderedGroup_3());

            	    }


            	    }


            	    }
            	    break;
            	case 2 :
            	    // InternalTableDSL.g:1325:4: ({...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:1325:4: ({...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) ) )
            	    // InternalTableDSL.g:1326:5: {...}? => ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableImageAccess().getUnorderedGroup_3(), 1) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableImage", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableImageAccess().getUnorderedGroup_3(), 1)");
            	    }
            	    // InternalTableDSL.g:1326:107: ( ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) ) )
            	    // InternalTableDSL.g:1327:6: ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableImageAccess().getUnorderedGroup_3(), 1);
            	    // InternalTableDSL.g:1330:9: ({...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) ) )
            	    // InternalTableDSL.g:1330:10: {...}? => ( (lv_hideImageLabel_5_0= 'hidelabel' ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableImage", "true");
            	    }
            	    // InternalTableDSL.g:1330:19: ( (lv_hideImageLabel_5_0= 'hidelabel' ) )
            	    // InternalTableDSL.g:1330:20: (lv_hideImageLabel_5_0= 'hidelabel' )
            	    {
            	    // InternalTableDSL.g:1330:20: (lv_hideImageLabel_5_0= 'hidelabel' )
            	    // InternalTableDSL.g:1331:10: lv_hideImageLabel_5_0= 'hidelabel'
            	    {
            	    lv_hideImageLabel_5_0=(Token)match(input,39,FOLLOW_25); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      										newLeafNode(lv_hideImageLabel_5_0, grammarAccess.getTableImageAccess().getHideImageLabelHidelabelKeyword_3_1_0());
            	      									
            	    }
            	    if ( state.backtracking==0 ) {

            	      										if (current==null) {
            	      											current = createModelElement(grammarAccess.getTableImageRule());
            	      										}
            	      										setWithLastConsumed(current, "hideImageLabel", true, "hidelabel");
            	      									
            	    }

            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableImageAccess().getUnorderedGroup_3());

            	    }


            	    }


            	    }
            	    break;
            	case 3 :
            	    // InternalTableDSL.g:1348:4: ({...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:1348:4: ({...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) ) )
            	    // InternalTableDSL.g:1349:5: {...}? => ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableImageAccess().getUnorderedGroup_3(), 2) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableImage", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableImageAccess().getUnorderedGroup_3(), 2)");
            	    }
            	    // InternalTableDSL.g:1349:107: ( ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) ) )
            	    // InternalTableDSL.g:1350:6: ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableImageAccess().getUnorderedGroup_3(), 2);
            	    // InternalTableDSL.g:1353:9: ({...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) ) )
            	    // InternalTableDSL.g:1353:10: {...}? => ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableImage", "true");
            	    }
            	    // InternalTableDSL.g:1353:19: ( ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) ) )
            	    // InternalTableDSL.g:1353:20: ( (lv_resize_6_0= 'resize' ) ) ( (lv_resizeString_7_0= RULE_STRING ) )
            	    {
            	    // InternalTableDSL.g:1353:20: ( (lv_resize_6_0= 'resize' ) )
            	    // InternalTableDSL.g:1354:10: (lv_resize_6_0= 'resize' )
            	    {
            	    // InternalTableDSL.g:1354:10: (lv_resize_6_0= 'resize' )
            	    // InternalTableDSL.g:1355:11: lv_resize_6_0= 'resize'
            	    {
            	    lv_resize_6_0=(Token)match(input,44,FOLLOW_8); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      											newLeafNode(lv_resize_6_0, grammarAccess.getTableImageAccess().getResizeResizeKeyword_3_2_0_0());
            	      										
            	    }
            	    if ( state.backtracking==0 ) {

            	      											if (current==null) {
            	      												current = createModelElement(grammarAccess.getTableImageRule());
            	      											}
            	      											setWithLastConsumed(current, "resize", true, "resize");
            	      										
            	    }

            	    }


            	    }

            	    // InternalTableDSL.g:1367:9: ( (lv_resizeString_7_0= RULE_STRING ) )
            	    // InternalTableDSL.g:1368:10: (lv_resizeString_7_0= RULE_STRING )
            	    {
            	    // InternalTableDSL.g:1368:10: (lv_resizeString_7_0= RULE_STRING )
            	    // InternalTableDSL.g:1369:11: lv_resizeString_7_0= RULE_STRING
            	    {
            	    lv_resizeString_7_0=(Token)match(input,RULE_STRING,FOLLOW_25); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      											newLeafNode(lv_resizeString_7_0, grammarAccess.getTableImageAccess().getResizeStringSTRINGTerminalRuleCall_3_2_1_0());
            	      										
            	    }
            	    if ( state.backtracking==0 ) {

            	      											if (current==null) {
            	      												current = createModelElement(grammarAccess.getTableImageRule());
            	      											}
            	      											setWithLastConsumed(
            	      												current,
            	      												"resizeString",
            	      												lv_resizeString_7_0,
            	      												"org.eclipse.xtext.xbase.Xtype.STRING");
            	      										
            	    }

            	    }


            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableImageAccess().getUnorderedGroup_3());

            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop19;
                }
            } while (true);


            }


            }

            getUnorderedGroupHelper().leave(grammarAccess.getTableImageAccess().getUnorderedGroup_3());

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableImage"


    // $ANTLR start "entryRuleTableTooltipPattern"
    // InternalTableDSL.g:1402:1: entryRuleTableTooltipPattern returns [EObject current=null] : iv_ruleTableTooltipPattern= ruleTableTooltipPattern EOF ;
    public final EObject entryRuleTableTooltipPattern() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableTooltipPattern = null;


        try {
            // InternalTableDSL.g:1402:60: (iv_ruleTableTooltipPattern= ruleTableTooltipPattern EOF )
            // InternalTableDSL.g:1403:2: iv_ruleTableTooltipPattern= ruleTableTooltipPattern EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableTooltipPatternRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableTooltipPattern=ruleTableTooltipPattern();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableTooltipPattern; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableTooltipPattern"


    // $ANTLR start "ruleTableTooltipPattern"
    // InternalTableDSL.g:1409:1: ruleTableTooltipPattern returns [EObject current=null] : ( () otherlv_1= 'tooltipPattern' ( (lv_tooltipPattern_2_0= ruleTRANSLATABLESTRING ) ) ) ;
    public final EObject ruleTableTooltipPattern() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        AntlrDatatypeRuleToken lv_tooltipPattern_2_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:1415:2: ( ( () otherlv_1= 'tooltipPattern' ( (lv_tooltipPattern_2_0= ruleTRANSLATABLESTRING ) ) ) )
            // InternalTableDSL.g:1416:2: ( () otherlv_1= 'tooltipPattern' ( (lv_tooltipPattern_2_0= ruleTRANSLATABLESTRING ) ) )
            {
            // InternalTableDSL.g:1416:2: ( () otherlv_1= 'tooltipPattern' ( (lv_tooltipPattern_2_0= ruleTRANSLATABLESTRING ) ) )
            // InternalTableDSL.g:1417:3: () otherlv_1= 'tooltipPattern' ( (lv_tooltipPattern_2_0= ruleTRANSLATABLESTRING ) )
            {
            // InternalTableDSL.g:1417:3: ()
            // InternalTableDSL.g:1418:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableTooltipPatternAccess().getTableTooltipPatternAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,45,FOLLOW_8); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableTooltipPatternAccess().getTooltipPatternKeyword_1());
              		
            }
            // InternalTableDSL.g:1428:3: ( (lv_tooltipPattern_2_0= ruleTRANSLATABLESTRING ) )
            // InternalTableDSL.g:1429:4: (lv_tooltipPattern_2_0= ruleTRANSLATABLESTRING )
            {
            // InternalTableDSL.g:1429:4: (lv_tooltipPattern_2_0= ruleTRANSLATABLESTRING )
            // InternalTableDSL.g:1430:5: lv_tooltipPattern_2_0= ruleTRANSLATABLESTRING
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableTooltipPatternAccess().getTooltipPatternTRANSLATABLESTRINGParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_tooltipPattern_2_0=ruleTRANSLATABLESTRING();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableTooltipPatternRule());
              					}
              					set(
              						current,
              						"tooltipPattern",
              						lv_tooltipPattern_2_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.TRANSLATABLESTRING");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableTooltipPattern"


    // $ANTLR start "entryRuleTableValueElement"
    // InternalTableDSL.g:1451:1: entryRuleTableValueElement returns [EObject current=null] : iv_ruleTableValueElement= ruleTableValueElement EOF ;
    public final EObject entryRuleTableValueElement() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableValueElement = null;


        try {
            // InternalTableDSL.g:1451:58: (iv_ruleTableValueElement= ruleTableValueElement EOF )
            // InternalTableDSL.g:1452:2: iv_ruleTableValueElement= ruleTableValueElement EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableValueElementRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableValueElement=ruleTableValueElement();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableValueElement; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableValueElement"


    // $ANTLR start "ruleTableValueElement"
    // InternalTableDSL.g:1458:1: ruleTableValueElement returns [EObject current=null] : (this_TableMeasure_0= ruleTableMeasure | this_TableDerived_1= ruleTableDerived | this_TableHierarchy_2= ruleTableHierarchy | this_TableAttribute_3= ruleTableAttribute | this_TableAggregation_4= ruleTableAggregation | this_TableOrdinal_5= ruleTableOrdinal | this_TableColumn_6= ruleTableColumn | this_TableTask_7= ruleTableTask | this_TableAllColumns_8= ruleTableAllColumns ) ;
    public final EObject ruleTableValueElement() throws RecognitionException {
        EObject current = null;

        EObject this_TableMeasure_0 = null;

        EObject this_TableDerived_1 = null;

        EObject this_TableHierarchy_2 = null;

        EObject this_TableAttribute_3 = null;

        EObject this_TableAggregation_4 = null;

        EObject this_TableOrdinal_5 = null;

        EObject this_TableColumn_6 = null;

        EObject this_TableTask_7 = null;

        EObject this_TableAllColumns_8 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:1464:2: ( (this_TableMeasure_0= ruleTableMeasure | this_TableDerived_1= ruleTableDerived | this_TableHierarchy_2= ruleTableHierarchy | this_TableAttribute_3= ruleTableAttribute | this_TableAggregation_4= ruleTableAggregation | this_TableOrdinal_5= ruleTableOrdinal | this_TableColumn_6= ruleTableColumn | this_TableTask_7= ruleTableTask | this_TableAllColumns_8= ruleTableAllColumns ) )
            // InternalTableDSL.g:1465:2: (this_TableMeasure_0= ruleTableMeasure | this_TableDerived_1= ruleTableDerived | this_TableHierarchy_2= ruleTableHierarchy | this_TableAttribute_3= ruleTableAttribute | this_TableAggregation_4= ruleTableAggregation | this_TableOrdinal_5= ruleTableOrdinal | this_TableColumn_6= ruleTableColumn | this_TableTask_7= ruleTableTask | this_TableAllColumns_8= ruleTableAllColumns )
            {
            // InternalTableDSL.g:1465:2: (this_TableMeasure_0= ruleTableMeasure | this_TableDerived_1= ruleTableDerived | this_TableHierarchy_2= ruleTableHierarchy | this_TableAttribute_3= ruleTableAttribute | this_TableAggregation_4= ruleTableAggregation | this_TableOrdinal_5= ruleTableOrdinal | this_TableColumn_6= ruleTableColumn | this_TableTask_7= ruleTableTask | this_TableAllColumns_8= ruleTableAllColumns )
            int alt20=9;
            switch ( input.LA(1) ) {
            case 50:
                {
                alt20=1;
                }
                break;
            case 51:
                {
                alt20=2;
                }
                break;
            case 52:
                {
                alt20=3;
                }
                break;
            case 53:
                {
                alt20=4;
                }
                break;
            case 54:
                {
                alt20=5;
                }
                break;
            case 48:
                {
                alt20=6;
                }
                break;
            case 49:
                {
                alt20=7;
                }
                break;
            case 46:
                {
                alt20=8;
                }
                break;
            case 47:
                {
                alt20=9;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 20, 0, input);

                throw nvae;
            }

            switch (alt20) {
                case 1 :
                    // InternalTableDSL.g:1466:3: this_TableMeasure_0= ruleTableMeasure
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableValueElementAccess().getTableMeasureParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableMeasure_0=ruleTableMeasure();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableMeasure_0;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:1475:3: this_TableDerived_1= ruleTableDerived
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableValueElementAccess().getTableDerivedParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableDerived_1=ruleTableDerived();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableDerived_1;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:1484:3: this_TableHierarchy_2= ruleTableHierarchy
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableValueElementAccess().getTableHierarchyParserRuleCall_2());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableHierarchy_2=ruleTableHierarchy();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableHierarchy_2;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:1493:3: this_TableAttribute_3= ruleTableAttribute
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableValueElementAccess().getTableAttributeParserRuleCall_3());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableAttribute_3=ruleTableAttribute();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableAttribute_3;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 5 :
                    // InternalTableDSL.g:1502:3: this_TableAggregation_4= ruleTableAggregation
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableValueElementAccess().getTableAggregationParserRuleCall_4());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableAggregation_4=ruleTableAggregation();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableAggregation_4;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 6 :
                    // InternalTableDSL.g:1511:3: this_TableOrdinal_5= ruleTableOrdinal
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableValueElementAccess().getTableOrdinalParserRuleCall_5());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableOrdinal_5=ruleTableOrdinal();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableOrdinal_5;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 7 :
                    // InternalTableDSL.g:1520:3: this_TableColumn_6= ruleTableColumn
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableValueElementAccess().getTableColumnParserRuleCall_6());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableColumn_6=ruleTableColumn();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableColumn_6;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 8 :
                    // InternalTableDSL.g:1529:3: this_TableTask_7= ruleTableTask
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableValueElementAccess().getTableTaskParserRuleCall_7());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableTask_7=ruleTableTask();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableTask_7;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 9 :
                    // InternalTableDSL.g:1538:3: this_TableAllColumns_8= ruleTableAllColumns
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableValueElementAccess().getTableAllColumnsParserRuleCall_8());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableAllColumns_8=ruleTableAllColumns();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableAllColumns_8;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableValueElement"


    // $ANTLR start "entryRuleTableTask"
    // InternalTableDSL.g:1550:1: entryRuleTableTask returns [EObject current=null] : iv_ruleTableTask= ruleTableTask EOF ;
    public final EObject entryRuleTableTask() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableTask = null;


        try {
            // InternalTableDSL.g:1550:50: (iv_ruleTableTask= ruleTableTask EOF )
            // InternalTableDSL.g:1551:2: iv_ruleTableTask= ruleTableTask EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableTaskRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableTask=ruleTableTask();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableTask; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableTask"


    // $ANTLR start "ruleTableTask"
    // InternalTableDSL.g:1557:1: ruleTableTask returns [EObject current=null] : ( () otherlv_1= 'taskId' ) ;
    public final EObject ruleTableTask() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;


        	enterRule();

        try {
            // InternalTableDSL.g:1563:2: ( ( () otherlv_1= 'taskId' ) )
            // InternalTableDSL.g:1564:2: ( () otherlv_1= 'taskId' )
            {
            // InternalTableDSL.g:1564:2: ( () otherlv_1= 'taskId' )
            // InternalTableDSL.g:1565:3: () otherlv_1= 'taskId'
            {
            // InternalTableDSL.g:1565:3: ()
            // InternalTableDSL.g:1566:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableTaskAccess().getTableTaskAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,46,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableTaskAccess().getTaskIdKeyword_1());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableTask"


    // $ANTLR start "entryRuleTableAllColumns"
    // InternalTableDSL.g:1580:1: entryRuleTableAllColumns returns [EObject current=null] : iv_ruleTableAllColumns= ruleTableAllColumns EOF ;
    public final EObject entryRuleTableAllColumns() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableAllColumns = null;


        try {
            // InternalTableDSL.g:1580:56: (iv_ruleTableAllColumns= ruleTableAllColumns EOF )
            // InternalTableDSL.g:1581:2: iv_ruleTableAllColumns= ruleTableAllColumns EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableAllColumnsRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableAllColumns=ruleTableAllColumns();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableAllColumns; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableAllColumns"


    // $ANTLR start "ruleTableAllColumns"
    // InternalTableDSL.g:1587:1: ruleTableAllColumns returns [EObject current=null] : ( () otherlv_1= 'allColumns' ) ;
    public final EObject ruleTableAllColumns() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;


        	enterRule();

        try {
            // InternalTableDSL.g:1593:2: ( ( () otherlv_1= 'allColumns' ) )
            // InternalTableDSL.g:1594:2: ( () otherlv_1= 'allColumns' )
            {
            // InternalTableDSL.g:1594:2: ( () otherlv_1= 'allColumns' )
            // InternalTableDSL.g:1595:3: () otherlv_1= 'allColumns'
            {
            // InternalTableDSL.g:1595:3: ()
            // InternalTableDSL.g:1596:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableAllColumnsAccess().getTableAllColumnsAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,47,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableAllColumnsAccess().getAllColumnsKeyword_1());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableAllColumns"


    // $ANTLR start "entryRuleTableOrdinal"
    // InternalTableDSL.g:1610:1: entryRuleTableOrdinal returns [EObject current=null] : iv_ruleTableOrdinal= ruleTableOrdinal EOF ;
    public final EObject entryRuleTableOrdinal() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableOrdinal = null;


        try {
            // InternalTableDSL.g:1610:53: (iv_ruleTableOrdinal= ruleTableOrdinal EOF )
            // InternalTableDSL.g:1611:2: iv_ruleTableOrdinal= ruleTableOrdinal EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableOrdinalRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableOrdinal=ruleTableOrdinal();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableOrdinal; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableOrdinal"


    // $ANTLR start "ruleTableOrdinal"
    // InternalTableDSL.g:1617:1: ruleTableOrdinal returns [EObject current=null] : (otherlv_0= 'ordinal' ( (lv_valueRef_1_0= ruleNumber ) ) ) ;
    public final EObject ruleTableOrdinal() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        AntlrDatatypeRuleToken lv_valueRef_1_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:1623:2: ( (otherlv_0= 'ordinal' ( (lv_valueRef_1_0= ruleNumber ) ) ) )
            // InternalTableDSL.g:1624:2: (otherlv_0= 'ordinal' ( (lv_valueRef_1_0= ruleNumber ) ) )
            {
            // InternalTableDSL.g:1624:2: (otherlv_0= 'ordinal' ( (lv_valueRef_1_0= ruleNumber ) ) )
            // InternalTableDSL.g:1625:3: otherlv_0= 'ordinal' ( (lv_valueRef_1_0= ruleNumber ) )
            {
            otherlv_0=(Token)match(input,48,FOLLOW_26); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getTableOrdinalAccess().getOrdinalKeyword_0());
              		
            }
            // InternalTableDSL.g:1629:3: ( (lv_valueRef_1_0= ruleNumber ) )
            // InternalTableDSL.g:1630:4: (lv_valueRef_1_0= ruleNumber )
            {
            // InternalTableDSL.g:1630:4: (lv_valueRef_1_0= ruleNumber )
            // InternalTableDSL.g:1631:5: lv_valueRef_1_0= ruleNumber
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableOrdinalAccess().getValueRefNumberParserRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_valueRef_1_0=ruleNumber();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableOrdinalRule());
              					}
              					set(
              						current,
              						"valueRef",
              						lv_valueRef_1_0,
              						"org.eclipse.xtext.xbase.Xbase.Number");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableOrdinal"


    // $ANTLR start "entryRuleTableColumn"
    // InternalTableDSL.g:1652:1: entryRuleTableColumn returns [EObject current=null] : iv_ruleTableColumn= ruleTableColumn EOF ;
    public final EObject entryRuleTableColumn() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableColumn = null;


        try {
            // InternalTableDSL.g:1652:52: (iv_ruleTableColumn= ruleTableColumn EOF )
            // InternalTableDSL.g:1653:2: iv_ruleTableColumn= ruleTableColumn EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableColumnRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableColumn=ruleTableColumn();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableColumn; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableColumn"


    // $ANTLR start "ruleTableColumn"
    // InternalTableDSL.g:1659:1: ruleTableColumn returns [EObject current=null] : (otherlv_0= 'column' ( (otherlv_1= RULE_ID ) ) ) ;
    public final EObject ruleTableColumn() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token otherlv_1=null;


        	enterRule();

        try {
            // InternalTableDSL.g:1665:2: ( (otherlv_0= 'column' ( (otherlv_1= RULE_ID ) ) ) )
            // InternalTableDSL.g:1666:2: (otherlv_0= 'column' ( (otherlv_1= RULE_ID ) ) )
            {
            // InternalTableDSL.g:1666:2: (otherlv_0= 'column' ( (otherlv_1= RULE_ID ) ) )
            // InternalTableDSL.g:1667:3: otherlv_0= 'column' ( (otherlv_1= RULE_ID ) )
            {
            otherlv_0=(Token)match(input,49,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getTableColumnAccess().getColumnKeyword_0());
              		
            }
            // InternalTableDSL.g:1671:3: ( (otherlv_1= RULE_ID ) )
            // InternalTableDSL.g:1672:4: (otherlv_1= RULE_ID )
            {
            // InternalTableDSL.g:1672:4: (otherlv_1= RULE_ID )
            // InternalTableDSL.g:1673:5: otherlv_1= RULE_ID
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableColumnRule());
              					}
              				
            }
            otherlv_1=(Token)match(input,RULE_ID,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_1, grammarAccess.getTableColumnAccess().getValueRefDatamartColumnCrossReference_1_0());
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableColumn"


    // $ANTLR start "entryRuleTableMeasure"
    // InternalTableDSL.g:1688:1: entryRuleTableMeasure returns [EObject current=null] : iv_ruleTableMeasure= ruleTableMeasure EOF ;
    public final EObject entryRuleTableMeasure() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableMeasure = null;


        try {
            // InternalTableDSL.g:1688:53: (iv_ruleTableMeasure= ruleTableMeasure EOF )
            // InternalTableDSL.g:1689:2: iv_ruleTableMeasure= ruleTableMeasure EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableMeasureRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableMeasure=ruleTableMeasure();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableMeasure; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableMeasure"


    // $ANTLR start "ruleTableMeasure"
    // InternalTableDSL.g:1695:1: ruleTableMeasure returns [EObject current=null] : (otherlv_0= 'measure' ( (otherlv_1= RULE_ID ) ) ) ;
    public final EObject ruleTableMeasure() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token otherlv_1=null;


        	enterRule();

        try {
            // InternalTableDSL.g:1701:2: ( (otherlv_0= 'measure' ( (otherlv_1= RULE_ID ) ) ) )
            // InternalTableDSL.g:1702:2: (otherlv_0= 'measure' ( (otherlv_1= RULE_ID ) ) )
            {
            // InternalTableDSL.g:1702:2: (otherlv_0= 'measure' ( (otherlv_1= RULE_ID ) ) )
            // InternalTableDSL.g:1703:3: otherlv_0= 'measure' ( (otherlv_1= RULE_ID ) )
            {
            otherlv_0=(Token)match(input,50,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getTableMeasureAccess().getMeasureKeyword_0());
              		
            }
            // InternalTableDSL.g:1707:3: ( (otherlv_1= RULE_ID ) )
            // InternalTableDSL.g:1708:4: (otherlv_1= RULE_ID )
            {
            // InternalTableDSL.g:1708:4: (otherlv_1= RULE_ID )
            // InternalTableDSL.g:1709:5: otherlv_1= RULE_ID
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableMeasureRule());
              					}
              				
            }
            otherlv_1=(Token)match(input,RULE_ID,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_1, grammarAccess.getTableMeasureAccess().getValueRefDatamartMeasureCrossReference_1_0());
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableMeasure"


    // $ANTLR start "entryRuleTableDerived"
    // InternalTableDSL.g:1724:1: entryRuleTableDerived returns [EObject current=null] : iv_ruleTableDerived= ruleTableDerived EOF ;
    public final EObject entryRuleTableDerived() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableDerived = null;


        try {
            // InternalTableDSL.g:1724:53: (iv_ruleTableDerived= ruleTableDerived EOF )
            // InternalTableDSL.g:1725:2: iv_ruleTableDerived= ruleTableDerived EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableDerivedRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableDerived=ruleTableDerived();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableDerived; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableDerived"


    // $ANTLR start "ruleTableDerived"
    // InternalTableDSL.g:1731:1: ruleTableDerived returns [EObject current=null] : (otherlv_0= 'derived' ( (otherlv_1= RULE_ID ) ) ) ;
    public final EObject ruleTableDerived() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token otherlv_1=null;


        	enterRule();

        try {
            // InternalTableDSL.g:1737:2: ( (otherlv_0= 'derived' ( (otherlv_1= RULE_ID ) ) ) )
            // InternalTableDSL.g:1738:2: (otherlv_0= 'derived' ( (otherlv_1= RULE_ID ) ) )
            {
            // InternalTableDSL.g:1738:2: (otherlv_0= 'derived' ( (otherlv_1= RULE_ID ) ) )
            // InternalTableDSL.g:1739:3: otherlv_0= 'derived' ( (otherlv_1= RULE_ID ) )
            {
            otherlv_0=(Token)match(input,51,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getTableDerivedAccess().getDerivedKeyword_0());
              		
            }
            // InternalTableDSL.g:1743:3: ( (otherlv_1= RULE_ID ) )
            // InternalTableDSL.g:1744:4: (otherlv_1= RULE_ID )
            {
            // InternalTableDSL.g:1744:4: (otherlv_1= RULE_ID )
            // InternalTableDSL.g:1745:5: otherlv_1= RULE_ID
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableDerivedRule());
              					}
              				
            }
            otherlv_1=(Token)match(input,RULE_ID,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_1, grammarAccess.getTableDerivedAccess().getValueRefDatamartDerivedMeasureCrossReference_1_0());
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableDerived"


    // $ANTLR start "entryRuleTableHierarchy"
    // InternalTableDSL.g:1760:1: entryRuleTableHierarchy returns [EObject current=null] : iv_ruleTableHierarchy= ruleTableHierarchy EOF ;
    public final EObject entryRuleTableHierarchy() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableHierarchy = null;


        try {
            // InternalTableDSL.g:1760:55: (iv_ruleTableHierarchy= ruleTableHierarchy EOF )
            // InternalTableDSL.g:1761:2: iv_ruleTableHierarchy= ruleTableHierarchy EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableHierarchyRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableHierarchy=ruleTableHierarchy();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableHierarchy; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableHierarchy"


    // $ANTLR start "ruleTableHierarchy"
    // InternalTableDSL.g:1767:1: ruleTableHierarchy returns [EObject current=null] : (otherlv_0= 'level' ( (otherlv_1= RULE_ID ) ) ) ;
    public final EObject ruleTableHierarchy() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token otherlv_1=null;


        	enterRule();

        try {
            // InternalTableDSL.g:1773:2: ( (otherlv_0= 'level' ( (otherlv_1= RULE_ID ) ) ) )
            // InternalTableDSL.g:1774:2: (otherlv_0= 'level' ( (otherlv_1= RULE_ID ) ) )
            {
            // InternalTableDSL.g:1774:2: (otherlv_0= 'level' ( (otherlv_1= RULE_ID ) ) )
            // InternalTableDSL.g:1775:3: otherlv_0= 'level' ( (otherlv_1= RULE_ID ) )
            {
            otherlv_0=(Token)match(input,52,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getTableHierarchyAccess().getLevelKeyword_0());
              		
            }
            // InternalTableDSL.g:1779:3: ( (otherlv_1= RULE_ID ) )
            // InternalTableDSL.g:1780:4: (otherlv_1= RULE_ID )
            {
            // InternalTableDSL.g:1780:4: (otherlv_1= RULE_ID )
            // InternalTableDSL.g:1781:5: otherlv_1= RULE_ID
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableHierarchyRule());
              					}
              				
            }
            otherlv_1=(Token)match(input,RULE_ID,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_1, grammarAccess.getTableHierarchyAccess().getValueRefCubeLevelCrossReference_1_0());
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableHierarchy"


    // $ANTLR start "entryRuleTableAttribute"
    // InternalTableDSL.g:1796:1: entryRuleTableAttribute returns [EObject current=null] : iv_ruleTableAttribute= ruleTableAttribute EOF ;
    public final EObject entryRuleTableAttribute() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableAttribute = null;


        try {
            // InternalTableDSL.g:1796:55: (iv_ruleTableAttribute= ruleTableAttribute EOF )
            // InternalTableDSL.g:1797:2: iv_ruleTableAttribute= ruleTableAttribute EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableAttributeRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableAttribute=ruleTableAttribute();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableAttribute; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableAttribute"


    // $ANTLR start "ruleTableAttribute"
    // InternalTableDSL.g:1803:1: ruleTableAttribute returns [EObject current=null] : ( () otherlv_1= 'property' ( (otherlv_2= RULE_ID ) ) ) ;
    public final EObject ruleTableAttribute() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;


        	enterRule();

        try {
            // InternalTableDSL.g:1809:2: ( ( () otherlv_1= 'property' ( (otherlv_2= RULE_ID ) ) ) )
            // InternalTableDSL.g:1810:2: ( () otherlv_1= 'property' ( (otherlv_2= RULE_ID ) ) )
            {
            // InternalTableDSL.g:1810:2: ( () otherlv_1= 'property' ( (otherlv_2= RULE_ID ) ) )
            // InternalTableDSL.g:1811:3: () otherlv_1= 'property' ( (otherlv_2= RULE_ID ) )
            {
            // InternalTableDSL.g:1811:3: ()
            // InternalTableDSL.g:1812:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableAttributeAccess().getTableAttributeAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,53,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableAttributeAccess().getPropertyKeyword_1());
              		
            }
            // InternalTableDSL.g:1822:3: ( (otherlv_2= RULE_ID ) )
            // InternalTableDSL.g:1823:4: (otherlv_2= RULE_ID )
            {
            // InternalTableDSL.g:1823:4: (otherlv_2= RULE_ID )
            // InternalTableDSL.g:1824:5: otherlv_2= RULE_ID
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableAttributeRule());
              					}
              				
            }
            otherlv_2=(Token)match(input,RULE_ID,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_2, grammarAccess.getTableAttributeAccess().getValueRefDatamartAttributeCrossReference_2_0());
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableAttribute"


    // $ANTLR start "entryRuleTableAggregation"
    // InternalTableDSL.g:1839:1: entryRuleTableAggregation returns [EObject current=null] : iv_ruleTableAggregation= ruleTableAggregation EOF ;
    public final EObject entryRuleTableAggregation() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableAggregation = null;


        try {
            // InternalTableDSL.g:1839:57: (iv_ruleTableAggregation= ruleTableAggregation EOF )
            // InternalTableDSL.g:1840:2: iv_ruleTableAggregation= ruleTableAggregation EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableAggregationRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableAggregation=ruleTableAggregation();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableAggregation; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableAggregation"


    // $ANTLR start "ruleTableAggregation"
    // InternalTableDSL.g:1846:1: ruleTableAggregation returns [EObject current=null] : (otherlv_0= 'aggregation' ( (otherlv_1= RULE_ID ) ) ) ;
    public final EObject ruleTableAggregation() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token otherlv_1=null;


        	enterRule();

        try {
            // InternalTableDSL.g:1852:2: ( (otherlv_0= 'aggregation' ( (otherlv_1= RULE_ID ) ) ) )
            // InternalTableDSL.g:1853:2: (otherlv_0= 'aggregation' ( (otherlv_1= RULE_ID ) ) )
            {
            // InternalTableDSL.g:1853:2: (otherlv_0= 'aggregation' ( (otherlv_1= RULE_ID ) ) )
            // InternalTableDSL.g:1854:3: otherlv_0= 'aggregation' ( (otherlv_1= RULE_ID ) )
            {
            otherlv_0=(Token)match(input,54,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getTableAggregationAccess().getAggregationKeyword_0());
              		
            }
            // InternalTableDSL.g:1858:3: ( (otherlv_1= RULE_ID ) )
            // InternalTableDSL.g:1859:4: (otherlv_1= RULE_ID )
            {
            // InternalTableDSL.g:1859:4: (otherlv_1= RULE_ID )
            // InternalTableDSL.g:1860:5: otherlv_1= RULE_ID
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableAggregationRule());
              					}
              				
            }
            otherlv_1=(Token)match(input,RULE_ID,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_1, grammarAccess.getTableAggregationAccess().getValueRefDatamartSetAggregationFunctionCrossReference_1_0());
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableAggregation"


    // $ANTLR start "entryRuleTableInterval"
    // InternalTableDSL.g:1875:1: entryRuleTableInterval returns [EObject current=null] : iv_ruleTableInterval= ruleTableInterval EOF ;
    public final EObject entryRuleTableInterval() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableInterval = null;


        try {
            // InternalTableDSL.g:1875:54: (iv_ruleTableInterval= ruleTableInterval EOF )
            // InternalTableDSL.g:1876:2: iv_ruleTableInterval= ruleTableInterval EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableIntervalRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableInterval=ruleTableInterval();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableInterval; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableInterval"


    // $ANTLR start "ruleTableInterval"
    // InternalTableDSL.g:1882:1: ruleTableInterval returns [EObject current=null] : (this_TableNumberInterval_0= ruleTableNumberInterval | this_TableIntInterval_1= ruleTableIntInterval | this_TableDateDayInterval_2= ruleTableDateDayInterval ) ;
    public final EObject ruleTableInterval() throws RecognitionException {
        EObject current = null;

        EObject this_TableNumberInterval_0 = null;

        EObject this_TableIntInterval_1 = null;

        EObject this_TableDateDayInterval_2 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:1888:2: ( (this_TableNumberInterval_0= ruleTableNumberInterval | this_TableIntInterval_1= ruleTableIntInterval | this_TableDateDayInterval_2= ruleTableDateDayInterval ) )
            // InternalTableDSL.g:1889:2: (this_TableNumberInterval_0= ruleTableNumberInterval | this_TableIntInterval_1= ruleTableIntInterval | this_TableDateDayInterval_2= ruleTableDateDayInterval )
            {
            // InternalTableDSL.g:1889:2: (this_TableNumberInterval_0= ruleTableNumberInterval | this_TableIntInterval_1= ruleTableIntInterval | this_TableDateDayInterval_2= ruleTableDateDayInterval )
            int alt21=3;
            switch ( input.LA(1) ) {
            case 55:
                {
                alt21=1;
                }
                break;
            case 56:
                {
                alt21=2;
                }
                break;
            case 57:
                {
                alt21=3;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 21, 0, input);

                throw nvae;
            }

            switch (alt21) {
                case 1 :
                    // InternalTableDSL.g:1890:3: this_TableNumberInterval_0= ruleTableNumberInterval
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableIntervalAccess().getTableNumberIntervalParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableNumberInterval_0=ruleTableNumberInterval();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableNumberInterval_0;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:1899:3: this_TableIntInterval_1= ruleTableIntInterval
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableIntervalAccess().getTableIntIntervalParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableIntInterval_1=ruleTableIntInterval();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableIntInterval_1;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:1908:3: this_TableDateDayInterval_2= ruleTableDateDayInterval
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableIntervalAccess().getTableDateDayIntervalParserRuleCall_2());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableDateDayInterval_2=ruleTableDateDayInterval();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableDateDayInterval_2;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableInterval"


    // $ANTLR start "entryRuleTableNumberInterval"
    // InternalTableDSL.g:1920:1: entryRuleTableNumberInterval returns [EObject current=null] : iv_ruleTableNumberInterval= ruleTableNumberInterval EOF ;
    public final EObject entryRuleTableNumberInterval() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableNumberInterval = null;


        try {
            // InternalTableDSL.g:1920:60: (iv_ruleTableNumberInterval= ruleTableNumberInterval EOF )
            // InternalTableDSL.g:1921:2: iv_ruleTableNumberInterval= ruleTableNumberInterval EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableNumberIntervalRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableNumberInterval=ruleTableNumberInterval();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableNumberInterval; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableNumberInterval"


    // $ANTLR start "ruleTableNumberInterval"
    // InternalTableDSL.g:1927:1: ruleTableNumberInterval returns [EObject current=null] : ( () otherlv_1= 'upToNumber' ( (lv_numberIntervalValue_2_0= ruleSignedNumber ) ) ( (lv_numberRange_3_0= ruleTableRangeElement ) ) ) ;
    public final EObject ruleTableNumberInterval() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        AntlrDatatypeRuleToken lv_numberIntervalValue_2_0 = null;

        EObject lv_numberRange_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:1933:2: ( ( () otherlv_1= 'upToNumber' ( (lv_numberIntervalValue_2_0= ruleSignedNumber ) ) ( (lv_numberRange_3_0= ruleTableRangeElement ) ) ) )
            // InternalTableDSL.g:1934:2: ( () otherlv_1= 'upToNumber' ( (lv_numberIntervalValue_2_0= ruleSignedNumber ) ) ( (lv_numberRange_3_0= ruleTableRangeElement ) ) )
            {
            // InternalTableDSL.g:1934:2: ( () otherlv_1= 'upToNumber' ( (lv_numberIntervalValue_2_0= ruleSignedNumber ) ) ( (lv_numberRange_3_0= ruleTableRangeElement ) ) )
            // InternalTableDSL.g:1935:3: () otherlv_1= 'upToNumber' ( (lv_numberIntervalValue_2_0= ruleSignedNumber ) ) ( (lv_numberRange_3_0= ruleTableRangeElement ) )
            {
            // InternalTableDSL.g:1935:3: ()
            // InternalTableDSL.g:1936:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableNumberIntervalAccess().getTableNumberIntervalAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,55,FOLLOW_27); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableNumberIntervalAccess().getUpToNumberKeyword_1());
              		
            }
            // InternalTableDSL.g:1946:3: ( (lv_numberIntervalValue_2_0= ruleSignedNumber ) )
            // InternalTableDSL.g:1947:4: (lv_numberIntervalValue_2_0= ruleSignedNumber )
            {
            // InternalTableDSL.g:1947:4: (lv_numberIntervalValue_2_0= ruleSignedNumber )
            // InternalTableDSL.g:1948:5: lv_numberIntervalValue_2_0= ruleSignedNumber
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableNumberIntervalAccess().getNumberIntervalValueSignedNumberParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_28);
            lv_numberIntervalValue_2_0=ruleSignedNumber();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableNumberIntervalRule());
              					}
              					set(
              						current,
              						"numberIntervalValue",
              						lv_numberIntervalValue_2_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.SignedNumber");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:1965:3: ( (lv_numberRange_3_0= ruleTableRangeElement ) )
            // InternalTableDSL.g:1966:4: (lv_numberRange_3_0= ruleTableRangeElement )
            {
            // InternalTableDSL.g:1966:4: (lv_numberRange_3_0= ruleTableRangeElement )
            // InternalTableDSL.g:1967:5: lv_numberRange_3_0= ruleTableRangeElement
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableNumberIntervalAccess().getNumberRangeTableRangeElementParserRuleCall_3_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_numberRange_3_0=ruleTableRangeElement();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableNumberIntervalRule());
              					}
              					set(
              						current,
              						"numberRange",
              						lv_numberRange_3_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.TableRangeElement");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableNumberInterval"


    // $ANTLR start "entryRuleTableIntInterval"
    // InternalTableDSL.g:1988:1: entryRuleTableIntInterval returns [EObject current=null] : iv_ruleTableIntInterval= ruleTableIntInterval EOF ;
    public final EObject entryRuleTableIntInterval() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableIntInterval = null;


        try {
            // InternalTableDSL.g:1988:57: (iv_ruleTableIntInterval= ruleTableIntInterval EOF )
            // InternalTableDSL.g:1989:2: iv_ruleTableIntInterval= ruleTableIntInterval EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableIntIntervalRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableIntInterval=ruleTableIntInterval();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableIntInterval; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableIntInterval"


    // $ANTLR start "ruleTableIntInterval"
    // InternalTableDSL.g:1995:1: ruleTableIntInterval returns [EObject current=null] : ( () otherlv_1= 'upToInteger' ( (lv_intIntervalValue_2_0= ruleSignedInt ) ) ( (lv_intRange_3_0= ruleTableRangeElement ) ) ) ;
    public final EObject ruleTableIntInterval() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        AntlrDatatypeRuleToken lv_intIntervalValue_2_0 = null;

        EObject lv_intRange_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:2001:2: ( ( () otherlv_1= 'upToInteger' ( (lv_intIntervalValue_2_0= ruleSignedInt ) ) ( (lv_intRange_3_0= ruleTableRangeElement ) ) ) )
            // InternalTableDSL.g:2002:2: ( () otherlv_1= 'upToInteger' ( (lv_intIntervalValue_2_0= ruleSignedInt ) ) ( (lv_intRange_3_0= ruleTableRangeElement ) ) )
            {
            // InternalTableDSL.g:2002:2: ( () otherlv_1= 'upToInteger' ( (lv_intIntervalValue_2_0= ruleSignedInt ) ) ( (lv_intRange_3_0= ruleTableRangeElement ) ) )
            // InternalTableDSL.g:2003:3: () otherlv_1= 'upToInteger' ( (lv_intIntervalValue_2_0= ruleSignedInt ) ) ( (lv_intRange_3_0= ruleTableRangeElement ) )
            {
            // InternalTableDSL.g:2003:3: ()
            // InternalTableDSL.g:2004:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableIntIntervalAccess().getTableIntIntervalAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,56,FOLLOW_29); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableIntIntervalAccess().getUpToIntegerKeyword_1());
              		
            }
            // InternalTableDSL.g:2014:3: ( (lv_intIntervalValue_2_0= ruleSignedInt ) )
            // InternalTableDSL.g:2015:4: (lv_intIntervalValue_2_0= ruleSignedInt )
            {
            // InternalTableDSL.g:2015:4: (lv_intIntervalValue_2_0= ruleSignedInt )
            // InternalTableDSL.g:2016:5: lv_intIntervalValue_2_0= ruleSignedInt
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableIntIntervalAccess().getIntIntervalValueSignedIntParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_28);
            lv_intIntervalValue_2_0=ruleSignedInt();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableIntIntervalRule());
              					}
              					set(
              						current,
              						"intIntervalValue",
              						lv_intIntervalValue_2_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.SignedInt");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:2033:3: ( (lv_intRange_3_0= ruleTableRangeElement ) )
            // InternalTableDSL.g:2034:4: (lv_intRange_3_0= ruleTableRangeElement )
            {
            // InternalTableDSL.g:2034:4: (lv_intRange_3_0= ruleTableRangeElement )
            // InternalTableDSL.g:2035:5: lv_intRange_3_0= ruleTableRangeElement
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableIntIntervalAccess().getIntRangeTableRangeElementParserRuleCall_3_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_intRange_3_0=ruleTableRangeElement();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableIntIntervalRule());
              					}
              					set(
              						current,
              						"intRange",
              						lv_intRange_3_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.TableRangeElement");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableIntInterval"


    // $ANTLR start "entryRuleTableDateDayInterval"
    // InternalTableDSL.g:2056:1: entryRuleTableDateDayInterval returns [EObject current=null] : iv_ruleTableDateDayInterval= ruleTableDateDayInterval EOF ;
    public final EObject entryRuleTableDateDayInterval() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableDateDayInterval = null;


        try {
            // InternalTableDSL.g:2056:61: (iv_ruleTableDateDayInterval= ruleTableDateDayInterval EOF )
            // InternalTableDSL.g:2057:2: iv_ruleTableDateDayInterval= ruleTableDateDayInterval EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableDateDayIntervalRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableDateDayInterval=ruleTableDateDayInterval();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableDateDayInterval; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableDateDayInterval"


    // $ANTLR start "ruleTableDateDayInterval"
    // InternalTableDSL.g:2063:1: ruleTableDateDayInterval returns [EObject current=null] : ( () otherlv_1= 'daysInPast' ( (lv_dateIntervalValue_2_0= ruleSignedInt ) ) ( (lv_dateRange_3_0= ruleTableRangeElement ) ) ) ;
    public final EObject ruleTableDateDayInterval() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        AntlrDatatypeRuleToken lv_dateIntervalValue_2_0 = null;

        EObject lv_dateRange_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:2069:2: ( ( () otherlv_1= 'daysInPast' ( (lv_dateIntervalValue_2_0= ruleSignedInt ) ) ( (lv_dateRange_3_0= ruleTableRangeElement ) ) ) )
            // InternalTableDSL.g:2070:2: ( () otherlv_1= 'daysInPast' ( (lv_dateIntervalValue_2_0= ruleSignedInt ) ) ( (lv_dateRange_3_0= ruleTableRangeElement ) ) )
            {
            // InternalTableDSL.g:2070:2: ( () otherlv_1= 'daysInPast' ( (lv_dateIntervalValue_2_0= ruleSignedInt ) ) ( (lv_dateRange_3_0= ruleTableRangeElement ) ) )
            // InternalTableDSL.g:2071:3: () otherlv_1= 'daysInPast' ( (lv_dateIntervalValue_2_0= ruleSignedInt ) ) ( (lv_dateRange_3_0= ruleTableRangeElement ) )
            {
            // InternalTableDSL.g:2071:3: ()
            // InternalTableDSL.g:2072:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableDateDayIntervalAccess().getTableDateDayIntervalAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,57,FOLLOW_29); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableDateDayIntervalAccess().getDaysInPastKeyword_1());
              		
            }
            // InternalTableDSL.g:2082:3: ( (lv_dateIntervalValue_2_0= ruleSignedInt ) )
            // InternalTableDSL.g:2083:4: (lv_dateIntervalValue_2_0= ruleSignedInt )
            {
            // InternalTableDSL.g:2083:4: (lv_dateIntervalValue_2_0= ruleSignedInt )
            // InternalTableDSL.g:2084:5: lv_dateIntervalValue_2_0= ruleSignedInt
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableDateDayIntervalAccess().getDateIntervalValueSignedIntParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_28);
            lv_dateIntervalValue_2_0=ruleSignedInt();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableDateDayIntervalRule());
              					}
              					set(
              						current,
              						"dateIntervalValue",
              						lv_dateIntervalValue_2_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.SignedInt");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:2101:3: ( (lv_dateRange_3_0= ruleTableRangeElement ) )
            // InternalTableDSL.g:2102:4: (lv_dateRange_3_0= ruleTableRangeElement )
            {
            // InternalTableDSL.g:2102:4: (lv_dateRange_3_0= ruleTableRangeElement )
            // InternalTableDSL.g:2103:5: lv_dateRange_3_0= ruleTableRangeElement
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableDateDayIntervalAccess().getDateRangeTableRangeElementParserRuleCall_3_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_dateRange_3_0=ruleTableRangeElement();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableDateDayIntervalRule());
              					}
              					set(
              						current,
              						"dateRange",
              						lv_dateRange_3_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.TableRangeElement");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableDateDayInterval"


    // $ANTLR start "entryRuleTableLookup"
    // InternalTableDSL.g:2124:1: entryRuleTableLookup returns [EObject current=null] : iv_ruleTableLookup= ruleTableLookup EOF ;
    public final EObject entryRuleTableLookup() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableLookup = null;


        try {
            // InternalTableDSL.g:2124:52: (iv_ruleTableLookup= ruleTableLookup EOF )
            // InternalTableDSL.g:2125:2: iv_ruleTableLookup= ruleTableLookup EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableLookupRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableLookup=ruleTableLookup();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableLookup; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableLookup"


    // $ANTLR start "ruleTableLookup"
    // InternalTableDSL.g:2131:1: ruleTableLookup returns [EObject current=null] : (this_TableNumberLookup_0= ruleTableNumberLookup | this_TableIntLookup_1= ruleTableIntLookup | this_TableStringLookup_2= ruleTableStringLookup | this_TableDateDayLookup_3= ruleTableDateDayLookup ) ;
    public final EObject ruleTableLookup() throws RecognitionException {
        EObject current = null;

        EObject this_TableNumberLookup_0 = null;

        EObject this_TableIntLookup_1 = null;

        EObject this_TableStringLookup_2 = null;

        EObject this_TableDateDayLookup_3 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:2137:2: ( (this_TableNumberLookup_0= ruleTableNumberLookup | this_TableIntLookup_1= ruleTableIntLookup | this_TableStringLookup_2= ruleTableStringLookup | this_TableDateDayLookup_3= ruleTableDateDayLookup ) )
            // InternalTableDSL.g:2138:2: (this_TableNumberLookup_0= ruleTableNumberLookup | this_TableIntLookup_1= ruleTableIntLookup | this_TableStringLookup_2= ruleTableStringLookup | this_TableDateDayLookup_3= ruleTableDateDayLookup )
            {
            // InternalTableDSL.g:2138:2: (this_TableNumberLookup_0= ruleTableNumberLookup | this_TableIntLookup_1= ruleTableIntLookup | this_TableStringLookup_2= ruleTableStringLookup | this_TableDateDayLookup_3= ruleTableDateDayLookup )
            int alt22=4;
            switch ( input.LA(1) ) {
            case 59:
                {
                alt22=1;
                }
                break;
            case 58:
                {
                alt22=2;
                }
                break;
            case 60:
                {
                alt22=3;
                }
                break;
            case 57:
                {
                alt22=4;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 22, 0, input);

                throw nvae;
            }

            switch (alt22) {
                case 1 :
                    // InternalTableDSL.g:2139:3: this_TableNumberLookup_0= ruleTableNumberLookup
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableLookupAccess().getTableNumberLookupParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableNumberLookup_0=ruleTableNumberLookup();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableNumberLookup_0;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:2148:3: this_TableIntLookup_1= ruleTableIntLookup
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableLookupAccess().getTableIntLookupParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableIntLookup_1=ruleTableIntLookup();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableIntLookup_1;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:2157:3: this_TableStringLookup_2= ruleTableStringLookup
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableLookupAccess().getTableStringLookupParserRuleCall_2());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableStringLookup_2=ruleTableStringLookup();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableStringLookup_2;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:2166:3: this_TableDateDayLookup_3= ruleTableDateDayLookup
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableLookupAccess().getTableDateDayLookupParserRuleCall_3());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableDateDayLookup_3=ruleTableDateDayLookup();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableDateDayLookup_3;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableLookup"


    // $ANTLR start "entryRuleTableIntLookup"
    // InternalTableDSL.g:2178:1: entryRuleTableIntLookup returns [EObject current=null] : iv_ruleTableIntLookup= ruleTableIntLookup EOF ;
    public final EObject entryRuleTableIntLookup() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableIntLookup = null;


        try {
            // InternalTableDSL.g:2178:55: (iv_ruleTableIntLookup= ruleTableIntLookup EOF )
            // InternalTableDSL.g:2179:2: iv_ruleTableIntLookup= ruleTableIntLookup EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableIntLookupRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableIntLookup=ruleTableIntLookup();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableIntLookup; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableIntLookup"


    // $ANTLR start "ruleTableIntLookup"
    // InternalTableDSL.g:2185:1: ruleTableIntLookup returns [EObject current=null] : ( () otherlv_1= 'integer' ( (lv_lookupValue_2_0= ruleSignedInt ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) ) ;
    public final EObject ruleTableIntLookup() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        AntlrDatatypeRuleToken lv_lookupValue_2_0 = null;

        EObject lv_discrete_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:2191:2: ( ( () otherlv_1= 'integer' ( (lv_lookupValue_2_0= ruleSignedInt ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) ) )
            // InternalTableDSL.g:2192:2: ( () otherlv_1= 'integer' ( (lv_lookupValue_2_0= ruleSignedInt ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) )
            {
            // InternalTableDSL.g:2192:2: ( () otherlv_1= 'integer' ( (lv_lookupValue_2_0= ruleSignedInt ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) )
            // InternalTableDSL.g:2193:3: () otherlv_1= 'integer' ( (lv_lookupValue_2_0= ruleSignedInt ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) )
            {
            // InternalTableDSL.g:2193:3: ()
            // InternalTableDSL.g:2194:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableIntLookupAccess().getTableIntLookupAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,58,FOLLOW_29); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableIntLookupAccess().getIntegerKeyword_1());
              		
            }
            // InternalTableDSL.g:2204:3: ( (lv_lookupValue_2_0= ruleSignedInt ) )
            // InternalTableDSL.g:2205:4: (lv_lookupValue_2_0= ruleSignedInt )
            {
            // InternalTableDSL.g:2205:4: (lv_lookupValue_2_0= ruleSignedInt )
            // InternalTableDSL.g:2206:5: lv_lookupValue_2_0= ruleSignedInt
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableIntLookupAccess().getLookupValueSignedIntParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_28);
            lv_lookupValue_2_0=ruleSignedInt();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableIntLookupRule());
              					}
              					set(
              						current,
              						"lookupValue",
              						lv_lookupValue_2_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.SignedInt");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:2223:3: ( (lv_discrete_3_0= ruleTableRangeElement ) )
            // InternalTableDSL.g:2224:4: (lv_discrete_3_0= ruleTableRangeElement )
            {
            // InternalTableDSL.g:2224:4: (lv_discrete_3_0= ruleTableRangeElement )
            // InternalTableDSL.g:2225:5: lv_discrete_3_0= ruleTableRangeElement
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableIntLookupAccess().getDiscreteTableRangeElementParserRuleCall_3_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_discrete_3_0=ruleTableRangeElement();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableIntLookupRule());
              					}
              					set(
              						current,
              						"discrete",
              						lv_discrete_3_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.TableRangeElement");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableIntLookup"


    // $ANTLR start "entryRuleTableNumberLookup"
    // InternalTableDSL.g:2246:1: entryRuleTableNumberLookup returns [EObject current=null] : iv_ruleTableNumberLookup= ruleTableNumberLookup EOF ;
    public final EObject entryRuleTableNumberLookup() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableNumberLookup = null;


        try {
            // InternalTableDSL.g:2246:58: (iv_ruleTableNumberLookup= ruleTableNumberLookup EOF )
            // InternalTableDSL.g:2247:2: iv_ruleTableNumberLookup= ruleTableNumberLookup EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableNumberLookupRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableNumberLookup=ruleTableNumberLookup();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableNumberLookup; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableNumberLookup"


    // $ANTLR start "ruleTableNumberLookup"
    // InternalTableDSL.g:2253:1: ruleTableNumberLookup returns [EObject current=null] : ( () otherlv_1= 'number' ( (lv_lookupValue_2_0= ruleSignedNumber ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) ) ;
    public final EObject ruleTableNumberLookup() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        AntlrDatatypeRuleToken lv_lookupValue_2_0 = null;

        EObject lv_discrete_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:2259:2: ( ( () otherlv_1= 'number' ( (lv_lookupValue_2_0= ruleSignedNumber ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) ) )
            // InternalTableDSL.g:2260:2: ( () otherlv_1= 'number' ( (lv_lookupValue_2_0= ruleSignedNumber ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) )
            {
            // InternalTableDSL.g:2260:2: ( () otherlv_1= 'number' ( (lv_lookupValue_2_0= ruleSignedNumber ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) )
            // InternalTableDSL.g:2261:3: () otherlv_1= 'number' ( (lv_lookupValue_2_0= ruleSignedNumber ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) )
            {
            // InternalTableDSL.g:2261:3: ()
            // InternalTableDSL.g:2262:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableNumberLookupAccess().getTableNumberLookupAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,59,FOLLOW_27); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableNumberLookupAccess().getNumberKeyword_1());
              		
            }
            // InternalTableDSL.g:2272:3: ( (lv_lookupValue_2_0= ruleSignedNumber ) )
            // InternalTableDSL.g:2273:4: (lv_lookupValue_2_0= ruleSignedNumber )
            {
            // InternalTableDSL.g:2273:4: (lv_lookupValue_2_0= ruleSignedNumber )
            // InternalTableDSL.g:2274:5: lv_lookupValue_2_0= ruleSignedNumber
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableNumberLookupAccess().getLookupValueSignedNumberParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_28);
            lv_lookupValue_2_0=ruleSignedNumber();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableNumberLookupRule());
              					}
              					set(
              						current,
              						"lookupValue",
              						lv_lookupValue_2_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.SignedNumber");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:2291:3: ( (lv_discrete_3_0= ruleTableRangeElement ) )
            // InternalTableDSL.g:2292:4: (lv_discrete_3_0= ruleTableRangeElement )
            {
            // InternalTableDSL.g:2292:4: (lv_discrete_3_0= ruleTableRangeElement )
            // InternalTableDSL.g:2293:5: lv_discrete_3_0= ruleTableRangeElement
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableNumberLookupAccess().getDiscreteTableRangeElementParserRuleCall_3_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_discrete_3_0=ruleTableRangeElement();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableNumberLookupRule());
              					}
              					set(
              						current,
              						"discrete",
              						lv_discrete_3_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.TableRangeElement");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableNumberLookup"


    // $ANTLR start "entryRuleTableStringLookup"
    // InternalTableDSL.g:2314:1: entryRuleTableStringLookup returns [EObject current=null] : iv_ruleTableStringLookup= ruleTableStringLookup EOF ;
    public final EObject entryRuleTableStringLookup() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableStringLookup = null;


        try {
            // InternalTableDSL.g:2314:58: (iv_ruleTableStringLookup= ruleTableStringLookup EOF )
            // InternalTableDSL.g:2315:2: iv_ruleTableStringLookup= ruleTableStringLookup EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableStringLookupRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableStringLookup=ruleTableStringLookup();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableStringLookup; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableStringLookup"


    // $ANTLR start "ruleTableStringLookup"
    // InternalTableDSL.g:2321:1: ruleTableStringLookup returns [EObject current=null] : ( () otherlv_1= 'string' ( (lv_lookupValue_2_0= RULE_STRING ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) ) ;
    public final EObject ruleTableStringLookup() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token lv_lookupValue_2_0=null;
        EObject lv_discrete_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:2327:2: ( ( () otherlv_1= 'string' ( (lv_lookupValue_2_0= RULE_STRING ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) ) )
            // InternalTableDSL.g:2328:2: ( () otherlv_1= 'string' ( (lv_lookupValue_2_0= RULE_STRING ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) )
            {
            // InternalTableDSL.g:2328:2: ( () otherlv_1= 'string' ( (lv_lookupValue_2_0= RULE_STRING ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) )
            // InternalTableDSL.g:2329:3: () otherlv_1= 'string' ( (lv_lookupValue_2_0= RULE_STRING ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) )
            {
            // InternalTableDSL.g:2329:3: ()
            // InternalTableDSL.g:2330:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableStringLookupAccess().getTableStringLookupAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,60,FOLLOW_8); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableStringLookupAccess().getStringKeyword_1());
              		
            }
            // InternalTableDSL.g:2340:3: ( (lv_lookupValue_2_0= RULE_STRING ) )
            // InternalTableDSL.g:2341:4: (lv_lookupValue_2_0= RULE_STRING )
            {
            // InternalTableDSL.g:2341:4: (lv_lookupValue_2_0= RULE_STRING )
            // InternalTableDSL.g:2342:5: lv_lookupValue_2_0= RULE_STRING
            {
            lv_lookupValue_2_0=(Token)match(input,RULE_STRING,FOLLOW_28); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(lv_lookupValue_2_0, grammarAccess.getTableStringLookupAccess().getLookupValueSTRINGTerminalRuleCall_2_0());
              				
            }
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableStringLookupRule());
              					}
              					setWithLastConsumed(
              						current,
              						"lookupValue",
              						lv_lookupValue_2_0,
              						"org.eclipse.xtext.xbase.Xtype.STRING");
              				
            }

            }


            }

            // InternalTableDSL.g:2358:3: ( (lv_discrete_3_0= ruleTableRangeElement ) )
            // InternalTableDSL.g:2359:4: (lv_discrete_3_0= ruleTableRangeElement )
            {
            // InternalTableDSL.g:2359:4: (lv_discrete_3_0= ruleTableRangeElement )
            // InternalTableDSL.g:2360:5: lv_discrete_3_0= ruleTableRangeElement
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableStringLookupAccess().getDiscreteTableRangeElementParserRuleCall_3_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_discrete_3_0=ruleTableRangeElement();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableStringLookupRule());
              					}
              					set(
              						current,
              						"discrete",
              						lv_discrete_3_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.TableRangeElement");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableStringLookup"


    // $ANTLR start "entryRuleTableDateDayLookup"
    // InternalTableDSL.g:2381:1: entryRuleTableDateDayLookup returns [EObject current=null] : iv_ruleTableDateDayLookup= ruleTableDateDayLookup EOF ;
    public final EObject entryRuleTableDateDayLookup() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableDateDayLookup = null;


        try {
            // InternalTableDSL.g:2381:59: (iv_ruleTableDateDayLookup= ruleTableDateDayLookup EOF )
            // InternalTableDSL.g:2382:2: iv_ruleTableDateDayLookup= ruleTableDateDayLookup EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableDateDayLookupRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableDateDayLookup=ruleTableDateDayLookup();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableDateDayLookup; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableDateDayLookup"


    // $ANTLR start "ruleTableDateDayLookup"
    // InternalTableDSL.g:2388:1: ruleTableDateDayLookup returns [EObject current=null] : ( () otherlv_1= 'daysInPast' ( (lv_lookupValue_2_0= ruleSignedInt ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) ) ;
    public final EObject ruleTableDateDayLookup() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        AntlrDatatypeRuleToken lv_lookupValue_2_0 = null;

        EObject lv_discrete_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:2394:2: ( ( () otherlv_1= 'daysInPast' ( (lv_lookupValue_2_0= ruleSignedInt ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) ) )
            // InternalTableDSL.g:2395:2: ( () otherlv_1= 'daysInPast' ( (lv_lookupValue_2_0= ruleSignedInt ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) )
            {
            // InternalTableDSL.g:2395:2: ( () otherlv_1= 'daysInPast' ( (lv_lookupValue_2_0= ruleSignedInt ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) ) )
            // InternalTableDSL.g:2396:3: () otherlv_1= 'daysInPast' ( (lv_lookupValue_2_0= ruleSignedInt ) ) ( (lv_discrete_3_0= ruleTableRangeElement ) )
            {
            // InternalTableDSL.g:2396:3: ()
            // InternalTableDSL.g:2397:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableDateDayLookupAccess().getTableDateDayLookupAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,57,FOLLOW_29); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableDateDayLookupAccess().getDaysInPastKeyword_1());
              		
            }
            // InternalTableDSL.g:2407:3: ( (lv_lookupValue_2_0= ruleSignedInt ) )
            // InternalTableDSL.g:2408:4: (lv_lookupValue_2_0= ruleSignedInt )
            {
            // InternalTableDSL.g:2408:4: (lv_lookupValue_2_0= ruleSignedInt )
            // InternalTableDSL.g:2409:5: lv_lookupValue_2_0= ruleSignedInt
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableDateDayLookupAccess().getLookupValueSignedIntParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_28);
            lv_lookupValue_2_0=ruleSignedInt();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableDateDayLookupRule());
              					}
              					set(
              						current,
              						"lookupValue",
              						lv_lookupValue_2_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.SignedInt");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:2426:3: ( (lv_discrete_3_0= ruleTableRangeElement ) )
            // InternalTableDSL.g:2427:4: (lv_discrete_3_0= ruleTableRangeElement )
            {
            // InternalTableDSL.g:2427:4: (lv_discrete_3_0= ruleTableRangeElement )
            // InternalTableDSL.g:2428:5: lv_discrete_3_0= ruleTableRangeElement
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableDateDayLookupAccess().getDiscreteTableRangeElementParserRuleCall_3_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_discrete_3_0=ruleTableRangeElement();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableDateDayLookupRule());
              					}
              					set(
              						current,
              						"discrete",
              						lv_discrete_3_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.TableRangeElement");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableDateDayLookup"


    // $ANTLR start "entryRuleTableDatamart"
    // InternalTableDSL.g:2449:1: entryRuleTableDatamart returns [EObject current=null] : iv_ruleTableDatamart= ruleTableDatamart EOF ;
    public final EObject entryRuleTableDatamart() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableDatamart = null;


        try {
            // InternalTableDSL.g:2449:54: (iv_ruleTableDatamart= ruleTableDatamart EOF )
            // InternalTableDSL.g:2450:2: iv_ruleTableDatamart= ruleTableDatamart EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableDatamartRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableDatamart=ruleTableDatamart();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableDatamart; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableDatamart"


    // $ANTLR start "ruleTableDatamart"
    // InternalTableDSL.g:2456:1: ruleTableDatamart returns [EObject current=null] : (otherlv_0= 'datamart' ( (otherlv_1= RULE_ID ) ) (otherlv_2= '{' ( (lv_elements_3_0= ruleTableElement ) )* otherlv_4= '}' )? ) ;
    public final EObject ruleTableDatamart() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token otherlv_1=null;
        Token otherlv_2=null;
        Token otherlv_4=null;
        EObject lv_elements_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:2462:2: ( (otherlv_0= 'datamart' ( (otherlv_1= RULE_ID ) ) (otherlv_2= '{' ( (lv_elements_3_0= ruleTableElement ) )* otherlv_4= '}' )? ) )
            // InternalTableDSL.g:2463:2: (otherlv_0= 'datamart' ( (otherlv_1= RULE_ID ) ) (otherlv_2= '{' ( (lv_elements_3_0= ruleTableElement ) )* otherlv_4= '}' )? )
            {
            // InternalTableDSL.g:2463:2: (otherlv_0= 'datamart' ( (otherlv_1= RULE_ID ) ) (otherlv_2= '{' ( (lv_elements_3_0= ruleTableElement ) )* otherlv_4= '}' )? )
            // InternalTableDSL.g:2464:3: otherlv_0= 'datamart' ( (otherlv_1= RULE_ID ) ) (otherlv_2= '{' ( (lv_elements_3_0= ruleTableElement ) )* otherlv_4= '}' )?
            {
            otherlv_0=(Token)match(input,61,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getTableDatamartAccess().getDatamartKeyword_0());
              		
            }
            // InternalTableDSL.g:2468:3: ( (otherlv_1= RULE_ID ) )
            // InternalTableDSL.g:2469:4: (otherlv_1= RULE_ID )
            {
            // InternalTableDSL.g:2469:4: (otherlv_1= RULE_ID )
            // InternalTableDSL.g:2470:5: otherlv_1= RULE_ID
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableDatamartRule());
              					}
              				
            }
            otherlv_1=(Token)match(input,RULE_ID,FOLLOW_5); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_1, grammarAccess.getTableDatamartAccess().getDatamartRefDatamartDefinitionCrossReference_1_0());
              				
            }

            }


            }

            // InternalTableDSL.g:2481:3: (otherlv_2= '{' ( (lv_elements_3_0= ruleTableElement ) )* otherlv_4= '}' )?
            int alt24=2;
            int LA24_0 = input.LA(1);

            if ( (LA24_0==16) ) {
                alt24=1;
            }
            switch (alt24) {
                case 1 :
                    // InternalTableDSL.g:2482:4: otherlv_2= '{' ( (lv_elements_3_0= ruleTableElement ) )* otherlv_4= '}'
                    {
                    otherlv_2=(Token)match(input,16,FOLLOW_30); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_2, grammarAccess.getTableDatamartAccess().getLeftCurlyBracketKeyword_2_0());
                      			
                    }
                    // InternalTableDSL.g:2486:4: ( (lv_elements_3_0= ruleTableElement ) )*
                    loop23:
                    do {
                        int alt23=2;
                        int LA23_0 = input.LA(1);

                        if ( (LA23_0==62) ) {
                            alt23=1;
                        }


                        switch (alt23) {
                    	case 1 :
                    	    // InternalTableDSL.g:2487:5: (lv_elements_3_0= ruleTableElement )
                    	    {
                    	    // InternalTableDSL.g:2487:5: (lv_elements_3_0= ruleTableElement )
                    	    // InternalTableDSL.g:2488:6: lv_elements_3_0= ruleTableElement
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      						newCompositeNode(grammarAccess.getTableDatamartAccess().getElementsTableElementParserRuleCall_2_1_0());
                    	      					
                    	    }
                    	    pushFollow(FOLLOW_30);
                    	    lv_elements_3_0=ruleTableElement();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      						if (current==null) {
                    	      							current = createModelElementForParent(grammarAccess.getTableDatamartRule());
                    	      						}
                    	      						add(
                    	      							current,
                    	      							"elements",
                    	      							lv_elements_3_0,
                    	      							"org.eclipse.osbp.xtext.table.TableDSL.TableElement");
                    	      						afterParserOrEnumRuleCall();
                    	      					
                    	    }

                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop23;
                        }
                    } while (true);

                    otherlv_4=(Token)match(input,17,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_4, grammarAccess.getTableDatamartAccess().getRightCurlyBracketKeyword_2_2());
                      			
                    }

                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableDatamart"


    // $ANTLR start "entryRuleTableElement"
    // InternalTableDSL.g:2514:1: entryRuleTableElement returns [EObject current=null] : iv_ruleTableElement= ruleTableElement EOF ;
    public final EObject entryRuleTableElement() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableElement = null;


        try {
            // InternalTableDSL.g:2514:53: (iv_ruleTableElement= ruleTableElement EOF )
            // InternalTableDSL.g:2515:2: iv_ruleTableElement= ruleTableElement EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableElementRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableElement=ruleTableElement();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableElement; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableElement"


    // $ANTLR start "ruleTableElement"
    // InternalTableDSL.g:2521:1: ruleTableElement returns [EObject current=null] : this_TableAxis_0= ruleTableAxis ;
    public final EObject ruleTableElement() throws RecognitionException {
        EObject current = null;

        EObject this_TableAxis_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:2527:2: (this_TableAxis_0= ruleTableAxis )
            // InternalTableDSL.g:2528:2: this_TableAxis_0= ruleTableAxis
            {
            if ( state.backtracking==0 ) {

              		newCompositeNode(grammarAccess.getTableElementAccess().getTableAxisParserRuleCall());
              	
            }
            pushFollow(FOLLOW_2);
            this_TableAxis_0=ruleTableAxis();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              		current = this_TableAxis_0;
              		afterParserOrEnumRuleCall();
              	
            }

            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableElement"


    // $ANTLR start "entryRuleTableEvent"
    // InternalTableDSL.g:2539:1: entryRuleTableEvent returns [EObject current=null] : iv_ruleTableEvent= ruleTableEvent EOF ;
    public final EObject entryRuleTableEvent() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableEvent = null;


        try {
            // InternalTableDSL.g:2539:51: (iv_ruleTableEvent= ruleTableEvent EOF )
            // InternalTableDSL.g:2540:2: iv_ruleTableEvent= ruleTableEvent EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableEventRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableEvent=ruleTableEvent();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableEvent; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableEvent"


    // $ANTLR start "ruleTableEvent"
    // InternalTableDSL.g:2546:1: ruleTableEvent returns [EObject current=null] : ( (lv_source_0_0= ruleTableValueElement ) ) ;
    public final EObject ruleTableEvent() throws RecognitionException {
        EObject current = null;

        EObject lv_source_0_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:2552:2: ( ( (lv_source_0_0= ruleTableValueElement ) ) )
            // InternalTableDSL.g:2553:2: ( (lv_source_0_0= ruleTableValueElement ) )
            {
            // InternalTableDSL.g:2553:2: ( (lv_source_0_0= ruleTableValueElement ) )
            // InternalTableDSL.g:2554:3: (lv_source_0_0= ruleTableValueElement )
            {
            // InternalTableDSL.g:2554:3: (lv_source_0_0= ruleTableValueElement )
            // InternalTableDSL.g:2555:4: lv_source_0_0= ruleTableValueElement
            {
            if ( state.backtracking==0 ) {

              				newCompositeNode(grammarAccess.getTableEventAccess().getSourceTableValueElementParserRuleCall_0());
              			
            }
            pushFollow(FOLLOW_2);
            lv_source_0_0=ruleTableValueElement();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              				if (current==null) {
              					current = createModelElementForParent(grammarAccess.getTableEventRule());
              				}
              				set(
              					current,
              					"source",
              					lv_source_0_0,
              					"org.eclipse.osbp.xtext.table.TableDSL.TableValueElement");
              				afterParserOrEnumRuleCall();
              			
            }

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableEvent"


    // $ANTLR start "entryRuleTableAxis"
    // InternalTableDSL.g:2575:1: entryRuleTableAxis returns [EObject current=null] : iv_ruleTableAxis= ruleTableAxis EOF ;
    public final EObject entryRuleTableAxis() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableAxis = null;


        try {
            // InternalTableDSL.g:2575:50: (iv_ruleTableAxis= ruleTableAxis EOF )
            // InternalTableDSL.g:2576:2: iv_ruleTableAxis= ruleTableAxis EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableAxisRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableAxis=ruleTableAxis();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableAxis; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableAxis"


    // $ANTLR start "ruleTableAxis"
    // InternalTableDSL.g:2582:1: ruleTableAxis returns [EObject current=null] : (otherlv_0= 'axis' ( (lv_axis_1_0= ruleAxisEnum ) ) ( ( ( ( ({...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) ) ) )* ) ) ) ( ( (lv_hasDetails_6_0= 'details' ) ) otherlv_7= '{' ( (lv_values_8_0= ruleTableValue ) )* otherlv_9= '}' )? ( ( (lv_hasEvents_10_0= 'notifyOnSelect' ) ) otherlv_11= '{' ( (lv_events_12_0= ruleTableEvent ) )* otherlv_13= '}' )? ) ;
    public final EObject ruleTableAxis() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token lv_hasRowHeight_3_0=null;
        Token lv_hasDetails_6_0=null;
        Token otherlv_7=null;
        Token otherlv_9=null;
        Token lv_hasEvents_10_0=null;
        Token otherlv_11=null;
        Token otherlv_13=null;
        Enumerator lv_axis_1_0 = null;

        AntlrDatatypeRuleToken lv_rowHeight_4_0 = null;

        EObject lv_preOrder_5_0 = null;

        EObject lv_values_8_0 = null;

        EObject lv_events_12_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:2588:2: ( (otherlv_0= 'axis' ( (lv_axis_1_0= ruleAxisEnum ) ) ( ( ( ( ({...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) ) ) )* ) ) ) ( ( (lv_hasDetails_6_0= 'details' ) ) otherlv_7= '{' ( (lv_values_8_0= ruleTableValue ) )* otherlv_9= '}' )? ( ( (lv_hasEvents_10_0= 'notifyOnSelect' ) ) otherlv_11= '{' ( (lv_events_12_0= ruleTableEvent ) )* otherlv_13= '}' )? ) )
            // InternalTableDSL.g:2589:2: (otherlv_0= 'axis' ( (lv_axis_1_0= ruleAxisEnum ) ) ( ( ( ( ({...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) ) ) )* ) ) ) ( ( (lv_hasDetails_6_0= 'details' ) ) otherlv_7= '{' ( (lv_values_8_0= ruleTableValue ) )* otherlv_9= '}' )? ( ( (lv_hasEvents_10_0= 'notifyOnSelect' ) ) otherlv_11= '{' ( (lv_events_12_0= ruleTableEvent ) )* otherlv_13= '}' )? )
            {
            // InternalTableDSL.g:2589:2: (otherlv_0= 'axis' ( (lv_axis_1_0= ruleAxisEnum ) ) ( ( ( ( ({...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) ) ) )* ) ) ) ( ( (lv_hasDetails_6_0= 'details' ) ) otherlv_7= '{' ( (lv_values_8_0= ruleTableValue ) )* otherlv_9= '}' )? ( ( (lv_hasEvents_10_0= 'notifyOnSelect' ) ) otherlv_11= '{' ( (lv_events_12_0= ruleTableEvent ) )* otherlv_13= '}' )? )
            // InternalTableDSL.g:2590:3: otherlv_0= 'axis' ( (lv_axis_1_0= ruleAxisEnum ) ) ( ( ( ( ({...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) ) ) )* ) ) ) ( ( (lv_hasDetails_6_0= 'details' ) ) otherlv_7= '{' ( (lv_values_8_0= ruleTableValue ) )* otherlv_9= '}' )? ( ( (lv_hasEvents_10_0= 'notifyOnSelect' ) ) otherlv_11= '{' ( (lv_events_12_0= ruleTableEvent ) )* otherlv_13= '}' )?
            {
            otherlv_0=(Token)match(input,62,FOLLOW_31); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getTableAxisAccess().getAxisKeyword_0());
              		
            }
            // InternalTableDSL.g:2594:3: ( (lv_axis_1_0= ruleAxisEnum ) )
            // InternalTableDSL.g:2595:4: (lv_axis_1_0= ruleAxisEnum )
            {
            // InternalTableDSL.g:2595:4: (lv_axis_1_0= ruleAxisEnum )
            // InternalTableDSL.g:2596:5: lv_axis_1_0= ruleAxisEnum
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableAxisAccess().getAxisAxisEnumEnumRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_32);
            lv_axis_1_0=ruleAxisEnum();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableAxisRule());
              					}
              					set(
              						current,
              						"axis",
              						lv_axis_1_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.AxisEnum");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:2613:3: ( ( ( ( ({...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) ) ) )* ) ) )
            // InternalTableDSL.g:2614:4: ( ( ( ({...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) ) ) )* ) )
            {
            // InternalTableDSL.g:2614:4: ( ( ( ({...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) ) ) )* ) )
            // InternalTableDSL.g:2615:5: ( ( ({...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) ) ) )* )
            {
            getUnorderedGroupHelper().enter(grammarAccess.getTableAxisAccess().getUnorderedGroup_2());
            // InternalTableDSL.g:2618:5: ( ( ({...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) ) ) )* )
            // InternalTableDSL.g:2619:6: ( ({...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) ) ) )*
            {
            // InternalTableDSL.g:2619:6: ( ({...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) ) ) | ({...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) ) ) )*
            loop25:
            do {
                int alt25=3;
                int LA25_0 = input.LA(1);

                if ( LA25_0 == 63 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableAxisAccess().getUnorderedGroup_2(), 0) ) {
                    alt25=1;
                }
                else if ( LA25_0 == 32 && getUnorderedGroupHelper().canSelect(grammarAccess.getTableAxisAccess().getUnorderedGroup_2(), 1) ) {
                    alt25=2;
                }


                switch (alt25) {
            	case 1 :
            	    // InternalTableDSL.g:2620:4: ({...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:2620:4: ({...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) ) )
            	    // InternalTableDSL.g:2621:5: {...}? => ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableAxisAccess().getUnorderedGroup_2(), 0) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableAxis", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableAxisAccess().getUnorderedGroup_2(), 0)");
            	    }
            	    // InternalTableDSL.g:2621:106: ( ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) ) )
            	    // InternalTableDSL.g:2622:6: ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableAxisAccess().getUnorderedGroup_2(), 0);
            	    // InternalTableDSL.g:2625:9: ({...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) ) )
            	    // InternalTableDSL.g:2625:10: {...}? => ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableAxis", "true");
            	    }
            	    // InternalTableDSL.g:2625:19: ( ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) ) )
            	    // InternalTableDSL.g:2625:20: ( (lv_hasRowHeight_3_0= 'rowheight' ) ) ( (lv_rowHeight_4_0= ruleNumber ) )
            	    {
            	    // InternalTableDSL.g:2625:20: ( (lv_hasRowHeight_3_0= 'rowheight' ) )
            	    // InternalTableDSL.g:2626:10: (lv_hasRowHeight_3_0= 'rowheight' )
            	    {
            	    // InternalTableDSL.g:2626:10: (lv_hasRowHeight_3_0= 'rowheight' )
            	    // InternalTableDSL.g:2627:11: lv_hasRowHeight_3_0= 'rowheight'
            	    {
            	    lv_hasRowHeight_3_0=(Token)match(input,63,FOLLOW_26); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      											newLeafNode(lv_hasRowHeight_3_0, grammarAccess.getTableAxisAccess().getHasRowHeightRowheightKeyword_2_0_0_0());
            	      										
            	    }
            	    if ( state.backtracking==0 ) {

            	      											if (current==null) {
            	      												current = createModelElement(grammarAccess.getTableAxisRule());
            	      											}
            	      											setWithLastConsumed(current, "hasRowHeight", true, "rowheight");
            	      										
            	    }

            	    }


            	    }

            	    // InternalTableDSL.g:2639:9: ( (lv_rowHeight_4_0= ruleNumber ) )
            	    // InternalTableDSL.g:2640:10: (lv_rowHeight_4_0= ruleNumber )
            	    {
            	    // InternalTableDSL.g:2640:10: (lv_rowHeight_4_0= ruleNumber )
            	    // InternalTableDSL.g:2641:11: lv_rowHeight_4_0= ruleNumber
            	    {
            	    if ( state.backtracking==0 ) {

            	      											newCompositeNode(grammarAccess.getTableAxisAccess().getRowHeightNumberParserRuleCall_2_0_1_0());
            	      										
            	    }
            	    pushFollow(FOLLOW_32);
            	    lv_rowHeight_4_0=ruleNumber();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      											if (current==null) {
            	      												current = createModelElementForParent(grammarAccess.getTableAxisRule());
            	      											}
            	      											set(
            	      												current,
            	      												"rowHeight",
            	      												lv_rowHeight_4_0,
            	      												"org.eclipse.xtext.xbase.Xbase.Number");
            	      											afterParserOrEnumRuleCall();
            	      										
            	    }

            	    }


            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableAxisAccess().getUnorderedGroup_2());

            	    }


            	    }


            	    }
            	    break;
            	case 2 :
            	    // InternalTableDSL.g:2664:4: ({...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) ) )
            	    {
            	    // InternalTableDSL.g:2664:4: ({...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) ) )
            	    // InternalTableDSL.g:2665:5: {...}? => ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) )
            	    {
            	    if ( ! getUnorderedGroupHelper().canSelect(grammarAccess.getTableAxisAccess().getUnorderedGroup_2(), 1) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableAxis", "getUnorderedGroupHelper().canSelect(grammarAccess.getTableAxisAccess().getUnorderedGroup_2(), 1)");
            	    }
            	    // InternalTableDSL.g:2665:106: ( ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) ) )
            	    // InternalTableDSL.g:2666:6: ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) )
            	    {
            	    getUnorderedGroupHelper().select(grammarAccess.getTableAxisAccess().getUnorderedGroup_2(), 1);
            	    // InternalTableDSL.g:2669:9: ({...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) ) )
            	    // InternalTableDSL.g:2669:10: {...}? => ( (lv_preOrder_5_0= ruleTablePreorder ) )
            	    {
            	    if ( !((true)) ) {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        throw new FailedPredicateException(input, "ruleTableAxis", "true");
            	    }
            	    // InternalTableDSL.g:2669:19: ( (lv_preOrder_5_0= ruleTablePreorder ) )
            	    // InternalTableDSL.g:2669:20: (lv_preOrder_5_0= ruleTablePreorder )
            	    {
            	    // InternalTableDSL.g:2669:20: (lv_preOrder_5_0= ruleTablePreorder )
            	    // InternalTableDSL.g:2670:10: lv_preOrder_5_0= ruleTablePreorder
            	    {
            	    if ( state.backtracking==0 ) {

            	      										newCompositeNode(grammarAccess.getTableAxisAccess().getPreOrderTablePreorderParserRuleCall_2_1_0());
            	      									
            	    }
            	    pushFollow(FOLLOW_32);
            	    lv_preOrder_5_0=ruleTablePreorder();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      										if (current==null) {
            	      											current = createModelElementForParent(grammarAccess.getTableAxisRule());
            	      										}
            	      										set(
            	      											current,
            	      											"preOrder",
            	      											lv_preOrder_5_0,
            	      											"org.eclipse.osbp.xtext.table.TableDSL.TablePreorder");
            	      										afterParserOrEnumRuleCall();
            	      									
            	    }

            	    }


            	    }


            	    }

            	    getUnorderedGroupHelper().returnFromSelection(grammarAccess.getTableAxisAccess().getUnorderedGroup_2());

            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop25;
                }
            } while (true);


            }


            }

            getUnorderedGroupHelper().leave(grammarAccess.getTableAxisAccess().getUnorderedGroup_2());

            }

            // InternalTableDSL.g:2699:3: ( ( (lv_hasDetails_6_0= 'details' ) ) otherlv_7= '{' ( (lv_values_8_0= ruleTableValue ) )* otherlv_9= '}' )?
            int alt27=2;
            int LA27_0 = input.LA(1);

            if ( (LA27_0==64) ) {
                alt27=1;
            }
            switch (alt27) {
                case 1 :
                    // InternalTableDSL.g:2700:4: ( (lv_hasDetails_6_0= 'details' ) ) otherlv_7= '{' ( (lv_values_8_0= ruleTableValue ) )* otherlv_9= '}'
                    {
                    // InternalTableDSL.g:2700:4: ( (lv_hasDetails_6_0= 'details' ) )
                    // InternalTableDSL.g:2701:5: (lv_hasDetails_6_0= 'details' )
                    {
                    // InternalTableDSL.g:2701:5: (lv_hasDetails_6_0= 'details' )
                    // InternalTableDSL.g:2702:6: lv_hasDetails_6_0= 'details'
                    {
                    lv_hasDetails_6_0=(Token)match(input,64,FOLLOW_21); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						newLeafNode(lv_hasDetails_6_0, grammarAccess.getTableAxisAccess().getHasDetailsDetailsKeyword_3_0_0());
                      					
                    }
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElement(grammarAccess.getTableAxisRule());
                      						}
                      						setWithLastConsumed(current, "hasDetails", true, "details");
                      					
                    }

                    }


                    }

                    otherlv_7=(Token)match(input,16,FOLLOW_33); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_7, grammarAccess.getTableAxisAccess().getLeftCurlyBracketKeyword_3_1());
                      			
                    }
                    // InternalTableDSL.g:2718:4: ( (lv_values_8_0= ruleTableValue ) )*
                    loop26:
                    do {
                        int alt26=2;
                        int LA26_0 = input.LA(1);

                        if ( (LA26_0==34) ) {
                            alt26=1;
                        }


                        switch (alt26) {
                    	case 1 :
                    	    // InternalTableDSL.g:2719:5: (lv_values_8_0= ruleTableValue )
                    	    {
                    	    // InternalTableDSL.g:2719:5: (lv_values_8_0= ruleTableValue )
                    	    // InternalTableDSL.g:2720:6: lv_values_8_0= ruleTableValue
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      						newCompositeNode(grammarAccess.getTableAxisAccess().getValuesTableValueParserRuleCall_3_2_0());
                    	      					
                    	    }
                    	    pushFollow(FOLLOW_33);
                    	    lv_values_8_0=ruleTableValue();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      						if (current==null) {
                    	      							current = createModelElementForParent(grammarAccess.getTableAxisRule());
                    	      						}
                    	      						add(
                    	      							current,
                    	      							"values",
                    	      							lv_values_8_0,
                    	      							"org.eclipse.osbp.xtext.table.TableDSL.TableValue");
                    	      						afterParserOrEnumRuleCall();
                    	      					
                    	    }

                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop26;
                        }
                    } while (true);

                    otherlv_9=(Token)match(input,17,FOLLOW_34); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_9, grammarAccess.getTableAxisAccess().getRightCurlyBracketKeyword_3_3());
                      			
                    }

                    }
                    break;

            }

            // InternalTableDSL.g:2742:3: ( ( (lv_hasEvents_10_0= 'notifyOnSelect' ) ) otherlv_11= '{' ( (lv_events_12_0= ruleTableEvent ) )* otherlv_13= '}' )?
            int alt29=2;
            int LA29_0 = input.LA(1);

            if ( (LA29_0==65) ) {
                alt29=1;
            }
            switch (alt29) {
                case 1 :
                    // InternalTableDSL.g:2743:4: ( (lv_hasEvents_10_0= 'notifyOnSelect' ) ) otherlv_11= '{' ( (lv_events_12_0= ruleTableEvent ) )* otherlv_13= '}'
                    {
                    // InternalTableDSL.g:2743:4: ( (lv_hasEvents_10_0= 'notifyOnSelect' ) )
                    // InternalTableDSL.g:2744:5: (lv_hasEvents_10_0= 'notifyOnSelect' )
                    {
                    // InternalTableDSL.g:2744:5: (lv_hasEvents_10_0= 'notifyOnSelect' )
                    // InternalTableDSL.g:2745:6: lv_hasEvents_10_0= 'notifyOnSelect'
                    {
                    lv_hasEvents_10_0=(Token)match(input,65,FOLLOW_21); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						newLeafNode(lv_hasEvents_10_0, grammarAccess.getTableAxisAccess().getHasEventsNotifyOnSelectKeyword_4_0_0());
                      					
                    }
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElement(grammarAccess.getTableAxisRule());
                      						}
                      						setWithLastConsumed(current, "hasEvents", true, "notifyOnSelect");
                      					
                    }

                    }


                    }

                    otherlv_11=(Token)match(input,16,FOLLOW_35); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_11, grammarAccess.getTableAxisAccess().getLeftCurlyBracketKeyword_4_1());
                      			
                    }
                    // InternalTableDSL.g:2761:4: ( (lv_events_12_0= ruleTableEvent ) )*
                    loop28:
                    do {
                        int alt28=2;
                        int LA28_0 = input.LA(1);

                        if ( ((LA28_0>=46 && LA28_0<=54)) ) {
                            alt28=1;
                        }


                        switch (alt28) {
                    	case 1 :
                    	    // InternalTableDSL.g:2762:5: (lv_events_12_0= ruleTableEvent )
                    	    {
                    	    // InternalTableDSL.g:2762:5: (lv_events_12_0= ruleTableEvent )
                    	    // InternalTableDSL.g:2763:6: lv_events_12_0= ruleTableEvent
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      						newCompositeNode(grammarAccess.getTableAxisAccess().getEventsTableEventParserRuleCall_4_2_0());
                    	      					
                    	    }
                    	    pushFollow(FOLLOW_35);
                    	    lv_events_12_0=ruleTableEvent();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      						if (current==null) {
                    	      							current = createModelElementForParent(grammarAccess.getTableAxisRule());
                    	      						}
                    	      						add(
                    	      							current,
                    	      							"events",
                    	      							lv_events_12_0,
                    	      							"org.eclipse.osbp.xtext.table.TableDSL.TableEvent");
                    	      						afterParserOrEnumRuleCall();
                    	      					
                    	    }

                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop28;
                        }
                    } while (true);

                    otherlv_13=(Token)match(input,17,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_13, grammarAccess.getTableAxisAccess().getRightCurlyBracketKeyword_4_3());
                      			
                    }

                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableAxis"


    // $ANTLR start "entryRuleTableRangeElement"
    // InternalTableDSL.g:2789:1: entryRuleTableRangeElement returns [EObject current=null] : iv_ruleTableRangeElement= ruleTableRangeElement EOF ;
    public final EObject entryRuleTableRangeElement() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableRangeElement = null;


        try {
            // InternalTableDSL.g:2789:58: (iv_ruleTableRangeElement= ruleTableRangeElement EOF )
            // InternalTableDSL.g:2790:2: iv_ruleTableRangeElement= ruleTableRangeElement EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableRangeElementRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableRangeElement=ruleTableRangeElement();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableRangeElement; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableRangeElement"


    // $ANTLR start "ruleTableRangeElement"
    // InternalTableDSL.g:2796:1: ruleTableRangeElement returns [EObject current=null] : (this_TableTextColor_0= ruleTableTextColor | this_TableCellColor_1= ruleTableCellColor | this_TableIcon_2= ruleTableIcon | this_TableTrend_3= ruleTableTrend | this_TableTooltip_4= ruleTableTooltip ) ;
    public final EObject ruleTableRangeElement() throws RecognitionException {
        EObject current = null;

        EObject this_TableTextColor_0 = null;

        EObject this_TableCellColor_1 = null;

        EObject this_TableIcon_2 = null;

        EObject this_TableTrend_3 = null;

        EObject this_TableTooltip_4 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:2802:2: ( (this_TableTextColor_0= ruleTableTextColor | this_TableCellColor_1= ruleTableCellColor | this_TableIcon_2= ruleTableIcon | this_TableTrend_3= ruleTableTrend | this_TableTooltip_4= ruleTableTooltip ) )
            // InternalTableDSL.g:2803:2: (this_TableTextColor_0= ruleTableTextColor | this_TableCellColor_1= ruleTableCellColor | this_TableIcon_2= ruleTableIcon | this_TableTrend_3= ruleTableTrend | this_TableTooltip_4= ruleTableTooltip )
            {
            // InternalTableDSL.g:2803:2: (this_TableTextColor_0= ruleTableTextColor | this_TableCellColor_1= ruleTableCellColor | this_TableIcon_2= ruleTableIcon | this_TableTrend_3= ruleTableTrend | this_TableTooltip_4= ruleTableTooltip )
            int alt30=5;
            switch ( input.LA(1) ) {
            case 66:
                {
                alt30=1;
                }
                break;
            case 67:
                {
                alt30=2;
                }
                break;
            case 36:
                {
                alt30=3;
                }
                break;
            case 68:
                {
                alt30=4;
                }
                break;
            case 69:
                {
                alt30=5;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 30, 0, input);

                throw nvae;
            }

            switch (alt30) {
                case 1 :
                    // InternalTableDSL.g:2804:3: this_TableTextColor_0= ruleTableTextColor
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableRangeElementAccess().getTableTextColorParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableTextColor_0=ruleTableTextColor();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableTextColor_0;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:2813:3: this_TableCellColor_1= ruleTableCellColor
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableRangeElementAccess().getTableCellColorParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableCellColor_1=ruleTableCellColor();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableCellColor_1;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:2822:3: this_TableIcon_2= ruleTableIcon
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableRangeElementAccess().getTableIconParserRuleCall_2());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableIcon_2=ruleTableIcon();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableIcon_2;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:2831:3: this_TableTrend_3= ruleTableTrend
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableRangeElementAccess().getTableTrendParserRuleCall_3());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableTrend_3=ruleTableTrend();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableTrend_3;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 5 :
                    // InternalTableDSL.g:2840:3: this_TableTooltip_4= ruleTableTooltip
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getTableRangeElementAccess().getTableTooltipParserRuleCall_4());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_TableTooltip_4=ruleTableTooltip();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_TableTooltip_4;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableRangeElement"


    // $ANTLR start "entryRuleTableTextColor"
    // InternalTableDSL.g:2852:1: entryRuleTableTextColor returns [EObject current=null] : iv_ruleTableTextColor= ruleTableTextColor EOF ;
    public final EObject entryRuleTableTextColor() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableTextColor = null;


        try {
            // InternalTableDSL.g:2852:55: (iv_ruleTableTextColor= ruleTableTextColor EOF )
            // InternalTableDSL.g:2853:2: iv_ruleTableTextColor= ruleTableTextColor EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableTextColorRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableTextColor=ruleTableTextColor();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableTextColor; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableTextColor"


    // $ANTLR start "ruleTableTextColor"
    // InternalTableDSL.g:2859:1: ruleTableTextColor returns [EObject current=null] : (otherlv_0= 'textcolor' ( (lv_rgb_1_0= RULE_STRING ) ) ) ;
    public final EObject ruleTableTextColor() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token lv_rgb_1_0=null;


        	enterRule();

        try {
            // InternalTableDSL.g:2865:2: ( (otherlv_0= 'textcolor' ( (lv_rgb_1_0= RULE_STRING ) ) ) )
            // InternalTableDSL.g:2866:2: (otherlv_0= 'textcolor' ( (lv_rgb_1_0= RULE_STRING ) ) )
            {
            // InternalTableDSL.g:2866:2: (otherlv_0= 'textcolor' ( (lv_rgb_1_0= RULE_STRING ) ) )
            // InternalTableDSL.g:2867:3: otherlv_0= 'textcolor' ( (lv_rgb_1_0= RULE_STRING ) )
            {
            otherlv_0=(Token)match(input,66,FOLLOW_8); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getTableTextColorAccess().getTextcolorKeyword_0());
              		
            }
            // InternalTableDSL.g:2871:3: ( (lv_rgb_1_0= RULE_STRING ) )
            // InternalTableDSL.g:2872:4: (lv_rgb_1_0= RULE_STRING )
            {
            // InternalTableDSL.g:2872:4: (lv_rgb_1_0= RULE_STRING )
            // InternalTableDSL.g:2873:5: lv_rgb_1_0= RULE_STRING
            {
            lv_rgb_1_0=(Token)match(input,RULE_STRING,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(lv_rgb_1_0, grammarAccess.getTableTextColorAccess().getRgbSTRINGTerminalRuleCall_1_0());
              				
            }
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableTextColorRule());
              					}
              					setWithLastConsumed(
              						current,
              						"rgb",
              						lv_rgb_1_0,
              						"org.eclipse.xtext.xbase.Xtype.STRING");
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableTextColor"


    // $ANTLR start "entryRuleTableCellColor"
    // InternalTableDSL.g:2893:1: entryRuleTableCellColor returns [EObject current=null] : iv_ruleTableCellColor= ruleTableCellColor EOF ;
    public final EObject entryRuleTableCellColor() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableCellColor = null;


        try {
            // InternalTableDSL.g:2893:55: (iv_ruleTableCellColor= ruleTableCellColor EOF )
            // InternalTableDSL.g:2894:2: iv_ruleTableCellColor= ruleTableCellColor EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableCellColorRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableCellColor=ruleTableCellColor();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableCellColor; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableCellColor"


    // $ANTLR start "ruleTableCellColor"
    // InternalTableDSL.g:2900:1: ruleTableCellColor returns [EObject current=null] : (otherlv_0= 'cellcolor' ( (lv_rgb_1_0= RULE_STRING ) ) ) ;
    public final EObject ruleTableCellColor() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token lv_rgb_1_0=null;


        	enterRule();

        try {
            // InternalTableDSL.g:2906:2: ( (otherlv_0= 'cellcolor' ( (lv_rgb_1_0= RULE_STRING ) ) ) )
            // InternalTableDSL.g:2907:2: (otherlv_0= 'cellcolor' ( (lv_rgb_1_0= RULE_STRING ) ) )
            {
            // InternalTableDSL.g:2907:2: (otherlv_0= 'cellcolor' ( (lv_rgb_1_0= RULE_STRING ) ) )
            // InternalTableDSL.g:2908:3: otherlv_0= 'cellcolor' ( (lv_rgb_1_0= RULE_STRING ) )
            {
            otherlv_0=(Token)match(input,67,FOLLOW_8); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getTableCellColorAccess().getCellcolorKeyword_0());
              		
            }
            // InternalTableDSL.g:2912:3: ( (lv_rgb_1_0= RULE_STRING ) )
            // InternalTableDSL.g:2913:4: (lv_rgb_1_0= RULE_STRING )
            {
            // InternalTableDSL.g:2913:4: (lv_rgb_1_0= RULE_STRING )
            // InternalTableDSL.g:2914:5: lv_rgb_1_0= RULE_STRING
            {
            lv_rgb_1_0=(Token)match(input,RULE_STRING,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(lv_rgb_1_0, grammarAccess.getTableCellColorAccess().getRgbSTRINGTerminalRuleCall_1_0());
              				
            }
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableCellColorRule());
              					}
              					setWithLastConsumed(
              						current,
              						"rgb",
              						lv_rgb_1_0,
              						"org.eclipse.xtext.xbase.Xtype.STRING");
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableCellColor"


    // $ANTLR start "entryRuleTableIcon"
    // InternalTableDSL.g:2934:1: entryRuleTableIcon returns [EObject current=null] : iv_ruleTableIcon= ruleTableIcon EOF ;
    public final EObject entryRuleTableIcon() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableIcon = null;


        try {
            // InternalTableDSL.g:2934:50: (iv_ruleTableIcon= ruleTableIcon EOF )
            // InternalTableDSL.g:2935:2: iv_ruleTableIcon= ruleTableIcon EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableIconRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableIcon=ruleTableIcon();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableIcon; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableIcon"


    // $ANTLR start "ruleTableIcon"
    // InternalTableDSL.g:2941:1: ruleTableIcon returns [EObject current=null] : (otherlv_0= 'icon' ( (lv_icon_1_0= RULE_STRING ) ) ) ;
    public final EObject ruleTableIcon() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token lv_icon_1_0=null;


        	enterRule();

        try {
            // InternalTableDSL.g:2947:2: ( (otherlv_0= 'icon' ( (lv_icon_1_0= RULE_STRING ) ) ) )
            // InternalTableDSL.g:2948:2: (otherlv_0= 'icon' ( (lv_icon_1_0= RULE_STRING ) ) )
            {
            // InternalTableDSL.g:2948:2: (otherlv_0= 'icon' ( (lv_icon_1_0= RULE_STRING ) ) )
            // InternalTableDSL.g:2949:3: otherlv_0= 'icon' ( (lv_icon_1_0= RULE_STRING ) )
            {
            otherlv_0=(Token)match(input,36,FOLLOW_8); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getTableIconAccess().getIconKeyword_0());
              		
            }
            // InternalTableDSL.g:2953:3: ( (lv_icon_1_0= RULE_STRING ) )
            // InternalTableDSL.g:2954:4: (lv_icon_1_0= RULE_STRING )
            {
            // InternalTableDSL.g:2954:4: (lv_icon_1_0= RULE_STRING )
            // InternalTableDSL.g:2955:5: lv_icon_1_0= RULE_STRING
            {
            lv_icon_1_0=(Token)match(input,RULE_STRING,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(lv_icon_1_0, grammarAccess.getTableIconAccess().getIconSTRINGTerminalRuleCall_1_0());
              				
            }
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableIconRule());
              					}
              					setWithLastConsumed(
              						current,
              						"icon",
              						lv_icon_1_0,
              						"org.eclipse.xtext.xbase.Xtype.STRING");
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableIcon"


    // $ANTLR start "entryRuleTableTrend"
    // InternalTableDSL.g:2975:1: entryRuleTableTrend returns [EObject current=null] : iv_ruleTableTrend= ruleTableTrend EOF ;
    public final EObject entryRuleTableTrend() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableTrend = null;


        try {
            // InternalTableDSL.g:2975:51: (iv_ruleTableTrend= ruleTableTrend EOF )
            // InternalTableDSL.g:2976:2: iv_ruleTableTrend= ruleTableTrend EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableTrendRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableTrend=ruleTableTrend();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableTrend; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableTrend"


    // $ANTLR start "ruleTableTrend"
    // InternalTableDSL.g:2982:1: ruleTableTrend returns [EObject current=null] : (otherlv_0= 'trend' ( (lv_icon_1_0= ruleTrendIconEnum ) ) ) ;
    public final EObject ruleTableTrend() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Enumerator lv_icon_1_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:2988:2: ( (otherlv_0= 'trend' ( (lv_icon_1_0= ruleTrendIconEnum ) ) ) )
            // InternalTableDSL.g:2989:2: (otherlv_0= 'trend' ( (lv_icon_1_0= ruleTrendIconEnum ) ) )
            {
            // InternalTableDSL.g:2989:2: (otherlv_0= 'trend' ( (lv_icon_1_0= ruleTrendIconEnum ) ) )
            // InternalTableDSL.g:2990:3: otherlv_0= 'trend' ( (lv_icon_1_0= ruleTrendIconEnum ) )
            {
            otherlv_0=(Token)match(input,68,FOLLOW_36); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getTableTrendAccess().getTrendKeyword_0());
              		
            }
            // InternalTableDSL.g:2994:3: ( (lv_icon_1_0= ruleTrendIconEnum ) )
            // InternalTableDSL.g:2995:4: (lv_icon_1_0= ruleTrendIconEnum )
            {
            // InternalTableDSL.g:2995:4: (lv_icon_1_0= ruleTrendIconEnum )
            // InternalTableDSL.g:2996:5: lv_icon_1_0= ruleTrendIconEnum
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableTrendAccess().getIconTrendIconEnumEnumRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_icon_1_0=ruleTrendIconEnum();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableTrendRule());
              					}
              					set(
              						current,
              						"icon",
              						lv_icon_1_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.TrendIconEnum");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableTrend"


    // $ANTLR start "entryRuleTableTooltip"
    // InternalTableDSL.g:3017:1: entryRuleTableTooltip returns [EObject current=null] : iv_ruleTableTooltip= ruleTableTooltip EOF ;
    public final EObject entryRuleTableTooltip() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableTooltip = null;


        try {
            // InternalTableDSL.g:3017:53: (iv_ruleTableTooltip= ruleTableTooltip EOF )
            // InternalTableDSL.g:3018:2: iv_ruleTableTooltip= ruleTableTooltip EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableTooltipRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableTooltip=ruleTableTooltip();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableTooltip; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableTooltip"


    // $ANTLR start "ruleTableTooltip"
    // InternalTableDSL.g:3024:1: ruleTableTooltip returns [EObject current=null] : (otherlv_0= 'tooltip' ( (lv_tooltip_1_0= ruleTRANSLATABLESTRING ) ) ) ;
    public final EObject ruleTableTooltip() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        AntlrDatatypeRuleToken lv_tooltip_1_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:3030:2: ( (otherlv_0= 'tooltip' ( (lv_tooltip_1_0= ruleTRANSLATABLESTRING ) ) ) )
            // InternalTableDSL.g:3031:2: (otherlv_0= 'tooltip' ( (lv_tooltip_1_0= ruleTRANSLATABLESTRING ) ) )
            {
            // InternalTableDSL.g:3031:2: (otherlv_0= 'tooltip' ( (lv_tooltip_1_0= ruleTRANSLATABLESTRING ) ) )
            // InternalTableDSL.g:3032:3: otherlv_0= 'tooltip' ( (lv_tooltip_1_0= ruleTRANSLATABLESTRING ) )
            {
            otherlv_0=(Token)match(input,69,FOLLOW_8); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getTableTooltipAccess().getTooltipKeyword_0());
              		
            }
            // InternalTableDSL.g:3036:3: ( (lv_tooltip_1_0= ruleTRANSLATABLESTRING ) )
            // InternalTableDSL.g:3037:4: (lv_tooltip_1_0= ruleTRANSLATABLESTRING )
            {
            // InternalTableDSL.g:3037:4: (lv_tooltip_1_0= ruleTRANSLATABLESTRING )
            // InternalTableDSL.g:3038:5: lv_tooltip_1_0= ruleTRANSLATABLESTRING
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableTooltipAccess().getTooltipTRANSLATABLESTRINGParserRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_tooltip_1_0=ruleTRANSLATABLESTRING();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableTooltipRule());
              					}
              					set(
              						current,
              						"tooltip",
              						lv_tooltip_1_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.TRANSLATABLESTRING");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableTooltip"


    // $ANTLR start "entryRuleTableGrid"
    // InternalTableDSL.g:3059:1: entryRuleTableGrid returns [EObject current=null] : iv_ruleTableGrid= ruleTableGrid EOF ;
    public final EObject entryRuleTableGrid() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableGrid = null;


        try {
            // InternalTableDSL.g:3059:50: (iv_ruleTableGrid= ruleTableGrid EOF )
            // InternalTableDSL.g:3060:2: iv_ruleTableGrid= ruleTableGrid EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableGridRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableGrid=ruleTableGrid();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableGrid; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableGrid"


    // $ANTLR start "ruleTableGrid"
    // InternalTableDSL.g:3066:1: ruleTableGrid returns [EObject current=null] : ( () otherlv_1= 'editable' otherlv_2= 'using' ( (lv_source_3_0= ruleTableDtoDatasource ) ) ) ;
    public final EObject ruleTableGrid() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        EObject lv_source_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:3072:2: ( ( () otherlv_1= 'editable' otherlv_2= 'using' ( (lv_source_3_0= ruleTableDtoDatasource ) ) ) )
            // InternalTableDSL.g:3073:2: ( () otherlv_1= 'editable' otherlv_2= 'using' ( (lv_source_3_0= ruleTableDtoDatasource ) ) )
            {
            // InternalTableDSL.g:3073:2: ( () otherlv_1= 'editable' otherlv_2= 'using' ( (lv_source_3_0= ruleTableDtoDatasource ) ) )
            // InternalTableDSL.g:3074:3: () otherlv_1= 'editable' otherlv_2= 'using' ( (lv_source_3_0= ruleTableDtoDatasource ) )
            {
            // InternalTableDSL.g:3074:3: ()
            // InternalTableDSL.g:3075:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getTableGridAccess().getTableGridAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,70,FOLLOW_37); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getTableGridAccess().getEditableKeyword_1());
              		
            }
            otherlv_2=(Token)match(input,29,FOLLOW_38); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_2, grammarAccess.getTableGridAccess().getUsingKeyword_2());
              		
            }
            // InternalTableDSL.g:3089:3: ( (lv_source_3_0= ruleTableDtoDatasource ) )
            // InternalTableDSL.g:3090:4: (lv_source_3_0= ruleTableDtoDatasource )
            {
            // InternalTableDSL.g:3090:4: (lv_source_3_0= ruleTableDtoDatasource )
            // InternalTableDSL.g:3091:5: lv_source_3_0= ruleTableDtoDatasource
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getTableGridAccess().getSourceTableDtoDatasourceParserRuleCall_3_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_source_3_0=ruleTableDtoDatasource();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getTableGridRule());
              					}
              					set(
              						current,
              						"source",
              						lv_source_3_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.TableDtoDatasource");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableGrid"


    // $ANTLR start "entryRuleProperty"
    // InternalTableDSL.g:3112:1: entryRuleProperty returns [EObject current=null] : iv_ruleProperty= ruleProperty EOF ;
    public final EObject entryRuleProperty() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleProperty = null;


        try {
            // InternalTableDSL.g:3112:49: (iv_ruleProperty= ruleProperty EOF )
            // InternalTableDSL.g:3113:2: iv_ruleProperty= ruleProperty EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getPropertyRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleProperty=ruleProperty();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleProperty; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleProperty"


    // $ANTLR start "ruleProperty"
    // InternalTableDSL.g:3119:1: ruleProperty returns [EObject current=null] : ( ( (lv_editable_0_0= 'editable' ) )? otherlv_1= 'prop' ( (lv_path_2_0= ruleNestedField ) ) otherlv_3= 'style' ( (lv_style_4_0= rulePropertyStyle ) ) ) ;
    public final EObject ruleProperty() throws RecognitionException {
        EObject current = null;

        Token lv_editable_0_0=null;
        Token otherlv_1=null;
        Token otherlv_3=null;
        EObject lv_path_2_0 = null;

        EObject lv_style_4_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:3125:2: ( ( ( (lv_editable_0_0= 'editable' ) )? otherlv_1= 'prop' ( (lv_path_2_0= ruleNestedField ) ) otherlv_3= 'style' ( (lv_style_4_0= rulePropertyStyle ) ) ) )
            // InternalTableDSL.g:3126:2: ( ( (lv_editable_0_0= 'editable' ) )? otherlv_1= 'prop' ( (lv_path_2_0= ruleNestedField ) ) otherlv_3= 'style' ( (lv_style_4_0= rulePropertyStyle ) ) )
            {
            // InternalTableDSL.g:3126:2: ( ( (lv_editable_0_0= 'editable' ) )? otherlv_1= 'prop' ( (lv_path_2_0= ruleNestedField ) ) otherlv_3= 'style' ( (lv_style_4_0= rulePropertyStyle ) ) )
            // InternalTableDSL.g:3127:3: ( (lv_editable_0_0= 'editable' ) )? otherlv_1= 'prop' ( (lv_path_2_0= ruleNestedField ) ) otherlv_3= 'style' ( (lv_style_4_0= rulePropertyStyle ) )
            {
            // InternalTableDSL.g:3127:3: ( (lv_editable_0_0= 'editable' ) )?
            int alt31=2;
            int LA31_0 = input.LA(1);

            if ( (LA31_0==70) ) {
                alt31=1;
            }
            switch (alt31) {
                case 1 :
                    // InternalTableDSL.g:3128:4: (lv_editable_0_0= 'editable' )
                    {
                    // InternalTableDSL.g:3128:4: (lv_editable_0_0= 'editable' )
                    // InternalTableDSL.g:3129:5: lv_editable_0_0= 'editable'
                    {
                    lv_editable_0_0=(Token)match(input,70,FOLLOW_39); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					newLeafNode(lv_editable_0_0, grammarAccess.getPropertyAccess().getEditableEditableKeyword_0_0());
                      				
                    }
                    if ( state.backtracking==0 ) {

                      					if (current==null) {
                      						current = createModelElement(grammarAccess.getPropertyRule());
                      					}
                      					setWithLastConsumed(current, "editable", true, "editable");
                      				
                    }

                    }


                    }
                    break;

            }

            otherlv_1=(Token)match(input,71,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getPropertyAccess().getPropKeyword_1());
              		
            }
            // InternalTableDSL.g:3145:3: ( (lv_path_2_0= ruleNestedField ) )
            // InternalTableDSL.g:3146:4: (lv_path_2_0= ruleNestedField )
            {
            // InternalTableDSL.g:3146:4: (lv_path_2_0= ruleNestedField )
            // InternalTableDSL.g:3147:5: lv_path_2_0= ruleNestedField
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getPropertyAccess().getPathNestedFieldParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_40);
            lv_path_2_0=ruleNestedField();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getPropertyRule());
              					}
              					set(
              						current,
              						"path",
              						lv_path_2_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.NestedField");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            otherlv_3=(Token)match(input,72,FOLLOW_41); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_3, grammarAccess.getPropertyAccess().getStyleKeyword_3());
              		
            }
            // InternalTableDSL.g:3168:3: ( (lv_style_4_0= rulePropertyStyle ) )
            // InternalTableDSL.g:3169:4: (lv_style_4_0= rulePropertyStyle )
            {
            // InternalTableDSL.g:3169:4: (lv_style_4_0= rulePropertyStyle )
            // InternalTableDSL.g:3170:5: lv_style_4_0= rulePropertyStyle
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getPropertyAccess().getStylePropertyStyleParserRuleCall_4_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_style_4_0=rulePropertyStyle();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getPropertyRule());
              					}
              					set(
              						current,
              						"style",
              						lv_style_4_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.PropertyStyle");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleProperty"


    // $ANTLR start "entryRuleTableDtoDatasource"
    // InternalTableDSL.g:3191:1: entryRuleTableDtoDatasource returns [EObject current=null] : iv_ruleTableDtoDatasource= ruleTableDtoDatasource EOF ;
    public final EObject entryRuleTableDtoDatasource() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleTableDtoDatasource = null;


        try {
            // InternalTableDSL.g:3191:59: (iv_ruleTableDtoDatasource= ruleTableDtoDatasource EOF )
            // InternalTableDSL.g:3192:2: iv_ruleTableDtoDatasource= ruleTableDtoDatasource EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTableDtoDatasourceRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTableDtoDatasource=ruleTableDtoDatasource();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTableDtoDatasource; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTableDtoDatasource"


    // $ANTLR start "ruleTableDtoDatasource"
    // InternalTableDSL.g:3198:1: ruleTableDtoDatasource returns [EObject current=null] : (otherlv_0= 'dto' ( (otherlv_1= RULE_ID ) ) (otherlv_2= '{' ( (lv_properties_3_0= ruleProperty ) )* otherlv_4= '}' )? ) ;
    public final EObject ruleTableDtoDatasource() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token otherlv_1=null;
        Token otherlv_2=null;
        Token otherlv_4=null;
        EObject lv_properties_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:3204:2: ( (otherlv_0= 'dto' ( (otherlv_1= RULE_ID ) ) (otherlv_2= '{' ( (lv_properties_3_0= ruleProperty ) )* otherlv_4= '}' )? ) )
            // InternalTableDSL.g:3205:2: (otherlv_0= 'dto' ( (otherlv_1= RULE_ID ) ) (otherlv_2= '{' ( (lv_properties_3_0= ruleProperty ) )* otherlv_4= '}' )? )
            {
            // InternalTableDSL.g:3205:2: (otherlv_0= 'dto' ( (otherlv_1= RULE_ID ) ) (otherlv_2= '{' ( (lv_properties_3_0= ruleProperty ) )* otherlv_4= '}' )? )
            // InternalTableDSL.g:3206:3: otherlv_0= 'dto' ( (otherlv_1= RULE_ID ) ) (otherlv_2= '{' ( (lv_properties_3_0= ruleProperty ) )* otherlv_4= '}' )?
            {
            otherlv_0=(Token)match(input,73,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getTableDtoDatasourceAccess().getDtoKeyword_0());
              		
            }
            // InternalTableDSL.g:3210:3: ( (otherlv_1= RULE_ID ) )
            // InternalTableDSL.g:3211:4: (otherlv_1= RULE_ID )
            {
            // InternalTableDSL.g:3211:4: (otherlv_1= RULE_ID )
            // InternalTableDSL.g:3212:5: otherlv_1= RULE_ID
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getTableDtoDatasourceRule());
              					}
              				
            }
            otherlv_1=(Token)match(input,RULE_ID,FOLLOW_5); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_1, grammarAccess.getTableDtoDatasourceAccess().getDtoSourceLDtoCrossReference_1_0());
              				
            }

            }


            }

            // InternalTableDSL.g:3223:3: (otherlv_2= '{' ( (lv_properties_3_0= ruleProperty ) )* otherlv_4= '}' )?
            int alt33=2;
            int LA33_0 = input.LA(1);

            if ( (LA33_0==16) ) {
                alt33=1;
            }
            switch (alt33) {
                case 1 :
                    // InternalTableDSL.g:3224:4: otherlv_2= '{' ( (lv_properties_3_0= ruleProperty ) )* otherlv_4= '}'
                    {
                    otherlv_2=(Token)match(input,16,FOLLOW_42); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_2, grammarAccess.getTableDtoDatasourceAccess().getLeftCurlyBracketKeyword_2_0());
                      			
                    }
                    // InternalTableDSL.g:3228:4: ( (lv_properties_3_0= ruleProperty ) )*
                    loop32:
                    do {
                        int alt32=2;
                        int LA32_0 = input.LA(1);

                        if ( ((LA32_0>=70 && LA32_0<=71)) ) {
                            alt32=1;
                        }


                        switch (alt32) {
                    	case 1 :
                    	    // InternalTableDSL.g:3229:5: (lv_properties_3_0= ruleProperty )
                    	    {
                    	    // InternalTableDSL.g:3229:5: (lv_properties_3_0= ruleProperty )
                    	    // InternalTableDSL.g:3230:6: lv_properties_3_0= ruleProperty
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      						newCompositeNode(grammarAccess.getTableDtoDatasourceAccess().getPropertiesPropertyParserRuleCall_2_1_0());
                    	      					
                    	    }
                    	    pushFollow(FOLLOW_42);
                    	    lv_properties_3_0=ruleProperty();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      						if (current==null) {
                    	      							current = createModelElementForParent(grammarAccess.getTableDtoDatasourceRule());
                    	      						}
                    	      						add(
                    	      							current,
                    	      							"properties",
                    	      							lv_properties_3_0,
                    	      							"org.eclipse.osbp.xtext.table.TableDSL.Property");
                    	      						afterParserOrEnumRuleCall();
                    	      					
                    	    }

                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop32;
                        }
                    } while (true);

                    otherlv_4=(Token)match(input,17,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_4, grammarAccess.getTableDtoDatasourceAccess().getRightCurlyBracketKeyword_2_2());
                      			
                    }

                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTableDtoDatasource"


    // $ANTLR start "entryRuleNestedField"
    // InternalTableDSL.g:3256:1: entryRuleNestedField returns [EObject current=null] : iv_ruleNestedField= ruleNestedField EOF ;
    public final EObject entryRuleNestedField() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleNestedField = null;


        try {
            // InternalTableDSL.g:3256:52: (iv_ruleNestedField= ruleNestedField EOF )
            // InternalTableDSL.g:3257:2: iv_ruleNestedField= ruleNestedField EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getNestedFieldRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleNestedField=ruleNestedField();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleNestedField; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleNestedField"


    // $ANTLR start "ruleNestedField"
    // InternalTableDSL.g:3263:1: ruleNestedField returns [EObject current=null] : ( () ( (otherlv_1= RULE_ID ) ) ( (lv_path_2_0= ruleNestedPath ) )? ) ;
    public final EObject ruleNestedField() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        EObject lv_path_2_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:3269:2: ( ( () ( (otherlv_1= RULE_ID ) ) ( (lv_path_2_0= ruleNestedPath ) )? ) )
            // InternalTableDSL.g:3270:2: ( () ( (otherlv_1= RULE_ID ) ) ( (lv_path_2_0= ruleNestedPath ) )? )
            {
            // InternalTableDSL.g:3270:2: ( () ( (otherlv_1= RULE_ID ) ) ( (lv_path_2_0= ruleNestedPath ) )? )
            // InternalTableDSL.g:3271:3: () ( (otherlv_1= RULE_ID ) ) ( (lv_path_2_0= ruleNestedPath ) )?
            {
            // InternalTableDSL.g:3271:3: ()
            // InternalTableDSL.g:3272:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getNestedFieldAccess().getCxGridNestedFieldAction_0(),
              					current);
              			
            }

            }

            // InternalTableDSL.g:3278:3: ( (otherlv_1= RULE_ID ) )
            // InternalTableDSL.g:3279:4: (otherlv_1= RULE_ID )
            {
            // InternalTableDSL.g:3279:4: (otherlv_1= RULE_ID )
            // InternalTableDSL.g:3280:5: otherlv_1= RULE_ID
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getNestedFieldRule());
              					}
              				
            }
            otherlv_1=(Token)match(input,RULE_ID,FOLLOW_43); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_1, grammarAccess.getNestedFieldAccess().getFieldJvmOperationCrossReference_1_0());
              				
            }

            }


            }

            // InternalTableDSL.g:3291:3: ( (lv_path_2_0= ruleNestedPath ) )?
            int alt34=2;
            int LA34_0 = input.LA(1);

            if ( (LA34_0==74) ) {
                alt34=1;
            }
            switch (alt34) {
                case 1 :
                    // InternalTableDSL.g:3292:4: (lv_path_2_0= ruleNestedPath )
                    {
                    // InternalTableDSL.g:3292:4: (lv_path_2_0= ruleNestedPath )
                    // InternalTableDSL.g:3293:5: lv_path_2_0= ruleNestedPath
                    {
                    if ( state.backtracking==0 ) {

                      					newCompositeNode(grammarAccess.getNestedFieldAccess().getPathNestedPathParserRuleCall_2_0());
                      				
                    }
                    pushFollow(FOLLOW_2);
                    lv_path_2_0=ruleNestedPath();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					if (current==null) {
                      						current = createModelElementForParent(grammarAccess.getNestedFieldRule());
                      					}
                      					set(
                      						current,
                      						"path",
                      						lv_path_2_0,
                      						"org.eclipse.osbp.xtext.table.TableDSL.NestedPath");
                      					afterParserOrEnumRuleCall();
                      				
                    }

                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleNestedField"


    // $ANTLR start "entryRuleNestedPath"
    // InternalTableDSL.g:3314:1: entryRuleNestedPath returns [EObject current=null] : iv_ruleNestedPath= ruleNestedPath EOF ;
    public final EObject entryRuleNestedPath() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleNestedPath = null;


        try {
            // InternalTableDSL.g:3314:51: (iv_ruleNestedPath= ruleNestedPath EOF )
            // InternalTableDSL.g:3315:2: iv_ruleNestedPath= ruleNestedPath EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getNestedPathRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleNestedPath=ruleNestedPath();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleNestedPath; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleNestedPath"


    // $ANTLR start "ruleNestedPath"
    // InternalTableDSL.g:3321:1: ruleNestedPath returns [EObject current=null] : ( () otherlv_1= '.' ( (otherlv_2= RULE_ID ) ) ( (lv_path_3_0= ruleNestedPath ) )? ) ;
    public final EObject ruleNestedPath() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        EObject lv_path_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:3327:2: ( ( () otherlv_1= '.' ( (otherlv_2= RULE_ID ) ) ( (lv_path_3_0= ruleNestedPath ) )? ) )
            // InternalTableDSL.g:3328:2: ( () otherlv_1= '.' ( (otherlv_2= RULE_ID ) ) ( (lv_path_3_0= ruleNestedPath ) )? )
            {
            // InternalTableDSL.g:3328:2: ( () otherlv_1= '.' ( (otherlv_2= RULE_ID ) ) ( (lv_path_3_0= ruleNestedPath ) )? )
            // InternalTableDSL.g:3329:3: () otherlv_1= '.' ( (otherlv_2= RULE_ID ) ) ( (lv_path_3_0= ruleNestedPath ) )?
            {
            // InternalTableDSL.g:3329:3: ()
            // InternalTableDSL.g:3330:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getNestedPathAccess().getCxGridNestedPathAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,74,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getNestedPathAccess().getFullStopKeyword_1());
              		
            }
            // InternalTableDSL.g:3340:3: ( (otherlv_2= RULE_ID ) )
            // InternalTableDSL.g:3341:4: (otherlv_2= RULE_ID )
            {
            // InternalTableDSL.g:3341:4: (otherlv_2= RULE_ID )
            // InternalTableDSL.g:3342:5: otherlv_2= RULE_ID
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getNestedPathRule());
              					}
              				
            }
            otherlv_2=(Token)match(input,RULE_ID,FOLLOW_43); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_2, grammarAccess.getNestedPathAccess().getFieldJvmOperationCrossReference_2_0());
              				
            }

            }


            }

            // InternalTableDSL.g:3353:3: ( (lv_path_3_0= ruleNestedPath ) )?
            int alt35=2;
            int LA35_0 = input.LA(1);

            if ( (LA35_0==74) ) {
                alt35=1;
            }
            switch (alt35) {
                case 1 :
                    // InternalTableDSL.g:3354:4: (lv_path_3_0= ruleNestedPath )
                    {
                    // InternalTableDSL.g:3354:4: (lv_path_3_0= ruleNestedPath )
                    // InternalTableDSL.g:3355:5: lv_path_3_0= ruleNestedPath
                    {
                    if ( state.backtracking==0 ) {

                      					newCompositeNode(grammarAccess.getNestedPathAccess().getPathNestedPathParserRuleCall_3_0());
                      				
                    }
                    pushFollow(FOLLOW_2);
                    lv_path_3_0=ruleNestedPath();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					if (current==null) {
                      						current = createModelElementForParent(grammarAccess.getNestedPathRule());
                      					}
                      					set(
                      						current,
                      						"path",
                      						lv_path_3_0,
                      						"org.eclipse.osbp.xtext.table.TableDSL.NestedPath");
                      					afterParserOrEnumRuleCall();
                      				
                    }

                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleNestedPath"


    // $ANTLR start "entryRulePropertyStyle"
    // InternalTableDSL.g:3376:1: entryRulePropertyStyle returns [EObject current=null] : iv_rulePropertyStyle= rulePropertyStyle EOF ;
    public final EObject entryRulePropertyStyle() throws RecognitionException {
        EObject current = null;

        EObject iv_rulePropertyStyle = null;


        try {
            // InternalTableDSL.g:3376:54: (iv_rulePropertyStyle= rulePropertyStyle EOF )
            // InternalTableDSL.g:3377:2: iv_rulePropertyStyle= rulePropertyStyle EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getPropertyStyleRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_rulePropertyStyle=rulePropertyStyle();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_rulePropertyStyle; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRulePropertyStyle"


    // $ANTLR start "rulePropertyStyle"
    // InternalTableDSL.g:3383:1: rulePropertyStyle returns [EObject current=null] : (this_PropertyButtonStyle_0= rulePropertyButtonStyle | this_PropertyHtmlStyle_1= rulePropertyHtmlStyle | this_PropertyProgressbarStyle_2= rulePropertyProgressbarStyle | this_PropertyTextStyle_3= rulePropertyTextStyle | this_PropertyBooleanStyle_4= rulePropertyBooleanStyle | this_PropertyDateStyle_5= rulePropertyDateStyle | this_PropertyNumberStyle_6= rulePropertyNumberStyle | this_PropertyImageStyle_7= rulePropertyImageStyle | this_PropertyBlobImageStyle_8= rulePropertyBlobImageStyle | this_GridPropIndicatorStyle_9= ruleGridPropIndicatorStyle ) ;
    public final EObject rulePropertyStyle() throws RecognitionException {
        EObject current = null;

        EObject this_PropertyButtonStyle_0 = null;

        EObject this_PropertyHtmlStyle_1 = null;

        EObject this_PropertyProgressbarStyle_2 = null;

        EObject this_PropertyTextStyle_3 = null;

        EObject this_PropertyBooleanStyle_4 = null;

        EObject this_PropertyDateStyle_5 = null;

        EObject this_PropertyNumberStyle_6 = null;

        EObject this_PropertyImageStyle_7 = null;

        EObject this_PropertyBlobImageStyle_8 = null;

        EObject this_GridPropIndicatorStyle_9 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:3389:2: ( (this_PropertyButtonStyle_0= rulePropertyButtonStyle | this_PropertyHtmlStyle_1= rulePropertyHtmlStyle | this_PropertyProgressbarStyle_2= rulePropertyProgressbarStyle | this_PropertyTextStyle_3= rulePropertyTextStyle | this_PropertyBooleanStyle_4= rulePropertyBooleanStyle | this_PropertyDateStyle_5= rulePropertyDateStyle | this_PropertyNumberStyle_6= rulePropertyNumberStyle | this_PropertyImageStyle_7= rulePropertyImageStyle | this_PropertyBlobImageStyle_8= rulePropertyBlobImageStyle | this_GridPropIndicatorStyle_9= ruleGridPropIndicatorStyle ) )
            // InternalTableDSL.g:3390:2: (this_PropertyButtonStyle_0= rulePropertyButtonStyle | this_PropertyHtmlStyle_1= rulePropertyHtmlStyle | this_PropertyProgressbarStyle_2= rulePropertyProgressbarStyle | this_PropertyTextStyle_3= rulePropertyTextStyle | this_PropertyBooleanStyle_4= rulePropertyBooleanStyle | this_PropertyDateStyle_5= rulePropertyDateStyle | this_PropertyNumberStyle_6= rulePropertyNumberStyle | this_PropertyImageStyle_7= rulePropertyImageStyle | this_PropertyBlobImageStyle_8= rulePropertyBlobImageStyle | this_GridPropIndicatorStyle_9= ruleGridPropIndicatorStyle )
            {
            // InternalTableDSL.g:3390:2: (this_PropertyButtonStyle_0= rulePropertyButtonStyle | this_PropertyHtmlStyle_1= rulePropertyHtmlStyle | this_PropertyProgressbarStyle_2= rulePropertyProgressbarStyle | this_PropertyTextStyle_3= rulePropertyTextStyle | this_PropertyBooleanStyle_4= rulePropertyBooleanStyle | this_PropertyDateStyle_5= rulePropertyDateStyle | this_PropertyNumberStyle_6= rulePropertyNumberStyle | this_PropertyImageStyle_7= rulePropertyImageStyle | this_PropertyBlobImageStyle_8= rulePropertyBlobImageStyle | this_GridPropIndicatorStyle_9= ruleGridPropIndicatorStyle )
            int alt36=10;
            switch ( input.LA(1) ) {
            case 75:
                {
                alt36=1;
                }
                break;
            case 77:
                {
                alt36=2;
                }
                break;
            case 82:
                {
                alt36=3;
                }
                break;
            case 87:
                {
                alt36=4;
                }
                break;
            case 78:
                {
                alt36=5;
                }
                break;
            case 79:
                {
                alt36=6;
                }
                break;
            case 81:
                {
                alt36=7;
                }
                break;
            case 89:
                {
                alt36=8;
                }
                break;
            case 88:
                {
                alt36=9;
                }
                break;
            case 84:
                {
                alt36=10;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 36, 0, input);

                throw nvae;
            }

            switch (alt36) {
                case 1 :
                    // InternalTableDSL.g:3391:3: this_PropertyButtonStyle_0= rulePropertyButtonStyle
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getPropertyStyleAccess().getPropertyButtonStyleParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_PropertyButtonStyle_0=rulePropertyButtonStyle();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_PropertyButtonStyle_0;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:3400:3: this_PropertyHtmlStyle_1= rulePropertyHtmlStyle
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getPropertyStyleAccess().getPropertyHtmlStyleParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_PropertyHtmlStyle_1=rulePropertyHtmlStyle();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_PropertyHtmlStyle_1;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:3409:3: this_PropertyProgressbarStyle_2= rulePropertyProgressbarStyle
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getPropertyStyleAccess().getPropertyProgressbarStyleParserRuleCall_2());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_PropertyProgressbarStyle_2=rulePropertyProgressbarStyle();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_PropertyProgressbarStyle_2;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:3418:3: this_PropertyTextStyle_3= rulePropertyTextStyle
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getPropertyStyleAccess().getPropertyTextStyleParserRuleCall_3());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_PropertyTextStyle_3=rulePropertyTextStyle();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_PropertyTextStyle_3;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 5 :
                    // InternalTableDSL.g:3427:3: this_PropertyBooleanStyle_4= rulePropertyBooleanStyle
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getPropertyStyleAccess().getPropertyBooleanStyleParserRuleCall_4());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_PropertyBooleanStyle_4=rulePropertyBooleanStyle();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_PropertyBooleanStyle_4;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 6 :
                    // InternalTableDSL.g:3436:3: this_PropertyDateStyle_5= rulePropertyDateStyle
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getPropertyStyleAccess().getPropertyDateStyleParserRuleCall_5());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_PropertyDateStyle_5=rulePropertyDateStyle();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_PropertyDateStyle_5;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 7 :
                    // InternalTableDSL.g:3445:3: this_PropertyNumberStyle_6= rulePropertyNumberStyle
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getPropertyStyleAccess().getPropertyNumberStyleParserRuleCall_6());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_PropertyNumberStyle_6=rulePropertyNumberStyle();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_PropertyNumberStyle_6;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 8 :
                    // InternalTableDSL.g:3454:3: this_PropertyImageStyle_7= rulePropertyImageStyle
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getPropertyStyleAccess().getPropertyImageStyleParserRuleCall_7());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_PropertyImageStyle_7=rulePropertyImageStyle();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_PropertyImageStyle_7;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 9 :
                    // InternalTableDSL.g:3463:3: this_PropertyBlobImageStyle_8= rulePropertyBlobImageStyle
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getPropertyStyleAccess().getPropertyBlobImageStyleParserRuleCall_8());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_PropertyBlobImageStyle_8=rulePropertyBlobImageStyle();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_PropertyBlobImageStyle_8;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 10 :
                    // InternalTableDSL.g:3472:3: this_GridPropIndicatorStyle_9= ruleGridPropIndicatorStyle
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getPropertyStyleAccess().getGridPropIndicatorStyleParserRuleCall_9());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_GridPropIndicatorStyle_9=ruleGridPropIndicatorStyle();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_GridPropIndicatorStyle_9;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "rulePropertyStyle"


    // $ANTLR start "entryRulePropertyButtonStyle"
    // InternalTableDSL.g:3484:1: entryRulePropertyButtonStyle returns [EObject current=null] : iv_rulePropertyButtonStyle= rulePropertyButtonStyle EOF ;
    public final EObject entryRulePropertyButtonStyle() throws RecognitionException {
        EObject current = null;

        EObject iv_rulePropertyButtonStyle = null;


        try {
            // InternalTableDSL.g:3484:60: (iv_rulePropertyButtonStyle= rulePropertyButtonStyle EOF )
            // InternalTableDSL.g:3485:2: iv_rulePropertyButtonStyle= rulePropertyButtonStyle EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getPropertyButtonStyleRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_rulePropertyButtonStyle=rulePropertyButtonStyle();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_rulePropertyButtonStyle; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRulePropertyButtonStyle"


    // $ANTLR start "rulePropertyButtonStyle"
    // InternalTableDSL.g:3491:1: rulePropertyButtonStyle returns [EObject current=null] : ( () otherlv_1= 'buttonStyle' otherlv_2= 'eventTopic' ( (lv_eventTopic_3_0= RULE_STRING ) ) ) ;
    public final EObject rulePropertyButtonStyle() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token lv_eventTopic_3_0=null;


        	enterRule();

        try {
            // InternalTableDSL.g:3497:2: ( ( () otherlv_1= 'buttonStyle' otherlv_2= 'eventTopic' ( (lv_eventTopic_3_0= RULE_STRING ) ) ) )
            // InternalTableDSL.g:3498:2: ( () otherlv_1= 'buttonStyle' otherlv_2= 'eventTopic' ( (lv_eventTopic_3_0= RULE_STRING ) ) )
            {
            // InternalTableDSL.g:3498:2: ( () otherlv_1= 'buttonStyle' otherlv_2= 'eventTopic' ( (lv_eventTopic_3_0= RULE_STRING ) ) )
            // InternalTableDSL.g:3499:3: () otherlv_1= 'buttonStyle' otherlv_2= 'eventTopic' ( (lv_eventTopic_3_0= RULE_STRING ) )
            {
            // InternalTableDSL.g:3499:3: ()
            // InternalTableDSL.g:3500:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getPropertyButtonStyleAccess().getCxGridPropButtonStyleAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,75,FOLLOW_44); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getPropertyButtonStyleAccess().getButtonStyleKeyword_1());
              		
            }
            otherlv_2=(Token)match(input,76,FOLLOW_8); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_2, grammarAccess.getPropertyButtonStyleAccess().getEventTopicKeyword_2());
              		
            }
            // InternalTableDSL.g:3514:3: ( (lv_eventTopic_3_0= RULE_STRING ) )
            // InternalTableDSL.g:3515:4: (lv_eventTopic_3_0= RULE_STRING )
            {
            // InternalTableDSL.g:3515:4: (lv_eventTopic_3_0= RULE_STRING )
            // InternalTableDSL.g:3516:5: lv_eventTopic_3_0= RULE_STRING
            {
            lv_eventTopic_3_0=(Token)match(input,RULE_STRING,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(lv_eventTopic_3_0, grammarAccess.getPropertyButtonStyleAccess().getEventTopicSTRINGTerminalRuleCall_3_0());
              				
            }
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getPropertyButtonStyleRule());
              					}
              					setWithLastConsumed(
              						current,
              						"eventTopic",
              						lv_eventTopic_3_0,
              						"org.eclipse.xtext.xbase.Xtype.STRING");
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "rulePropertyButtonStyle"


    // $ANTLR start "entryRulePropertyHtmlStyle"
    // InternalTableDSL.g:3536:1: entryRulePropertyHtmlStyle returns [EObject current=null] : iv_rulePropertyHtmlStyle= rulePropertyHtmlStyle EOF ;
    public final EObject entryRulePropertyHtmlStyle() throws RecognitionException {
        EObject current = null;

        EObject iv_rulePropertyHtmlStyle = null;


        try {
            // InternalTableDSL.g:3536:58: (iv_rulePropertyHtmlStyle= rulePropertyHtmlStyle EOF )
            // InternalTableDSL.g:3537:2: iv_rulePropertyHtmlStyle= rulePropertyHtmlStyle EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getPropertyHtmlStyleRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_rulePropertyHtmlStyle=rulePropertyHtmlStyle();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_rulePropertyHtmlStyle; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRulePropertyHtmlStyle"


    // $ANTLR start "rulePropertyHtmlStyle"
    // InternalTableDSL.g:3543:1: rulePropertyHtmlStyle returns [EObject current=null] : ( () otherlv_1= 'htmlStyle' ) ;
    public final EObject rulePropertyHtmlStyle() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;


        	enterRule();

        try {
            // InternalTableDSL.g:3549:2: ( ( () otherlv_1= 'htmlStyle' ) )
            // InternalTableDSL.g:3550:2: ( () otherlv_1= 'htmlStyle' )
            {
            // InternalTableDSL.g:3550:2: ( () otherlv_1= 'htmlStyle' )
            // InternalTableDSL.g:3551:3: () otherlv_1= 'htmlStyle'
            {
            // InternalTableDSL.g:3551:3: ()
            // InternalTableDSL.g:3552:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getPropertyHtmlStyleAccess().getCxGridPropHtmlStyleAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,77,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getPropertyHtmlStyleAccess().getHtmlStyleKeyword_1());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "rulePropertyHtmlStyle"


    // $ANTLR start "entryRulePropertyBooleanStyle"
    // InternalTableDSL.g:3566:1: entryRulePropertyBooleanStyle returns [EObject current=null] : iv_rulePropertyBooleanStyle= rulePropertyBooleanStyle EOF ;
    public final EObject entryRulePropertyBooleanStyle() throws RecognitionException {
        EObject current = null;

        EObject iv_rulePropertyBooleanStyle = null;


        try {
            // InternalTableDSL.g:3566:61: (iv_rulePropertyBooleanStyle= rulePropertyBooleanStyle EOF )
            // InternalTableDSL.g:3567:2: iv_rulePropertyBooleanStyle= rulePropertyBooleanStyle EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getPropertyBooleanStyleRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_rulePropertyBooleanStyle=rulePropertyBooleanStyle();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_rulePropertyBooleanStyle; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRulePropertyBooleanStyle"


    // $ANTLR start "rulePropertyBooleanStyle"
    // InternalTableDSL.g:3573:1: rulePropertyBooleanStyle returns [EObject current=null] : ( () otherlv_1= 'boolStyle' ) ;
    public final EObject rulePropertyBooleanStyle() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;


        	enterRule();

        try {
            // InternalTableDSL.g:3579:2: ( ( () otherlv_1= 'boolStyle' ) )
            // InternalTableDSL.g:3580:2: ( () otherlv_1= 'boolStyle' )
            {
            // InternalTableDSL.g:3580:2: ( () otherlv_1= 'boolStyle' )
            // InternalTableDSL.g:3581:3: () otherlv_1= 'boolStyle'
            {
            // InternalTableDSL.g:3581:3: ()
            // InternalTableDSL.g:3582:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getPropertyBooleanStyleAccess().getCxGridPropBooleanStyleAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,78,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getPropertyBooleanStyleAccess().getBoolStyleKeyword_1());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "rulePropertyBooleanStyle"


    // $ANTLR start "entryRulePropertyDateStyle"
    // InternalTableDSL.g:3596:1: entryRulePropertyDateStyle returns [EObject current=null] : iv_rulePropertyDateStyle= rulePropertyDateStyle EOF ;
    public final EObject entryRulePropertyDateStyle() throws RecognitionException {
        EObject current = null;

        EObject iv_rulePropertyDateStyle = null;


        try {
            // InternalTableDSL.g:3596:58: (iv_rulePropertyDateStyle= rulePropertyDateStyle EOF )
            // InternalTableDSL.g:3597:2: iv_rulePropertyDateStyle= rulePropertyDateStyle EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getPropertyDateStyleRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_rulePropertyDateStyle=rulePropertyDateStyle();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_rulePropertyDateStyle; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRulePropertyDateStyle"


    // $ANTLR start "rulePropertyDateStyle"
    // InternalTableDSL.g:3603:1: rulePropertyDateStyle returns [EObject current=null] : ( () otherlv_1= 'dateStyle' otherlv_2= 'format' ( (lv_dateFormat_3_0= RULE_STRING ) ) ) ;
    public final EObject rulePropertyDateStyle() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token lv_dateFormat_3_0=null;


        	enterRule();

        try {
            // InternalTableDSL.g:3609:2: ( ( () otherlv_1= 'dateStyle' otherlv_2= 'format' ( (lv_dateFormat_3_0= RULE_STRING ) ) ) )
            // InternalTableDSL.g:3610:2: ( () otherlv_1= 'dateStyle' otherlv_2= 'format' ( (lv_dateFormat_3_0= RULE_STRING ) ) )
            {
            // InternalTableDSL.g:3610:2: ( () otherlv_1= 'dateStyle' otherlv_2= 'format' ( (lv_dateFormat_3_0= RULE_STRING ) ) )
            // InternalTableDSL.g:3611:3: () otherlv_1= 'dateStyle' otherlv_2= 'format' ( (lv_dateFormat_3_0= RULE_STRING ) )
            {
            // InternalTableDSL.g:3611:3: ()
            // InternalTableDSL.g:3612:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getPropertyDateStyleAccess().getCxGridPropDateStyleAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,79,FOLLOW_45); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getPropertyDateStyleAccess().getDateStyleKeyword_1());
              		
            }
            otherlv_2=(Token)match(input,80,FOLLOW_8); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_2, grammarAccess.getPropertyDateStyleAccess().getFormatKeyword_2());
              		
            }
            // InternalTableDSL.g:3626:3: ( (lv_dateFormat_3_0= RULE_STRING ) )
            // InternalTableDSL.g:3627:4: (lv_dateFormat_3_0= RULE_STRING )
            {
            // InternalTableDSL.g:3627:4: (lv_dateFormat_3_0= RULE_STRING )
            // InternalTableDSL.g:3628:5: lv_dateFormat_3_0= RULE_STRING
            {
            lv_dateFormat_3_0=(Token)match(input,RULE_STRING,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(lv_dateFormat_3_0, grammarAccess.getPropertyDateStyleAccess().getDateFormatSTRINGTerminalRuleCall_3_0());
              				
            }
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getPropertyDateStyleRule());
              					}
              					setWithLastConsumed(
              						current,
              						"dateFormat",
              						lv_dateFormat_3_0,
              						"org.eclipse.xtext.xbase.Xtype.STRING");
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "rulePropertyDateStyle"


    // $ANTLR start "entryRulePropertyNumberStyle"
    // InternalTableDSL.g:3648:1: entryRulePropertyNumberStyle returns [EObject current=null] : iv_rulePropertyNumberStyle= rulePropertyNumberStyle EOF ;
    public final EObject entryRulePropertyNumberStyle() throws RecognitionException {
        EObject current = null;

        EObject iv_rulePropertyNumberStyle = null;


        try {
            // InternalTableDSL.g:3648:60: (iv_rulePropertyNumberStyle= rulePropertyNumberStyle EOF )
            // InternalTableDSL.g:3649:2: iv_rulePropertyNumberStyle= rulePropertyNumberStyle EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getPropertyNumberStyleRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_rulePropertyNumberStyle=rulePropertyNumberStyle();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_rulePropertyNumberStyle; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRulePropertyNumberStyle"


    // $ANTLR start "rulePropertyNumberStyle"
    // InternalTableDSL.g:3655:1: rulePropertyNumberStyle returns [EObject current=null] : ( () otherlv_1= 'numberStyle' otherlv_2= 'format' ( (lv_numberFormat_3_0= RULE_STRING ) ) ) ;
    public final EObject rulePropertyNumberStyle() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token lv_numberFormat_3_0=null;


        	enterRule();

        try {
            // InternalTableDSL.g:3661:2: ( ( () otherlv_1= 'numberStyle' otherlv_2= 'format' ( (lv_numberFormat_3_0= RULE_STRING ) ) ) )
            // InternalTableDSL.g:3662:2: ( () otherlv_1= 'numberStyle' otherlv_2= 'format' ( (lv_numberFormat_3_0= RULE_STRING ) ) )
            {
            // InternalTableDSL.g:3662:2: ( () otherlv_1= 'numberStyle' otherlv_2= 'format' ( (lv_numberFormat_3_0= RULE_STRING ) ) )
            // InternalTableDSL.g:3663:3: () otherlv_1= 'numberStyle' otherlv_2= 'format' ( (lv_numberFormat_3_0= RULE_STRING ) )
            {
            // InternalTableDSL.g:3663:3: ()
            // InternalTableDSL.g:3664:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getPropertyNumberStyleAccess().getCxGridPropNumberStyleAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,81,FOLLOW_45); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getPropertyNumberStyleAccess().getNumberStyleKeyword_1());
              		
            }
            otherlv_2=(Token)match(input,80,FOLLOW_8); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_2, grammarAccess.getPropertyNumberStyleAccess().getFormatKeyword_2());
              		
            }
            // InternalTableDSL.g:3678:3: ( (lv_numberFormat_3_0= RULE_STRING ) )
            // InternalTableDSL.g:3679:4: (lv_numberFormat_3_0= RULE_STRING )
            {
            // InternalTableDSL.g:3679:4: (lv_numberFormat_3_0= RULE_STRING )
            // InternalTableDSL.g:3680:5: lv_numberFormat_3_0= RULE_STRING
            {
            lv_numberFormat_3_0=(Token)match(input,RULE_STRING,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(lv_numberFormat_3_0, grammarAccess.getPropertyNumberStyleAccess().getNumberFormatSTRINGTerminalRuleCall_3_0());
              				
            }
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getPropertyNumberStyleRule());
              					}
              					setWithLastConsumed(
              						current,
              						"numberFormat",
              						lv_numberFormat_3_0,
              						"org.eclipse.xtext.xbase.Xtype.STRING");
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "rulePropertyNumberStyle"


    // $ANTLR start "entryRulePropertyProgressbarStyle"
    // InternalTableDSL.g:3700:1: entryRulePropertyProgressbarStyle returns [EObject current=null] : iv_rulePropertyProgressbarStyle= rulePropertyProgressbarStyle EOF ;
    public final EObject entryRulePropertyProgressbarStyle() throws RecognitionException {
        EObject current = null;

        EObject iv_rulePropertyProgressbarStyle = null;


        try {
            // InternalTableDSL.g:3700:65: (iv_rulePropertyProgressbarStyle= rulePropertyProgressbarStyle EOF )
            // InternalTableDSL.g:3701:2: iv_rulePropertyProgressbarStyle= rulePropertyProgressbarStyle EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getPropertyProgressbarStyleRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_rulePropertyProgressbarStyle=rulePropertyProgressbarStyle();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_rulePropertyProgressbarStyle; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRulePropertyProgressbarStyle"


    // $ANTLR start "rulePropertyProgressbarStyle"
    // InternalTableDSL.g:3707:1: rulePropertyProgressbarStyle returns [EObject current=null] : ( () otherlv_1= 'progressbarStyle' otherlv_2= 'max' ( (lv_maxValue_3_0= ruleLDouble ) ) ) ;
    public final EObject rulePropertyProgressbarStyle() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        AntlrDatatypeRuleToken lv_maxValue_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:3713:2: ( ( () otherlv_1= 'progressbarStyle' otherlv_2= 'max' ( (lv_maxValue_3_0= ruleLDouble ) ) ) )
            // InternalTableDSL.g:3714:2: ( () otherlv_1= 'progressbarStyle' otherlv_2= 'max' ( (lv_maxValue_3_0= ruleLDouble ) ) )
            {
            // InternalTableDSL.g:3714:2: ( () otherlv_1= 'progressbarStyle' otherlv_2= 'max' ( (lv_maxValue_3_0= ruleLDouble ) ) )
            // InternalTableDSL.g:3715:3: () otherlv_1= 'progressbarStyle' otherlv_2= 'max' ( (lv_maxValue_3_0= ruleLDouble ) )
            {
            // InternalTableDSL.g:3715:3: ()
            // InternalTableDSL.g:3716:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getPropertyProgressbarStyleAccess().getCxGridPropProgressbarStyleAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,82,FOLLOW_46); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getPropertyProgressbarStyleAccess().getProgressbarStyleKeyword_1());
              		
            }
            otherlv_2=(Token)match(input,83,FOLLOW_47); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_2, grammarAccess.getPropertyProgressbarStyleAccess().getMaxKeyword_2());
              		
            }
            // InternalTableDSL.g:3730:3: ( (lv_maxValue_3_0= ruleLDouble ) )
            // InternalTableDSL.g:3731:4: (lv_maxValue_3_0= ruleLDouble )
            {
            // InternalTableDSL.g:3731:4: (lv_maxValue_3_0= ruleLDouble )
            // InternalTableDSL.g:3732:5: lv_maxValue_3_0= ruleLDouble
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getPropertyProgressbarStyleAccess().getMaxValueLDoubleParserRuleCall_3_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_maxValue_3_0=ruleLDouble();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getPropertyProgressbarStyleRule());
              					}
              					set(
              						current,
              						"maxValue",
              						lv_maxValue_3_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.LDouble");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "rulePropertyProgressbarStyle"


    // $ANTLR start "entryRuleGridPropIndicatorStyle"
    // InternalTableDSL.g:3753:1: entryRuleGridPropIndicatorStyle returns [EObject current=null] : iv_ruleGridPropIndicatorStyle= ruleGridPropIndicatorStyle EOF ;
    public final EObject entryRuleGridPropIndicatorStyle() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleGridPropIndicatorStyle = null;


        try {
            // InternalTableDSL.g:3753:63: (iv_ruleGridPropIndicatorStyle= ruleGridPropIndicatorStyle EOF )
            // InternalTableDSL.g:3754:2: iv_ruleGridPropIndicatorStyle= ruleGridPropIndicatorStyle EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getGridPropIndicatorStyleRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleGridPropIndicatorStyle=ruleGridPropIndicatorStyle();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleGridPropIndicatorStyle; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleGridPropIndicatorStyle"


    // $ANTLR start "ruleGridPropIndicatorStyle"
    // InternalTableDSL.g:3760:1: ruleGridPropIndicatorStyle returns [EObject current=null] : ( () otherlv_1= 'indicatorStyle' otherlv_2= 'greenFrom' ( (lv_greenStarts_3_0= ruleLDouble ) ) otherlv_4= 'redUntil' ( (lv_redEnds_5_0= ruleLDouble ) ) ) ;
    public final EObject ruleGridPropIndicatorStyle() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token otherlv_4=null;
        AntlrDatatypeRuleToken lv_greenStarts_3_0 = null;

        AntlrDatatypeRuleToken lv_redEnds_5_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:3766:2: ( ( () otherlv_1= 'indicatorStyle' otherlv_2= 'greenFrom' ( (lv_greenStarts_3_0= ruleLDouble ) ) otherlv_4= 'redUntil' ( (lv_redEnds_5_0= ruleLDouble ) ) ) )
            // InternalTableDSL.g:3767:2: ( () otherlv_1= 'indicatorStyle' otherlv_2= 'greenFrom' ( (lv_greenStarts_3_0= ruleLDouble ) ) otherlv_4= 'redUntil' ( (lv_redEnds_5_0= ruleLDouble ) ) )
            {
            // InternalTableDSL.g:3767:2: ( () otherlv_1= 'indicatorStyle' otherlv_2= 'greenFrom' ( (lv_greenStarts_3_0= ruleLDouble ) ) otherlv_4= 'redUntil' ( (lv_redEnds_5_0= ruleLDouble ) ) )
            // InternalTableDSL.g:3768:3: () otherlv_1= 'indicatorStyle' otherlv_2= 'greenFrom' ( (lv_greenStarts_3_0= ruleLDouble ) ) otherlv_4= 'redUntil' ( (lv_redEnds_5_0= ruleLDouble ) )
            {
            // InternalTableDSL.g:3768:3: ()
            // InternalTableDSL.g:3769:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getGridPropIndicatorStyleAccess().getCxGridPropIndicatorStyleAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,84,FOLLOW_48); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getGridPropIndicatorStyleAccess().getIndicatorStyleKeyword_1());
              		
            }
            otherlv_2=(Token)match(input,85,FOLLOW_47); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_2, grammarAccess.getGridPropIndicatorStyleAccess().getGreenFromKeyword_2());
              		
            }
            // InternalTableDSL.g:3783:3: ( (lv_greenStarts_3_0= ruleLDouble ) )
            // InternalTableDSL.g:3784:4: (lv_greenStarts_3_0= ruleLDouble )
            {
            // InternalTableDSL.g:3784:4: (lv_greenStarts_3_0= ruleLDouble )
            // InternalTableDSL.g:3785:5: lv_greenStarts_3_0= ruleLDouble
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getGridPropIndicatorStyleAccess().getGreenStartsLDoubleParserRuleCall_3_0());
              				
            }
            pushFollow(FOLLOW_49);
            lv_greenStarts_3_0=ruleLDouble();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getGridPropIndicatorStyleRule());
              					}
              					set(
              						current,
              						"greenStarts",
              						lv_greenStarts_3_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.LDouble");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            otherlv_4=(Token)match(input,86,FOLLOW_47); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_4, grammarAccess.getGridPropIndicatorStyleAccess().getRedUntilKeyword_4());
              		
            }
            // InternalTableDSL.g:3806:3: ( (lv_redEnds_5_0= ruleLDouble ) )
            // InternalTableDSL.g:3807:4: (lv_redEnds_5_0= ruleLDouble )
            {
            // InternalTableDSL.g:3807:4: (lv_redEnds_5_0= ruleLDouble )
            // InternalTableDSL.g:3808:5: lv_redEnds_5_0= ruleLDouble
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getGridPropIndicatorStyleAccess().getRedEndsLDoubleParserRuleCall_5_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_redEnds_5_0=ruleLDouble();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getGridPropIndicatorStyleRule());
              					}
              					set(
              						current,
              						"redEnds",
              						lv_redEnds_5_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.LDouble");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleGridPropIndicatorStyle"


    // $ANTLR start "entryRulePropertyTextStyle"
    // InternalTableDSL.g:3829:1: entryRulePropertyTextStyle returns [EObject current=null] : iv_rulePropertyTextStyle= rulePropertyTextStyle EOF ;
    public final EObject entryRulePropertyTextStyle() throws RecognitionException {
        EObject current = null;

        EObject iv_rulePropertyTextStyle = null;


        try {
            // InternalTableDSL.g:3829:58: (iv_rulePropertyTextStyle= rulePropertyTextStyle EOF )
            // InternalTableDSL.g:3830:2: iv_rulePropertyTextStyle= rulePropertyTextStyle EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getPropertyTextStyleRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_rulePropertyTextStyle=rulePropertyTextStyle();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_rulePropertyTextStyle; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRulePropertyTextStyle"


    // $ANTLR start "rulePropertyTextStyle"
    // InternalTableDSL.g:3836:1: rulePropertyTextStyle returns [EObject current=null] : ( () otherlv_1= 'textStyle' ) ;
    public final EObject rulePropertyTextStyle() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;


        	enterRule();

        try {
            // InternalTableDSL.g:3842:2: ( ( () otherlv_1= 'textStyle' ) )
            // InternalTableDSL.g:3843:2: ( () otherlv_1= 'textStyle' )
            {
            // InternalTableDSL.g:3843:2: ( () otherlv_1= 'textStyle' )
            // InternalTableDSL.g:3844:3: () otherlv_1= 'textStyle'
            {
            // InternalTableDSL.g:3844:3: ()
            // InternalTableDSL.g:3845:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getPropertyTextStyleAccess().getCxGridPropTextStyleAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,87,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getPropertyTextStyleAccess().getTextStyleKeyword_1());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "rulePropertyTextStyle"


    // $ANTLR start "entryRulePropertyBlobImageStyle"
    // InternalTableDSL.g:3859:1: entryRulePropertyBlobImageStyle returns [EObject current=null] : iv_rulePropertyBlobImageStyle= rulePropertyBlobImageStyle EOF ;
    public final EObject entryRulePropertyBlobImageStyle() throws RecognitionException {
        EObject current = null;

        EObject iv_rulePropertyBlobImageStyle = null;


        try {
            // InternalTableDSL.g:3859:63: (iv_rulePropertyBlobImageStyle= rulePropertyBlobImageStyle EOF )
            // InternalTableDSL.g:3860:2: iv_rulePropertyBlobImageStyle= rulePropertyBlobImageStyle EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getPropertyBlobImageStyleRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_rulePropertyBlobImageStyle=rulePropertyBlobImageStyle();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_rulePropertyBlobImageStyle; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRulePropertyBlobImageStyle"


    // $ANTLR start "rulePropertyBlobImageStyle"
    // InternalTableDSL.g:3866:1: rulePropertyBlobImageStyle returns [EObject current=null] : ( () otherlv_1= 'blobImageStyle' ) ;
    public final EObject rulePropertyBlobImageStyle() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;


        	enterRule();

        try {
            // InternalTableDSL.g:3872:2: ( ( () otherlv_1= 'blobImageStyle' ) )
            // InternalTableDSL.g:3873:2: ( () otherlv_1= 'blobImageStyle' )
            {
            // InternalTableDSL.g:3873:2: ( () otherlv_1= 'blobImageStyle' )
            // InternalTableDSL.g:3874:3: () otherlv_1= 'blobImageStyle'
            {
            // InternalTableDSL.g:3874:3: ()
            // InternalTableDSL.g:3875:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getPropertyBlobImageStyleAccess().getCxGridPropBlobImageStyleAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,88,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getPropertyBlobImageStyleAccess().getBlobImageStyleKeyword_1());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "rulePropertyBlobImageStyle"


    // $ANTLR start "entryRulePropertyImageStyle"
    // InternalTableDSL.g:3889:1: entryRulePropertyImageStyle returns [EObject current=null] : iv_rulePropertyImageStyle= rulePropertyImageStyle EOF ;
    public final EObject entryRulePropertyImageStyle() throws RecognitionException {
        EObject current = null;

        EObject iv_rulePropertyImageStyle = null;


        try {
            // InternalTableDSL.g:3889:59: (iv_rulePropertyImageStyle= rulePropertyImageStyle EOF )
            // InternalTableDSL.g:3890:2: iv_rulePropertyImageStyle= rulePropertyImageStyle EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getPropertyImageStyleRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_rulePropertyImageStyle=rulePropertyImageStyle();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_rulePropertyImageStyle; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRulePropertyImageStyle"


    // $ANTLR start "rulePropertyImageStyle"
    // InternalTableDSL.g:3896:1: rulePropertyImageStyle returns [EObject current=null] : ( () otherlv_1= 'imageStyle' (otherlv_2= 'eventTopic' ( (lv_eventTopic_3_0= RULE_STRING ) ) )? otherlv_4= '{' ( (lv_configs_5_0= ruleStyleConfig ) )* otherlv_6= '}' ) ;
    public final EObject rulePropertyImageStyle() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token lv_eventTopic_3_0=null;
        Token otherlv_4=null;
        Token otherlv_6=null;
        EObject lv_configs_5_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:3902:2: ( ( () otherlv_1= 'imageStyle' (otherlv_2= 'eventTopic' ( (lv_eventTopic_3_0= RULE_STRING ) ) )? otherlv_4= '{' ( (lv_configs_5_0= ruleStyleConfig ) )* otherlv_6= '}' ) )
            // InternalTableDSL.g:3903:2: ( () otherlv_1= 'imageStyle' (otherlv_2= 'eventTopic' ( (lv_eventTopic_3_0= RULE_STRING ) ) )? otherlv_4= '{' ( (lv_configs_5_0= ruleStyleConfig ) )* otherlv_6= '}' )
            {
            // InternalTableDSL.g:3903:2: ( () otherlv_1= 'imageStyle' (otherlv_2= 'eventTopic' ( (lv_eventTopic_3_0= RULE_STRING ) ) )? otherlv_4= '{' ( (lv_configs_5_0= ruleStyleConfig ) )* otherlv_6= '}' )
            // InternalTableDSL.g:3904:3: () otherlv_1= 'imageStyle' (otherlv_2= 'eventTopic' ( (lv_eventTopic_3_0= RULE_STRING ) ) )? otherlv_4= '{' ( (lv_configs_5_0= ruleStyleConfig ) )* otherlv_6= '}'
            {
            // InternalTableDSL.g:3904:3: ()
            // InternalTableDSL.g:3905:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getPropertyImageStyleAccess().getCxGridPropImageStyleAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,89,FOLLOW_50); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getPropertyImageStyleAccess().getImageStyleKeyword_1());
              		
            }
            // InternalTableDSL.g:3915:3: (otherlv_2= 'eventTopic' ( (lv_eventTopic_3_0= RULE_STRING ) ) )?
            int alt37=2;
            int LA37_0 = input.LA(1);

            if ( (LA37_0==76) ) {
                alt37=1;
            }
            switch (alt37) {
                case 1 :
                    // InternalTableDSL.g:3916:4: otherlv_2= 'eventTopic' ( (lv_eventTopic_3_0= RULE_STRING ) )
                    {
                    otherlv_2=(Token)match(input,76,FOLLOW_8); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_2, grammarAccess.getPropertyImageStyleAccess().getEventTopicKeyword_2_0());
                      			
                    }
                    // InternalTableDSL.g:3920:4: ( (lv_eventTopic_3_0= RULE_STRING ) )
                    // InternalTableDSL.g:3921:5: (lv_eventTopic_3_0= RULE_STRING )
                    {
                    // InternalTableDSL.g:3921:5: (lv_eventTopic_3_0= RULE_STRING )
                    // InternalTableDSL.g:3922:6: lv_eventTopic_3_0= RULE_STRING
                    {
                    lv_eventTopic_3_0=(Token)match(input,RULE_STRING,FOLLOW_21); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						newLeafNode(lv_eventTopic_3_0, grammarAccess.getPropertyImageStyleAccess().getEventTopicSTRINGTerminalRuleCall_2_1_0());
                      					
                    }
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElement(grammarAccess.getPropertyImageStyleRule());
                      						}
                      						setWithLastConsumed(
                      							current,
                      							"eventTopic",
                      							lv_eventTopic_3_0,
                      							"org.eclipse.xtext.xbase.Xtype.STRING");
                      					
                    }

                    }


                    }


                    }
                    break;

            }

            otherlv_4=(Token)match(input,16,FOLLOW_51); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_4, grammarAccess.getPropertyImageStyleAccess().getLeftCurlyBracketKeyword_3());
              		
            }
            // InternalTableDSL.g:3943:3: ( (lv_configs_5_0= ruleStyleConfig ) )*
            loop38:
            do {
                int alt38=2;
                int LA38_0 = input.LA(1);

                if ( ((LA38_0>=59 && LA38_0<=60)) ) {
                    alt38=1;
                }


                switch (alt38) {
            	case 1 :
            	    // InternalTableDSL.g:3944:4: (lv_configs_5_0= ruleStyleConfig )
            	    {
            	    // InternalTableDSL.g:3944:4: (lv_configs_5_0= ruleStyleConfig )
            	    // InternalTableDSL.g:3945:5: lv_configs_5_0= ruleStyleConfig
            	    {
            	    if ( state.backtracking==0 ) {

            	      					newCompositeNode(grammarAccess.getPropertyImageStyleAccess().getConfigsStyleConfigParserRuleCall_4_0());
            	      				
            	    }
            	    pushFollow(FOLLOW_51);
            	    lv_configs_5_0=ruleStyleConfig();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      					if (current==null) {
            	      						current = createModelElementForParent(grammarAccess.getPropertyImageStyleRule());
            	      					}
            	      					add(
            	      						current,
            	      						"configs",
            	      						lv_configs_5_0,
            	      						"org.eclipse.osbp.xtext.table.TableDSL.StyleConfig");
            	      					afterParserOrEnumRuleCall();
            	      				
            	    }

            	    }


            	    }
            	    break;

            	default :
            	    break loop38;
                }
            } while (true);

            otherlv_6=(Token)match(input,17,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_6, grammarAccess.getPropertyImageStyleAccess().getRightCurlyBracketKeyword_5());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "rulePropertyImageStyle"


    // $ANTLR start "entryRuleStyleConfig"
    // InternalTableDSL.g:3970:1: entryRuleStyleConfig returns [EObject current=null] : iv_ruleStyleConfig= ruleStyleConfig EOF ;
    public final EObject entryRuleStyleConfig() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleStyleConfig = null;


        try {
            // InternalTableDSL.g:3970:52: (iv_ruleStyleConfig= ruleStyleConfig EOF )
            // InternalTableDSL.g:3971:2: iv_ruleStyleConfig= ruleStyleConfig EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getStyleConfigRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleStyleConfig=ruleStyleConfig();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleStyleConfig; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleStyleConfig"


    // $ANTLR start "ruleStyleConfig"
    // InternalTableDSL.g:3977:1: ruleStyleConfig returns [EObject current=null] : (this_NumericToResourceStyleConfig_0= ruleNumericToResourceStyleConfig | this_StringToResourceStyleConfig_1= ruleStringToResourceStyleConfig ) ;
    public final EObject ruleStyleConfig() throws RecognitionException {
        EObject current = null;

        EObject this_NumericToResourceStyleConfig_0 = null;

        EObject this_StringToResourceStyleConfig_1 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:3983:2: ( (this_NumericToResourceStyleConfig_0= ruleNumericToResourceStyleConfig | this_StringToResourceStyleConfig_1= ruleStringToResourceStyleConfig ) )
            // InternalTableDSL.g:3984:2: (this_NumericToResourceStyleConfig_0= ruleNumericToResourceStyleConfig | this_StringToResourceStyleConfig_1= ruleStringToResourceStyleConfig )
            {
            // InternalTableDSL.g:3984:2: (this_NumericToResourceStyleConfig_0= ruleNumericToResourceStyleConfig | this_StringToResourceStyleConfig_1= ruleStringToResourceStyleConfig )
            int alt39=2;
            int LA39_0 = input.LA(1);

            if ( (LA39_0==59) ) {
                alt39=1;
            }
            else if ( (LA39_0==60) ) {
                alt39=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 39, 0, input);

                throw nvae;
            }
            switch (alt39) {
                case 1 :
                    // InternalTableDSL.g:3985:3: this_NumericToResourceStyleConfig_0= ruleNumericToResourceStyleConfig
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getStyleConfigAccess().getNumericToResourceStyleConfigParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_NumericToResourceStyleConfig_0=ruleNumericToResourceStyleConfig();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_NumericToResourceStyleConfig_0;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:3994:3: this_StringToResourceStyleConfig_1= ruleStringToResourceStyleConfig
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getStyleConfigAccess().getStringToResourceStyleConfigParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_StringToResourceStyleConfig_1=ruleStringToResourceStyleConfig();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_StringToResourceStyleConfig_1;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleStyleConfig"


    // $ANTLR start "entryRuleNumericToResourceStyleConfig"
    // InternalTableDSL.g:4006:1: entryRuleNumericToResourceStyleConfig returns [EObject current=null] : iv_ruleNumericToResourceStyleConfig= ruleNumericToResourceStyleConfig EOF ;
    public final EObject entryRuleNumericToResourceStyleConfig() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleNumericToResourceStyleConfig = null;


        try {
            // InternalTableDSL.g:4006:69: (iv_ruleNumericToResourceStyleConfig= ruleNumericToResourceStyleConfig EOF )
            // InternalTableDSL.g:4007:2: iv_ruleNumericToResourceStyleConfig= ruleNumericToResourceStyleConfig EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getNumericToResourceStyleConfigRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleNumericToResourceStyleConfig=ruleNumericToResourceStyleConfig();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleNumericToResourceStyleConfig; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleNumericToResourceStyleConfig"


    // $ANTLR start "ruleNumericToResourceStyleConfig"
    // InternalTableDSL.g:4013:1: ruleNumericToResourceStyleConfig returns [EObject current=null] : (otherlv_0= 'number' ( (lv_compare_1_0= ruleStyleCompare ) ) ( (lv_value_2_0= ruleLDouble ) ) otherlv_3= 'then' ( (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE ) ) ) ;
    public final EObject ruleNumericToResourceStyleConfig() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token otherlv_3=null;
        Token lv_resourceThemePath_4_0=null;
        Enumerator lv_compare_1_0 = null;

        AntlrDatatypeRuleToken lv_value_2_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:4019:2: ( (otherlv_0= 'number' ( (lv_compare_1_0= ruleStyleCompare ) ) ( (lv_value_2_0= ruleLDouble ) ) otherlv_3= 'then' ( (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE ) ) ) )
            // InternalTableDSL.g:4020:2: (otherlv_0= 'number' ( (lv_compare_1_0= ruleStyleCompare ) ) ( (lv_value_2_0= ruleLDouble ) ) otherlv_3= 'then' ( (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE ) ) )
            {
            // InternalTableDSL.g:4020:2: (otherlv_0= 'number' ( (lv_compare_1_0= ruleStyleCompare ) ) ( (lv_value_2_0= ruleLDouble ) ) otherlv_3= 'then' ( (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE ) ) )
            // InternalTableDSL.g:4021:3: otherlv_0= 'number' ( (lv_compare_1_0= ruleStyleCompare ) ) ( (lv_value_2_0= ruleLDouble ) ) otherlv_3= 'then' ( (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE ) )
            {
            otherlv_0=(Token)match(input,59,FOLLOW_52); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getNumericToResourceStyleConfigAccess().getNumberKeyword_0());
              		
            }
            // InternalTableDSL.g:4025:3: ( (lv_compare_1_0= ruleStyleCompare ) )
            // InternalTableDSL.g:4026:4: (lv_compare_1_0= ruleStyleCompare )
            {
            // InternalTableDSL.g:4026:4: (lv_compare_1_0= ruleStyleCompare )
            // InternalTableDSL.g:4027:5: lv_compare_1_0= ruleStyleCompare
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getNumericToResourceStyleConfigAccess().getCompareStyleCompareEnumRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_47);
            lv_compare_1_0=ruleStyleCompare();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getNumericToResourceStyleConfigRule());
              					}
              					set(
              						current,
              						"compare",
              						lv_compare_1_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.StyleCompare");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:4044:3: ( (lv_value_2_0= ruleLDouble ) )
            // InternalTableDSL.g:4045:4: (lv_value_2_0= ruleLDouble )
            {
            // InternalTableDSL.g:4045:4: (lv_value_2_0= ruleLDouble )
            // InternalTableDSL.g:4046:5: lv_value_2_0= ruleLDouble
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getNumericToResourceStyleConfigAccess().getValueLDoubleParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_53);
            lv_value_2_0=ruleLDouble();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getNumericToResourceStyleConfigRule());
              					}
              					set(
              						current,
              						"value",
              						lv_value_2_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.LDouble");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            otherlv_3=(Token)match(input,90,FOLLOW_54); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_3, grammarAccess.getNumericToResourceStyleConfigAccess().getThenKeyword_3());
              		
            }
            // InternalTableDSL.g:4067:3: ( (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE ) )
            // InternalTableDSL.g:4068:4: (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE )
            {
            // InternalTableDSL.g:4068:4: (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE )
            // InternalTableDSL.g:4069:5: lv_resourceThemePath_4_0= RULE_THEME_RESOURCE
            {
            lv_resourceThemePath_4_0=(Token)match(input,RULE_THEME_RESOURCE,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(lv_resourceThemePath_4_0, grammarAccess.getNumericToResourceStyleConfigAccess().getResourceThemePathTHEME_RESOURCETerminalRuleCall_4_0());
              				
            }
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getNumericToResourceStyleConfigRule());
              					}
              					setWithLastConsumed(
              						current,
              						"resourceThemePath",
              						lv_resourceThemePath_4_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.THEME_RESOURCE");
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleNumericToResourceStyleConfig"


    // $ANTLR start "entryRuleStringToResourceStyleConfig"
    // InternalTableDSL.g:4089:1: entryRuleStringToResourceStyleConfig returns [EObject current=null] : iv_ruleStringToResourceStyleConfig= ruleStringToResourceStyleConfig EOF ;
    public final EObject entryRuleStringToResourceStyleConfig() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleStringToResourceStyleConfig = null;


        try {
            // InternalTableDSL.g:4089:68: (iv_ruleStringToResourceStyleConfig= ruleStringToResourceStyleConfig EOF )
            // InternalTableDSL.g:4090:2: iv_ruleStringToResourceStyleConfig= ruleStringToResourceStyleConfig EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getStringToResourceStyleConfigRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleStringToResourceStyleConfig=ruleStringToResourceStyleConfig();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleStringToResourceStyleConfig; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleStringToResourceStyleConfig"


    // $ANTLR start "ruleStringToResourceStyleConfig"
    // InternalTableDSL.g:4096:1: ruleStringToResourceStyleConfig returns [EObject current=null] : (otherlv_0= 'string' ( (lv_compare_1_0= ruleStyleCompare ) ) ( (lv_value_2_0= RULE_STRING ) ) otherlv_3= 'then' ( (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE ) ) ) ;
    public final EObject ruleStringToResourceStyleConfig() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token lv_value_2_0=null;
        Token otherlv_3=null;
        Token lv_resourceThemePath_4_0=null;
        Enumerator lv_compare_1_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:4102:2: ( (otherlv_0= 'string' ( (lv_compare_1_0= ruleStyleCompare ) ) ( (lv_value_2_0= RULE_STRING ) ) otherlv_3= 'then' ( (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE ) ) ) )
            // InternalTableDSL.g:4103:2: (otherlv_0= 'string' ( (lv_compare_1_0= ruleStyleCompare ) ) ( (lv_value_2_0= RULE_STRING ) ) otherlv_3= 'then' ( (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE ) ) )
            {
            // InternalTableDSL.g:4103:2: (otherlv_0= 'string' ( (lv_compare_1_0= ruleStyleCompare ) ) ( (lv_value_2_0= RULE_STRING ) ) otherlv_3= 'then' ( (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE ) ) )
            // InternalTableDSL.g:4104:3: otherlv_0= 'string' ( (lv_compare_1_0= ruleStyleCompare ) ) ( (lv_value_2_0= RULE_STRING ) ) otherlv_3= 'then' ( (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE ) )
            {
            otherlv_0=(Token)match(input,60,FOLLOW_52); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getStringToResourceStyleConfigAccess().getStringKeyword_0());
              		
            }
            // InternalTableDSL.g:4108:3: ( (lv_compare_1_0= ruleStyleCompare ) )
            // InternalTableDSL.g:4109:4: (lv_compare_1_0= ruleStyleCompare )
            {
            // InternalTableDSL.g:4109:4: (lv_compare_1_0= ruleStyleCompare )
            // InternalTableDSL.g:4110:5: lv_compare_1_0= ruleStyleCompare
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getStringToResourceStyleConfigAccess().getCompareStyleCompareEnumRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_8);
            lv_compare_1_0=ruleStyleCompare();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getStringToResourceStyleConfigRule());
              					}
              					set(
              						current,
              						"compare",
              						lv_compare_1_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.StyleCompare");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:4127:3: ( (lv_value_2_0= RULE_STRING ) )
            // InternalTableDSL.g:4128:4: (lv_value_2_0= RULE_STRING )
            {
            // InternalTableDSL.g:4128:4: (lv_value_2_0= RULE_STRING )
            // InternalTableDSL.g:4129:5: lv_value_2_0= RULE_STRING
            {
            lv_value_2_0=(Token)match(input,RULE_STRING,FOLLOW_53); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(lv_value_2_0, grammarAccess.getStringToResourceStyleConfigAccess().getValueSTRINGTerminalRuleCall_2_0());
              				
            }
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getStringToResourceStyleConfigRule());
              					}
              					setWithLastConsumed(
              						current,
              						"value",
              						lv_value_2_0,
              						"org.eclipse.xtext.xbase.Xtype.STRING");
              				
            }

            }


            }

            otherlv_3=(Token)match(input,90,FOLLOW_54); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_3, grammarAccess.getStringToResourceStyleConfigAccess().getThenKeyword_3());
              		
            }
            // InternalTableDSL.g:4149:3: ( (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE ) )
            // InternalTableDSL.g:4150:4: (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE )
            {
            // InternalTableDSL.g:4150:4: (lv_resourceThemePath_4_0= RULE_THEME_RESOURCE )
            // InternalTableDSL.g:4151:5: lv_resourceThemePath_4_0= RULE_THEME_RESOURCE
            {
            lv_resourceThemePath_4_0=(Token)match(input,RULE_THEME_RESOURCE,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(lv_resourceThemePath_4_0, grammarAccess.getStringToResourceStyleConfigAccess().getResourceThemePathTHEME_RESOURCETerminalRuleCall_4_0());
              				
            }
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getStringToResourceStyleConfigRule());
              					}
              					setWithLastConsumed(
              						current,
              						"resourceThemePath",
              						lv_resourceThemePath_4_0,
              						"org.eclipse.osbp.xtext.table.TableDSL.THEME_RESOURCE");
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleStringToResourceStyleConfig"


    // $ANTLR start "entryRuleLInt"
    // InternalTableDSL.g:4171:1: entryRuleLInt returns [String current=null] : iv_ruleLInt= ruleLInt EOF ;
    public final String entryRuleLInt() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleLInt = null;


        try {
            // InternalTableDSL.g:4171:44: (iv_ruleLInt= ruleLInt EOF )
            // InternalTableDSL.g:4172:2: iv_ruleLInt= ruleLInt EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getLIntRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleLInt=ruleLInt();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleLInt.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleLInt"


    // $ANTLR start "ruleLInt"
    // InternalTableDSL.g:4178:1: ruleLInt returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : ( (kw= '+' | kw= '-' )? this_INT_2= RULE_INT ) ;
    public final AntlrDatatypeRuleToken ruleLInt() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;
        Token this_INT_2=null;


        	enterRule();

        try {
            // InternalTableDSL.g:4184:2: ( ( (kw= '+' | kw= '-' )? this_INT_2= RULE_INT ) )
            // InternalTableDSL.g:4185:2: ( (kw= '+' | kw= '-' )? this_INT_2= RULE_INT )
            {
            // InternalTableDSL.g:4185:2: ( (kw= '+' | kw= '-' )? this_INT_2= RULE_INT )
            // InternalTableDSL.g:4186:3: (kw= '+' | kw= '-' )? this_INT_2= RULE_INT
            {
            // InternalTableDSL.g:4186:3: (kw= '+' | kw= '-' )?
            int alt40=3;
            int LA40_0 = input.LA(1);

            if ( (LA40_0==91) ) {
                alt40=1;
            }
            else if ( (LA40_0==92) ) {
                alt40=2;
            }
            switch (alt40) {
                case 1 :
                    // InternalTableDSL.g:4187:4: kw= '+'
                    {
                    kw=(Token)match(input,91,FOLLOW_55); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getLIntAccess().getPlusSignKeyword_0_0());
                      			
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:4193:4: kw= '-'
                    {
                    kw=(Token)match(input,92,FOLLOW_55); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getLIntAccess().getHyphenMinusKeyword_0_1());
                      			
                    }

                    }
                    break;

            }

            this_INT_2=(Token)match(input,RULE_INT,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current.merge(this_INT_2);
              		
            }
            if ( state.backtracking==0 ) {

              			newLeafNode(this_INT_2, grammarAccess.getLIntAccess().getINTTerminalRuleCall_1());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleLInt"


    // $ANTLR start "entryRuleLDouble"
    // InternalTableDSL.g:4210:1: entryRuleLDouble returns [String current=null] : iv_ruleLDouble= ruleLDouble EOF ;
    public final String entryRuleLDouble() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleLDouble = null;


        try {
            // InternalTableDSL.g:4210:47: (iv_ruleLDouble= ruleLDouble EOF )
            // InternalTableDSL.g:4211:2: iv_ruleLDouble= ruleLDouble EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getLDoubleRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleLDouble=ruleLDouble();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleLDouble.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleLDouble"


    // $ANTLR start "ruleLDouble"
    // InternalTableDSL.g:4217:1: ruleLDouble returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (this_LInt_0= ruleLInt (kw= '.' this_INT_2= RULE_INT )? ) ;
    public final AntlrDatatypeRuleToken ruleLDouble() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;
        Token this_INT_2=null;
        AntlrDatatypeRuleToken this_LInt_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:4223:2: ( (this_LInt_0= ruleLInt (kw= '.' this_INT_2= RULE_INT )? ) )
            // InternalTableDSL.g:4224:2: (this_LInt_0= ruleLInt (kw= '.' this_INT_2= RULE_INT )? )
            {
            // InternalTableDSL.g:4224:2: (this_LInt_0= ruleLInt (kw= '.' this_INT_2= RULE_INT )? )
            // InternalTableDSL.g:4225:3: this_LInt_0= ruleLInt (kw= '.' this_INT_2= RULE_INT )?
            {
            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getLDoubleAccess().getLIntParserRuleCall_0());
              		
            }
            pushFollow(FOLLOW_43);
            this_LInt_0=ruleLInt();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current.merge(this_LInt_0);
              		
            }
            if ( state.backtracking==0 ) {

              			afterParserOrEnumRuleCall();
              		
            }
            // InternalTableDSL.g:4235:3: (kw= '.' this_INT_2= RULE_INT )?
            int alt41=2;
            int LA41_0 = input.LA(1);

            if ( (LA41_0==74) ) {
                alt41=1;
            }
            switch (alt41) {
                case 1 :
                    // InternalTableDSL.g:4236:4: kw= '.' this_INT_2= RULE_INT
                    {
                    kw=(Token)match(input,74,FOLLOW_55); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getLDoubleAccess().getFullStopKeyword_1_0());
                      			
                    }
                    this_INT_2=(Token)match(input,RULE_INT,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(this_INT_2);
                      			
                    }
                    if ( state.backtracking==0 ) {

                      				newLeafNode(this_INT_2, grammarAccess.getLDoubleAccess().getINTTerminalRuleCall_1_1());
                      			
                    }

                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleLDouble"


    // $ANTLR start "entryRuleSignedNumber"
    // InternalTableDSL.g:4253:1: entryRuleSignedNumber returns [String current=null] : iv_ruleSignedNumber= ruleSignedNumber EOF ;
    public final String entryRuleSignedNumber() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleSignedNumber = null;


        try {
            // InternalTableDSL.g:4253:52: (iv_ruleSignedNumber= ruleSignedNumber EOF )
            // InternalTableDSL.g:4254:2: iv_ruleSignedNumber= ruleSignedNumber EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getSignedNumberRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleSignedNumber=ruleSignedNumber();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleSignedNumber.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleSignedNumber"


    // $ANTLR start "ruleSignedNumber"
    // InternalTableDSL.g:4260:1: ruleSignedNumber returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : ( (kw= '-' )? this_Number_1= ruleNumber ) ;
    public final AntlrDatatypeRuleToken ruleSignedNumber() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;
        AntlrDatatypeRuleToken this_Number_1 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:4266:2: ( ( (kw= '-' )? this_Number_1= ruleNumber ) )
            // InternalTableDSL.g:4267:2: ( (kw= '-' )? this_Number_1= ruleNumber )
            {
            // InternalTableDSL.g:4267:2: ( (kw= '-' )? this_Number_1= ruleNumber )
            // InternalTableDSL.g:4268:3: (kw= '-' )? this_Number_1= ruleNumber
            {
            // InternalTableDSL.g:4268:3: (kw= '-' )?
            int alt42=2;
            int LA42_0 = input.LA(1);

            if ( (LA42_0==92) ) {
                alt42=1;
            }
            switch (alt42) {
                case 1 :
                    // InternalTableDSL.g:4269:4: kw= '-'
                    {
                    kw=(Token)match(input,92,FOLLOW_26); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getSignedNumberAccess().getHyphenMinusKeyword_0());
                      			
                    }

                    }
                    break;

            }

            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getSignedNumberAccess().getNumberParserRuleCall_1());
              		
            }
            pushFollow(FOLLOW_2);
            this_Number_1=ruleNumber();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current.merge(this_Number_1);
              		
            }
            if ( state.backtracking==0 ) {

              			afterParserOrEnumRuleCall();
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleSignedNumber"


    // $ANTLR start "entryRuleSignedInt"
    // InternalTableDSL.g:4289:1: entryRuleSignedInt returns [String current=null] : iv_ruleSignedInt= ruleSignedInt EOF ;
    public final String entryRuleSignedInt() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleSignedInt = null;


        try {
            // InternalTableDSL.g:4289:49: (iv_ruleSignedInt= ruleSignedInt EOF )
            // InternalTableDSL.g:4290:2: iv_ruleSignedInt= ruleSignedInt EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getSignedIntRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleSignedInt=ruleSignedInt();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleSignedInt.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleSignedInt"


    // $ANTLR start "ruleSignedInt"
    // InternalTableDSL.g:4296:1: ruleSignedInt returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : ( (kw= '-' )? this_INT_1= RULE_INT ) ;
    public final AntlrDatatypeRuleToken ruleSignedInt() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;
        Token this_INT_1=null;


        	enterRule();

        try {
            // InternalTableDSL.g:4302:2: ( ( (kw= '-' )? this_INT_1= RULE_INT ) )
            // InternalTableDSL.g:4303:2: ( (kw= '-' )? this_INT_1= RULE_INT )
            {
            // InternalTableDSL.g:4303:2: ( (kw= '-' )? this_INT_1= RULE_INT )
            // InternalTableDSL.g:4304:3: (kw= '-' )? this_INT_1= RULE_INT
            {
            // InternalTableDSL.g:4304:3: (kw= '-' )?
            int alt43=2;
            int LA43_0 = input.LA(1);

            if ( (LA43_0==92) ) {
                alt43=1;
            }
            switch (alt43) {
                case 1 :
                    // InternalTableDSL.g:4305:4: kw= '-'
                    {
                    kw=(Token)match(input,92,FOLLOW_55); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getSignedIntAccess().getHyphenMinusKeyword_0());
                      			
                    }

                    }
                    break;

            }

            this_INT_1=(Token)match(input,RULE_INT,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current.merge(this_INT_1);
              		
            }
            if ( state.backtracking==0 ) {

              			newLeafNode(this_INT_1, grammarAccess.getSignedIntAccess().getINTTerminalRuleCall_1());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleSignedInt"


    // $ANTLR start "entryRuleTRANSLATABLESTRING"
    // InternalTableDSL.g:4322:1: entryRuleTRANSLATABLESTRING returns [String current=null] : iv_ruleTRANSLATABLESTRING= ruleTRANSLATABLESTRING EOF ;
    public final String entryRuleTRANSLATABLESTRING() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleTRANSLATABLESTRING = null;


        try {
            // InternalTableDSL.g:4322:58: (iv_ruleTRANSLATABLESTRING= ruleTRANSLATABLESTRING EOF )
            // InternalTableDSL.g:4323:2: iv_ruleTRANSLATABLESTRING= ruleTRANSLATABLESTRING EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getTRANSLATABLESTRINGRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleTRANSLATABLESTRING=ruleTRANSLATABLESTRING();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleTRANSLATABLESTRING.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleTRANSLATABLESTRING"


    // $ANTLR start "ruleTRANSLATABLESTRING"
    // InternalTableDSL.g:4329:1: ruleTRANSLATABLESTRING returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : this_STRING_0= RULE_STRING ;
    public final AntlrDatatypeRuleToken ruleTRANSLATABLESTRING() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token this_STRING_0=null;


        	enterRule();

        try {
            // InternalTableDSL.g:4335:2: (this_STRING_0= RULE_STRING )
            // InternalTableDSL.g:4336:2: this_STRING_0= RULE_STRING
            {
            this_STRING_0=(Token)match(input,RULE_STRING,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              		current.merge(this_STRING_0);
              	
            }
            if ( state.backtracking==0 ) {

              		newLeafNode(this_STRING_0, grammarAccess.getTRANSLATABLESTRINGAccess().getSTRINGTerminalRuleCall());
              	
            }

            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTRANSLATABLESTRING"


    // $ANTLR start "entryRuleXImportDeclaration"
    // InternalTableDSL.g:4346:1: entryRuleXImportDeclaration returns [EObject current=null] : iv_ruleXImportDeclaration= ruleXImportDeclaration EOF ;
    public final EObject entryRuleXImportDeclaration() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXImportDeclaration = null;


        try {
            // InternalTableDSL.g:4346:59: (iv_ruleXImportDeclaration= ruleXImportDeclaration EOF )
            // InternalTableDSL.g:4347:2: iv_ruleXImportDeclaration= ruleXImportDeclaration EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXImportDeclarationRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXImportDeclaration=ruleXImportDeclaration();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXImportDeclaration; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXImportDeclaration"


    // $ANTLR start "ruleXImportDeclaration"
    // InternalTableDSL.g:4353:1: ruleXImportDeclaration returns [EObject current=null] : ( () otherlv_1= 'import' ( ( ( (lv_static_2_0= 'static' ) ) ( (lv_extension_3_0= 'extension' ) )? ( ( ruleQualifiedNameInStaticImport ) ) ( ( (lv_wildcard_5_0= '*' ) ) | ( (lv_memberName_6_0= ruleValidID ) ) ) ) | ( ( ruleQualifiedName ) ) | ( (lv_importedNamespace_8_0= ruleQualifiedNameWithWildcard ) ) | ( ( (lv_fqnImport_9_0= 'ns' ) ) ( (lv_importedFullyQualifiedName_10_0= ruleQualifiedName ) ) ) ) (otherlv_11= ';' )? ) ;
    public final EObject ruleXImportDeclaration() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token lv_static_2_0=null;
        Token lv_extension_3_0=null;
        Token lv_wildcard_5_0=null;
        Token lv_fqnImport_9_0=null;
        Token otherlv_11=null;
        AntlrDatatypeRuleToken lv_memberName_6_0 = null;

        AntlrDatatypeRuleToken lv_importedNamespace_8_0 = null;

        AntlrDatatypeRuleToken lv_importedFullyQualifiedName_10_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:4359:2: ( ( () otherlv_1= 'import' ( ( ( (lv_static_2_0= 'static' ) ) ( (lv_extension_3_0= 'extension' ) )? ( ( ruleQualifiedNameInStaticImport ) ) ( ( (lv_wildcard_5_0= '*' ) ) | ( (lv_memberName_6_0= ruleValidID ) ) ) ) | ( ( ruleQualifiedName ) ) | ( (lv_importedNamespace_8_0= ruleQualifiedNameWithWildcard ) ) | ( ( (lv_fqnImport_9_0= 'ns' ) ) ( (lv_importedFullyQualifiedName_10_0= ruleQualifiedName ) ) ) ) (otherlv_11= ';' )? ) )
            // InternalTableDSL.g:4360:2: ( () otherlv_1= 'import' ( ( ( (lv_static_2_0= 'static' ) ) ( (lv_extension_3_0= 'extension' ) )? ( ( ruleQualifiedNameInStaticImport ) ) ( ( (lv_wildcard_5_0= '*' ) ) | ( (lv_memberName_6_0= ruleValidID ) ) ) ) | ( ( ruleQualifiedName ) ) | ( (lv_importedNamespace_8_0= ruleQualifiedNameWithWildcard ) ) | ( ( (lv_fqnImport_9_0= 'ns' ) ) ( (lv_importedFullyQualifiedName_10_0= ruleQualifiedName ) ) ) ) (otherlv_11= ';' )? )
            {
            // InternalTableDSL.g:4360:2: ( () otherlv_1= 'import' ( ( ( (lv_static_2_0= 'static' ) ) ( (lv_extension_3_0= 'extension' ) )? ( ( ruleQualifiedNameInStaticImport ) ) ( ( (lv_wildcard_5_0= '*' ) ) | ( (lv_memberName_6_0= ruleValidID ) ) ) ) | ( ( ruleQualifiedName ) ) | ( (lv_importedNamespace_8_0= ruleQualifiedNameWithWildcard ) ) | ( ( (lv_fqnImport_9_0= 'ns' ) ) ( (lv_importedFullyQualifiedName_10_0= ruleQualifiedName ) ) ) ) (otherlv_11= ';' )? )
            // InternalTableDSL.g:4361:3: () otherlv_1= 'import' ( ( ( (lv_static_2_0= 'static' ) ) ( (lv_extension_3_0= 'extension' ) )? ( ( ruleQualifiedNameInStaticImport ) ) ( ( (lv_wildcard_5_0= '*' ) ) | ( (lv_memberName_6_0= ruleValidID ) ) ) ) | ( ( ruleQualifiedName ) ) | ( (lv_importedNamespace_8_0= ruleQualifiedNameWithWildcard ) ) | ( ( (lv_fqnImport_9_0= 'ns' ) ) ( (lv_importedFullyQualifiedName_10_0= ruleQualifiedName ) ) ) ) (otherlv_11= ';' )?
            {
            // InternalTableDSL.g:4361:3: ()
            // InternalTableDSL.g:4362:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXImportDeclarationAccess().getOXImportDeclarationAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,93,FOLLOW_56); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXImportDeclarationAccess().getImportKeyword_1());
              		
            }
            // InternalTableDSL.g:4372:3: ( ( ( (lv_static_2_0= 'static' ) ) ( (lv_extension_3_0= 'extension' ) )? ( ( ruleQualifiedNameInStaticImport ) ) ( ( (lv_wildcard_5_0= '*' ) ) | ( (lv_memberName_6_0= ruleValidID ) ) ) ) | ( ( ruleQualifiedName ) ) | ( (lv_importedNamespace_8_0= ruleQualifiedNameWithWildcard ) ) | ( ( (lv_fqnImport_9_0= 'ns' ) ) ( (lv_importedFullyQualifiedName_10_0= ruleQualifiedName ) ) ) )
            int alt46=4;
            alt46 = dfa46.predict(input);
            switch (alt46) {
                case 1 :
                    // InternalTableDSL.g:4373:4: ( ( (lv_static_2_0= 'static' ) ) ( (lv_extension_3_0= 'extension' ) )? ( ( ruleQualifiedNameInStaticImport ) ) ( ( (lv_wildcard_5_0= '*' ) ) | ( (lv_memberName_6_0= ruleValidID ) ) ) )
                    {
                    // InternalTableDSL.g:4373:4: ( ( (lv_static_2_0= 'static' ) ) ( (lv_extension_3_0= 'extension' ) )? ( ( ruleQualifiedNameInStaticImport ) ) ( ( (lv_wildcard_5_0= '*' ) ) | ( (lv_memberName_6_0= ruleValidID ) ) ) )
                    // InternalTableDSL.g:4374:5: ( (lv_static_2_0= 'static' ) ) ( (lv_extension_3_0= 'extension' ) )? ( ( ruleQualifiedNameInStaticImport ) ) ( ( (lv_wildcard_5_0= '*' ) ) | ( (lv_memberName_6_0= ruleValidID ) ) )
                    {
                    // InternalTableDSL.g:4374:5: ( (lv_static_2_0= 'static' ) )
                    // InternalTableDSL.g:4375:6: (lv_static_2_0= 'static' )
                    {
                    // InternalTableDSL.g:4375:6: (lv_static_2_0= 'static' )
                    // InternalTableDSL.g:4376:7: lv_static_2_0= 'static'
                    {
                    lv_static_2_0=(Token)match(input,94,FOLLOW_57); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      							newLeafNode(lv_static_2_0, grammarAccess.getXImportDeclarationAccess().getStaticStaticKeyword_2_0_0_0());
                      						
                    }
                    if ( state.backtracking==0 ) {

                      							if (current==null) {
                      								current = createModelElement(grammarAccess.getXImportDeclarationRule());
                      							}
                      							setWithLastConsumed(current, "static", true, "static");
                      						
                    }

                    }


                    }

                    // InternalTableDSL.g:4388:5: ( (lv_extension_3_0= 'extension' ) )?
                    int alt44=2;
                    int LA44_0 = input.LA(1);

                    if ( (LA44_0==95) ) {
                        alt44=1;
                    }
                    switch (alt44) {
                        case 1 :
                            // InternalTableDSL.g:4389:6: (lv_extension_3_0= 'extension' )
                            {
                            // InternalTableDSL.g:4389:6: (lv_extension_3_0= 'extension' )
                            // InternalTableDSL.g:4390:7: lv_extension_3_0= 'extension'
                            {
                            lv_extension_3_0=(Token)match(input,95,FOLLOW_57); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              							newLeafNode(lv_extension_3_0, grammarAccess.getXImportDeclarationAccess().getExtensionExtensionKeyword_2_0_1_0());
                              						
                            }
                            if ( state.backtracking==0 ) {

                              							if (current==null) {
                              								current = createModelElement(grammarAccess.getXImportDeclarationRule());
                              							}
                              							setWithLastConsumed(current, "extension", true, "extension");
                              						
                            }

                            }


                            }
                            break;

                    }

                    // InternalTableDSL.g:4402:5: ( ( ruleQualifiedNameInStaticImport ) )
                    // InternalTableDSL.g:4403:6: ( ruleQualifiedNameInStaticImport )
                    {
                    // InternalTableDSL.g:4403:6: ( ruleQualifiedNameInStaticImport )
                    // InternalTableDSL.g:4404:7: ruleQualifiedNameInStaticImport
                    {
                    if ( state.backtracking==0 ) {

                      							if (current==null) {
                      								current = createModelElement(grammarAccess.getXImportDeclarationRule());
                      							}
                      						
                    }
                    if ( state.backtracking==0 ) {

                      							newCompositeNode(grammarAccess.getXImportDeclarationAccess().getImportedTypeJvmDeclaredTypeCrossReference_2_0_2_0());
                      						
                    }
                    pushFollow(FOLLOW_58);
                    ruleQualifiedNameInStaticImport();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      							afterParserOrEnumRuleCall();
                      						
                    }

                    }


                    }

                    // InternalTableDSL.g:4418:5: ( ( (lv_wildcard_5_0= '*' ) ) | ( (lv_memberName_6_0= ruleValidID ) ) )
                    int alt45=2;
                    int LA45_0 = input.LA(1);

                    if ( (LA45_0==96) ) {
                        alt45=1;
                    }
                    else if ( (LA45_0==RULE_ID) ) {
                        alt45=2;
                    }
                    else {
                        if (state.backtracking>0) {state.failed=true; return current;}
                        NoViableAltException nvae =
                            new NoViableAltException("", 45, 0, input);

                        throw nvae;
                    }
                    switch (alt45) {
                        case 1 :
                            // InternalTableDSL.g:4419:6: ( (lv_wildcard_5_0= '*' ) )
                            {
                            // InternalTableDSL.g:4419:6: ( (lv_wildcard_5_0= '*' ) )
                            // InternalTableDSL.g:4420:7: (lv_wildcard_5_0= '*' )
                            {
                            // InternalTableDSL.g:4420:7: (lv_wildcard_5_0= '*' )
                            // InternalTableDSL.g:4421:8: lv_wildcard_5_0= '*'
                            {
                            lv_wildcard_5_0=(Token)match(input,96,FOLLOW_59); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              								newLeafNode(lv_wildcard_5_0, grammarAccess.getXImportDeclarationAccess().getWildcardAsteriskKeyword_2_0_3_0_0());
                              							
                            }
                            if ( state.backtracking==0 ) {

                              								if (current==null) {
                              									current = createModelElement(grammarAccess.getXImportDeclarationRule());
                              								}
                              								setWithLastConsumed(current, "wildcard", true, "*");
                              							
                            }

                            }


                            }


                            }
                            break;
                        case 2 :
                            // InternalTableDSL.g:4434:6: ( (lv_memberName_6_0= ruleValidID ) )
                            {
                            // InternalTableDSL.g:4434:6: ( (lv_memberName_6_0= ruleValidID ) )
                            // InternalTableDSL.g:4435:7: (lv_memberName_6_0= ruleValidID )
                            {
                            // InternalTableDSL.g:4435:7: (lv_memberName_6_0= ruleValidID )
                            // InternalTableDSL.g:4436:8: lv_memberName_6_0= ruleValidID
                            {
                            if ( state.backtracking==0 ) {

                              								newCompositeNode(grammarAccess.getXImportDeclarationAccess().getMemberNameValidIDParserRuleCall_2_0_3_1_0());
                              							
                            }
                            pushFollow(FOLLOW_59);
                            lv_memberName_6_0=ruleValidID();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              								if (current==null) {
                              									current = createModelElementForParent(grammarAccess.getXImportDeclarationRule());
                              								}
                              								set(
                              									current,
                              									"memberName",
                              									lv_memberName_6_0,
                              									"org.eclipse.xtext.xbase.Xtype.ValidID");
                              								afterParserOrEnumRuleCall();
                              							
                            }

                            }


                            }


                            }
                            break;

                    }


                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:4456:4: ( ( ruleQualifiedName ) )
                    {
                    // InternalTableDSL.g:4456:4: ( ( ruleQualifiedName ) )
                    // InternalTableDSL.g:4457:5: ( ruleQualifiedName )
                    {
                    // InternalTableDSL.g:4457:5: ( ruleQualifiedName )
                    // InternalTableDSL.g:4458:6: ruleQualifiedName
                    {
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElement(grammarAccess.getXImportDeclarationRule());
                      						}
                      					
                    }
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXImportDeclarationAccess().getImportedTypeJvmDeclaredTypeCrossReference_2_1_0());
                      					
                    }
                    pushFollow(FOLLOW_59);
                    ruleQualifiedName();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }


                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:4473:4: ( (lv_importedNamespace_8_0= ruleQualifiedNameWithWildcard ) )
                    {
                    // InternalTableDSL.g:4473:4: ( (lv_importedNamespace_8_0= ruleQualifiedNameWithWildcard ) )
                    // InternalTableDSL.g:4474:5: (lv_importedNamespace_8_0= ruleQualifiedNameWithWildcard )
                    {
                    // InternalTableDSL.g:4474:5: (lv_importedNamespace_8_0= ruleQualifiedNameWithWildcard )
                    // InternalTableDSL.g:4475:6: lv_importedNamespace_8_0= ruleQualifiedNameWithWildcard
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXImportDeclarationAccess().getImportedNamespaceQualifiedNameWithWildcardParserRuleCall_2_2_0());
                      					
                    }
                    pushFollow(FOLLOW_59);
                    lv_importedNamespace_8_0=ruleQualifiedNameWithWildcard();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getXImportDeclarationRule());
                      						}
                      						set(
                      							current,
                      							"importedNamespace",
                      							lv_importedNamespace_8_0,
                      							"org.eclipse.xtext.xbase.Xtype.QualifiedNameWithWildcard");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }


                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:4493:4: ( ( (lv_fqnImport_9_0= 'ns' ) ) ( (lv_importedFullyQualifiedName_10_0= ruleQualifiedName ) ) )
                    {
                    // InternalTableDSL.g:4493:4: ( ( (lv_fqnImport_9_0= 'ns' ) ) ( (lv_importedFullyQualifiedName_10_0= ruleQualifiedName ) ) )
                    // InternalTableDSL.g:4494:5: ( (lv_fqnImport_9_0= 'ns' ) ) ( (lv_importedFullyQualifiedName_10_0= ruleQualifiedName ) )
                    {
                    // InternalTableDSL.g:4494:5: ( (lv_fqnImport_9_0= 'ns' ) )
                    // InternalTableDSL.g:4495:6: (lv_fqnImport_9_0= 'ns' )
                    {
                    // InternalTableDSL.g:4495:6: (lv_fqnImport_9_0= 'ns' )
                    // InternalTableDSL.g:4496:7: lv_fqnImport_9_0= 'ns'
                    {
                    lv_fqnImport_9_0=(Token)match(input,97,FOLLOW_4); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      							newLeafNode(lv_fqnImport_9_0, grammarAccess.getXImportDeclarationAccess().getFqnImportNsKeyword_2_3_0_0());
                      						
                    }
                    if ( state.backtracking==0 ) {

                      							if (current==null) {
                      								current = createModelElement(grammarAccess.getXImportDeclarationRule());
                      							}
                      							setWithLastConsumed(current, "fqnImport", true, "ns");
                      						
                    }

                    }


                    }

                    // InternalTableDSL.g:4508:5: ( (lv_importedFullyQualifiedName_10_0= ruleQualifiedName ) )
                    // InternalTableDSL.g:4509:6: (lv_importedFullyQualifiedName_10_0= ruleQualifiedName )
                    {
                    // InternalTableDSL.g:4509:6: (lv_importedFullyQualifiedName_10_0= ruleQualifiedName )
                    // InternalTableDSL.g:4510:7: lv_importedFullyQualifiedName_10_0= ruleQualifiedName
                    {
                    if ( state.backtracking==0 ) {

                      							newCompositeNode(grammarAccess.getXImportDeclarationAccess().getImportedFullyQualifiedNameQualifiedNameParserRuleCall_2_3_1_0());
                      						
                    }
                    pushFollow(FOLLOW_59);
                    lv_importedFullyQualifiedName_10_0=ruleQualifiedName();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      							if (current==null) {
                      								current = createModelElementForParent(grammarAccess.getXImportDeclarationRule());
                      							}
                      							set(
                      								current,
                      								"importedFullyQualifiedName",
                      								lv_importedFullyQualifiedName_10_0,
                      								"org.eclipse.xtext.xbase.Xbase.QualifiedName");
                      							afterParserOrEnumRuleCall();
                      						
                    }

                    }


                    }


                    }


                    }
                    break;

            }

            // InternalTableDSL.g:4529:3: (otherlv_11= ';' )?
            int alt47=2;
            int LA47_0 = input.LA(1);

            if ( (LA47_0==98) ) {
                alt47=1;
            }
            switch (alt47) {
                case 1 :
                    // InternalTableDSL.g:4530:4: otherlv_11= ';'
                    {
                    otherlv_11=(Token)match(input,98,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_11, grammarAccess.getXImportDeclarationAccess().getSemicolonKeyword_3());
                      			
                    }

                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXImportDeclaration"


    // $ANTLR start "entryRuleXAnnotation"
    // InternalTableDSL.g:4539:1: entryRuleXAnnotation returns [EObject current=null] : iv_ruleXAnnotation= ruleXAnnotation EOF ;
    public final EObject entryRuleXAnnotation() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXAnnotation = null;


        try {
            // InternalTableDSL.g:4539:52: (iv_ruleXAnnotation= ruleXAnnotation EOF )
            // InternalTableDSL.g:4540:2: iv_ruleXAnnotation= ruleXAnnotation EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXAnnotationRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXAnnotation=ruleXAnnotation();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXAnnotation; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXAnnotation"


    // $ANTLR start "ruleXAnnotation"
    // InternalTableDSL.g:4546:1: ruleXAnnotation returns [EObject current=null] : ( () otherlv_1= '@' ( ( ruleQualifiedName ) ) ( ( ( '(' )=>otherlv_3= '(' ) ( ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair ) ) (otherlv_5= ',' ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) ) )* ) | ( (lv_value_7_0= ruleXAnnotationElementValueOrCommaList ) ) )? otherlv_8= ')' )? ) ;
    public final EObject ruleXAnnotation() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_3=null;
        Token otherlv_5=null;
        Token otherlv_8=null;
        EObject lv_elementValuePairs_4_0 = null;

        EObject lv_elementValuePairs_6_0 = null;

        EObject lv_value_7_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:4552:2: ( ( () otherlv_1= '@' ( ( ruleQualifiedName ) ) ( ( ( '(' )=>otherlv_3= '(' ) ( ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair ) ) (otherlv_5= ',' ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) ) )* ) | ( (lv_value_7_0= ruleXAnnotationElementValueOrCommaList ) ) )? otherlv_8= ')' )? ) )
            // InternalTableDSL.g:4553:2: ( () otherlv_1= '@' ( ( ruleQualifiedName ) ) ( ( ( '(' )=>otherlv_3= '(' ) ( ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair ) ) (otherlv_5= ',' ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) ) )* ) | ( (lv_value_7_0= ruleXAnnotationElementValueOrCommaList ) ) )? otherlv_8= ')' )? )
            {
            // InternalTableDSL.g:4553:2: ( () otherlv_1= '@' ( ( ruleQualifiedName ) ) ( ( ( '(' )=>otherlv_3= '(' ) ( ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair ) ) (otherlv_5= ',' ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) ) )* ) | ( (lv_value_7_0= ruleXAnnotationElementValueOrCommaList ) ) )? otherlv_8= ')' )? )
            // InternalTableDSL.g:4554:3: () otherlv_1= '@' ( ( ruleQualifiedName ) ) ( ( ( '(' )=>otherlv_3= '(' ) ( ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair ) ) (otherlv_5= ',' ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) ) )* ) | ( (lv_value_7_0= ruleXAnnotationElementValueOrCommaList ) ) )? otherlv_8= ')' )?
            {
            // InternalTableDSL.g:4554:3: ()
            // InternalTableDSL.g:4555:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXAnnotationAccess().getXAnnotationAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,99,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXAnnotationAccess().getCommercialAtKeyword_1());
              		
            }
            // InternalTableDSL.g:4565:3: ( ( ruleQualifiedName ) )
            // InternalTableDSL.g:4566:4: ( ruleQualifiedName )
            {
            // InternalTableDSL.g:4566:4: ( ruleQualifiedName )
            // InternalTableDSL.g:4567:5: ruleQualifiedName
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getXAnnotationRule());
              					}
              				
            }
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXAnnotationAccess().getAnnotationTypeJvmAnnotationTypeCrossReference_2_0());
              				
            }
            pushFollow(FOLLOW_60);
            ruleQualifiedName();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:4581:3: ( ( ( '(' )=>otherlv_3= '(' ) ( ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair ) ) (otherlv_5= ',' ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) ) )* ) | ( (lv_value_7_0= ruleXAnnotationElementValueOrCommaList ) ) )? otherlv_8= ')' )?
            int alt50=2;
            int LA50_0 = input.LA(1);

            if ( (LA50_0==100) && (synpred1_InternalTableDSL())) {
                alt50=1;
            }
            switch (alt50) {
                case 1 :
                    // InternalTableDSL.g:4582:4: ( ( '(' )=>otherlv_3= '(' ) ( ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair ) ) (otherlv_5= ',' ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) ) )* ) | ( (lv_value_7_0= ruleXAnnotationElementValueOrCommaList ) ) )? otherlv_8= ')'
                    {
                    // InternalTableDSL.g:4582:4: ( ( '(' )=>otherlv_3= '(' )
                    // InternalTableDSL.g:4583:5: ( '(' )=>otherlv_3= '('
                    {
                    otherlv_3=(Token)match(input,100,FOLLOW_61); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					newLeafNode(otherlv_3, grammarAccess.getXAnnotationAccess().getLeftParenthesisKeyword_3_0());
                      				
                    }

                    }

                    // InternalTableDSL.g:4589:4: ( ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair ) ) (otherlv_5= ',' ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) ) )* ) | ( (lv_value_7_0= ruleXAnnotationElementValueOrCommaList ) ) )?
                    int alt49=3;
                    alt49 = dfa49.predict(input);
                    switch (alt49) {
                        case 1 :
                            // InternalTableDSL.g:4590:5: ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair ) ) (otherlv_5= ',' ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) ) )* )
                            {
                            // InternalTableDSL.g:4590:5: ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair ) ) (otherlv_5= ',' ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) ) )* )
                            // InternalTableDSL.g:4591:6: ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair ) ) (otherlv_5= ',' ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) ) )*
                            {
                            // InternalTableDSL.g:4591:6: ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair ) )
                            // InternalTableDSL.g:4592:7: ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair )
                            {
                            // InternalTableDSL.g:4601:7: (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair )
                            // InternalTableDSL.g:4602:8: lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair
                            {
                            if ( state.backtracking==0 ) {

                              								newCompositeNode(grammarAccess.getXAnnotationAccess().getElementValuePairsXAnnotationElementValuePairParserRuleCall_3_1_0_0_0());
                              							
                            }
                            pushFollow(FOLLOW_62);
                            lv_elementValuePairs_4_0=ruleXAnnotationElementValuePair();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              								if (current==null) {
                              									current = createModelElementForParent(grammarAccess.getXAnnotationRule());
                              								}
                              								add(
                              									current,
                              									"elementValuePairs",
                              									lv_elementValuePairs_4_0,
                              									"org.eclipse.xtext.xbase.annotations.XbaseWithAnnotations.XAnnotationElementValuePair");
                              								afterParserOrEnumRuleCall();
                              							
                            }

                            }


                            }

                            // InternalTableDSL.g:4619:6: (otherlv_5= ',' ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) ) )*
                            loop48:
                            do {
                                int alt48=2;
                                int LA48_0 = input.LA(1);

                                if ( (LA48_0==101) ) {
                                    alt48=1;
                                }


                                switch (alt48) {
                            	case 1 :
                            	    // InternalTableDSL.g:4620:7: otherlv_5= ',' ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) )
                            	    {
                            	    otherlv_5=(Token)match(input,101,FOLLOW_4); if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      							newLeafNode(otherlv_5, grammarAccess.getXAnnotationAccess().getCommaKeyword_3_1_0_1_0());
                            	      						
                            	    }
                            	    // InternalTableDSL.g:4624:7: ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) )
                            	    // InternalTableDSL.g:4625:8: ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair )
                            	    {
                            	    // InternalTableDSL.g:4634:8: (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair )
                            	    // InternalTableDSL.g:4635:9: lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair
                            	    {
                            	    if ( state.backtracking==0 ) {

                            	      									newCompositeNode(grammarAccess.getXAnnotationAccess().getElementValuePairsXAnnotationElementValuePairParserRuleCall_3_1_0_1_1_0());
                            	      								
                            	    }
                            	    pushFollow(FOLLOW_62);
                            	    lv_elementValuePairs_6_0=ruleXAnnotationElementValuePair();

                            	    state._fsp--;
                            	    if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      									if (current==null) {
                            	      										current = createModelElementForParent(grammarAccess.getXAnnotationRule());
                            	      									}
                            	      									add(
                            	      										current,
                            	      										"elementValuePairs",
                            	      										lv_elementValuePairs_6_0,
                            	      										"org.eclipse.xtext.xbase.annotations.XbaseWithAnnotations.XAnnotationElementValuePair");
                            	      									afterParserOrEnumRuleCall();
                            	      								
                            	    }

                            	    }


                            	    }


                            	    }
                            	    break;

                            	default :
                            	    break loop48;
                                }
                            } while (true);


                            }


                            }
                            break;
                        case 2 :
                            // InternalTableDSL.g:4655:5: ( (lv_value_7_0= ruleXAnnotationElementValueOrCommaList ) )
                            {
                            // InternalTableDSL.g:4655:5: ( (lv_value_7_0= ruleXAnnotationElementValueOrCommaList ) )
                            // InternalTableDSL.g:4656:6: (lv_value_7_0= ruleXAnnotationElementValueOrCommaList )
                            {
                            // InternalTableDSL.g:4656:6: (lv_value_7_0= ruleXAnnotationElementValueOrCommaList )
                            // InternalTableDSL.g:4657:7: lv_value_7_0= ruleXAnnotationElementValueOrCommaList
                            {
                            if ( state.backtracking==0 ) {

                              							newCompositeNode(grammarAccess.getXAnnotationAccess().getValueXAnnotationElementValueOrCommaListParserRuleCall_3_1_1_0());
                              						
                            }
                            pushFollow(FOLLOW_63);
                            lv_value_7_0=ruleXAnnotationElementValueOrCommaList();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              							if (current==null) {
                              								current = createModelElementForParent(grammarAccess.getXAnnotationRule());
                              							}
                              							set(
                              								current,
                              								"value",
                              								lv_value_7_0,
                              								"org.eclipse.xtext.xbase.annotations.XbaseWithAnnotations.XAnnotationElementValueOrCommaList");
                              							afterParserOrEnumRuleCall();
                              						
                            }

                            }


                            }


                            }
                            break;

                    }

                    otherlv_8=(Token)match(input,102,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_8, grammarAccess.getXAnnotationAccess().getRightParenthesisKeyword_3_2());
                      			
                    }

                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXAnnotation"


    // $ANTLR start "entryRuleXAnnotationElementValuePair"
    // InternalTableDSL.g:4684:1: entryRuleXAnnotationElementValuePair returns [EObject current=null] : iv_ruleXAnnotationElementValuePair= ruleXAnnotationElementValuePair EOF ;
    public final EObject entryRuleXAnnotationElementValuePair() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXAnnotationElementValuePair = null;


        try {
            // InternalTableDSL.g:4684:68: (iv_ruleXAnnotationElementValuePair= ruleXAnnotationElementValuePair EOF )
            // InternalTableDSL.g:4685:2: iv_ruleXAnnotationElementValuePair= ruleXAnnotationElementValuePair EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXAnnotationElementValuePairRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXAnnotationElementValuePair=ruleXAnnotationElementValuePair();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXAnnotationElementValuePair; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXAnnotationElementValuePair"


    // $ANTLR start "ruleXAnnotationElementValuePair"
    // InternalTableDSL.g:4691:1: ruleXAnnotationElementValuePair returns [EObject current=null] : ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> ( ( ( ruleValidID ) ) otherlv_1= '=' ) ) ( (lv_value_2_0= ruleXAnnotationElementValue ) ) ) ;
    public final EObject ruleXAnnotationElementValuePair() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        EObject lv_value_2_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:4697:2: ( ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> ( ( ( ruleValidID ) ) otherlv_1= '=' ) ) ( (lv_value_2_0= ruleXAnnotationElementValue ) ) ) )
            // InternalTableDSL.g:4698:2: ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> ( ( ( ruleValidID ) ) otherlv_1= '=' ) ) ( (lv_value_2_0= ruleXAnnotationElementValue ) ) )
            {
            // InternalTableDSL.g:4698:2: ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> ( ( ( ruleValidID ) ) otherlv_1= '=' ) ) ( (lv_value_2_0= ruleXAnnotationElementValue ) ) )
            // InternalTableDSL.g:4699:3: ( ( ( ( ( ruleValidID ) ) '=' ) )=> ( ( ( ruleValidID ) ) otherlv_1= '=' ) ) ( (lv_value_2_0= ruleXAnnotationElementValue ) )
            {
            // InternalTableDSL.g:4699:3: ( ( ( ( ( ruleValidID ) ) '=' ) )=> ( ( ( ruleValidID ) ) otherlv_1= '=' ) )
            // InternalTableDSL.g:4700:4: ( ( ( ( ruleValidID ) ) '=' ) )=> ( ( ( ruleValidID ) ) otherlv_1= '=' )
            {
            // InternalTableDSL.g:4709:4: ( ( ( ruleValidID ) ) otherlv_1= '=' )
            // InternalTableDSL.g:4710:5: ( ( ruleValidID ) ) otherlv_1= '='
            {
            // InternalTableDSL.g:4710:5: ( ( ruleValidID ) )
            // InternalTableDSL.g:4711:6: ( ruleValidID )
            {
            // InternalTableDSL.g:4711:6: ( ruleValidID )
            // InternalTableDSL.g:4712:7: ruleValidID
            {
            if ( state.backtracking==0 ) {

              							if (current==null) {
              								current = createModelElement(grammarAccess.getXAnnotationElementValuePairRule());
              							}
              						
            }
            if ( state.backtracking==0 ) {

              							newCompositeNode(grammarAccess.getXAnnotationElementValuePairAccess().getElementJvmOperationCrossReference_0_0_0_0());
              						
            }
            pushFollow(FOLLOW_64);
            ruleValidID();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              							afterParserOrEnumRuleCall();
              						
            }

            }


            }

            otherlv_1=(Token)match(input,103,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_1, grammarAccess.getXAnnotationElementValuePairAccess().getEqualsSignKeyword_0_0_1());
              				
            }

            }


            }

            // InternalTableDSL.g:4732:3: ( (lv_value_2_0= ruleXAnnotationElementValue ) )
            // InternalTableDSL.g:4733:4: (lv_value_2_0= ruleXAnnotationElementValue )
            {
            // InternalTableDSL.g:4733:4: (lv_value_2_0= ruleXAnnotationElementValue )
            // InternalTableDSL.g:4734:5: lv_value_2_0= ruleXAnnotationElementValue
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXAnnotationElementValuePairAccess().getValueXAnnotationElementValueParserRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_value_2_0=ruleXAnnotationElementValue();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXAnnotationElementValuePairRule());
              					}
              					set(
              						current,
              						"value",
              						lv_value_2_0,
              						"org.eclipse.xtext.xbase.annotations.XbaseWithAnnotations.XAnnotationElementValue");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXAnnotationElementValuePair"


    // $ANTLR start "entryRuleXAnnotationElementValueOrCommaList"
    // InternalTableDSL.g:4755:1: entryRuleXAnnotationElementValueOrCommaList returns [EObject current=null] : iv_ruleXAnnotationElementValueOrCommaList= ruleXAnnotationElementValueOrCommaList EOF ;
    public final EObject entryRuleXAnnotationElementValueOrCommaList() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXAnnotationElementValueOrCommaList = null;


        try {
            // InternalTableDSL.g:4755:75: (iv_ruleXAnnotationElementValueOrCommaList= ruleXAnnotationElementValueOrCommaList EOF )
            // InternalTableDSL.g:4756:2: iv_ruleXAnnotationElementValueOrCommaList= ruleXAnnotationElementValueOrCommaList EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXAnnotationElementValueOrCommaListRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXAnnotationElementValueOrCommaList=ruleXAnnotationElementValueOrCommaList();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXAnnotationElementValueOrCommaList; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXAnnotationElementValueOrCommaList"


    // $ANTLR start "ruleXAnnotationElementValueOrCommaList"
    // InternalTableDSL.g:4762:1: ruleXAnnotationElementValueOrCommaList returns [EObject current=null] : ( ( ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']' ) | (this_XAnnotationOrExpression_7= ruleXAnnotationOrExpression ( () (otherlv_9= ',' ( (lv_elements_10_0= ruleXAnnotationOrExpression ) ) )+ )? ) ) ;
    public final EObject ruleXAnnotationElementValueOrCommaList() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token otherlv_4=null;
        Token otherlv_6=null;
        Token otherlv_9=null;
        EObject lv_elements_3_0 = null;

        EObject lv_elements_5_0 = null;

        EObject this_XAnnotationOrExpression_7 = null;

        EObject lv_elements_10_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:4768:2: ( ( ( ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']' ) | (this_XAnnotationOrExpression_7= ruleXAnnotationOrExpression ( () (otherlv_9= ',' ( (lv_elements_10_0= ruleXAnnotationOrExpression ) ) )+ )? ) ) )
            // InternalTableDSL.g:4769:2: ( ( ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']' ) | (this_XAnnotationOrExpression_7= ruleXAnnotationOrExpression ( () (otherlv_9= ',' ( (lv_elements_10_0= ruleXAnnotationOrExpression ) ) )+ )? ) )
            {
            // InternalTableDSL.g:4769:2: ( ( ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']' ) | (this_XAnnotationOrExpression_7= ruleXAnnotationOrExpression ( () (otherlv_9= ',' ( (lv_elements_10_0= ruleXAnnotationOrExpression ) ) )+ )? ) )
            int alt55=2;
            alt55 = dfa55.predict(input);
            switch (alt55) {
                case 1 :
                    // InternalTableDSL.g:4770:3: ( ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']' )
                    {
                    // InternalTableDSL.g:4770:3: ( ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']' )
                    // InternalTableDSL.g:4771:4: ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']'
                    {
                    // InternalTableDSL.g:4771:4: ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) )
                    // InternalTableDSL.g:4772:5: ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' )
                    {
                    // InternalTableDSL.g:4779:5: ( () otherlv_1= '#' otherlv_2= '[' )
                    // InternalTableDSL.g:4780:6: () otherlv_1= '#' otherlv_2= '['
                    {
                    // InternalTableDSL.g:4780:6: ()
                    // InternalTableDSL.g:4781:7: 
                    {
                    if ( state.backtracking==0 ) {

                      							current = forceCreateModelElement(
                      								grammarAccess.getXAnnotationElementValueOrCommaListAccess().getXListLiteralAction_0_0_0_0(),
                      								current);
                      						
                    }

                    }

                    otherlv_1=(Token)match(input,104,FOLLOW_66); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						newLeafNode(otherlv_1, grammarAccess.getXAnnotationElementValueOrCommaListAccess().getNumberSignKeyword_0_0_0_1());
                      					
                    }
                    otherlv_2=(Token)match(input,105,FOLLOW_67); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						newLeafNode(otherlv_2, grammarAccess.getXAnnotationElementValueOrCommaListAccess().getLeftSquareBracketKeyword_0_0_0_2());
                      					
                    }

                    }


                    }

                    // InternalTableDSL.g:4797:4: ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )?
                    int alt52=2;
                    int LA52_0 = input.LA(1);

                    if ( ((LA52_0>=RULE_ID && LA52_0<=RULE_STRING)||(LA52_0>=RULE_INT && LA52_0<=RULE_DECIMAL)||LA52_0==16||(LA52_0>=91 && LA52_0<=95)||(LA52_0>=99 && LA52_0<=100)||(LA52_0>=104 && LA52_0<=105)||LA52_0==112||LA52_0==131||LA52_0==137||LA52_0==139||(LA52_0>=143 && LA52_0<=145)||(LA52_0>=148 && LA52_0<=157)||LA52_0==159) ) {
                        alt52=1;
                    }
                    switch (alt52) {
                        case 1 :
                            // InternalTableDSL.g:4798:5: ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )*
                            {
                            // InternalTableDSL.g:4798:5: ( (lv_elements_3_0= ruleXAnnotationOrExpression ) )
                            // InternalTableDSL.g:4799:6: (lv_elements_3_0= ruleXAnnotationOrExpression )
                            {
                            // InternalTableDSL.g:4799:6: (lv_elements_3_0= ruleXAnnotationOrExpression )
                            // InternalTableDSL.g:4800:7: lv_elements_3_0= ruleXAnnotationOrExpression
                            {
                            if ( state.backtracking==0 ) {

                              							newCompositeNode(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getElementsXAnnotationOrExpressionParserRuleCall_0_1_0_0());
                              						
                            }
                            pushFollow(FOLLOW_68);
                            lv_elements_3_0=ruleXAnnotationOrExpression();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              							if (current==null) {
                              								current = createModelElementForParent(grammarAccess.getXAnnotationElementValueOrCommaListRule());
                              							}
                              							add(
                              								current,
                              								"elements",
                              								lv_elements_3_0,
                              								"org.eclipse.xtext.xbase.annotations.XbaseWithAnnotations.XAnnotationOrExpression");
                              							afterParserOrEnumRuleCall();
                              						
                            }

                            }


                            }

                            // InternalTableDSL.g:4817:5: (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )*
                            loop51:
                            do {
                                int alt51=2;
                                int LA51_0 = input.LA(1);

                                if ( (LA51_0==101) ) {
                                    alt51=1;
                                }


                                switch (alt51) {
                            	case 1 :
                            	    // InternalTableDSL.g:4818:6: otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) )
                            	    {
                            	    otherlv_4=(Token)match(input,101,FOLLOW_65); if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      						newLeafNode(otherlv_4, grammarAccess.getXAnnotationElementValueOrCommaListAccess().getCommaKeyword_0_1_1_0());
                            	      					
                            	    }
                            	    // InternalTableDSL.g:4822:6: ( (lv_elements_5_0= ruleXAnnotationOrExpression ) )
                            	    // InternalTableDSL.g:4823:7: (lv_elements_5_0= ruleXAnnotationOrExpression )
                            	    {
                            	    // InternalTableDSL.g:4823:7: (lv_elements_5_0= ruleXAnnotationOrExpression )
                            	    // InternalTableDSL.g:4824:8: lv_elements_5_0= ruleXAnnotationOrExpression
                            	    {
                            	    if ( state.backtracking==0 ) {

                            	      								newCompositeNode(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getElementsXAnnotationOrExpressionParserRuleCall_0_1_1_1_0());
                            	      							
                            	    }
                            	    pushFollow(FOLLOW_68);
                            	    lv_elements_5_0=ruleXAnnotationOrExpression();

                            	    state._fsp--;
                            	    if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      								if (current==null) {
                            	      									current = createModelElementForParent(grammarAccess.getXAnnotationElementValueOrCommaListRule());
                            	      								}
                            	      								add(
                            	      									current,
                            	      									"elements",
                            	      									lv_elements_5_0,
                            	      									"org.eclipse.xtext.xbase.annotations.XbaseWithAnnotations.XAnnotationOrExpression");
                            	      								afterParserOrEnumRuleCall();
                            	      							
                            	    }

                            	    }


                            	    }


                            	    }
                            	    break;

                            	default :
                            	    break loop51;
                                }
                            } while (true);


                            }
                            break;

                    }

                    otherlv_6=(Token)match(input,106,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_6, grammarAccess.getXAnnotationElementValueOrCommaListAccess().getRightSquareBracketKeyword_0_2());
                      			
                    }

                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:4849:3: (this_XAnnotationOrExpression_7= ruleXAnnotationOrExpression ( () (otherlv_9= ',' ( (lv_elements_10_0= ruleXAnnotationOrExpression ) ) )+ )? )
                    {
                    // InternalTableDSL.g:4849:3: (this_XAnnotationOrExpression_7= ruleXAnnotationOrExpression ( () (otherlv_9= ',' ( (lv_elements_10_0= ruleXAnnotationOrExpression ) ) )+ )? )
                    // InternalTableDSL.g:4850:4: this_XAnnotationOrExpression_7= ruleXAnnotationOrExpression ( () (otherlv_9= ',' ( (lv_elements_10_0= ruleXAnnotationOrExpression ) ) )+ )?
                    {
                    if ( state.backtracking==0 ) {

                      				newCompositeNode(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getXAnnotationOrExpressionParserRuleCall_1_0());
                      			
                    }
                    pushFollow(FOLLOW_69);
                    this_XAnnotationOrExpression_7=ruleXAnnotationOrExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = this_XAnnotationOrExpression_7;
                      				afterParserOrEnumRuleCall();
                      			
                    }
                    // InternalTableDSL.g:4858:4: ( () (otherlv_9= ',' ( (lv_elements_10_0= ruleXAnnotationOrExpression ) ) )+ )?
                    int alt54=2;
                    int LA54_0 = input.LA(1);

                    if ( (LA54_0==101) ) {
                        alt54=1;
                    }
                    switch (alt54) {
                        case 1 :
                            // InternalTableDSL.g:4859:5: () (otherlv_9= ',' ( (lv_elements_10_0= ruleXAnnotationOrExpression ) ) )+
                            {
                            // InternalTableDSL.g:4859:5: ()
                            // InternalTableDSL.g:4860:6: 
                            {
                            if ( state.backtracking==0 ) {

                              						current = forceCreateModelElementAndAdd(
                              							grammarAccess.getXAnnotationElementValueOrCommaListAccess().getXListLiteralElementsAction_1_1_0(),
                              							current);
                              					
                            }

                            }

                            // InternalTableDSL.g:4866:5: (otherlv_9= ',' ( (lv_elements_10_0= ruleXAnnotationOrExpression ) ) )+
                            int cnt53=0;
                            loop53:
                            do {
                                int alt53=2;
                                int LA53_0 = input.LA(1);

                                if ( (LA53_0==101) ) {
                                    alt53=1;
                                }


                                switch (alt53) {
                            	case 1 :
                            	    // InternalTableDSL.g:4867:6: otherlv_9= ',' ( (lv_elements_10_0= ruleXAnnotationOrExpression ) )
                            	    {
                            	    otherlv_9=(Token)match(input,101,FOLLOW_65); if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      						newLeafNode(otherlv_9, grammarAccess.getXAnnotationElementValueOrCommaListAccess().getCommaKeyword_1_1_1_0());
                            	      					
                            	    }
                            	    // InternalTableDSL.g:4871:6: ( (lv_elements_10_0= ruleXAnnotationOrExpression ) )
                            	    // InternalTableDSL.g:4872:7: (lv_elements_10_0= ruleXAnnotationOrExpression )
                            	    {
                            	    // InternalTableDSL.g:4872:7: (lv_elements_10_0= ruleXAnnotationOrExpression )
                            	    // InternalTableDSL.g:4873:8: lv_elements_10_0= ruleXAnnotationOrExpression
                            	    {
                            	    if ( state.backtracking==0 ) {

                            	      								newCompositeNode(grammarAccess.getXAnnotationElementValueOrCommaListAccess().getElementsXAnnotationOrExpressionParserRuleCall_1_1_1_1_0());
                            	      							
                            	    }
                            	    pushFollow(FOLLOW_69);
                            	    lv_elements_10_0=ruleXAnnotationOrExpression();

                            	    state._fsp--;
                            	    if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      								if (current==null) {
                            	      									current = createModelElementForParent(grammarAccess.getXAnnotationElementValueOrCommaListRule());
                            	      								}
                            	      								add(
                            	      									current,
                            	      									"elements",
                            	      									lv_elements_10_0,
                            	      									"org.eclipse.xtext.xbase.annotations.XbaseWithAnnotations.XAnnotationOrExpression");
                            	      								afterParserOrEnumRuleCall();
                            	      							
                            	    }

                            	    }


                            	    }


                            	    }
                            	    break;

                            	default :
                            	    if ( cnt53 >= 1 ) break loop53;
                            	    if (state.backtracking>0) {state.failed=true; return current;}
                                        EarlyExitException eee =
                                            new EarlyExitException(53, input);
                                        throw eee;
                                }
                                cnt53++;
                            } while (true);


                            }
                            break;

                    }


                    }


                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXAnnotationElementValueOrCommaList"


    // $ANTLR start "entryRuleXAnnotationElementValue"
    // InternalTableDSL.g:4897:1: entryRuleXAnnotationElementValue returns [EObject current=null] : iv_ruleXAnnotationElementValue= ruleXAnnotationElementValue EOF ;
    public final EObject entryRuleXAnnotationElementValue() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXAnnotationElementValue = null;


        try {
            // InternalTableDSL.g:4897:64: (iv_ruleXAnnotationElementValue= ruleXAnnotationElementValue EOF )
            // InternalTableDSL.g:4898:2: iv_ruleXAnnotationElementValue= ruleXAnnotationElementValue EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXAnnotationElementValueRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXAnnotationElementValue=ruleXAnnotationElementValue();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXAnnotationElementValue; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXAnnotationElementValue"


    // $ANTLR start "ruleXAnnotationElementValue"
    // InternalTableDSL.g:4904:1: ruleXAnnotationElementValue returns [EObject current=null] : ( ( ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']' ) | this_XAnnotationOrExpression_7= ruleXAnnotationOrExpression ) ;
    public final EObject ruleXAnnotationElementValue() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token otherlv_4=null;
        Token otherlv_6=null;
        EObject lv_elements_3_0 = null;

        EObject lv_elements_5_0 = null;

        EObject this_XAnnotationOrExpression_7 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:4910:2: ( ( ( ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']' ) | this_XAnnotationOrExpression_7= ruleXAnnotationOrExpression ) )
            // InternalTableDSL.g:4911:2: ( ( ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']' ) | this_XAnnotationOrExpression_7= ruleXAnnotationOrExpression )
            {
            // InternalTableDSL.g:4911:2: ( ( ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']' ) | this_XAnnotationOrExpression_7= ruleXAnnotationOrExpression )
            int alt58=2;
            alt58 = dfa58.predict(input);
            switch (alt58) {
                case 1 :
                    // InternalTableDSL.g:4912:3: ( ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']' )
                    {
                    // InternalTableDSL.g:4912:3: ( ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']' )
                    // InternalTableDSL.g:4913:4: ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']'
                    {
                    // InternalTableDSL.g:4913:4: ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) )
                    // InternalTableDSL.g:4914:5: ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' )
                    {
                    // InternalTableDSL.g:4921:5: ( () otherlv_1= '#' otherlv_2= '[' )
                    // InternalTableDSL.g:4922:6: () otherlv_1= '#' otherlv_2= '['
                    {
                    // InternalTableDSL.g:4922:6: ()
                    // InternalTableDSL.g:4923:7: 
                    {
                    if ( state.backtracking==0 ) {

                      							current = forceCreateModelElement(
                      								grammarAccess.getXAnnotationElementValueAccess().getXListLiteralAction_0_0_0_0(),
                      								current);
                      						
                    }

                    }

                    otherlv_1=(Token)match(input,104,FOLLOW_66); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						newLeafNode(otherlv_1, grammarAccess.getXAnnotationElementValueAccess().getNumberSignKeyword_0_0_0_1());
                      					
                    }
                    otherlv_2=(Token)match(input,105,FOLLOW_67); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						newLeafNode(otherlv_2, grammarAccess.getXAnnotationElementValueAccess().getLeftSquareBracketKeyword_0_0_0_2());
                      					
                    }

                    }


                    }

                    // InternalTableDSL.g:4939:4: ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )?
                    int alt57=2;
                    int LA57_0 = input.LA(1);

                    if ( ((LA57_0>=RULE_ID && LA57_0<=RULE_STRING)||(LA57_0>=RULE_INT && LA57_0<=RULE_DECIMAL)||LA57_0==16||(LA57_0>=91 && LA57_0<=95)||(LA57_0>=99 && LA57_0<=100)||(LA57_0>=104 && LA57_0<=105)||LA57_0==112||LA57_0==131||LA57_0==137||LA57_0==139||(LA57_0>=143 && LA57_0<=145)||(LA57_0>=148 && LA57_0<=157)||LA57_0==159) ) {
                        alt57=1;
                    }
                    switch (alt57) {
                        case 1 :
                            // InternalTableDSL.g:4940:5: ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )*
                            {
                            // InternalTableDSL.g:4940:5: ( (lv_elements_3_0= ruleXAnnotationOrExpression ) )
                            // InternalTableDSL.g:4941:6: (lv_elements_3_0= ruleXAnnotationOrExpression )
                            {
                            // InternalTableDSL.g:4941:6: (lv_elements_3_0= ruleXAnnotationOrExpression )
                            // InternalTableDSL.g:4942:7: lv_elements_3_0= ruleXAnnotationOrExpression
                            {
                            if ( state.backtracking==0 ) {

                              							newCompositeNode(grammarAccess.getXAnnotationElementValueAccess().getElementsXAnnotationOrExpressionParserRuleCall_0_1_0_0());
                              						
                            }
                            pushFollow(FOLLOW_68);
                            lv_elements_3_0=ruleXAnnotationOrExpression();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              							if (current==null) {
                              								current = createModelElementForParent(grammarAccess.getXAnnotationElementValueRule());
                              							}
                              							add(
                              								current,
                              								"elements",
                              								lv_elements_3_0,
                              								"org.eclipse.xtext.xbase.annotations.XbaseWithAnnotations.XAnnotationOrExpression");
                              							afterParserOrEnumRuleCall();
                              						
                            }

                            }


                            }

                            // InternalTableDSL.g:4959:5: (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )*
                            loop56:
                            do {
                                int alt56=2;
                                int LA56_0 = input.LA(1);

                                if ( (LA56_0==101) ) {
                                    alt56=1;
                                }


                                switch (alt56) {
                            	case 1 :
                            	    // InternalTableDSL.g:4960:6: otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) )
                            	    {
                            	    otherlv_4=(Token)match(input,101,FOLLOW_65); if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      						newLeafNode(otherlv_4, grammarAccess.getXAnnotationElementValueAccess().getCommaKeyword_0_1_1_0());
                            	      					
                            	    }
                            	    // InternalTableDSL.g:4964:6: ( (lv_elements_5_0= ruleXAnnotationOrExpression ) )
                            	    // InternalTableDSL.g:4965:7: (lv_elements_5_0= ruleXAnnotationOrExpression )
                            	    {
                            	    // InternalTableDSL.g:4965:7: (lv_elements_5_0= ruleXAnnotationOrExpression )
                            	    // InternalTableDSL.g:4966:8: lv_elements_5_0= ruleXAnnotationOrExpression
                            	    {
                            	    if ( state.backtracking==0 ) {

                            	      								newCompositeNode(grammarAccess.getXAnnotationElementValueAccess().getElementsXAnnotationOrExpressionParserRuleCall_0_1_1_1_0());
                            	      							
                            	    }
                            	    pushFollow(FOLLOW_68);
                            	    lv_elements_5_0=ruleXAnnotationOrExpression();

                            	    state._fsp--;
                            	    if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      								if (current==null) {
                            	      									current = createModelElementForParent(grammarAccess.getXAnnotationElementValueRule());
                            	      								}
                            	      								add(
                            	      									current,
                            	      									"elements",
                            	      									lv_elements_5_0,
                            	      									"org.eclipse.xtext.xbase.annotations.XbaseWithAnnotations.XAnnotationOrExpression");
                            	      								afterParserOrEnumRuleCall();
                            	      							
                            	    }

                            	    }


                            	    }


                            	    }
                            	    break;

                            	default :
                            	    break loop56;
                                }
                            } while (true);


                            }
                            break;

                    }

                    otherlv_6=(Token)match(input,106,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_6, grammarAccess.getXAnnotationElementValueAccess().getRightSquareBracketKeyword_0_2());
                      			
                    }

                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:4991:3: this_XAnnotationOrExpression_7= ruleXAnnotationOrExpression
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXAnnotationElementValueAccess().getXAnnotationOrExpressionParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XAnnotationOrExpression_7=ruleXAnnotationOrExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XAnnotationOrExpression_7;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXAnnotationElementValue"


    // $ANTLR start "entryRuleXAnnotationOrExpression"
    // InternalTableDSL.g:5003:1: entryRuleXAnnotationOrExpression returns [EObject current=null] : iv_ruleXAnnotationOrExpression= ruleXAnnotationOrExpression EOF ;
    public final EObject entryRuleXAnnotationOrExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXAnnotationOrExpression = null;


        try {
            // InternalTableDSL.g:5003:64: (iv_ruleXAnnotationOrExpression= ruleXAnnotationOrExpression EOF )
            // InternalTableDSL.g:5004:2: iv_ruleXAnnotationOrExpression= ruleXAnnotationOrExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXAnnotationOrExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXAnnotationOrExpression=ruleXAnnotationOrExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXAnnotationOrExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXAnnotationOrExpression"


    // $ANTLR start "ruleXAnnotationOrExpression"
    // InternalTableDSL.g:5010:1: ruleXAnnotationOrExpression returns [EObject current=null] : (this_XAnnotation_0= ruleXAnnotation | this_XExpression_1= ruleXExpression ) ;
    public final EObject ruleXAnnotationOrExpression() throws RecognitionException {
        EObject current = null;

        EObject this_XAnnotation_0 = null;

        EObject this_XExpression_1 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:5016:2: ( (this_XAnnotation_0= ruleXAnnotation | this_XExpression_1= ruleXExpression ) )
            // InternalTableDSL.g:5017:2: (this_XAnnotation_0= ruleXAnnotation | this_XExpression_1= ruleXExpression )
            {
            // InternalTableDSL.g:5017:2: (this_XAnnotation_0= ruleXAnnotation | this_XExpression_1= ruleXExpression )
            int alt59=2;
            int LA59_0 = input.LA(1);

            if ( (LA59_0==99) ) {
                alt59=1;
            }
            else if ( ((LA59_0>=RULE_ID && LA59_0<=RULE_STRING)||(LA59_0>=RULE_INT && LA59_0<=RULE_DECIMAL)||LA59_0==16||(LA59_0>=91 && LA59_0<=95)||LA59_0==100||(LA59_0>=104 && LA59_0<=105)||LA59_0==112||LA59_0==131||LA59_0==137||LA59_0==139||(LA59_0>=143 && LA59_0<=145)||(LA59_0>=148 && LA59_0<=157)||LA59_0==159) ) {
                alt59=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 59, 0, input);

                throw nvae;
            }
            switch (alt59) {
                case 1 :
                    // InternalTableDSL.g:5018:3: this_XAnnotation_0= ruleXAnnotation
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXAnnotationOrExpressionAccess().getXAnnotationParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XAnnotation_0=ruleXAnnotation();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XAnnotation_0;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:5027:3: this_XExpression_1= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXAnnotationOrExpressionAccess().getXExpressionParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XExpression_1=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XExpression_1;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXAnnotationOrExpression"


    // $ANTLR start "entryRuleXExpression"
    // InternalTableDSL.g:5039:1: entryRuleXExpression returns [EObject current=null] : iv_ruleXExpression= ruleXExpression EOF ;
    public final EObject entryRuleXExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXExpression = null;


        try {
            // InternalTableDSL.g:5039:52: (iv_ruleXExpression= ruleXExpression EOF )
            // InternalTableDSL.g:5040:2: iv_ruleXExpression= ruleXExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXExpression=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXExpression"


    // $ANTLR start "ruleXExpression"
    // InternalTableDSL.g:5046:1: ruleXExpression returns [EObject current=null] : this_XAssignment_0= ruleXAssignment ;
    public final EObject ruleXExpression() throws RecognitionException {
        EObject current = null;

        EObject this_XAssignment_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:5052:2: (this_XAssignment_0= ruleXAssignment )
            // InternalTableDSL.g:5053:2: this_XAssignment_0= ruleXAssignment
            {
            if ( state.backtracking==0 ) {

              		newCompositeNode(grammarAccess.getXExpressionAccess().getXAssignmentParserRuleCall());
              	
            }
            pushFollow(FOLLOW_2);
            this_XAssignment_0=ruleXAssignment();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              		current = this_XAssignment_0;
              		afterParserOrEnumRuleCall();
              	
            }

            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXExpression"


    // $ANTLR start "entryRuleXAssignment"
    // InternalTableDSL.g:5064:1: entryRuleXAssignment returns [EObject current=null] : iv_ruleXAssignment= ruleXAssignment EOF ;
    public final EObject entryRuleXAssignment() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXAssignment = null;


        try {
            // InternalTableDSL.g:5064:52: (iv_ruleXAssignment= ruleXAssignment EOF )
            // InternalTableDSL.g:5065:2: iv_ruleXAssignment= ruleXAssignment EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXAssignmentRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXAssignment=ruleXAssignment();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXAssignment; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXAssignment"


    // $ANTLR start "ruleXAssignment"
    // InternalTableDSL.g:5071:1: ruleXAssignment returns [EObject current=null] : ( ( () ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ( (lv_value_3_0= ruleXAssignment ) ) ) | (this_XOrExpression_4= ruleXOrExpression ( ( ( ( () ( ( ruleOpMultiAssign ) ) ) )=> ( () ( ( ruleOpMultiAssign ) ) ) ) ( (lv_rightOperand_7_0= ruleXAssignment ) ) )? ) ) ;
    public final EObject ruleXAssignment() throws RecognitionException {
        EObject current = null;

        EObject lv_value_3_0 = null;

        EObject this_XOrExpression_4 = null;

        EObject lv_rightOperand_7_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:5077:2: ( ( ( () ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ( (lv_value_3_0= ruleXAssignment ) ) ) | (this_XOrExpression_4= ruleXOrExpression ( ( ( ( () ( ( ruleOpMultiAssign ) ) ) )=> ( () ( ( ruleOpMultiAssign ) ) ) ) ( (lv_rightOperand_7_0= ruleXAssignment ) ) )? ) ) )
            // InternalTableDSL.g:5078:2: ( ( () ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ( (lv_value_3_0= ruleXAssignment ) ) ) | (this_XOrExpression_4= ruleXOrExpression ( ( ( ( () ( ( ruleOpMultiAssign ) ) ) )=> ( () ( ( ruleOpMultiAssign ) ) ) ) ( (lv_rightOperand_7_0= ruleXAssignment ) ) )? ) )
            {
            // InternalTableDSL.g:5078:2: ( ( () ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ( (lv_value_3_0= ruleXAssignment ) ) ) | (this_XOrExpression_4= ruleXOrExpression ( ( ( ( () ( ( ruleOpMultiAssign ) ) ) )=> ( () ( ( ruleOpMultiAssign ) ) ) ) ( (lv_rightOperand_7_0= ruleXAssignment ) ) )? ) )
            int alt61=2;
            switch ( input.LA(1) ) {
            case RULE_ID:
                {
                int LA61_1 = input.LA(2);

                if ( (LA61_1==103) ) {
                    alt61=1;
                }
                else if ( (LA61_1==EOF||(LA61_1>=RULE_ID && LA61_1<=RULE_STRING)||(LA61_1>=RULE_INT && LA61_1<=RULE_DECIMAL)||(LA61_1>=16 && LA61_1<=17)||LA61_1==20||LA61_1==74||(LA61_1>=91 && LA61_1<=96)||LA61_1==98||(LA61_1>=100 && LA61_1<=102)||(LA61_1>=104 && LA61_1<=135)||(LA61_1>=137 && LA61_1<=160)) ) {
                    alt61=2;
                }
                else {
                    if (state.backtracking>0) {state.failed=true; return current;}
                    NoViableAltException nvae =
                        new NoViableAltException("", 61, 1, input);

                    throw nvae;
                }
                }
                break;
            case 148:
                {
                int LA61_2 = input.LA(2);

                if ( (LA61_2==103) ) {
                    alt61=1;
                }
                else if ( (LA61_2==EOF||(LA61_2>=RULE_ID && LA61_2<=RULE_STRING)||(LA61_2>=RULE_INT && LA61_2<=RULE_DECIMAL)||(LA61_2>=16 && LA61_2<=17)||LA61_2==20||LA61_2==74||(LA61_2>=91 && LA61_2<=96)||LA61_2==98||(LA61_2>=100 && LA61_2<=102)||(LA61_2>=104 && LA61_2<=135)||(LA61_2>=137 && LA61_2<=160)) ) {
                    alt61=2;
                }
                else {
                    if (state.backtracking>0) {state.failed=true; return current;}
                    NoViableAltException nvae =
                        new NoViableAltException("", 61, 2, input);

                    throw nvae;
                }
                }
                break;
            case 94:
                {
                int LA61_3 = input.LA(2);

                if ( (LA61_3==103) ) {
                    alt61=1;
                }
                else if ( (LA61_3==EOF||(LA61_3>=RULE_ID && LA61_3<=RULE_STRING)||(LA61_3>=RULE_INT && LA61_3<=RULE_DECIMAL)||(LA61_3>=16 && LA61_3<=17)||LA61_3==20||LA61_3==74||(LA61_3>=91 && LA61_3<=96)||LA61_3==98||(LA61_3>=100 && LA61_3<=102)||(LA61_3>=104 && LA61_3<=135)||(LA61_3>=137 && LA61_3<=160)) ) {
                    alt61=2;
                }
                else {
                    if (state.backtracking>0) {state.failed=true; return current;}
                    NoViableAltException nvae =
                        new NoViableAltException("", 61, 3, input);

                    throw nvae;
                }
                }
                break;
            case 93:
                {
                int LA61_4 = input.LA(2);

                if ( (LA61_4==103) ) {
                    alt61=1;
                }
                else if ( (LA61_4==EOF||(LA61_4>=RULE_ID && LA61_4<=RULE_STRING)||(LA61_4>=RULE_INT && LA61_4<=RULE_DECIMAL)||(LA61_4>=16 && LA61_4<=17)||LA61_4==20||LA61_4==74||(LA61_4>=91 && LA61_4<=96)||LA61_4==98||(LA61_4>=100 && LA61_4<=102)||(LA61_4>=104 && LA61_4<=135)||(LA61_4>=137 && LA61_4<=160)) ) {
                    alt61=2;
                }
                else {
                    if (state.backtracking>0) {state.failed=true; return current;}
                    NoViableAltException nvae =
                        new NoViableAltException("", 61, 4, input);

                    throw nvae;
                }
                }
                break;
            case 95:
                {
                int LA61_5 = input.LA(2);

                if ( (LA61_5==EOF||(LA61_5>=RULE_ID && LA61_5<=RULE_STRING)||(LA61_5>=RULE_INT && LA61_5<=RULE_DECIMAL)||(LA61_5>=16 && LA61_5<=17)||LA61_5==20||LA61_5==74||(LA61_5>=91 && LA61_5<=96)||LA61_5==98||(LA61_5>=100 && LA61_5<=102)||(LA61_5>=104 && LA61_5<=135)||(LA61_5>=137 && LA61_5<=160)) ) {
                    alt61=2;
                }
                else if ( (LA61_5==103) ) {
                    alt61=1;
                }
                else {
                    if (state.backtracking>0) {state.failed=true; return current;}
                    NoViableAltException nvae =
                        new NoViableAltException("", 61, 5, input);

                    throw nvae;
                }
                }
                break;
            case RULE_STRING:
            case RULE_INT:
            case RULE_HEX:
            case RULE_DECIMAL:
            case 16:
            case 91:
            case 92:
            case 100:
            case 104:
            case 105:
            case 112:
            case 131:
            case 137:
            case 139:
            case 143:
            case 144:
            case 145:
            case 149:
            case 150:
            case 151:
            case 152:
            case 153:
            case 154:
            case 155:
            case 156:
            case 157:
            case 159:
                {
                alt61=2;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 61, 0, input);

                throw nvae;
            }

            switch (alt61) {
                case 1 :
                    // InternalTableDSL.g:5079:3: ( () ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ( (lv_value_3_0= ruleXAssignment ) ) )
                    {
                    // InternalTableDSL.g:5079:3: ( () ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ( (lv_value_3_0= ruleXAssignment ) ) )
                    // InternalTableDSL.g:5080:4: () ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ( (lv_value_3_0= ruleXAssignment ) )
                    {
                    // InternalTableDSL.g:5080:4: ()
                    // InternalTableDSL.g:5081:5: 
                    {
                    if ( state.backtracking==0 ) {

                      					current = forceCreateModelElement(
                      						grammarAccess.getXAssignmentAccess().getXAssignmentAction_0_0(),
                      						current);
                      				
                    }

                    }

                    // InternalTableDSL.g:5087:4: ( ( ruleFeatureCallID ) )
                    // InternalTableDSL.g:5088:5: ( ruleFeatureCallID )
                    {
                    // InternalTableDSL.g:5088:5: ( ruleFeatureCallID )
                    // InternalTableDSL.g:5089:6: ruleFeatureCallID
                    {
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElement(grammarAccess.getXAssignmentRule());
                      						}
                      					
                    }
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXAssignmentAccess().getFeatureJvmIdentifiableElementCrossReference_0_1_0());
                      					
                    }
                    pushFollow(FOLLOW_64);
                    ruleFeatureCallID();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }

                    if ( state.backtracking==0 ) {

                      				newCompositeNode(grammarAccess.getXAssignmentAccess().getOpSingleAssignParserRuleCall_0_2());
                      			
                    }
                    pushFollow(FOLLOW_65);
                    ruleOpSingleAssign();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				afterParserOrEnumRuleCall();
                      			
                    }
                    // InternalTableDSL.g:5110:4: ( (lv_value_3_0= ruleXAssignment ) )
                    // InternalTableDSL.g:5111:5: (lv_value_3_0= ruleXAssignment )
                    {
                    // InternalTableDSL.g:5111:5: (lv_value_3_0= ruleXAssignment )
                    // InternalTableDSL.g:5112:6: lv_value_3_0= ruleXAssignment
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXAssignmentAccess().getValueXAssignmentParserRuleCall_0_3_0());
                      					
                    }
                    pushFollow(FOLLOW_2);
                    lv_value_3_0=ruleXAssignment();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getXAssignmentRule());
                      						}
                      						set(
                      							current,
                      							"value",
                      							lv_value_3_0,
                      							"org.eclipse.xtext.xbase.Xbase.XAssignment");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }


                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:5131:3: (this_XOrExpression_4= ruleXOrExpression ( ( ( ( () ( ( ruleOpMultiAssign ) ) ) )=> ( () ( ( ruleOpMultiAssign ) ) ) ) ( (lv_rightOperand_7_0= ruleXAssignment ) ) )? )
                    {
                    // InternalTableDSL.g:5131:3: (this_XOrExpression_4= ruleXOrExpression ( ( ( ( () ( ( ruleOpMultiAssign ) ) ) )=> ( () ( ( ruleOpMultiAssign ) ) ) ) ( (lv_rightOperand_7_0= ruleXAssignment ) ) )? )
                    // InternalTableDSL.g:5132:4: this_XOrExpression_4= ruleXOrExpression ( ( ( ( () ( ( ruleOpMultiAssign ) ) ) )=> ( () ( ( ruleOpMultiAssign ) ) ) ) ( (lv_rightOperand_7_0= ruleXAssignment ) ) )?
                    {
                    if ( state.backtracking==0 ) {

                      				newCompositeNode(grammarAccess.getXAssignmentAccess().getXOrExpressionParserRuleCall_1_0());
                      			
                    }
                    pushFollow(FOLLOW_70);
                    this_XOrExpression_4=ruleXOrExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = this_XOrExpression_4;
                      				afterParserOrEnumRuleCall();
                      			
                    }
                    // InternalTableDSL.g:5140:4: ( ( ( ( () ( ( ruleOpMultiAssign ) ) ) )=> ( () ( ( ruleOpMultiAssign ) ) ) ) ( (lv_rightOperand_7_0= ruleXAssignment ) ) )?
                    int alt60=2;
                    alt60 = dfa60.predict(input);
                    switch (alt60) {
                        case 1 :
                            // InternalTableDSL.g:5141:5: ( ( ( () ( ( ruleOpMultiAssign ) ) ) )=> ( () ( ( ruleOpMultiAssign ) ) ) ) ( (lv_rightOperand_7_0= ruleXAssignment ) )
                            {
                            // InternalTableDSL.g:5141:5: ( ( ( () ( ( ruleOpMultiAssign ) ) ) )=> ( () ( ( ruleOpMultiAssign ) ) ) )
                            // InternalTableDSL.g:5142:6: ( ( () ( ( ruleOpMultiAssign ) ) ) )=> ( () ( ( ruleOpMultiAssign ) ) )
                            {
                            // InternalTableDSL.g:5152:6: ( () ( ( ruleOpMultiAssign ) ) )
                            // InternalTableDSL.g:5153:7: () ( ( ruleOpMultiAssign ) )
                            {
                            // InternalTableDSL.g:5153:7: ()
                            // InternalTableDSL.g:5154:8: 
                            {
                            if ( state.backtracking==0 ) {

                              								current = forceCreateModelElementAndSet(
                              									grammarAccess.getXAssignmentAccess().getXBinaryOperationLeftOperandAction_1_1_0_0_0(),
                              									current);
                              							
                            }

                            }

                            // InternalTableDSL.g:5160:7: ( ( ruleOpMultiAssign ) )
                            // InternalTableDSL.g:5161:8: ( ruleOpMultiAssign )
                            {
                            // InternalTableDSL.g:5161:8: ( ruleOpMultiAssign )
                            // InternalTableDSL.g:5162:9: ruleOpMultiAssign
                            {
                            if ( state.backtracking==0 ) {

                              									if (current==null) {
                              										current = createModelElement(grammarAccess.getXAssignmentRule());
                              									}
                              								
                            }
                            if ( state.backtracking==0 ) {

                              									newCompositeNode(grammarAccess.getXAssignmentAccess().getFeatureJvmIdentifiableElementCrossReference_1_1_0_0_1_0());
                              								
                            }
                            pushFollow(FOLLOW_65);
                            ruleOpMultiAssign();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              									afterParserOrEnumRuleCall();
                              								
                            }

                            }


                            }


                            }


                            }

                            // InternalTableDSL.g:5178:5: ( (lv_rightOperand_7_0= ruleXAssignment ) )
                            // InternalTableDSL.g:5179:6: (lv_rightOperand_7_0= ruleXAssignment )
                            {
                            // InternalTableDSL.g:5179:6: (lv_rightOperand_7_0= ruleXAssignment )
                            // InternalTableDSL.g:5180:7: lv_rightOperand_7_0= ruleXAssignment
                            {
                            if ( state.backtracking==0 ) {

                              							newCompositeNode(grammarAccess.getXAssignmentAccess().getRightOperandXAssignmentParserRuleCall_1_1_1_0());
                              						
                            }
                            pushFollow(FOLLOW_2);
                            lv_rightOperand_7_0=ruleXAssignment();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              							if (current==null) {
                              								current = createModelElementForParent(grammarAccess.getXAssignmentRule());
                              							}
                              							set(
                              								current,
                              								"rightOperand",
                              								lv_rightOperand_7_0,
                              								"org.eclipse.xtext.xbase.Xbase.XAssignment");
                              							afterParserOrEnumRuleCall();
                              						
                            }

                            }


                            }


                            }
                            break;

                    }


                    }


                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXAssignment"


    // $ANTLR start "entryRuleOpSingleAssign"
    // InternalTableDSL.g:5203:1: entryRuleOpSingleAssign returns [String current=null] : iv_ruleOpSingleAssign= ruleOpSingleAssign EOF ;
    public final String entryRuleOpSingleAssign() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleOpSingleAssign = null;


        try {
            // InternalTableDSL.g:5203:54: (iv_ruleOpSingleAssign= ruleOpSingleAssign EOF )
            // InternalTableDSL.g:5204:2: iv_ruleOpSingleAssign= ruleOpSingleAssign EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getOpSingleAssignRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleOpSingleAssign=ruleOpSingleAssign();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleOpSingleAssign.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleOpSingleAssign"


    // $ANTLR start "ruleOpSingleAssign"
    // InternalTableDSL.g:5210:1: ruleOpSingleAssign returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : kw= '=' ;
    public final AntlrDatatypeRuleToken ruleOpSingleAssign() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;


        	enterRule();

        try {
            // InternalTableDSL.g:5216:2: (kw= '=' )
            // InternalTableDSL.g:5217:2: kw= '='
            {
            kw=(Token)match(input,103,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              		current.merge(kw);
              		newLeafNode(kw, grammarAccess.getOpSingleAssignAccess().getEqualsSignKeyword());
              	
            }

            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleOpSingleAssign"


    // $ANTLR start "entryRuleOpMultiAssign"
    // InternalTableDSL.g:5225:1: entryRuleOpMultiAssign returns [String current=null] : iv_ruleOpMultiAssign= ruleOpMultiAssign EOF ;
    public final String entryRuleOpMultiAssign() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleOpMultiAssign = null;


        try {
            // InternalTableDSL.g:5225:53: (iv_ruleOpMultiAssign= ruleOpMultiAssign EOF )
            // InternalTableDSL.g:5226:2: iv_ruleOpMultiAssign= ruleOpMultiAssign EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getOpMultiAssignRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleOpMultiAssign=ruleOpMultiAssign();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleOpMultiAssign.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleOpMultiAssign"


    // $ANTLR start "ruleOpMultiAssign"
    // InternalTableDSL.g:5232:1: ruleOpMultiAssign returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (kw= '+=' | kw= '-=' | kw= '*=' | kw= '/=' | kw= '%=' | (kw= '<' kw= '<' kw= '=' ) | (kw= '>' (kw= '>' )? kw= '>=' ) ) ;
    public final AntlrDatatypeRuleToken ruleOpMultiAssign() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;


        	enterRule();

        try {
            // InternalTableDSL.g:5238:2: ( (kw= '+=' | kw= '-=' | kw= '*=' | kw= '/=' | kw= '%=' | (kw= '<' kw= '<' kw= '=' ) | (kw= '>' (kw= '>' )? kw= '>=' ) ) )
            // InternalTableDSL.g:5239:2: (kw= '+=' | kw= '-=' | kw= '*=' | kw= '/=' | kw= '%=' | (kw= '<' kw= '<' kw= '=' ) | (kw= '>' (kw= '>' )? kw= '>=' ) )
            {
            // InternalTableDSL.g:5239:2: (kw= '+=' | kw= '-=' | kw= '*=' | kw= '/=' | kw= '%=' | (kw= '<' kw= '<' kw= '=' ) | (kw= '>' (kw= '>' )? kw= '>=' ) )
            int alt63=7;
            switch ( input.LA(1) ) {
            case 107:
                {
                alt63=1;
                }
                break;
            case 108:
                {
                alt63=2;
                }
                break;
            case 109:
                {
                alt63=3;
                }
                break;
            case 110:
                {
                alt63=4;
                }
                break;
            case 111:
                {
                alt63=5;
                }
                break;
            case 112:
                {
                alt63=6;
                }
                break;
            case 113:
                {
                alt63=7;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 63, 0, input);

                throw nvae;
            }

            switch (alt63) {
                case 1 :
                    // InternalTableDSL.g:5240:3: kw= '+='
                    {
                    kw=(Token)match(input,107,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpMultiAssignAccess().getPlusSignEqualsSignKeyword_0());
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:5246:3: kw= '-='
                    {
                    kw=(Token)match(input,108,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpMultiAssignAccess().getHyphenMinusEqualsSignKeyword_1());
                      		
                    }

                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:5252:3: kw= '*='
                    {
                    kw=(Token)match(input,109,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpMultiAssignAccess().getAsteriskEqualsSignKeyword_2());
                      		
                    }

                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:5258:3: kw= '/='
                    {
                    kw=(Token)match(input,110,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpMultiAssignAccess().getSolidusEqualsSignKeyword_3());
                      		
                    }

                    }
                    break;
                case 5 :
                    // InternalTableDSL.g:5264:3: kw= '%='
                    {
                    kw=(Token)match(input,111,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpMultiAssignAccess().getPercentSignEqualsSignKeyword_4());
                      		
                    }

                    }
                    break;
                case 6 :
                    // InternalTableDSL.g:5270:3: (kw= '<' kw= '<' kw= '=' )
                    {
                    // InternalTableDSL.g:5270:3: (kw= '<' kw= '<' kw= '=' )
                    // InternalTableDSL.g:5271:4: kw= '<' kw= '<' kw= '='
                    {
                    kw=(Token)match(input,112,FOLLOW_71); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getOpMultiAssignAccess().getLessThanSignKeyword_5_0());
                      			
                    }
                    kw=(Token)match(input,112,FOLLOW_64); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getOpMultiAssignAccess().getLessThanSignKeyword_5_1());
                      			
                    }
                    kw=(Token)match(input,103,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getOpMultiAssignAccess().getEqualsSignKeyword_5_2());
                      			
                    }

                    }


                    }
                    break;
                case 7 :
                    // InternalTableDSL.g:5288:3: (kw= '>' (kw= '>' )? kw= '>=' )
                    {
                    // InternalTableDSL.g:5288:3: (kw= '>' (kw= '>' )? kw= '>=' )
                    // InternalTableDSL.g:5289:4: kw= '>' (kw= '>' )? kw= '>='
                    {
                    kw=(Token)match(input,113,FOLLOW_72); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getOpMultiAssignAccess().getGreaterThanSignKeyword_6_0());
                      			
                    }
                    // InternalTableDSL.g:5294:4: (kw= '>' )?
                    int alt62=2;
                    int LA62_0 = input.LA(1);

                    if ( (LA62_0==113) ) {
                        alt62=1;
                    }
                    switch (alt62) {
                        case 1 :
                            // InternalTableDSL.g:5295:5: kw= '>'
                            {
                            kw=(Token)match(input,113,FOLLOW_73); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              					current.merge(kw);
                              					newLeafNode(kw, grammarAccess.getOpMultiAssignAccess().getGreaterThanSignKeyword_6_1());
                              				
                            }

                            }
                            break;

                    }

                    kw=(Token)match(input,114,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getOpMultiAssignAccess().getGreaterThanSignEqualsSignKeyword_6_2());
                      			
                    }

                    }


                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleOpMultiAssign"


    // $ANTLR start "entryRuleXOrExpression"
    // InternalTableDSL.g:5311:1: entryRuleXOrExpression returns [EObject current=null] : iv_ruleXOrExpression= ruleXOrExpression EOF ;
    public final EObject entryRuleXOrExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXOrExpression = null;


        try {
            // InternalTableDSL.g:5311:54: (iv_ruleXOrExpression= ruleXOrExpression EOF )
            // InternalTableDSL.g:5312:2: iv_ruleXOrExpression= ruleXOrExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXOrExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXOrExpression=ruleXOrExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXOrExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXOrExpression"


    // $ANTLR start "ruleXOrExpression"
    // InternalTableDSL.g:5318:1: ruleXOrExpression returns [EObject current=null] : (this_XAndExpression_0= ruleXAndExpression ( ( ( ( () ( ( ruleOpOr ) ) ) )=> ( () ( ( ruleOpOr ) ) ) ) ( (lv_rightOperand_3_0= ruleXAndExpression ) ) )* ) ;
    public final EObject ruleXOrExpression() throws RecognitionException {
        EObject current = null;

        EObject this_XAndExpression_0 = null;

        EObject lv_rightOperand_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:5324:2: ( (this_XAndExpression_0= ruleXAndExpression ( ( ( ( () ( ( ruleOpOr ) ) ) )=> ( () ( ( ruleOpOr ) ) ) ) ( (lv_rightOperand_3_0= ruleXAndExpression ) ) )* ) )
            // InternalTableDSL.g:5325:2: (this_XAndExpression_0= ruleXAndExpression ( ( ( ( () ( ( ruleOpOr ) ) ) )=> ( () ( ( ruleOpOr ) ) ) ) ( (lv_rightOperand_3_0= ruleXAndExpression ) ) )* )
            {
            // InternalTableDSL.g:5325:2: (this_XAndExpression_0= ruleXAndExpression ( ( ( ( () ( ( ruleOpOr ) ) ) )=> ( () ( ( ruleOpOr ) ) ) ) ( (lv_rightOperand_3_0= ruleXAndExpression ) ) )* )
            // InternalTableDSL.g:5326:3: this_XAndExpression_0= ruleXAndExpression ( ( ( ( () ( ( ruleOpOr ) ) ) )=> ( () ( ( ruleOpOr ) ) ) ) ( (lv_rightOperand_3_0= ruleXAndExpression ) ) )*
            {
            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getXOrExpressionAccess().getXAndExpressionParserRuleCall_0());
              		
            }
            pushFollow(FOLLOW_74);
            this_XAndExpression_0=ruleXAndExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current = this_XAndExpression_0;
              			afterParserOrEnumRuleCall();
              		
            }
            // InternalTableDSL.g:5334:3: ( ( ( ( () ( ( ruleOpOr ) ) ) )=> ( () ( ( ruleOpOr ) ) ) ) ( (lv_rightOperand_3_0= ruleXAndExpression ) ) )*
            loop64:
            do {
                int alt64=2;
                int LA64_0 = input.LA(1);

                if ( (LA64_0==115) ) {
                    int LA64_2 = input.LA(2);

                    if ( (synpred8_InternalTableDSL()) ) {
                        alt64=1;
                    }


                }


                switch (alt64) {
            	case 1 :
            	    // InternalTableDSL.g:5335:4: ( ( ( () ( ( ruleOpOr ) ) ) )=> ( () ( ( ruleOpOr ) ) ) ) ( (lv_rightOperand_3_0= ruleXAndExpression ) )
            	    {
            	    // InternalTableDSL.g:5335:4: ( ( ( () ( ( ruleOpOr ) ) ) )=> ( () ( ( ruleOpOr ) ) ) )
            	    // InternalTableDSL.g:5336:5: ( ( () ( ( ruleOpOr ) ) ) )=> ( () ( ( ruleOpOr ) ) )
            	    {
            	    // InternalTableDSL.g:5346:5: ( () ( ( ruleOpOr ) ) )
            	    // InternalTableDSL.g:5347:6: () ( ( ruleOpOr ) )
            	    {
            	    // InternalTableDSL.g:5347:6: ()
            	    // InternalTableDSL.g:5348:7: 
            	    {
            	    if ( state.backtracking==0 ) {

            	      							current = forceCreateModelElementAndSet(
            	      								grammarAccess.getXOrExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0(),
            	      								current);
            	      						
            	    }

            	    }

            	    // InternalTableDSL.g:5354:6: ( ( ruleOpOr ) )
            	    // InternalTableDSL.g:5355:7: ( ruleOpOr )
            	    {
            	    // InternalTableDSL.g:5355:7: ( ruleOpOr )
            	    // InternalTableDSL.g:5356:8: ruleOpOr
            	    {
            	    if ( state.backtracking==0 ) {

            	      								if (current==null) {
            	      									current = createModelElement(grammarAccess.getXOrExpressionRule());
            	      								}
            	      							
            	    }
            	    if ( state.backtracking==0 ) {

            	      								newCompositeNode(grammarAccess.getXOrExpressionAccess().getFeatureJvmIdentifiableElementCrossReference_1_0_0_1_0());
            	      							
            	    }
            	    pushFollow(FOLLOW_65);
            	    ruleOpOr();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      								afterParserOrEnumRuleCall();
            	      							
            	    }

            	    }


            	    }


            	    }


            	    }

            	    // InternalTableDSL.g:5372:4: ( (lv_rightOperand_3_0= ruleXAndExpression ) )
            	    // InternalTableDSL.g:5373:5: (lv_rightOperand_3_0= ruleXAndExpression )
            	    {
            	    // InternalTableDSL.g:5373:5: (lv_rightOperand_3_0= ruleXAndExpression )
            	    // InternalTableDSL.g:5374:6: lv_rightOperand_3_0= ruleXAndExpression
            	    {
            	    if ( state.backtracking==0 ) {

            	      						newCompositeNode(grammarAccess.getXOrExpressionAccess().getRightOperandXAndExpressionParserRuleCall_1_1_0());
            	      					
            	    }
            	    pushFollow(FOLLOW_74);
            	    lv_rightOperand_3_0=ruleXAndExpression();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      						if (current==null) {
            	      							current = createModelElementForParent(grammarAccess.getXOrExpressionRule());
            	      						}
            	      						set(
            	      							current,
            	      							"rightOperand",
            	      							lv_rightOperand_3_0,
            	      							"org.eclipse.xtext.xbase.Xbase.XAndExpression");
            	      						afterParserOrEnumRuleCall();
            	      					
            	    }

            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop64;
                }
            } while (true);


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXOrExpression"


    // $ANTLR start "entryRuleOpOr"
    // InternalTableDSL.g:5396:1: entryRuleOpOr returns [String current=null] : iv_ruleOpOr= ruleOpOr EOF ;
    public final String entryRuleOpOr() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleOpOr = null;


        try {
            // InternalTableDSL.g:5396:44: (iv_ruleOpOr= ruleOpOr EOF )
            // InternalTableDSL.g:5397:2: iv_ruleOpOr= ruleOpOr EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getOpOrRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleOpOr=ruleOpOr();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleOpOr.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleOpOr"


    // $ANTLR start "ruleOpOr"
    // InternalTableDSL.g:5403:1: ruleOpOr returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : kw= '||' ;
    public final AntlrDatatypeRuleToken ruleOpOr() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;


        	enterRule();

        try {
            // InternalTableDSL.g:5409:2: (kw= '||' )
            // InternalTableDSL.g:5410:2: kw= '||'
            {
            kw=(Token)match(input,115,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              		current.merge(kw);
              		newLeafNode(kw, grammarAccess.getOpOrAccess().getVerticalLineVerticalLineKeyword());
              	
            }

            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleOpOr"


    // $ANTLR start "entryRuleXAndExpression"
    // InternalTableDSL.g:5418:1: entryRuleXAndExpression returns [EObject current=null] : iv_ruleXAndExpression= ruleXAndExpression EOF ;
    public final EObject entryRuleXAndExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXAndExpression = null;


        try {
            // InternalTableDSL.g:5418:55: (iv_ruleXAndExpression= ruleXAndExpression EOF )
            // InternalTableDSL.g:5419:2: iv_ruleXAndExpression= ruleXAndExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXAndExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXAndExpression=ruleXAndExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXAndExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXAndExpression"


    // $ANTLR start "ruleXAndExpression"
    // InternalTableDSL.g:5425:1: ruleXAndExpression returns [EObject current=null] : (this_XEqualityExpression_0= ruleXEqualityExpression ( ( ( ( () ( ( ruleOpAnd ) ) ) )=> ( () ( ( ruleOpAnd ) ) ) ) ( (lv_rightOperand_3_0= ruleXEqualityExpression ) ) )* ) ;
    public final EObject ruleXAndExpression() throws RecognitionException {
        EObject current = null;

        EObject this_XEqualityExpression_0 = null;

        EObject lv_rightOperand_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:5431:2: ( (this_XEqualityExpression_0= ruleXEqualityExpression ( ( ( ( () ( ( ruleOpAnd ) ) ) )=> ( () ( ( ruleOpAnd ) ) ) ) ( (lv_rightOperand_3_0= ruleXEqualityExpression ) ) )* ) )
            // InternalTableDSL.g:5432:2: (this_XEqualityExpression_0= ruleXEqualityExpression ( ( ( ( () ( ( ruleOpAnd ) ) ) )=> ( () ( ( ruleOpAnd ) ) ) ) ( (lv_rightOperand_3_0= ruleXEqualityExpression ) ) )* )
            {
            // InternalTableDSL.g:5432:2: (this_XEqualityExpression_0= ruleXEqualityExpression ( ( ( ( () ( ( ruleOpAnd ) ) ) )=> ( () ( ( ruleOpAnd ) ) ) ) ( (lv_rightOperand_3_0= ruleXEqualityExpression ) ) )* )
            // InternalTableDSL.g:5433:3: this_XEqualityExpression_0= ruleXEqualityExpression ( ( ( ( () ( ( ruleOpAnd ) ) ) )=> ( () ( ( ruleOpAnd ) ) ) ) ( (lv_rightOperand_3_0= ruleXEqualityExpression ) ) )*
            {
            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getXAndExpressionAccess().getXEqualityExpressionParserRuleCall_0());
              		
            }
            pushFollow(FOLLOW_75);
            this_XEqualityExpression_0=ruleXEqualityExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current = this_XEqualityExpression_0;
              			afterParserOrEnumRuleCall();
              		
            }
            // InternalTableDSL.g:5441:3: ( ( ( ( () ( ( ruleOpAnd ) ) ) )=> ( () ( ( ruleOpAnd ) ) ) ) ( (lv_rightOperand_3_0= ruleXEqualityExpression ) ) )*
            loop65:
            do {
                int alt65=2;
                int LA65_0 = input.LA(1);

                if ( (LA65_0==116) ) {
                    int LA65_2 = input.LA(2);

                    if ( (synpred9_InternalTableDSL()) ) {
                        alt65=1;
                    }


                }


                switch (alt65) {
            	case 1 :
            	    // InternalTableDSL.g:5442:4: ( ( ( () ( ( ruleOpAnd ) ) ) )=> ( () ( ( ruleOpAnd ) ) ) ) ( (lv_rightOperand_3_0= ruleXEqualityExpression ) )
            	    {
            	    // InternalTableDSL.g:5442:4: ( ( ( () ( ( ruleOpAnd ) ) ) )=> ( () ( ( ruleOpAnd ) ) ) )
            	    // InternalTableDSL.g:5443:5: ( ( () ( ( ruleOpAnd ) ) ) )=> ( () ( ( ruleOpAnd ) ) )
            	    {
            	    // InternalTableDSL.g:5453:5: ( () ( ( ruleOpAnd ) ) )
            	    // InternalTableDSL.g:5454:6: () ( ( ruleOpAnd ) )
            	    {
            	    // InternalTableDSL.g:5454:6: ()
            	    // InternalTableDSL.g:5455:7: 
            	    {
            	    if ( state.backtracking==0 ) {

            	      							current = forceCreateModelElementAndSet(
            	      								grammarAccess.getXAndExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0(),
            	      								current);
            	      						
            	    }

            	    }

            	    // InternalTableDSL.g:5461:6: ( ( ruleOpAnd ) )
            	    // InternalTableDSL.g:5462:7: ( ruleOpAnd )
            	    {
            	    // InternalTableDSL.g:5462:7: ( ruleOpAnd )
            	    // InternalTableDSL.g:5463:8: ruleOpAnd
            	    {
            	    if ( state.backtracking==0 ) {

            	      								if (current==null) {
            	      									current = createModelElement(grammarAccess.getXAndExpressionRule());
            	      								}
            	      							
            	    }
            	    if ( state.backtracking==0 ) {

            	      								newCompositeNode(grammarAccess.getXAndExpressionAccess().getFeatureJvmIdentifiableElementCrossReference_1_0_0_1_0());
            	      							
            	    }
            	    pushFollow(FOLLOW_65);
            	    ruleOpAnd();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      								afterParserOrEnumRuleCall();
            	      							
            	    }

            	    }


            	    }


            	    }


            	    }

            	    // InternalTableDSL.g:5479:4: ( (lv_rightOperand_3_0= ruleXEqualityExpression ) )
            	    // InternalTableDSL.g:5480:5: (lv_rightOperand_3_0= ruleXEqualityExpression )
            	    {
            	    // InternalTableDSL.g:5480:5: (lv_rightOperand_3_0= ruleXEqualityExpression )
            	    // InternalTableDSL.g:5481:6: lv_rightOperand_3_0= ruleXEqualityExpression
            	    {
            	    if ( state.backtracking==0 ) {

            	      						newCompositeNode(grammarAccess.getXAndExpressionAccess().getRightOperandXEqualityExpressionParserRuleCall_1_1_0());
            	      					
            	    }
            	    pushFollow(FOLLOW_75);
            	    lv_rightOperand_3_0=ruleXEqualityExpression();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      						if (current==null) {
            	      							current = createModelElementForParent(grammarAccess.getXAndExpressionRule());
            	      						}
            	      						set(
            	      							current,
            	      							"rightOperand",
            	      							lv_rightOperand_3_0,
            	      							"org.eclipse.xtext.xbase.Xbase.XEqualityExpression");
            	      						afterParserOrEnumRuleCall();
            	      					
            	    }

            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop65;
                }
            } while (true);


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXAndExpression"


    // $ANTLR start "entryRuleOpAnd"
    // InternalTableDSL.g:5503:1: entryRuleOpAnd returns [String current=null] : iv_ruleOpAnd= ruleOpAnd EOF ;
    public final String entryRuleOpAnd() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleOpAnd = null;


        try {
            // InternalTableDSL.g:5503:45: (iv_ruleOpAnd= ruleOpAnd EOF )
            // InternalTableDSL.g:5504:2: iv_ruleOpAnd= ruleOpAnd EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getOpAndRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleOpAnd=ruleOpAnd();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleOpAnd.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleOpAnd"


    // $ANTLR start "ruleOpAnd"
    // InternalTableDSL.g:5510:1: ruleOpAnd returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : kw= '&&' ;
    public final AntlrDatatypeRuleToken ruleOpAnd() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;


        	enterRule();

        try {
            // InternalTableDSL.g:5516:2: (kw= '&&' )
            // InternalTableDSL.g:5517:2: kw= '&&'
            {
            kw=(Token)match(input,116,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              		current.merge(kw);
              		newLeafNode(kw, grammarAccess.getOpAndAccess().getAmpersandAmpersandKeyword());
              	
            }

            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleOpAnd"


    // $ANTLR start "entryRuleXEqualityExpression"
    // InternalTableDSL.g:5525:1: entryRuleXEqualityExpression returns [EObject current=null] : iv_ruleXEqualityExpression= ruleXEqualityExpression EOF ;
    public final EObject entryRuleXEqualityExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXEqualityExpression = null;


        try {
            // InternalTableDSL.g:5525:60: (iv_ruleXEqualityExpression= ruleXEqualityExpression EOF )
            // InternalTableDSL.g:5526:2: iv_ruleXEqualityExpression= ruleXEqualityExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXEqualityExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXEqualityExpression=ruleXEqualityExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXEqualityExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXEqualityExpression"


    // $ANTLR start "ruleXEqualityExpression"
    // InternalTableDSL.g:5532:1: ruleXEqualityExpression returns [EObject current=null] : (this_XRelationalExpression_0= ruleXRelationalExpression ( ( ( ( () ( ( ruleOpEquality ) ) ) )=> ( () ( ( ruleOpEquality ) ) ) ) ( (lv_rightOperand_3_0= ruleXRelationalExpression ) ) )* ) ;
    public final EObject ruleXEqualityExpression() throws RecognitionException {
        EObject current = null;

        EObject this_XRelationalExpression_0 = null;

        EObject lv_rightOperand_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:5538:2: ( (this_XRelationalExpression_0= ruleXRelationalExpression ( ( ( ( () ( ( ruleOpEquality ) ) ) )=> ( () ( ( ruleOpEquality ) ) ) ) ( (lv_rightOperand_3_0= ruleXRelationalExpression ) ) )* ) )
            // InternalTableDSL.g:5539:2: (this_XRelationalExpression_0= ruleXRelationalExpression ( ( ( ( () ( ( ruleOpEquality ) ) ) )=> ( () ( ( ruleOpEquality ) ) ) ) ( (lv_rightOperand_3_0= ruleXRelationalExpression ) ) )* )
            {
            // InternalTableDSL.g:5539:2: (this_XRelationalExpression_0= ruleXRelationalExpression ( ( ( ( () ( ( ruleOpEquality ) ) ) )=> ( () ( ( ruleOpEquality ) ) ) ) ( (lv_rightOperand_3_0= ruleXRelationalExpression ) ) )* )
            // InternalTableDSL.g:5540:3: this_XRelationalExpression_0= ruleXRelationalExpression ( ( ( ( () ( ( ruleOpEquality ) ) ) )=> ( () ( ( ruleOpEquality ) ) ) ) ( (lv_rightOperand_3_0= ruleXRelationalExpression ) ) )*
            {
            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getXEqualityExpressionAccess().getXRelationalExpressionParserRuleCall_0());
              		
            }
            pushFollow(FOLLOW_76);
            this_XRelationalExpression_0=ruleXRelationalExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current = this_XRelationalExpression_0;
              			afterParserOrEnumRuleCall();
              		
            }
            // InternalTableDSL.g:5548:3: ( ( ( ( () ( ( ruleOpEquality ) ) ) )=> ( () ( ( ruleOpEquality ) ) ) ) ( (lv_rightOperand_3_0= ruleXRelationalExpression ) ) )*
            loop66:
            do {
                int alt66=2;
                switch ( input.LA(1) ) {
                case 117:
                    {
                    int LA66_2 = input.LA(2);

                    if ( (synpred10_InternalTableDSL()) ) {
                        alt66=1;
                    }


                    }
                    break;
                case 118:
                    {
                    int LA66_3 = input.LA(2);

                    if ( (synpred10_InternalTableDSL()) ) {
                        alt66=1;
                    }


                    }
                    break;
                case 119:
                    {
                    int LA66_4 = input.LA(2);

                    if ( (synpred10_InternalTableDSL()) ) {
                        alt66=1;
                    }


                    }
                    break;
                case 120:
                    {
                    int LA66_5 = input.LA(2);

                    if ( (synpred10_InternalTableDSL()) ) {
                        alt66=1;
                    }


                    }
                    break;

                }

                switch (alt66) {
            	case 1 :
            	    // InternalTableDSL.g:5549:4: ( ( ( () ( ( ruleOpEquality ) ) ) )=> ( () ( ( ruleOpEquality ) ) ) ) ( (lv_rightOperand_3_0= ruleXRelationalExpression ) )
            	    {
            	    // InternalTableDSL.g:5549:4: ( ( ( () ( ( ruleOpEquality ) ) ) )=> ( () ( ( ruleOpEquality ) ) ) )
            	    // InternalTableDSL.g:5550:5: ( ( () ( ( ruleOpEquality ) ) ) )=> ( () ( ( ruleOpEquality ) ) )
            	    {
            	    // InternalTableDSL.g:5560:5: ( () ( ( ruleOpEquality ) ) )
            	    // InternalTableDSL.g:5561:6: () ( ( ruleOpEquality ) )
            	    {
            	    // InternalTableDSL.g:5561:6: ()
            	    // InternalTableDSL.g:5562:7: 
            	    {
            	    if ( state.backtracking==0 ) {

            	      							current = forceCreateModelElementAndSet(
            	      								grammarAccess.getXEqualityExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0(),
            	      								current);
            	      						
            	    }

            	    }

            	    // InternalTableDSL.g:5568:6: ( ( ruleOpEquality ) )
            	    // InternalTableDSL.g:5569:7: ( ruleOpEquality )
            	    {
            	    // InternalTableDSL.g:5569:7: ( ruleOpEquality )
            	    // InternalTableDSL.g:5570:8: ruleOpEquality
            	    {
            	    if ( state.backtracking==0 ) {

            	      								if (current==null) {
            	      									current = createModelElement(grammarAccess.getXEqualityExpressionRule());
            	      								}
            	      							
            	    }
            	    if ( state.backtracking==0 ) {

            	      								newCompositeNode(grammarAccess.getXEqualityExpressionAccess().getFeatureJvmIdentifiableElementCrossReference_1_0_0_1_0());
            	      							
            	    }
            	    pushFollow(FOLLOW_65);
            	    ruleOpEquality();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      								afterParserOrEnumRuleCall();
            	      							
            	    }

            	    }


            	    }


            	    }


            	    }

            	    // InternalTableDSL.g:5586:4: ( (lv_rightOperand_3_0= ruleXRelationalExpression ) )
            	    // InternalTableDSL.g:5587:5: (lv_rightOperand_3_0= ruleXRelationalExpression )
            	    {
            	    // InternalTableDSL.g:5587:5: (lv_rightOperand_3_0= ruleXRelationalExpression )
            	    // InternalTableDSL.g:5588:6: lv_rightOperand_3_0= ruleXRelationalExpression
            	    {
            	    if ( state.backtracking==0 ) {

            	      						newCompositeNode(grammarAccess.getXEqualityExpressionAccess().getRightOperandXRelationalExpressionParserRuleCall_1_1_0());
            	      					
            	    }
            	    pushFollow(FOLLOW_76);
            	    lv_rightOperand_3_0=ruleXRelationalExpression();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      						if (current==null) {
            	      							current = createModelElementForParent(grammarAccess.getXEqualityExpressionRule());
            	      						}
            	      						set(
            	      							current,
            	      							"rightOperand",
            	      							lv_rightOperand_3_0,
            	      							"org.eclipse.xtext.xbase.Xbase.XRelationalExpression");
            	      						afterParserOrEnumRuleCall();
            	      					
            	    }

            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop66;
                }
            } while (true);


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXEqualityExpression"


    // $ANTLR start "entryRuleOpEquality"
    // InternalTableDSL.g:5610:1: entryRuleOpEquality returns [String current=null] : iv_ruleOpEquality= ruleOpEquality EOF ;
    public final String entryRuleOpEquality() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleOpEquality = null;


        try {
            // InternalTableDSL.g:5610:50: (iv_ruleOpEquality= ruleOpEquality EOF )
            // InternalTableDSL.g:5611:2: iv_ruleOpEquality= ruleOpEquality EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getOpEqualityRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleOpEquality=ruleOpEquality();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleOpEquality.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleOpEquality"


    // $ANTLR start "ruleOpEquality"
    // InternalTableDSL.g:5617:1: ruleOpEquality returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (kw= '==' | kw= '!=' | kw= '===' | kw= '!==' ) ;
    public final AntlrDatatypeRuleToken ruleOpEquality() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;


        	enterRule();

        try {
            // InternalTableDSL.g:5623:2: ( (kw= '==' | kw= '!=' | kw= '===' | kw= '!==' ) )
            // InternalTableDSL.g:5624:2: (kw= '==' | kw= '!=' | kw= '===' | kw= '!==' )
            {
            // InternalTableDSL.g:5624:2: (kw= '==' | kw= '!=' | kw= '===' | kw= '!==' )
            int alt67=4;
            switch ( input.LA(1) ) {
            case 117:
                {
                alt67=1;
                }
                break;
            case 118:
                {
                alt67=2;
                }
                break;
            case 119:
                {
                alt67=3;
                }
                break;
            case 120:
                {
                alt67=4;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 67, 0, input);

                throw nvae;
            }

            switch (alt67) {
                case 1 :
                    // InternalTableDSL.g:5625:3: kw= '=='
                    {
                    kw=(Token)match(input,117,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpEqualityAccess().getEqualsSignEqualsSignKeyword_0());
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:5631:3: kw= '!='
                    {
                    kw=(Token)match(input,118,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpEqualityAccess().getExclamationMarkEqualsSignKeyword_1());
                      		
                    }

                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:5637:3: kw= '==='
                    {
                    kw=(Token)match(input,119,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpEqualityAccess().getEqualsSignEqualsSignEqualsSignKeyword_2());
                      		
                    }

                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:5643:3: kw= '!=='
                    {
                    kw=(Token)match(input,120,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpEqualityAccess().getExclamationMarkEqualsSignEqualsSignKeyword_3());
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleOpEquality"


    // $ANTLR start "entryRuleXRelationalExpression"
    // InternalTableDSL.g:5652:1: entryRuleXRelationalExpression returns [EObject current=null] : iv_ruleXRelationalExpression= ruleXRelationalExpression EOF ;
    public final EObject entryRuleXRelationalExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXRelationalExpression = null;


        try {
            // InternalTableDSL.g:5652:62: (iv_ruleXRelationalExpression= ruleXRelationalExpression EOF )
            // InternalTableDSL.g:5653:2: iv_ruleXRelationalExpression= ruleXRelationalExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXRelationalExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXRelationalExpression=ruleXRelationalExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXRelationalExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXRelationalExpression"


    // $ANTLR start "ruleXRelationalExpression"
    // InternalTableDSL.g:5659:1: ruleXRelationalExpression returns [EObject current=null] : (this_XOtherOperatorExpression_0= ruleXOtherOperatorExpression ( ( ( ( ( () 'instanceof' ) )=> ( () otherlv_2= 'instanceof' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) ) ) | ( ( ( ( () ( ( ruleOpCompare ) ) ) )=> ( () ( ( ruleOpCompare ) ) ) ) ( (lv_rightOperand_6_0= ruleXOtherOperatorExpression ) ) ) )* ) ;
    public final EObject ruleXRelationalExpression() throws RecognitionException {
        EObject current = null;

        Token otherlv_2=null;
        EObject this_XOtherOperatorExpression_0 = null;

        EObject lv_type_3_0 = null;

        EObject lv_rightOperand_6_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:5665:2: ( (this_XOtherOperatorExpression_0= ruleXOtherOperatorExpression ( ( ( ( ( () 'instanceof' ) )=> ( () otherlv_2= 'instanceof' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) ) ) | ( ( ( ( () ( ( ruleOpCompare ) ) ) )=> ( () ( ( ruleOpCompare ) ) ) ) ( (lv_rightOperand_6_0= ruleXOtherOperatorExpression ) ) ) )* ) )
            // InternalTableDSL.g:5666:2: (this_XOtherOperatorExpression_0= ruleXOtherOperatorExpression ( ( ( ( ( () 'instanceof' ) )=> ( () otherlv_2= 'instanceof' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) ) ) | ( ( ( ( () ( ( ruleOpCompare ) ) ) )=> ( () ( ( ruleOpCompare ) ) ) ) ( (lv_rightOperand_6_0= ruleXOtherOperatorExpression ) ) ) )* )
            {
            // InternalTableDSL.g:5666:2: (this_XOtherOperatorExpression_0= ruleXOtherOperatorExpression ( ( ( ( ( () 'instanceof' ) )=> ( () otherlv_2= 'instanceof' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) ) ) | ( ( ( ( () ( ( ruleOpCompare ) ) ) )=> ( () ( ( ruleOpCompare ) ) ) ) ( (lv_rightOperand_6_0= ruleXOtherOperatorExpression ) ) ) )* )
            // InternalTableDSL.g:5667:3: this_XOtherOperatorExpression_0= ruleXOtherOperatorExpression ( ( ( ( ( () 'instanceof' ) )=> ( () otherlv_2= 'instanceof' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) ) ) | ( ( ( ( () ( ( ruleOpCompare ) ) ) )=> ( () ( ( ruleOpCompare ) ) ) ) ( (lv_rightOperand_6_0= ruleXOtherOperatorExpression ) ) ) )*
            {
            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getXRelationalExpressionAccess().getXOtherOperatorExpressionParserRuleCall_0());
              		
            }
            pushFollow(FOLLOW_77);
            this_XOtherOperatorExpression_0=ruleXOtherOperatorExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current = this_XOtherOperatorExpression_0;
              			afterParserOrEnumRuleCall();
              		
            }
            // InternalTableDSL.g:5675:3: ( ( ( ( ( () 'instanceof' ) )=> ( () otherlv_2= 'instanceof' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) ) ) | ( ( ( ( () ( ( ruleOpCompare ) ) ) )=> ( () ( ( ruleOpCompare ) ) ) ) ( (lv_rightOperand_6_0= ruleXOtherOperatorExpression ) ) ) )*
            loop68:
            do {
                int alt68=3;
                switch ( input.LA(1) ) {
                case 112:
                    {
                    int LA68_2 = input.LA(2);

                    if ( (synpred12_InternalTableDSL()) ) {
                        alt68=2;
                    }


                    }
                    break;
                case 113:
                    {
                    int LA68_3 = input.LA(2);

                    if ( (synpred12_InternalTableDSL()) ) {
                        alt68=2;
                    }


                    }
                    break;
                case 121:
                    {
                    int LA68_4 = input.LA(2);

                    if ( (synpred11_InternalTableDSL()) ) {
                        alt68=1;
                    }


                    }
                    break;
                case 114:
                    {
                    int LA68_5 = input.LA(2);

                    if ( (synpred12_InternalTableDSL()) ) {
                        alt68=2;
                    }


                    }
                    break;

                }

                switch (alt68) {
            	case 1 :
            	    // InternalTableDSL.g:5676:4: ( ( ( ( () 'instanceof' ) )=> ( () otherlv_2= 'instanceof' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) ) )
            	    {
            	    // InternalTableDSL.g:5676:4: ( ( ( ( () 'instanceof' ) )=> ( () otherlv_2= 'instanceof' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) ) )
            	    // InternalTableDSL.g:5677:5: ( ( ( () 'instanceof' ) )=> ( () otherlv_2= 'instanceof' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) )
            	    {
            	    // InternalTableDSL.g:5677:5: ( ( ( () 'instanceof' ) )=> ( () otherlv_2= 'instanceof' ) )
            	    // InternalTableDSL.g:5678:6: ( ( () 'instanceof' ) )=> ( () otherlv_2= 'instanceof' )
            	    {
            	    // InternalTableDSL.g:5684:6: ( () otherlv_2= 'instanceof' )
            	    // InternalTableDSL.g:5685:7: () otherlv_2= 'instanceof'
            	    {
            	    // InternalTableDSL.g:5685:7: ()
            	    // InternalTableDSL.g:5686:8: 
            	    {
            	    if ( state.backtracking==0 ) {

            	      								current = forceCreateModelElementAndSet(
            	      									grammarAccess.getXRelationalExpressionAccess().getXInstanceOfExpressionExpressionAction_1_0_0_0_0(),
            	      									current);
            	      							
            	    }

            	    }

            	    otherlv_2=(Token)match(input,121,FOLLOW_78); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      							newLeafNode(otherlv_2, grammarAccess.getXRelationalExpressionAccess().getInstanceofKeyword_1_0_0_0_1());
            	      						
            	    }

            	    }


            	    }

            	    // InternalTableDSL.g:5698:5: ( (lv_type_3_0= ruleJvmTypeReference ) )
            	    // InternalTableDSL.g:5699:6: (lv_type_3_0= ruleJvmTypeReference )
            	    {
            	    // InternalTableDSL.g:5699:6: (lv_type_3_0= ruleJvmTypeReference )
            	    // InternalTableDSL.g:5700:7: lv_type_3_0= ruleJvmTypeReference
            	    {
            	    if ( state.backtracking==0 ) {

            	      							newCompositeNode(grammarAccess.getXRelationalExpressionAccess().getTypeJvmTypeReferenceParserRuleCall_1_0_1_0());
            	      						
            	    }
            	    pushFollow(FOLLOW_77);
            	    lv_type_3_0=ruleJvmTypeReference();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      							if (current==null) {
            	      								current = createModelElementForParent(grammarAccess.getXRelationalExpressionRule());
            	      							}
            	      							set(
            	      								current,
            	      								"type",
            	      								lv_type_3_0,
            	      								"org.eclipse.xtext.xbase.Xtype.JvmTypeReference");
            	      							afterParserOrEnumRuleCall();
            	      						
            	    }

            	    }


            	    }


            	    }


            	    }
            	    break;
            	case 2 :
            	    // InternalTableDSL.g:5719:4: ( ( ( ( () ( ( ruleOpCompare ) ) ) )=> ( () ( ( ruleOpCompare ) ) ) ) ( (lv_rightOperand_6_0= ruleXOtherOperatorExpression ) ) )
            	    {
            	    // InternalTableDSL.g:5719:4: ( ( ( ( () ( ( ruleOpCompare ) ) ) )=> ( () ( ( ruleOpCompare ) ) ) ) ( (lv_rightOperand_6_0= ruleXOtherOperatorExpression ) ) )
            	    // InternalTableDSL.g:5720:5: ( ( ( () ( ( ruleOpCompare ) ) ) )=> ( () ( ( ruleOpCompare ) ) ) ) ( (lv_rightOperand_6_0= ruleXOtherOperatorExpression ) )
            	    {
            	    // InternalTableDSL.g:5720:5: ( ( ( () ( ( ruleOpCompare ) ) ) )=> ( () ( ( ruleOpCompare ) ) ) )
            	    // InternalTableDSL.g:5721:6: ( ( () ( ( ruleOpCompare ) ) ) )=> ( () ( ( ruleOpCompare ) ) )
            	    {
            	    // InternalTableDSL.g:5731:6: ( () ( ( ruleOpCompare ) ) )
            	    // InternalTableDSL.g:5732:7: () ( ( ruleOpCompare ) )
            	    {
            	    // InternalTableDSL.g:5732:7: ()
            	    // InternalTableDSL.g:5733:8: 
            	    {
            	    if ( state.backtracking==0 ) {

            	      								current = forceCreateModelElementAndSet(
            	      									grammarAccess.getXRelationalExpressionAccess().getXBinaryOperationLeftOperandAction_1_1_0_0_0(),
            	      									current);
            	      							
            	    }

            	    }

            	    // InternalTableDSL.g:5739:7: ( ( ruleOpCompare ) )
            	    // InternalTableDSL.g:5740:8: ( ruleOpCompare )
            	    {
            	    // InternalTableDSL.g:5740:8: ( ruleOpCompare )
            	    // InternalTableDSL.g:5741:9: ruleOpCompare
            	    {
            	    if ( state.backtracking==0 ) {

            	      									if (current==null) {
            	      										current = createModelElement(grammarAccess.getXRelationalExpressionRule());
            	      									}
            	      								
            	    }
            	    if ( state.backtracking==0 ) {

            	      									newCompositeNode(grammarAccess.getXRelationalExpressionAccess().getFeatureJvmIdentifiableElementCrossReference_1_1_0_0_1_0());
            	      								
            	    }
            	    pushFollow(FOLLOW_65);
            	    ruleOpCompare();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      									afterParserOrEnumRuleCall();
            	      								
            	    }

            	    }


            	    }


            	    }


            	    }

            	    // InternalTableDSL.g:5757:5: ( (lv_rightOperand_6_0= ruleXOtherOperatorExpression ) )
            	    // InternalTableDSL.g:5758:6: (lv_rightOperand_6_0= ruleXOtherOperatorExpression )
            	    {
            	    // InternalTableDSL.g:5758:6: (lv_rightOperand_6_0= ruleXOtherOperatorExpression )
            	    // InternalTableDSL.g:5759:7: lv_rightOperand_6_0= ruleXOtherOperatorExpression
            	    {
            	    if ( state.backtracking==0 ) {

            	      							newCompositeNode(grammarAccess.getXRelationalExpressionAccess().getRightOperandXOtherOperatorExpressionParserRuleCall_1_1_1_0());
            	      						
            	    }
            	    pushFollow(FOLLOW_77);
            	    lv_rightOperand_6_0=ruleXOtherOperatorExpression();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      							if (current==null) {
            	      								current = createModelElementForParent(grammarAccess.getXRelationalExpressionRule());
            	      							}
            	      							set(
            	      								current,
            	      								"rightOperand",
            	      								lv_rightOperand_6_0,
            	      								"org.eclipse.xtext.xbase.Xbase.XOtherOperatorExpression");
            	      							afterParserOrEnumRuleCall();
            	      						
            	    }

            	    }


            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop68;
                }
            } while (true);


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXRelationalExpression"


    // $ANTLR start "entryRuleOpCompare"
    // InternalTableDSL.g:5782:1: entryRuleOpCompare returns [String current=null] : iv_ruleOpCompare= ruleOpCompare EOF ;
    public final String entryRuleOpCompare() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleOpCompare = null;


        try {
            // InternalTableDSL.g:5782:49: (iv_ruleOpCompare= ruleOpCompare EOF )
            // InternalTableDSL.g:5783:2: iv_ruleOpCompare= ruleOpCompare EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getOpCompareRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleOpCompare=ruleOpCompare();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleOpCompare.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleOpCompare"


    // $ANTLR start "ruleOpCompare"
    // InternalTableDSL.g:5789:1: ruleOpCompare returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (kw= '>=' | (kw= '<' kw= '=' ) | kw= '>' | kw= '<' ) ;
    public final AntlrDatatypeRuleToken ruleOpCompare() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;


        	enterRule();

        try {
            // InternalTableDSL.g:5795:2: ( (kw= '>=' | (kw= '<' kw= '=' ) | kw= '>' | kw= '<' ) )
            // InternalTableDSL.g:5796:2: (kw= '>=' | (kw= '<' kw= '=' ) | kw= '>' | kw= '<' )
            {
            // InternalTableDSL.g:5796:2: (kw= '>=' | (kw= '<' kw= '=' ) | kw= '>' | kw= '<' )
            int alt69=4;
            switch ( input.LA(1) ) {
            case 114:
                {
                alt69=1;
                }
                break;
            case 112:
                {
                int LA69_2 = input.LA(2);

                if ( (LA69_2==EOF||(LA69_2>=RULE_ID && LA69_2<=RULE_STRING)||(LA69_2>=RULE_INT && LA69_2<=RULE_DECIMAL)||LA69_2==16||(LA69_2>=91 && LA69_2<=95)||LA69_2==100||(LA69_2>=104 && LA69_2<=105)||LA69_2==112||LA69_2==131||LA69_2==137||LA69_2==139||(LA69_2>=143 && LA69_2<=145)||(LA69_2>=148 && LA69_2<=157)||LA69_2==159) ) {
                    alt69=4;
                }
                else if ( (LA69_2==103) ) {
                    alt69=2;
                }
                else {
                    if (state.backtracking>0) {state.failed=true; return current;}
                    NoViableAltException nvae =
                        new NoViableAltException("", 69, 2, input);

                    throw nvae;
                }
                }
                break;
            case 113:
                {
                alt69=3;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 69, 0, input);

                throw nvae;
            }

            switch (alt69) {
                case 1 :
                    // InternalTableDSL.g:5797:3: kw= '>='
                    {
                    kw=(Token)match(input,114,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpCompareAccess().getGreaterThanSignEqualsSignKeyword_0());
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:5803:3: (kw= '<' kw= '=' )
                    {
                    // InternalTableDSL.g:5803:3: (kw= '<' kw= '=' )
                    // InternalTableDSL.g:5804:4: kw= '<' kw= '='
                    {
                    kw=(Token)match(input,112,FOLLOW_64); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getOpCompareAccess().getLessThanSignKeyword_1_0());
                      			
                    }
                    kw=(Token)match(input,103,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getOpCompareAccess().getEqualsSignKeyword_1_1());
                      			
                    }

                    }


                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:5816:3: kw= '>'
                    {
                    kw=(Token)match(input,113,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpCompareAccess().getGreaterThanSignKeyword_2());
                      		
                    }

                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:5822:3: kw= '<'
                    {
                    kw=(Token)match(input,112,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpCompareAccess().getLessThanSignKeyword_3());
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleOpCompare"


    // $ANTLR start "entryRuleXOtherOperatorExpression"
    // InternalTableDSL.g:5831:1: entryRuleXOtherOperatorExpression returns [EObject current=null] : iv_ruleXOtherOperatorExpression= ruleXOtherOperatorExpression EOF ;
    public final EObject entryRuleXOtherOperatorExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXOtherOperatorExpression = null;


        try {
            // InternalTableDSL.g:5831:65: (iv_ruleXOtherOperatorExpression= ruleXOtherOperatorExpression EOF )
            // InternalTableDSL.g:5832:2: iv_ruleXOtherOperatorExpression= ruleXOtherOperatorExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXOtherOperatorExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXOtherOperatorExpression=ruleXOtherOperatorExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXOtherOperatorExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXOtherOperatorExpression"


    // $ANTLR start "ruleXOtherOperatorExpression"
    // InternalTableDSL.g:5838:1: ruleXOtherOperatorExpression returns [EObject current=null] : (this_XAdditiveExpression_0= ruleXAdditiveExpression ( ( ( ( () ( ( ruleOpOther ) ) ) )=> ( () ( ( ruleOpOther ) ) ) ) ( (lv_rightOperand_3_0= ruleXAdditiveExpression ) ) )* ) ;
    public final EObject ruleXOtherOperatorExpression() throws RecognitionException {
        EObject current = null;

        EObject this_XAdditiveExpression_0 = null;

        EObject lv_rightOperand_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:5844:2: ( (this_XAdditiveExpression_0= ruleXAdditiveExpression ( ( ( ( () ( ( ruleOpOther ) ) ) )=> ( () ( ( ruleOpOther ) ) ) ) ( (lv_rightOperand_3_0= ruleXAdditiveExpression ) ) )* ) )
            // InternalTableDSL.g:5845:2: (this_XAdditiveExpression_0= ruleXAdditiveExpression ( ( ( ( () ( ( ruleOpOther ) ) ) )=> ( () ( ( ruleOpOther ) ) ) ) ( (lv_rightOperand_3_0= ruleXAdditiveExpression ) ) )* )
            {
            // InternalTableDSL.g:5845:2: (this_XAdditiveExpression_0= ruleXAdditiveExpression ( ( ( ( () ( ( ruleOpOther ) ) ) )=> ( () ( ( ruleOpOther ) ) ) ) ( (lv_rightOperand_3_0= ruleXAdditiveExpression ) ) )* )
            // InternalTableDSL.g:5846:3: this_XAdditiveExpression_0= ruleXAdditiveExpression ( ( ( ( () ( ( ruleOpOther ) ) ) )=> ( () ( ( ruleOpOther ) ) ) ) ( (lv_rightOperand_3_0= ruleXAdditiveExpression ) ) )*
            {
            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getXOtherOperatorExpressionAccess().getXAdditiveExpressionParserRuleCall_0());
              		
            }
            pushFollow(FOLLOW_79);
            this_XAdditiveExpression_0=ruleXAdditiveExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current = this_XAdditiveExpression_0;
              			afterParserOrEnumRuleCall();
              		
            }
            // InternalTableDSL.g:5854:3: ( ( ( ( () ( ( ruleOpOther ) ) ) )=> ( () ( ( ruleOpOther ) ) ) ) ( (lv_rightOperand_3_0= ruleXAdditiveExpression ) ) )*
            loop70:
            do {
                int alt70=2;
                alt70 = dfa70.predict(input);
                switch (alt70) {
            	case 1 :
            	    // InternalTableDSL.g:5855:4: ( ( ( () ( ( ruleOpOther ) ) ) )=> ( () ( ( ruleOpOther ) ) ) ) ( (lv_rightOperand_3_0= ruleXAdditiveExpression ) )
            	    {
            	    // InternalTableDSL.g:5855:4: ( ( ( () ( ( ruleOpOther ) ) ) )=> ( () ( ( ruleOpOther ) ) ) )
            	    // InternalTableDSL.g:5856:5: ( ( () ( ( ruleOpOther ) ) ) )=> ( () ( ( ruleOpOther ) ) )
            	    {
            	    // InternalTableDSL.g:5866:5: ( () ( ( ruleOpOther ) ) )
            	    // InternalTableDSL.g:5867:6: () ( ( ruleOpOther ) )
            	    {
            	    // InternalTableDSL.g:5867:6: ()
            	    // InternalTableDSL.g:5868:7: 
            	    {
            	    if ( state.backtracking==0 ) {

            	      							current = forceCreateModelElementAndSet(
            	      								grammarAccess.getXOtherOperatorExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0(),
            	      								current);
            	      						
            	    }

            	    }

            	    // InternalTableDSL.g:5874:6: ( ( ruleOpOther ) )
            	    // InternalTableDSL.g:5875:7: ( ruleOpOther )
            	    {
            	    // InternalTableDSL.g:5875:7: ( ruleOpOther )
            	    // InternalTableDSL.g:5876:8: ruleOpOther
            	    {
            	    if ( state.backtracking==0 ) {

            	      								if (current==null) {
            	      									current = createModelElement(grammarAccess.getXOtherOperatorExpressionRule());
            	      								}
            	      							
            	    }
            	    if ( state.backtracking==0 ) {

            	      								newCompositeNode(grammarAccess.getXOtherOperatorExpressionAccess().getFeatureJvmIdentifiableElementCrossReference_1_0_0_1_0());
            	      							
            	    }
            	    pushFollow(FOLLOW_65);
            	    ruleOpOther();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      								afterParserOrEnumRuleCall();
            	      							
            	    }

            	    }


            	    }


            	    }


            	    }

            	    // InternalTableDSL.g:5892:4: ( (lv_rightOperand_3_0= ruleXAdditiveExpression ) )
            	    // InternalTableDSL.g:5893:5: (lv_rightOperand_3_0= ruleXAdditiveExpression )
            	    {
            	    // InternalTableDSL.g:5893:5: (lv_rightOperand_3_0= ruleXAdditiveExpression )
            	    // InternalTableDSL.g:5894:6: lv_rightOperand_3_0= ruleXAdditiveExpression
            	    {
            	    if ( state.backtracking==0 ) {

            	      						newCompositeNode(grammarAccess.getXOtherOperatorExpressionAccess().getRightOperandXAdditiveExpressionParserRuleCall_1_1_0());
            	      					
            	    }
            	    pushFollow(FOLLOW_79);
            	    lv_rightOperand_3_0=ruleXAdditiveExpression();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      						if (current==null) {
            	      							current = createModelElementForParent(grammarAccess.getXOtherOperatorExpressionRule());
            	      						}
            	      						set(
            	      							current,
            	      							"rightOperand",
            	      							lv_rightOperand_3_0,
            	      							"org.eclipse.xtext.xbase.Xbase.XAdditiveExpression");
            	      						afterParserOrEnumRuleCall();
            	      					
            	    }

            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop70;
                }
            } while (true);


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXOtherOperatorExpression"


    // $ANTLR start "entryRuleOpOther"
    // InternalTableDSL.g:5916:1: entryRuleOpOther returns [String current=null] : iv_ruleOpOther= ruleOpOther EOF ;
    public final String entryRuleOpOther() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleOpOther = null;


        try {
            // InternalTableDSL.g:5916:47: (iv_ruleOpOther= ruleOpOther EOF )
            // InternalTableDSL.g:5917:2: iv_ruleOpOther= ruleOpOther EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getOpOtherRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleOpOther=ruleOpOther();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleOpOther.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleOpOther"


    // $ANTLR start "ruleOpOther"
    // InternalTableDSL.g:5923:1: ruleOpOther returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (kw= '->' | kw= '..<' | (kw= '>' kw= '..' ) | kw= '..' | kw= '=>' | (kw= '>' ( ( ( ( '>' '>' ) )=> (kw= '>' kw= '>' ) ) | kw= '>' ) ) | (kw= '<' ( ( ( ( '<' '<' ) )=> (kw= '<' kw= '<' ) ) | kw= '<' | kw= '=>' ) ) | kw= '<>' | kw= '?:' ) ;
    public final AntlrDatatypeRuleToken ruleOpOther() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;


        	enterRule();

        try {
            // InternalTableDSL.g:5929:2: ( (kw= '->' | kw= '..<' | (kw= '>' kw= '..' ) | kw= '..' | kw= '=>' | (kw= '>' ( ( ( ( '>' '>' ) )=> (kw= '>' kw= '>' ) ) | kw= '>' ) ) | (kw= '<' ( ( ( ( '<' '<' ) )=> (kw= '<' kw= '<' ) ) | kw= '<' | kw= '=>' ) ) | kw= '<>' | kw= '?:' ) )
            // InternalTableDSL.g:5930:2: (kw= '->' | kw= '..<' | (kw= '>' kw= '..' ) | kw= '..' | kw= '=>' | (kw= '>' ( ( ( ( '>' '>' ) )=> (kw= '>' kw= '>' ) ) | kw= '>' ) ) | (kw= '<' ( ( ( ( '<' '<' ) )=> (kw= '<' kw= '<' ) ) | kw= '<' | kw= '=>' ) ) | kw= '<>' | kw= '?:' )
            {
            // InternalTableDSL.g:5930:2: (kw= '->' | kw= '..<' | (kw= '>' kw= '..' ) | kw= '..' | kw= '=>' | (kw= '>' ( ( ( ( '>' '>' ) )=> (kw= '>' kw= '>' ) ) | kw= '>' ) ) | (kw= '<' ( ( ( ( '<' '<' ) )=> (kw= '<' kw= '<' ) ) | kw= '<' | kw= '=>' ) ) | kw= '<>' | kw= '?:' )
            int alt73=9;
            alt73 = dfa73.predict(input);
            switch (alt73) {
                case 1 :
                    // InternalTableDSL.g:5931:3: kw= '->'
                    {
                    kw=(Token)match(input,122,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpOtherAccess().getHyphenMinusGreaterThanSignKeyword_0());
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:5937:3: kw= '..<'
                    {
                    kw=(Token)match(input,123,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpOtherAccess().getFullStopFullStopLessThanSignKeyword_1());
                      		
                    }

                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:5943:3: (kw= '>' kw= '..' )
                    {
                    // InternalTableDSL.g:5943:3: (kw= '>' kw= '..' )
                    // InternalTableDSL.g:5944:4: kw= '>' kw= '..'
                    {
                    kw=(Token)match(input,113,FOLLOW_80); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getOpOtherAccess().getGreaterThanSignKeyword_2_0());
                      			
                    }
                    kw=(Token)match(input,124,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getOpOtherAccess().getFullStopFullStopKeyword_2_1());
                      			
                    }

                    }


                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:5956:3: kw= '..'
                    {
                    kw=(Token)match(input,124,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpOtherAccess().getFullStopFullStopKeyword_3());
                      		
                    }

                    }
                    break;
                case 5 :
                    // InternalTableDSL.g:5962:3: kw= '=>'
                    {
                    kw=(Token)match(input,125,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpOtherAccess().getEqualsSignGreaterThanSignKeyword_4());
                      		
                    }

                    }
                    break;
                case 6 :
                    // InternalTableDSL.g:5968:3: (kw= '>' ( ( ( ( '>' '>' ) )=> (kw= '>' kw= '>' ) ) | kw= '>' ) )
                    {
                    // InternalTableDSL.g:5968:3: (kw= '>' ( ( ( ( '>' '>' ) )=> (kw= '>' kw= '>' ) ) | kw= '>' ) )
                    // InternalTableDSL.g:5969:4: kw= '>' ( ( ( ( '>' '>' ) )=> (kw= '>' kw= '>' ) ) | kw= '>' )
                    {
                    kw=(Token)match(input,113,FOLLOW_81); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getOpOtherAccess().getGreaterThanSignKeyword_5_0());
                      			
                    }
                    // InternalTableDSL.g:5974:4: ( ( ( ( '>' '>' ) )=> (kw= '>' kw= '>' ) ) | kw= '>' )
                    int alt71=2;
                    int LA71_0 = input.LA(1);

                    if ( (LA71_0==113) ) {
                        int LA71_1 = input.LA(2);

                        if ( (LA71_1==EOF||(LA71_1>=RULE_ID && LA71_1<=RULE_STRING)||(LA71_1>=RULE_INT && LA71_1<=RULE_DECIMAL)||LA71_1==16||(LA71_1>=91 && LA71_1<=95)||LA71_1==100||(LA71_1>=104 && LA71_1<=105)||LA71_1==112||LA71_1==131||LA71_1==137||LA71_1==139||(LA71_1>=143 && LA71_1<=145)||(LA71_1>=148 && LA71_1<=157)||LA71_1==159) ) {
                            alt71=2;
                        }
                        else if ( (LA71_1==113) && (synpred14_InternalTableDSL())) {
                            alt71=1;
                        }
                        else {
                            if (state.backtracking>0) {state.failed=true; return current;}
                            NoViableAltException nvae =
                                new NoViableAltException("", 71, 1, input);

                            throw nvae;
                        }
                    }
                    else {
                        if (state.backtracking>0) {state.failed=true; return current;}
                        NoViableAltException nvae =
                            new NoViableAltException("", 71, 0, input);

                        throw nvae;
                    }
                    switch (alt71) {
                        case 1 :
                            // InternalTableDSL.g:5975:5: ( ( ( '>' '>' ) )=> (kw= '>' kw= '>' ) )
                            {
                            // InternalTableDSL.g:5975:5: ( ( ( '>' '>' ) )=> (kw= '>' kw= '>' ) )
                            // InternalTableDSL.g:5976:6: ( ( '>' '>' ) )=> (kw= '>' kw= '>' )
                            {
                            // InternalTableDSL.g:5981:6: (kw= '>' kw= '>' )
                            // InternalTableDSL.g:5982:7: kw= '>' kw= '>'
                            {
                            kw=(Token)match(input,113,FOLLOW_81); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              							current.merge(kw);
                              							newLeafNode(kw, grammarAccess.getOpOtherAccess().getGreaterThanSignKeyword_5_1_0_0_0());
                              						
                            }
                            kw=(Token)match(input,113,FOLLOW_2); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              							current.merge(kw);
                              							newLeafNode(kw, grammarAccess.getOpOtherAccess().getGreaterThanSignKeyword_5_1_0_0_1());
                              						
                            }

                            }


                            }


                            }
                            break;
                        case 2 :
                            // InternalTableDSL.g:5995:5: kw= '>'
                            {
                            kw=(Token)match(input,113,FOLLOW_2); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              					current.merge(kw);
                              					newLeafNode(kw, grammarAccess.getOpOtherAccess().getGreaterThanSignKeyword_5_1_1());
                              				
                            }

                            }
                            break;

                    }


                    }


                    }
                    break;
                case 7 :
                    // InternalTableDSL.g:6003:3: (kw= '<' ( ( ( ( '<' '<' ) )=> (kw= '<' kw= '<' ) ) | kw= '<' | kw= '=>' ) )
                    {
                    // InternalTableDSL.g:6003:3: (kw= '<' ( ( ( ( '<' '<' ) )=> (kw= '<' kw= '<' ) ) | kw= '<' | kw= '=>' ) )
                    // InternalTableDSL.g:6004:4: kw= '<' ( ( ( ( '<' '<' ) )=> (kw= '<' kw= '<' ) ) | kw= '<' | kw= '=>' )
                    {
                    kw=(Token)match(input,112,FOLLOW_82); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current.merge(kw);
                      				newLeafNode(kw, grammarAccess.getOpOtherAccess().getLessThanSignKeyword_6_0());
                      			
                    }
                    // InternalTableDSL.g:6009:4: ( ( ( ( '<' '<' ) )=> (kw= '<' kw= '<' ) ) | kw= '<' | kw= '=>' )
                    int alt72=3;
                    int LA72_0 = input.LA(1);

                    if ( (LA72_0==112) ) {
                        int LA72_1 = input.LA(2);

                        if ( (synpred15_InternalTableDSL()) ) {
                            alt72=1;
                        }
                        else if ( (true) ) {
                            alt72=2;
                        }
                        else {
                            if (state.backtracking>0) {state.failed=true; return current;}
                            NoViableAltException nvae =
                                new NoViableAltException("", 72, 1, input);

                            throw nvae;
                        }
                    }
                    else if ( (LA72_0==125) ) {
                        alt72=3;
                    }
                    else {
                        if (state.backtracking>0) {state.failed=true; return current;}
                        NoViableAltException nvae =
                            new NoViableAltException("", 72, 0, input);

                        throw nvae;
                    }
                    switch (alt72) {
                        case 1 :
                            // InternalTableDSL.g:6010:5: ( ( ( '<' '<' ) )=> (kw= '<' kw= '<' ) )
                            {
                            // InternalTableDSL.g:6010:5: ( ( ( '<' '<' ) )=> (kw= '<' kw= '<' ) )
                            // InternalTableDSL.g:6011:6: ( ( '<' '<' ) )=> (kw= '<' kw= '<' )
                            {
                            // InternalTableDSL.g:6016:6: (kw= '<' kw= '<' )
                            // InternalTableDSL.g:6017:7: kw= '<' kw= '<'
                            {
                            kw=(Token)match(input,112,FOLLOW_71); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              							current.merge(kw);
                              							newLeafNode(kw, grammarAccess.getOpOtherAccess().getLessThanSignKeyword_6_1_0_0_0());
                              						
                            }
                            kw=(Token)match(input,112,FOLLOW_2); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              							current.merge(kw);
                              							newLeafNode(kw, grammarAccess.getOpOtherAccess().getLessThanSignKeyword_6_1_0_0_1());
                              						
                            }

                            }


                            }


                            }
                            break;
                        case 2 :
                            // InternalTableDSL.g:6030:5: kw= '<'
                            {
                            kw=(Token)match(input,112,FOLLOW_2); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              					current.merge(kw);
                              					newLeafNode(kw, grammarAccess.getOpOtherAccess().getLessThanSignKeyword_6_1_1());
                              				
                            }

                            }
                            break;
                        case 3 :
                            // InternalTableDSL.g:6036:5: kw= '=>'
                            {
                            kw=(Token)match(input,125,FOLLOW_2); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              					current.merge(kw);
                              					newLeafNode(kw, grammarAccess.getOpOtherAccess().getEqualsSignGreaterThanSignKeyword_6_1_2());
                              				
                            }

                            }
                            break;

                    }


                    }


                    }
                    break;
                case 8 :
                    // InternalTableDSL.g:6044:3: kw= '<>'
                    {
                    kw=(Token)match(input,126,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpOtherAccess().getLessThanSignGreaterThanSignKeyword_7());
                      		
                    }

                    }
                    break;
                case 9 :
                    // InternalTableDSL.g:6050:3: kw= '?:'
                    {
                    kw=(Token)match(input,127,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpOtherAccess().getQuestionMarkColonKeyword_8());
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleOpOther"


    // $ANTLR start "entryRuleXAdditiveExpression"
    // InternalTableDSL.g:6059:1: entryRuleXAdditiveExpression returns [EObject current=null] : iv_ruleXAdditiveExpression= ruleXAdditiveExpression EOF ;
    public final EObject entryRuleXAdditiveExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXAdditiveExpression = null;


        try {
            // InternalTableDSL.g:6059:60: (iv_ruleXAdditiveExpression= ruleXAdditiveExpression EOF )
            // InternalTableDSL.g:6060:2: iv_ruleXAdditiveExpression= ruleXAdditiveExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXAdditiveExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXAdditiveExpression=ruleXAdditiveExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXAdditiveExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXAdditiveExpression"


    // $ANTLR start "ruleXAdditiveExpression"
    // InternalTableDSL.g:6066:1: ruleXAdditiveExpression returns [EObject current=null] : (this_XMultiplicativeExpression_0= ruleXMultiplicativeExpression ( ( ( ( () ( ( ruleOpAdd ) ) ) )=> ( () ( ( ruleOpAdd ) ) ) ) ( (lv_rightOperand_3_0= ruleXMultiplicativeExpression ) ) )* ) ;
    public final EObject ruleXAdditiveExpression() throws RecognitionException {
        EObject current = null;

        EObject this_XMultiplicativeExpression_0 = null;

        EObject lv_rightOperand_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:6072:2: ( (this_XMultiplicativeExpression_0= ruleXMultiplicativeExpression ( ( ( ( () ( ( ruleOpAdd ) ) ) )=> ( () ( ( ruleOpAdd ) ) ) ) ( (lv_rightOperand_3_0= ruleXMultiplicativeExpression ) ) )* ) )
            // InternalTableDSL.g:6073:2: (this_XMultiplicativeExpression_0= ruleXMultiplicativeExpression ( ( ( ( () ( ( ruleOpAdd ) ) ) )=> ( () ( ( ruleOpAdd ) ) ) ) ( (lv_rightOperand_3_0= ruleXMultiplicativeExpression ) ) )* )
            {
            // InternalTableDSL.g:6073:2: (this_XMultiplicativeExpression_0= ruleXMultiplicativeExpression ( ( ( ( () ( ( ruleOpAdd ) ) ) )=> ( () ( ( ruleOpAdd ) ) ) ) ( (lv_rightOperand_3_0= ruleXMultiplicativeExpression ) ) )* )
            // InternalTableDSL.g:6074:3: this_XMultiplicativeExpression_0= ruleXMultiplicativeExpression ( ( ( ( () ( ( ruleOpAdd ) ) ) )=> ( () ( ( ruleOpAdd ) ) ) ) ( (lv_rightOperand_3_0= ruleXMultiplicativeExpression ) ) )*
            {
            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getXAdditiveExpressionAccess().getXMultiplicativeExpressionParserRuleCall_0());
              		
            }
            pushFollow(FOLLOW_83);
            this_XMultiplicativeExpression_0=ruleXMultiplicativeExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current = this_XMultiplicativeExpression_0;
              			afterParserOrEnumRuleCall();
              		
            }
            // InternalTableDSL.g:6082:3: ( ( ( ( () ( ( ruleOpAdd ) ) ) )=> ( () ( ( ruleOpAdd ) ) ) ) ( (lv_rightOperand_3_0= ruleXMultiplicativeExpression ) ) )*
            loop74:
            do {
                int alt74=2;
                int LA74_0 = input.LA(1);

                if ( (LA74_0==91) ) {
                    int LA74_2 = input.LA(2);

                    if ( (synpred16_InternalTableDSL()) ) {
                        alt74=1;
                    }


                }
                else if ( (LA74_0==92) ) {
                    int LA74_3 = input.LA(2);

                    if ( (synpred16_InternalTableDSL()) ) {
                        alt74=1;
                    }


                }


                switch (alt74) {
            	case 1 :
            	    // InternalTableDSL.g:6083:4: ( ( ( () ( ( ruleOpAdd ) ) ) )=> ( () ( ( ruleOpAdd ) ) ) ) ( (lv_rightOperand_3_0= ruleXMultiplicativeExpression ) )
            	    {
            	    // InternalTableDSL.g:6083:4: ( ( ( () ( ( ruleOpAdd ) ) ) )=> ( () ( ( ruleOpAdd ) ) ) )
            	    // InternalTableDSL.g:6084:5: ( ( () ( ( ruleOpAdd ) ) ) )=> ( () ( ( ruleOpAdd ) ) )
            	    {
            	    // InternalTableDSL.g:6094:5: ( () ( ( ruleOpAdd ) ) )
            	    // InternalTableDSL.g:6095:6: () ( ( ruleOpAdd ) )
            	    {
            	    // InternalTableDSL.g:6095:6: ()
            	    // InternalTableDSL.g:6096:7: 
            	    {
            	    if ( state.backtracking==0 ) {

            	      							current = forceCreateModelElementAndSet(
            	      								grammarAccess.getXAdditiveExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0(),
            	      								current);
            	      						
            	    }

            	    }

            	    // InternalTableDSL.g:6102:6: ( ( ruleOpAdd ) )
            	    // InternalTableDSL.g:6103:7: ( ruleOpAdd )
            	    {
            	    // InternalTableDSL.g:6103:7: ( ruleOpAdd )
            	    // InternalTableDSL.g:6104:8: ruleOpAdd
            	    {
            	    if ( state.backtracking==0 ) {

            	      								if (current==null) {
            	      									current = createModelElement(grammarAccess.getXAdditiveExpressionRule());
            	      								}
            	      							
            	    }
            	    if ( state.backtracking==0 ) {

            	      								newCompositeNode(grammarAccess.getXAdditiveExpressionAccess().getFeatureJvmIdentifiableElementCrossReference_1_0_0_1_0());
            	      							
            	    }
            	    pushFollow(FOLLOW_65);
            	    ruleOpAdd();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      								afterParserOrEnumRuleCall();
            	      							
            	    }

            	    }


            	    }


            	    }


            	    }

            	    // InternalTableDSL.g:6120:4: ( (lv_rightOperand_3_0= ruleXMultiplicativeExpression ) )
            	    // InternalTableDSL.g:6121:5: (lv_rightOperand_3_0= ruleXMultiplicativeExpression )
            	    {
            	    // InternalTableDSL.g:6121:5: (lv_rightOperand_3_0= ruleXMultiplicativeExpression )
            	    // InternalTableDSL.g:6122:6: lv_rightOperand_3_0= ruleXMultiplicativeExpression
            	    {
            	    if ( state.backtracking==0 ) {

            	      						newCompositeNode(grammarAccess.getXAdditiveExpressionAccess().getRightOperandXMultiplicativeExpressionParserRuleCall_1_1_0());
            	      					
            	    }
            	    pushFollow(FOLLOW_83);
            	    lv_rightOperand_3_0=ruleXMultiplicativeExpression();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      						if (current==null) {
            	      							current = createModelElementForParent(grammarAccess.getXAdditiveExpressionRule());
            	      						}
            	      						set(
            	      							current,
            	      							"rightOperand",
            	      							lv_rightOperand_3_0,
            	      							"org.eclipse.xtext.xbase.Xbase.XMultiplicativeExpression");
            	      						afterParserOrEnumRuleCall();
            	      					
            	    }

            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop74;
                }
            } while (true);


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXAdditiveExpression"


    // $ANTLR start "entryRuleOpAdd"
    // InternalTableDSL.g:6144:1: entryRuleOpAdd returns [String current=null] : iv_ruleOpAdd= ruleOpAdd EOF ;
    public final String entryRuleOpAdd() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleOpAdd = null;


        try {
            // InternalTableDSL.g:6144:45: (iv_ruleOpAdd= ruleOpAdd EOF )
            // InternalTableDSL.g:6145:2: iv_ruleOpAdd= ruleOpAdd EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getOpAddRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleOpAdd=ruleOpAdd();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleOpAdd.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleOpAdd"


    // $ANTLR start "ruleOpAdd"
    // InternalTableDSL.g:6151:1: ruleOpAdd returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (kw= '+' | kw= '-' ) ;
    public final AntlrDatatypeRuleToken ruleOpAdd() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;


        	enterRule();

        try {
            // InternalTableDSL.g:6157:2: ( (kw= '+' | kw= '-' ) )
            // InternalTableDSL.g:6158:2: (kw= '+' | kw= '-' )
            {
            // InternalTableDSL.g:6158:2: (kw= '+' | kw= '-' )
            int alt75=2;
            int LA75_0 = input.LA(1);

            if ( (LA75_0==91) ) {
                alt75=1;
            }
            else if ( (LA75_0==92) ) {
                alt75=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 75, 0, input);

                throw nvae;
            }
            switch (alt75) {
                case 1 :
                    // InternalTableDSL.g:6159:3: kw= '+'
                    {
                    kw=(Token)match(input,91,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpAddAccess().getPlusSignKeyword_0());
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:6165:3: kw= '-'
                    {
                    kw=(Token)match(input,92,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpAddAccess().getHyphenMinusKeyword_1());
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleOpAdd"


    // $ANTLR start "entryRuleXMultiplicativeExpression"
    // InternalTableDSL.g:6174:1: entryRuleXMultiplicativeExpression returns [EObject current=null] : iv_ruleXMultiplicativeExpression= ruleXMultiplicativeExpression EOF ;
    public final EObject entryRuleXMultiplicativeExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXMultiplicativeExpression = null;


        try {
            // InternalTableDSL.g:6174:66: (iv_ruleXMultiplicativeExpression= ruleXMultiplicativeExpression EOF )
            // InternalTableDSL.g:6175:2: iv_ruleXMultiplicativeExpression= ruleXMultiplicativeExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXMultiplicativeExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXMultiplicativeExpression=ruleXMultiplicativeExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXMultiplicativeExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXMultiplicativeExpression"


    // $ANTLR start "ruleXMultiplicativeExpression"
    // InternalTableDSL.g:6181:1: ruleXMultiplicativeExpression returns [EObject current=null] : (this_XUnaryOperation_0= ruleXUnaryOperation ( ( ( ( () ( ( ruleOpMulti ) ) ) )=> ( () ( ( ruleOpMulti ) ) ) ) ( (lv_rightOperand_3_0= ruleXUnaryOperation ) ) )* ) ;
    public final EObject ruleXMultiplicativeExpression() throws RecognitionException {
        EObject current = null;

        EObject this_XUnaryOperation_0 = null;

        EObject lv_rightOperand_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:6187:2: ( (this_XUnaryOperation_0= ruleXUnaryOperation ( ( ( ( () ( ( ruleOpMulti ) ) ) )=> ( () ( ( ruleOpMulti ) ) ) ) ( (lv_rightOperand_3_0= ruleXUnaryOperation ) ) )* ) )
            // InternalTableDSL.g:6188:2: (this_XUnaryOperation_0= ruleXUnaryOperation ( ( ( ( () ( ( ruleOpMulti ) ) ) )=> ( () ( ( ruleOpMulti ) ) ) ) ( (lv_rightOperand_3_0= ruleXUnaryOperation ) ) )* )
            {
            // InternalTableDSL.g:6188:2: (this_XUnaryOperation_0= ruleXUnaryOperation ( ( ( ( () ( ( ruleOpMulti ) ) ) )=> ( () ( ( ruleOpMulti ) ) ) ) ( (lv_rightOperand_3_0= ruleXUnaryOperation ) ) )* )
            // InternalTableDSL.g:6189:3: this_XUnaryOperation_0= ruleXUnaryOperation ( ( ( ( () ( ( ruleOpMulti ) ) ) )=> ( () ( ( ruleOpMulti ) ) ) ) ( (lv_rightOperand_3_0= ruleXUnaryOperation ) ) )*
            {
            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getXMultiplicativeExpressionAccess().getXUnaryOperationParserRuleCall_0());
              		
            }
            pushFollow(FOLLOW_84);
            this_XUnaryOperation_0=ruleXUnaryOperation();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current = this_XUnaryOperation_0;
              			afterParserOrEnumRuleCall();
              		
            }
            // InternalTableDSL.g:6197:3: ( ( ( ( () ( ( ruleOpMulti ) ) ) )=> ( () ( ( ruleOpMulti ) ) ) ) ( (lv_rightOperand_3_0= ruleXUnaryOperation ) ) )*
            loop76:
            do {
                int alt76=2;
                switch ( input.LA(1) ) {
                case 96:
                    {
                    int LA76_2 = input.LA(2);

                    if ( (synpred17_InternalTableDSL()) ) {
                        alt76=1;
                    }


                    }
                    break;
                case 128:
                    {
                    int LA76_3 = input.LA(2);

                    if ( (synpred17_InternalTableDSL()) ) {
                        alt76=1;
                    }


                    }
                    break;
                case 129:
                    {
                    int LA76_4 = input.LA(2);

                    if ( (synpred17_InternalTableDSL()) ) {
                        alt76=1;
                    }


                    }
                    break;
                case 130:
                    {
                    int LA76_5 = input.LA(2);

                    if ( (synpred17_InternalTableDSL()) ) {
                        alt76=1;
                    }


                    }
                    break;

                }

                switch (alt76) {
            	case 1 :
            	    // InternalTableDSL.g:6198:4: ( ( ( () ( ( ruleOpMulti ) ) ) )=> ( () ( ( ruleOpMulti ) ) ) ) ( (lv_rightOperand_3_0= ruleXUnaryOperation ) )
            	    {
            	    // InternalTableDSL.g:6198:4: ( ( ( () ( ( ruleOpMulti ) ) ) )=> ( () ( ( ruleOpMulti ) ) ) )
            	    // InternalTableDSL.g:6199:5: ( ( () ( ( ruleOpMulti ) ) ) )=> ( () ( ( ruleOpMulti ) ) )
            	    {
            	    // InternalTableDSL.g:6209:5: ( () ( ( ruleOpMulti ) ) )
            	    // InternalTableDSL.g:6210:6: () ( ( ruleOpMulti ) )
            	    {
            	    // InternalTableDSL.g:6210:6: ()
            	    // InternalTableDSL.g:6211:7: 
            	    {
            	    if ( state.backtracking==0 ) {

            	      							current = forceCreateModelElementAndSet(
            	      								grammarAccess.getXMultiplicativeExpressionAccess().getXBinaryOperationLeftOperandAction_1_0_0_0(),
            	      								current);
            	      						
            	    }

            	    }

            	    // InternalTableDSL.g:6217:6: ( ( ruleOpMulti ) )
            	    // InternalTableDSL.g:6218:7: ( ruleOpMulti )
            	    {
            	    // InternalTableDSL.g:6218:7: ( ruleOpMulti )
            	    // InternalTableDSL.g:6219:8: ruleOpMulti
            	    {
            	    if ( state.backtracking==0 ) {

            	      								if (current==null) {
            	      									current = createModelElement(grammarAccess.getXMultiplicativeExpressionRule());
            	      								}
            	      							
            	    }
            	    if ( state.backtracking==0 ) {

            	      								newCompositeNode(grammarAccess.getXMultiplicativeExpressionAccess().getFeatureJvmIdentifiableElementCrossReference_1_0_0_1_0());
            	      							
            	    }
            	    pushFollow(FOLLOW_65);
            	    ruleOpMulti();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      								afterParserOrEnumRuleCall();
            	      							
            	    }

            	    }


            	    }


            	    }


            	    }

            	    // InternalTableDSL.g:6235:4: ( (lv_rightOperand_3_0= ruleXUnaryOperation ) )
            	    // InternalTableDSL.g:6236:5: (lv_rightOperand_3_0= ruleXUnaryOperation )
            	    {
            	    // InternalTableDSL.g:6236:5: (lv_rightOperand_3_0= ruleXUnaryOperation )
            	    // InternalTableDSL.g:6237:6: lv_rightOperand_3_0= ruleXUnaryOperation
            	    {
            	    if ( state.backtracking==0 ) {

            	      						newCompositeNode(grammarAccess.getXMultiplicativeExpressionAccess().getRightOperandXUnaryOperationParserRuleCall_1_1_0());
            	      					
            	    }
            	    pushFollow(FOLLOW_84);
            	    lv_rightOperand_3_0=ruleXUnaryOperation();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      						if (current==null) {
            	      							current = createModelElementForParent(grammarAccess.getXMultiplicativeExpressionRule());
            	      						}
            	      						set(
            	      							current,
            	      							"rightOperand",
            	      							lv_rightOperand_3_0,
            	      							"org.eclipse.xtext.xbase.Xbase.XUnaryOperation");
            	      						afterParserOrEnumRuleCall();
            	      					
            	    }

            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop76;
                }
            } while (true);


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXMultiplicativeExpression"


    // $ANTLR start "entryRuleOpMulti"
    // InternalTableDSL.g:6259:1: entryRuleOpMulti returns [String current=null] : iv_ruleOpMulti= ruleOpMulti EOF ;
    public final String entryRuleOpMulti() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleOpMulti = null;


        try {
            // InternalTableDSL.g:6259:47: (iv_ruleOpMulti= ruleOpMulti EOF )
            // InternalTableDSL.g:6260:2: iv_ruleOpMulti= ruleOpMulti EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getOpMultiRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleOpMulti=ruleOpMulti();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleOpMulti.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleOpMulti"


    // $ANTLR start "ruleOpMulti"
    // InternalTableDSL.g:6266:1: ruleOpMulti returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (kw= '*' | kw= '**' | kw= '/' | kw= '%' ) ;
    public final AntlrDatatypeRuleToken ruleOpMulti() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;


        	enterRule();

        try {
            // InternalTableDSL.g:6272:2: ( (kw= '*' | kw= '**' | kw= '/' | kw= '%' ) )
            // InternalTableDSL.g:6273:2: (kw= '*' | kw= '**' | kw= '/' | kw= '%' )
            {
            // InternalTableDSL.g:6273:2: (kw= '*' | kw= '**' | kw= '/' | kw= '%' )
            int alt77=4;
            switch ( input.LA(1) ) {
            case 96:
                {
                alt77=1;
                }
                break;
            case 128:
                {
                alt77=2;
                }
                break;
            case 129:
                {
                alt77=3;
                }
                break;
            case 130:
                {
                alt77=4;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 77, 0, input);

                throw nvae;
            }

            switch (alt77) {
                case 1 :
                    // InternalTableDSL.g:6274:3: kw= '*'
                    {
                    kw=(Token)match(input,96,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpMultiAccess().getAsteriskKeyword_0());
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:6280:3: kw= '**'
                    {
                    kw=(Token)match(input,128,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpMultiAccess().getAsteriskAsteriskKeyword_1());
                      		
                    }

                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:6286:3: kw= '/'
                    {
                    kw=(Token)match(input,129,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpMultiAccess().getSolidusKeyword_2());
                      		
                    }

                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:6292:3: kw= '%'
                    {
                    kw=(Token)match(input,130,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpMultiAccess().getPercentSignKeyword_3());
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleOpMulti"


    // $ANTLR start "entryRuleXUnaryOperation"
    // InternalTableDSL.g:6301:1: entryRuleXUnaryOperation returns [EObject current=null] : iv_ruleXUnaryOperation= ruleXUnaryOperation EOF ;
    public final EObject entryRuleXUnaryOperation() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXUnaryOperation = null;


        try {
            // InternalTableDSL.g:6301:56: (iv_ruleXUnaryOperation= ruleXUnaryOperation EOF )
            // InternalTableDSL.g:6302:2: iv_ruleXUnaryOperation= ruleXUnaryOperation EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXUnaryOperationRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXUnaryOperation=ruleXUnaryOperation();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXUnaryOperation; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXUnaryOperation"


    // $ANTLR start "ruleXUnaryOperation"
    // InternalTableDSL.g:6308:1: ruleXUnaryOperation returns [EObject current=null] : ( ( () ( ( ruleOpUnary ) ) ( (lv_operand_2_0= ruleXUnaryOperation ) ) ) | this_XCastedExpression_3= ruleXCastedExpression ) ;
    public final EObject ruleXUnaryOperation() throws RecognitionException {
        EObject current = null;

        EObject lv_operand_2_0 = null;

        EObject this_XCastedExpression_3 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:6314:2: ( ( ( () ( ( ruleOpUnary ) ) ( (lv_operand_2_0= ruleXUnaryOperation ) ) ) | this_XCastedExpression_3= ruleXCastedExpression ) )
            // InternalTableDSL.g:6315:2: ( ( () ( ( ruleOpUnary ) ) ( (lv_operand_2_0= ruleXUnaryOperation ) ) ) | this_XCastedExpression_3= ruleXCastedExpression )
            {
            // InternalTableDSL.g:6315:2: ( ( () ( ( ruleOpUnary ) ) ( (lv_operand_2_0= ruleXUnaryOperation ) ) ) | this_XCastedExpression_3= ruleXCastedExpression )
            int alt78=2;
            int LA78_0 = input.LA(1);

            if ( ((LA78_0>=91 && LA78_0<=92)||LA78_0==131) ) {
                alt78=1;
            }
            else if ( ((LA78_0>=RULE_ID && LA78_0<=RULE_STRING)||(LA78_0>=RULE_INT && LA78_0<=RULE_DECIMAL)||LA78_0==16||(LA78_0>=93 && LA78_0<=95)||LA78_0==100||(LA78_0>=104 && LA78_0<=105)||LA78_0==112||LA78_0==137||LA78_0==139||(LA78_0>=143 && LA78_0<=145)||(LA78_0>=148 && LA78_0<=157)||LA78_0==159) ) {
                alt78=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 78, 0, input);

                throw nvae;
            }
            switch (alt78) {
                case 1 :
                    // InternalTableDSL.g:6316:3: ( () ( ( ruleOpUnary ) ) ( (lv_operand_2_0= ruleXUnaryOperation ) ) )
                    {
                    // InternalTableDSL.g:6316:3: ( () ( ( ruleOpUnary ) ) ( (lv_operand_2_0= ruleXUnaryOperation ) ) )
                    // InternalTableDSL.g:6317:4: () ( ( ruleOpUnary ) ) ( (lv_operand_2_0= ruleXUnaryOperation ) )
                    {
                    // InternalTableDSL.g:6317:4: ()
                    // InternalTableDSL.g:6318:5: 
                    {
                    if ( state.backtracking==0 ) {

                      					current = forceCreateModelElement(
                      						grammarAccess.getXUnaryOperationAccess().getXUnaryOperationAction_0_0(),
                      						current);
                      				
                    }

                    }

                    // InternalTableDSL.g:6324:4: ( ( ruleOpUnary ) )
                    // InternalTableDSL.g:6325:5: ( ruleOpUnary )
                    {
                    // InternalTableDSL.g:6325:5: ( ruleOpUnary )
                    // InternalTableDSL.g:6326:6: ruleOpUnary
                    {
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElement(grammarAccess.getXUnaryOperationRule());
                      						}
                      					
                    }
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXUnaryOperationAccess().getFeatureJvmIdentifiableElementCrossReference_0_1_0());
                      					
                    }
                    pushFollow(FOLLOW_65);
                    ruleOpUnary();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }

                    // InternalTableDSL.g:6340:4: ( (lv_operand_2_0= ruleXUnaryOperation ) )
                    // InternalTableDSL.g:6341:5: (lv_operand_2_0= ruleXUnaryOperation )
                    {
                    // InternalTableDSL.g:6341:5: (lv_operand_2_0= ruleXUnaryOperation )
                    // InternalTableDSL.g:6342:6: lv_operand_2_0= ruleXUnaryOperation
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXUnaryOperationAccess().getOperandXUnaryOperationParserRuleCall_0_2_0());
                      					
                    }
                    pushFollow(FOLLOW_2);
                    lv_operand_2_0=ruleXUnaryOperation();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getXUnaryOperationRule());
                      						}
                      						set(
                      							current,
                      							"operand",
                      							lv_operand_2_0,
                      							"org.eclipse.xtext.xbase.Xbase.XUnaryOperation");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }


                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:6361:3: this_XCastedExpression_3= ruleXCastedExpression
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXUnaryOperationAccess().getXCastedExpressionParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XCastedExpression_3=ruleXCastedExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XCastedExpression_3;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXUnaryOperation"


    // $ANTLR start "entryRuleOpUnary"
    // InternalTableDSL.g:6373:1: entryRuleOpUnary returns [String current=null] : iv_ruleOpUnary= ruleOpUnary EOF ;
    public final String entryRuleOpUnary() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleOpUnary = null;


        try {
            // InternalTableDSL.g:6373:47: (iv_ruleOpUnary= ruleOpUnary EOF )
            // InternalTableDSL.g:6374:2: iv_ruleOpUnary= ruleOpUnary EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getOpUnaryRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleOpUnary=ruleOpUnary();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleOpUnary.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleOpUnary"


    // $ANTLR start "ruleOpUnary"
    // InternalTableDSL.g:6380:1: ruleOpUnary returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (kw= '!' | kw= '-' | kw= '+' ) ;
    public final AntlrDatatypeRuleToken ruleOpUnary() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;


        	enterRule();

        try {
            // InternalTableDSL.g:6386:2: ( (kw= '!' | kw= '-' | kw= '+' ) )
            // InternalTableDSL.g:6387:2: (kw= '!' | kw= '-' | kw= '+' )
            {
            // InternalTableDSL.g:6387:2: (kw= '!' | kw= '-' | kw= '+' )
            int alt79=3;
            switch ( input.LA(1) ) {
            case 131:
                {
                alt79=1;
                }
                break;
            case 92:
                {
                alt79=2;
                }
                break;
            case 91:
                {
                alt79=3;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 79, 0, input);

                throw nvae;
            }

            switch (alt79) {
                case 1 :
                    // InternalTableDSL.g:6388:3: kw= '!'
                    {
                    kw=(Token)match(input,131,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpUnaryAccess().getExclamationMarkKeyword_0());
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:6394:3: kw= '-'
                    {
                    kw=(Token)match(input,92,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpUnaryAccess().getHyphenMinusKeyword_1());
                      		
                    }

                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:6400:3: kw= '+'
                    {
                    kw=(Token)match(input,91,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpUnaryAccess().getPlusSignKeyword_2());
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleOpUnary"


    // $ANTLR start "entryRuleXCastedExpression"
    // InternalTableDSL.g:6409:1: entryRuleXCastedExpression returns [EObject current=null] : iv_ruleXCastedExpression= ruleXCastedExpression EOF ;
    public final EObject entryRuleXCastedExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXCastedExpression = null;


        try {
            // InternalTableDSL.g:6409:58: (iv_ruleXCastedExpression= ruleXCastedExpression EOF )
            // InternalTableDSL.g:6410:2: iv_ruleXCastedExpression= ruleXCastedExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXCastedExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXCastedExpression=ruleXCastedExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXCastedExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXCastedExpression"


    // $ANTLR start "ruleXCastedExpression"
    // InternalTableDSL.g:6416:1: ruleXCastedExpression returns [EObject current=null] : (this_XPostfixOperation_0= ruleXPostfixOperation ( ( ( ( () 'as' ) )=> ( () otherlv_2= 'as' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) ) )* ) ;
    public final EObject ruleXCastedExpression() throws RecognitionException {
        EObject current = null;

        Token otherlv_2=null;
        EObject this_XPostfixOperation_0 = null;

        EObject lv_type_3_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:6422:2: ( (this_XPostfixOperation_0= ruleXPostfixOperation ( ( ( ( () 'as' ) )=> ( () otherlv_2= 'as' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) ) )* ) )
            // InternalTableDSL.g:6423:2: (this_XPostfixOperation_0= ruleXPostfixOperation ( ( ( ( () 'as' ) )=> ( () otherlv_2= 'as' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) ) )* )
            {
            // InternalTableDSL.g:6423:2: (this_XPostfixOperation_0= ruleXPostfixOperation ( ( ( ( () 'as' ) )=> ( () otherlv_2= 'as' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) ) )* )
            // InternalTableDSL.g:6424:3: this_XPostfixOperation_0= ruleXPostfixOperation ( ( ( ( () 'as' ) )=> ( () otherlv_2= 'as' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) ) )*
            {
            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getXCastedExpressionAccess().getXPostfixOperationParserRuleCall_0());
              		
            }
            pushFollow(FOLLOW_85);
            this_XPostfixOperation_0=ruleXPostfixOperation();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current = this_XPostfixOperation_0;
              			afterParserOrEnumRuleCall();
              		
            }
            // InternalTableDSL.g:6432:3: ( ( ( ( () 'as' ) )=> ( () otherlv_2= 'as' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) ) )*
            loop80:
            do {
                int alt80=2;
                int LA80_0 = input.LA(1);

                if ( (LA80_0==20) ) {
                    int LA80_2 = input.LA(2);

                    if ( (synpred18_InternalTableDSL()) ) {
                        alt80=1;
                    }


                }


                switch (alt80) {
            	case 1 :
            	    // InternalTableDSL.g:6433:4: ( ( ( () 'as' ) )=> ( () otherlv_2= 'as' ) ) ( (lv_type_3_0= ruleJvmTypeReference ) )
            	    {
            	    // InternalTableDSL.g:6433:4: ( ( ( () 'as' ) )=> ( () otherlv_2= 'as' ) )
            	    // InternalTableDSL.g:6434:5: ( ( () 'as' ) )=> ( () otherlv_2= 'as' )
            	    {
            	    // InternalTableDSL.g:6440:5: ( () otherlv_2= 'as' )
            	    // InternalTableDSL.g:6441:6: () otherlv_2= 'as'
            	    {
            	    // InternalTableDSL.g:6441:6: ()
            	    // InternalTableDSL.g:6442:7: 
            	    {
            	    if ( state.backtracking==0 ) {

            	      							current = forceCreateModelElementAndSet(
            	      								grammarAccess.getXCastedExpressionAccess().getXCastedExpressionTargetAction_1_0_0_0(),
            	      								current);
            	      						
            	    }

            	    }

            	    otherlv_2=(Token)match(input,20,FOLLOW_78); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      						newLeafNode(otherlv_2, grammarAccess.getXCastedExpressionAccess().getAsKeyword_1_0_0_1());
            	      					
            	    }

            	    }


            	    }

            	    // InternalTableDSL.g:6454:4: ( (lv_type_3_0= ruleJvmTypeReference ) )
            	    // InternalTableDSL.g:6455:5: (lv_type_3_0= ruleJvmTypeReference )
            	    {
            	    // InternalTableDSL.g:6455:5: (lv_type_3_0= ruleJvmTypeReference )
            	    // InternalTableDSL.g:6456:6: lv_type_3_0= ruleJvmTypeReference
            	    {
            	    if ( state.backtracking==0 ) {

            	      						newCompositeNode(grammarAccess.getXCastedExpressionAccess().getTypeJvmTypeReferenceParserRuleCall_1_1_0());
            	      					
            	    }
            	    pushFollow(FOLLOW_85);
            	    lv_type_3_0=ruleJvmTypeReference();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      						if (current==null) {
            	      							current = createModelElementForParent(grammarAccess.getXCastedExpressionRule());
            	      						}
            	      						set(
            	      							current,
            	      							"type",
            	      							lv_type_3_0,
            	      							"org.eclipse.xtext.xbase.Xtype.JvmTypeReference");
            	      						afterParserOrEnumRuleCall();
            	      					
            	    }

            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop80;
                }
            } while (true);


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXCastedExpression"


    // $ANTLR start "entryRuleXPostfixOperation"
    // InternalTableDSL.g:6478:1: entryRuleXPostfixOperation returns [EObject current=null] : iv_ruleXPostfixOperation= ruleXPostfixOperation EOF ;
    public final EObject entryRuleXPostfixOperation() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXPostfixOperation = null;


        try {
            // InternalTableDSL.g:6478:58: (iv_ruleXPostfixOperation= ruleXPostfixOperation EOF )
            // InternalTableDSL.g:6479:2: iv_ruleXPostfixOperation= ruleXPostfixOperation EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXPostfixOperationRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXPostfixOperation=ruleXPostfixOperation();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXPostfixOperation; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXPostfixOperation"


    // $ANTLR start "ruleXPostfixOperation"
    // InternalTableDSL.g:6485:1: ruleXPostfixOperation returns [EObject current=null] : (this_XMemberFeatureCall_0= ruleXMemberFeatureCall ( ( ( () ( ( ruleOpPostfix ) ) ) )=> ( () ( ( ruleOpPostfix ) ) ) )? ) ;
    public final EObject ruleXPostfixOperation() throws RecognitionException {
        EObject current = null;

        EObject this_XMemberFeatureCall_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:6491:2: ( (this_XMemberFeatureCall_0= ruleXMemberFeatureCall ( ( ( () ( ( ruleOpPostfix ) ) ) )=> ( () ( ( ruleOpPostfix ) ) ) )? ) )
            // InternalTableDSL.g:6492:2: (this_XMemberFeatureCall_0= ruleXMemberFeatureCall ( ( ( () ( ( ruleOpPostfix ) ) ) )=> ( () ( ( ruleOpPostfix ) ) ) )? )
            {
            // InternalTableDSL.g:6492:2: (this_XMemberFeatureCall_0= ruleXMemberFeatureCall ( ( ( () ( ( ruleOpPostfix ) ) ) )=> ( () ( ( ruleOpPostfix ) ) ) )? )
            // InternalTableDSL.g:6493:3: this_XMemberFeatureCall_0= ruleXMemberFeatureCall ( ( ( () ( ( ruleOpPostfix ) ) ) )=> ( () ( ( ruleOpPostfix ) ) ) )?
            {
            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getXPostfixOperationAccess().getXMemberFeatureCallParserRuleCall_0());
              		
            }
            pushFollow(FOLLOW_86);
            this_XMemberFeatureCall_0=ruleXMemberFeatureCall();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current = this_XMemberFeatureCall_0;
              			afterParserOrEnumRuleCall();
              		
            }
            // InternalTableDSL.g:6501:3: ( ( ( () ( ( ruleOpPostfix ) ) ) )=> ( () ( ( ruleOpPostfix ) ) ) )?
            int alt81=2;
            int LA81_0 = input.LA(1);

            if ( (LA81_0==132) ) {
                int LA81_1 = input.LA(2);

                if ( (synpred19_InternalTableDSL()) ) {
                    alt81=1;
                }
            }
            else if ( (LA81_0==133) ) {
                int LA81_2 = input.LA(2);

                if ( (synpred19_InternalTableDSL()) ) {
                    alt81=1;
                }
            }
            switch (alt81) {
                case 1 :
                    // InternalTableDSL.g:6502:4: ( ( () ( ( ruleOpPostfix ) ) ) )=> ( () ( ( ruleOpPostfix ) ) )
                    {
                    // InternalTableDSL.g:6512:4: ( () ( ( ruleOpPostfix ) ) )
                    // InternalTableDSL.g:6513:5: () ( ( ruleOpPostfix ) )
                    {
                    // InternalTableDSL.g:6513:5: ()
                    // InternalTableDSL.g:6514:6: 
                    {
                    if ( state.backtracking==0 ) {

                      						current = forceCreateModelElementAndSet(
                      							grammarAccess.getXPostfixOperationAccess().getXPostfixOperationOperandAction_1_0_0(),
                      							current);
                      					
                    }

                    }

                    // InternalTableDSL.g:6520:5: ( ( ruleOpPostfix ) )
                    // InternalTableDSL.g:6521:6: ( ruleOpPostfix )
                    {
                    // InternalTableDSL.g:6521:6: ( ruleOpPostfix )
                    // InternalTableDSL.g:6522:7: ruleOpPostfix
                    {
                    if ( state.backtracking==0 ) {

                      							if (current==null) {
                      								current = createModelElement(grammarAccess.getXPostfixOperationRule());
                      							}
                      						
                    }
                    if ( state.backtracking==0 ) {

                      							newCompositeNode(grammarAccess.getXPostfixOperationAccess().getFeatureJvmIdentifiableElementCrossReference_1_0_1_0());
                      						
                    }
                    pushFollow(FOLLOW_2);
                    ruleOpPostfix();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      							afterParserOrEnumRuleCall();
                      						
                    }

                    }


                    }


                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXPostfixOperation"


    // $ANTLR start "entryRuleOpPostfix"
    // InternalTableDSL.g:6542:1: entryRuleOpPostfix returns [String current=null] : iv_ruleOpPostfix= ruleOpPostfix EOF ;
    public final String entryRuleOpPostfix() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleOpPostfix = null;


        try {
            // InternalTableDSL.g:6542:49: (iv_ruleOpPostfix= ruleOpPostfix EOF )
            // InternalTableDSL.g:6543:2: iv_ruleOpPostfix= ruleOpPostfix EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getOpPostfixRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleOpPostfix=ruleOpPostfix();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleOpPostfix.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleOpPostfix"


    // $ANTLR start "ruleOpPostfix"
    // InternalTableDSL.g:6549:1: ruleOpPostfix returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (kw= '++' | kw= '--' ) ;
    public final AntlrDatatypeRuleToken ruleOpPostfix() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;


        	enterRule();

        try {
            // InternalTableDSL.g:6555:2: ( (kw= '++' | kw= '--' ) )
            // InternalTableDSL.g:6556:2: (kw= '++' | kw= '--' )
            {
            // InternalTableDSL.g:6556:2: (kw= '++' | kw= '--' )
            int alt82=2;
            int LA82_0 = input.LA(1);

            if ( (LA82_0==132) ) {
                alt82=1;
            }
            else if ( (LA82_0==133) ) {
                alt82=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 82, 0, input);

                throw nvae;
            }
            switch (alt82) {
                case 1 :
                    // InternalTableDSL.g:6557:3: kw= '++'
                    {
                    kw=(Token)match(input,132,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpPostfixAccess().getPlusSignPlusSignKeyword_0());
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:6563:3: kw= '--'
                    {
                    kw=(Token)match(input,133,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getOpPostfixAccess().getHyphenMinusHyphenMinusKeyword_1());
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleOpPostfix"


    // $ANTLR start "entryRuleXMemberFeatureCall"
    // InternalTableDSL.g:6572:1: entryRuleXMemberFeatureCall returns [EObject current=null] : iv_ruleXMemberFeatureCall= ruleXMemberFeatureCall EOF ;
    public final EObject entryRuleXMemberFeatureCall() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXMemberFeatureCall = null;


        try {
            // InternalTableDSL.g:6572:59: (iv_ruleXMemberFeatureCall= ruleXMemberFeatureCall EOF )
            // InternalTableDSL.g:6573:2: iv_ruleXMemberFeatureCall= ruleXMemberFeatureCall EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXMemberFeatureCallRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXMemberFeatureCall=ruleXMemberFeatureCall();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXMemberFeatureCall; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXMemberFeatureCall"


    // $ANTLR start "ruleXMemberFeatureCall"
    // InternalTableDSL.g:6579:1: ruleXMemberFeatureCall returns [EObject current=null] : (this_XPrimaryExpression_0= ruleXPrimaryExpression ( ( ( ( ( () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) )=> ( () (otherlv_2= '.' | ( (lv_explicitStatic_3_0= '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) ) ( (lv_value_6_0= ruleXAssignment ) ) ) | ( ( ( ( () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) ) ) )=> ( () (otherlv_8= '.' | ( (lv_nullSafe_9_0= '?.' ) ) | ( (lv_explicitStatic_10_0= '::' ) ) ) ) ) (otherlv_11= '<' ( (lv_typeArguments_12_0= ruleJvmArgumentTypeReference ) ) (otherlv_13= ',' ( (lv_typeArguments_14_0= ruleJvmArgumentTypeReference ) ) )* otherlv_15= '>' )? ( ( ruleIdOrSuper ) ) ( ( ( ( '(' ) )=> (lv_explicitOperationCall_17_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) ) | ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* ) )? otherlv_22= ')' )? ( ( ( () '[' ) )=> (lv_memberCallArguments_23_0= ruleXClosure ) )? ) )* ) ;
    public final EObject ruleXMemberFeatureCall() throws RecognitionException {
        EObject current = null;

        Token otherlv_2=null;
        Token lv_explicitStatic_3_0=null;
        Token otherlv_8=null;
        Token lv_nullSafe_9_0=null;
        Token lv_explicitStatic_10_0=null;
        Token otherlv_11=null;
        Token otherlv_13=null;
        Token otherlv_15=null;
        Token lv_explicitOperationCall_17_0=null;
        Token otherlv_20=null;
        Token otherlv_22=null;
        EObject this_XPrimaryExpression_0 = null;

        EObject lv_value_6_0 = null;

        EObject lv_typeArguments_12_0 = null;

        EObject lv_typeArguments_14_0 = null;

        EObject lv_memberCallArguments_18_0 = null;

        EObject lv_memberCallArguments_19_0 = null;

        EObject lv_memberCallArguments_21_0 = null;

        EObject lv_memberCallArguments_23_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:6585:2: ( (this_XPrimaryExpression_0= ruleXPrimaryExpression ( ( ( ( ( () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) )=> ( () (otherlv_2= '.' | ( (lv_explicitStatic_3_0= '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) ) ( (lv_value_6_0= ruleXAssignment ) ) ) | ( ( ( ( () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) ) ) )=> ( () (otherlv_8= '.' | ( (lv_nullSafe_9_0= '?.' ) ) | ( (lv_explicitStatic_10_0= '::' ) ) ) ) ) (otherlv_11= '<' ( (lv_typeArguments_12_0= ruleJvmArgumentTypeReference ) ) (otherlv_13= ',' ( (lv_typeArguments_14_0= ruleJvmArgumentTypeReference ) ) )* otherlv_15= '>' )? ( ( ruleIdOrSuper ) ) ( ( ( ( '(' ) )=> (lv_explicitOperationCall_17_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) ) | ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* ) )? otherlv_22= ')' )? ( ( ( () '[' ) )=> (lv_memberCallArguments_23_0= ruleXClosure ) )? ) )* ) )
            // InternalTableDSL.g:6586:2: (this_XPrimaryExpression_0= ruleXPrimaryExpression ( ( ( ( ( () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) )=> ( () (otherlv_2= '.' | ( (lv_explicitStatic_3_0= '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) ) ( (lv_value_6_0= ruleXAssignment ) ) ) | ( ( ( ( () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) ) ) )=> ( () (otherlv_8= '.' | ( (lv_nullSafe_9_0= '?.' ) ) | ( (lv_explicitStatic_10_0= '::' ) ) ) ) ) (otherlv_11= '<' ( (lv_typeArguments_12_0= ruleJvmArgumentTypeReference ) ) (otherlv_13= ',' ( (lv_typeArguments_14_0= ruleJvmArgumentTypeReference ) ) )* otherlv_15= '>' )? ( ( ruleIdOrSuper ) ) ( ( ( ( '(' ) )=> (lv_explicitOperationCall_17_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) ) | ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* ) )? otherlv_22= ')' )? ( ( ( () '[' ) )=> (lv_memberCallArguments_23_0= ruleXClosure ) )? ) )* )
            {
            // InternalTableDSL.g:6586:2: (this_XPrimaryExpression_0= ruleXPrimaryExpression ( ( ( ( ( () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) )=> ( () (otherlv_2= '.' | ( (lv_explicitStatic_3_0= '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) ) ( (lv_value_6_0= ruleXAssignment ) ) ) | ( ( ( ( () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) ) ) )=> ( () (otherlv_8= '.' | ( (lv_nullSafe_9_0= '?.' ) ) | ( (lv_explicitStatic_10_0= '::' ) ) ) ) ) (otherlv_11= '<' ( (lv_typeArguments_12_0= ruleJvmArgumentTypeReference ) ) (otherlv_13= ',' ( (lv_typeArguments_14_0= ruleJvmArgumentTypeReference ) ) )* otherlv_15= '>' )? ( ( ruleIdOrSuper ) ) ( ( ( ( '(' ) )=> (lv_explicitOperationCall_17_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) ) | ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* ) )? otherlv_22= ')' )? ( ( ( () '[' ) )=> (lv_memberCallArguments_23_0= ruleXClosure ) )? ) )* )
            // InternalTableDSL.g:6587:3: this_XPrimaryExpression_0= ruleXPrimaryExpression ( ( ( ( ( () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) )=> ( () (otherlv_2= '.' | ( (lv_explicitStatic_3_0= '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) ) ( (lv_value_6_0= ruleXAssignment ) ) ) | ( ( ( ( () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) ) ) )=> ( () (otherlv_8= '.' | ( (lv_nullSafe_9_0= '?.' ) ) | ( (lv_explicitStatic_10_0= '::' ) ) ) ) ) (otherlv_11= '<' ( (lv_typeArguments_12_0= ruleJvmArgumentTypeReference ) ) (otherlv_13= ',' ( (lv_typeArguments_14_0= ruleJvmArgumentTypeReference ) ) )* otherlv_15= '>' )? ( ( ruleIdOrSuper ) ) ( ( ( ( '(' ) )=> (lv_explicitOperationCall_17_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) ) | ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* ) )? otherlv_22= ')' )? ( ( ( () '[' ) )=> (lv_memberCallArguments_23_0= ruleXClosure ) )? ) )*
            {
            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getXMemberFeatureCallAccess().getXPrimaryExpressionParserRuleCall_0());
              		
            }
            pushFollow(FOLLOW_87);
            this_XPrimaryExpression_0=ruleXPrimaryExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current = this_XPrimaryExpression_0;
              			afterParserOrEnumRuleCall();
              		
            }
            // InternalTableDSL.g:6595:3: ( ( ( ( ( () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) )=> ( () (otherlv_2= '.' | ( (lv_explicitStatic_3_0= '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) ) ( (lv_value_6_0= ruleXAssignment ) ) ) | ( ( ( ( () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) ) ) )=> ( () (otherlv_8= '.' | ( (lv_nullSafe_9_0= '?.' ) ) | ( (lv_explicitStatic_10_0= '::' ) ) ) ) ) (otherlv_11= '<' ( (lv_typeArguments_12_0= ruleJvmArgumentTypeReference ) ) (otherlv_13= ',' ( (lv_typeArguments_14_0= ruleJvmArgumentTypeReference ) ) )* otherlv_15= '>' )? ( ( ruleIdOrSuper ) ) ( ( ( ( '(' ) )=> (lv_explicitOperationCall_17_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) ) | ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* ) )? otherlv_22= ')' )? ( ( ( () '[' ) )=> (lv_memberCallArguments_23_0= ruleXClosure ) )? ) )*
            loop91:
            do {
                int alt91=3;
                switch ( input.LA(1) ) {
                case 74:
                    {
                    int LA91_2 = input.LA(2);

                    if ( (synpred20_InternalTableDSL()) ) {
                        alt91=1;
                    }
                    else if ( (synpred21_InternalTableDSL()) ) {
                        alt91=2;
                    }


                    }
                    break;
                case 134:
                    {
                    int LA91_3 = input.LA(2);

                    if ( (synpred20_InternalTableDSL()) ) {
                        alt91=1;
                    }
                    else if ( (synpred21_InternalTableDSL()) ) {
                        alt91=2;
                    }


                    }
                    break;
                case 135:
                    {
                    int LA91_4 = input.LA(2);

                    if ( (synpred21_InternalTableDSL()) ) {
                        alt91=2;
                    }


                    }
                    break;

                }

                switch (alt91) {
            	case 1 :
            	    // InternalTableDSL.g:6596:4: ( ( ( ( () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) )=> ( () (otherlv_2= '.' | ( (lv_explicitStatic_3_0= '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) ) ( (lv_value_6_0= ruleXAssignment ) ) )
            	    {
            	    // InternalTableDSL.g:6596:4: ( ( ( ( () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) )=> ( () (otherlv_2= '.' | ( (lv_explicitStatic_3_0= '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) ) ( (lv_value_6_0= ruleXAssignment ) ) )
            	    // InternalTableDSL.g:6597:5: ( ( ( () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) )=> ( () (otherlv_2= '.' | ( (lv_explicitStatic_3_0= '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) ) ( (lv_value_6_0= ruleXAssignment ) )
            	    {
            	    // InternalTableDSL.g:6597:5: ( ( ( () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) )=> ( () (otherlv_2= '.' | ( (lv_explicitStatic_3_0= '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) )
            	    // InternalTableDSL.g:6598:6: ( ( () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) )=> ( () (otherlv_2= '.' | ( (lv_explicitStatic_3_0= '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign )
            	    {
            	    // InternalTableDSL.g:6618:6: ( () (otherlv_2= '.' | ( (lv_explicitStatic_3_0= '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign )
            	    // InternalTableDSL.g:6619:7: () (otherlv_2= '.' | ( (lv_explicitStatic_3_0= '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign
            	    {
            	    // InternalTableDSL.g:6619:7: ()
            	    // InternalTableDSL.g:6620:8: 
            	    {
            	    if ( state.backtracking==0 ) {

            	      								current = forceCreateModelElementAndSet(
            	      									grammarAccess.getXMemberFeatureCallAccess().getXAssignmentAssignableAction_1_0_0_0_0(),
            	      									current);
            	      							
            	    }

            	    }

            	    // InternalTableDSL.g:6626:7: (otherlv_2= '.' | ( (lv_explicitStatic_3_0= '::' ) ) )
            	    int alt83=2;
            	    int LA83_0 = input.LA(1);

            	    if ( (LA83_0==74) ) {
            	        alt83=1;
            	    }
            	    else if ( (LA83_0==134) ) {
            	        alt83=2;
            	    }
            	    else {
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        NoViableAltException nvae =
            	            new NoViableAltException("", 83, 0, input);

            	        throw nvae;
            	    }
            	    switch (alt83) {
            	        case 1 :
            	            // InternalTableDSL.g:6627:8: otherlv_2= '.'
            	            {
            	            otherlv_2=(Token)match(input,74,FOLLOW_88); if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              								newLeafNode(otherlv_2, grammarAccess.getXMemberFeatureCallAccess().getFullStopKeyword_1_0_0_0_1_0());
            	              							
            	            }

            	            }
            	            break;
            	        case 2 :
            	            // InternalTableDSL.g:6632:8: ( (lv_explicitStatic_3_0= '::' ) )
            	            {
            	            // InternalTableDSL.g:6632:8: ( (lv_explicitStatic_3_0= '::' ) )
            	            // InternalTableDSL.g:6633:9: (lv_explicitStatic_3_0= '::' )
            	            {
            	            // InternalTableDSL.g:6633:9: (lv_explicitStatic_3_0= '::' )
            	            // InternalTableDSL.g:6634:10: lv_explicitStatic_3_0= '::'
            	            {
            	            lv_explicitStatic_3_0=(Token)match(input,134,FOLLOW_88); if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              										newLeafNode(lv_explicitStatic_3_0, grammarAccess.getXMemberFeatureCallAccess().getExplicitStaticColonColonKeyword_1_0_0_0_1_1_0());
            	              									
            	            }
            	            if ( state.backtracking==0 ) {

            	              										if (current==null) {
            	              											current = createModelElement(grammarAccess.getXMemberFeatureCallRule());
            	              										}
            	              										setWithLastConsumed(current, "explicitStatic", true, "::");
            	              									
            	            }

            	            }


            	            }


            	            }
            	            break;

            	    }

            	    // InternalTableDSL.g:6647:7: ( ( ruleFeatureCallID ) )
            	    // InternalTableDSL.g:6648:8: ( ruleFeatureCallID )
            	    {
            	    // InternalTableDSL.g:6648:8: ( ruleFeatureCallID )
            	    // InternalTableDSL.g:6649:9: ruleFeatureCallID
            	    {
            	    if ( state.backtracking==0 ) {

            	      									if (current==null) {
            	      										current = createModelElement(grammarAccess.getXMemberFeatureCallRule());
            	      									}
            	      								
            	    }
            	    if ( state.backtracking==0 ) {

            	      									newCompositeNode(grammarAccess.getXMemberFeatureCallAccess().getFeatureJvmIdentifiableElementCrossReference_1_0_0_0_2_0());
            	      								
            	    }
            	    pushFollow(FOLLOW_64);
            	    ruleFeatureCallID();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      									afterParserOrEnumRuleCall();
            	      								
            	    }

            	    }


            	    }

            	    if ( state.backtracking==0 ) {

            	      							newCompositeNode(grammarAccess.getXMemberFeatureCallAccess().getOpSingleAssignParserRuleCall_1_0_0_0_3());
            	      						
            	    }
            	    pushFollow(FOLLOW_65);
            	    ruleOpSingleAssign();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      							afterParserOrEnumRuleCall();
            	      						
            	    }

            	    }


            	    }

            	    // InternalTableDSL.g:6672:5: ( (lv_value_6_0= ruleXAssignment ) )
            	    // InternalTableDSL.g:6673:6: (lv_value_6_0= ruleXAssignment )
            	    {
            	    // InternalTableDSL.g:6673:6: (lv_value_6_0= ruleXAssignment )
            	    // InternalTableDSL.g:6674:7: lv_value_6_0= ruleXAssignment
            	    {
            	    if ( state.backtracking==0 ) {

            	      							newCompositeNode(grammarAccess.getXMemberFeatureCallAccess().getValueXAssignmentParserRuleCall_1_0_1_0());
            	      						
            	    }
            	    pushFollow(FOLLOW_87);
            	    lv_value_6_0=ruleXAssignment();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      							if (current==null) {
            	      								current = createModelElementForParent(grammarAccess.getXMemberFeatureCallRule());
            	      							}
            	      							set(
            	      								current,
            	      								"value",
            	      								lv_value_6_0,
            	      								"org.eclipse.xtext.xbase.Xbase.XAssignment");
            	      							afterParserOrEnumRuleCall();
            	      						
            	    }

            	    }


            	    }


            	    }


            	    }
            	    break;
            	case 2 :
            	    // InternalTableDSL.g:6693:4: ( ( ( ( () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) ) ) )=> ( () (otherlv_8= '.' | ( (lv_nullSafe_9_0= '?.' ) ) | ( (lv_explicitStatic_10_0= '::' ) ) ) ) ) (otherlv_11= '<' ( (lv_typeArguments_12_0= ruleJvmArgumentTypeReference ) ) (otherlv_13= ',' ( (lv_typeArguments_14_0= ruleJvmArgumentTypeReference ) ) )* otherlv_15= '>' )? ( ( ruleIdOrSuper ) ) ( ( ( ( '(' ) )=> (lv_explicitOperationCall_17_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) ) | ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* ) )? otherlv_22= ')' )? ( ( ( () '[' ) )=> (lv_memberCallArguments_23_0= ruleXClosure ) )? )
            	    {
            	    // InternalTableDSL.g:6693:4: ( ( ( ( () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) ) ) )=> ( () (otherlv_8= '.' | ( (lv_nullSafe_9_0= '?.' ) ) | ( (lv_explicitStatic_10_0= '::' ) ) ) ) ) (otherlv_11= '<' ( (lv_typeArguments_12_0= ruleJvmArgumentTypeReference ) ) (otherlv_13= ',' ( (lv_typeArguments_14_0= ruleJvmArgumentTypeReference ) ) )* otherlv_15= '>' )? ( ( ruleIdOrSuper ) ) ( ( ( ( '(' ) )=> (lv_explicitOperationCall_17_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) ) | ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* ) )? otherlv_22= ')' )? ( ( ( () '[' ) )=> (lv_memberCallArguments_23_0= ruleXClosure ) )? )
            	    // InternalTableDSL.g:6694:5: ( ( ( () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) ) ) )=> ( () (otherlv_8= '.' | ( (lv_nullSafe_9_0= '?.' ) ) | ( (lv_explicitStatic_10_0= '::' ) ) ) ) ) (otherlv_11= '<' ( (lv_typeArguments_12_0= ruleJvmArgumentTypeReference ) ) (otherlv_13= ',' ( (lv_typeArguments_14_0= ruleJvmArgumentTypeReference ) ) )* otherlv_15= '>' )? ( ( ruleIdOrSuper ) ) ( ( ( ( '(' ) )=> (lv_explicitOperationCall_17_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) ) | ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* ) )? otherlv_22= ')' )? ( ( ( () '[' ) )=> (lv_memberCallArguments_23_0= ruleXClosure ) )?
            	    {
            	    // InternalTableDSL.g:6694:5: ( ( ( () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) ) ) )=> ( () (otherlv_8= '.' | ( (lv_nullSafe_9_0= '?.' ) ) | ( (lv_explicitStatic_10_0= '::' ) ) ) ) )
            	    // InternalTableDSL.g:6695:6: ( ( () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) ) ) )=> ( () (otherlv_8= '.' | ( (lv_nullSafe_9_0= '?.' ) ) | ( (lv_explicitStatic_10_0= '::' ) ) ) )
            	    {
            	    // InternalTableDSL.g:6715:6: ( () (otherlv_8= '.' | ( (lv_nullSafe_9_0= '?.' ) ) | ( (lv_explicitStatic_10_0= '::' ) ) ) )
            	    // InternalTableDSL.g:6716:7: () (otherlv_8= '.' | ( (lv_nullSafe_9_0= '?.' ) ) | ( (lv_explicitStatic_10_0= '::' ) ) )
            	    {
            	    // InternalTableDSL.g:6716:7: ()
            	    // InternalTableDSL.g:6717:8: 
            	    {
            	    if ( state.backtracking==0 ) {

            	      								current = forceCreateModelElementAndSet(
            	      									grammarAccess.getXMemberFeatureCallAccess().getXMemberFeatureCallMemberCallTargetAction_1_1_0_0_0(),
            	      									current);
            	      							
            	    }

            	    }

            	    // InternalTableDSL.g:6723:7: (otherlv_8= '.' | ( (lv_nullSafe_9_0= '?.' ) ) | ( (lv_explicitStatic_10_0= '::' ) ) )
            	    int alt84=3;
            	    switch ( input.LA(1) ) {
            	    case 74:
            	        {
            	        alt84=1;
            	        }
            	        break;
            	    case 135:
            	        {
            	        alt84=2;
            	        }
            	        break;
            	    case 134:
            	        {
            	        alt84=3;
            	        }
            	        break;
            	    default:
            	        if (state.backtracking>0) {state.failed=true; return current;}
            	        NoViableAltException nvae =
            	            new NoViableAltException("", 84, 0, input);

            	        throw nvae;
            	    }

            	    switch (alt84) {
            	        case 1 :
            	            // InternalTableDSL.g:6724:8: otherlv_8= '.'
            	            {
            	            otherlv_8=(Token)match(input,74,FOLLOW_89); if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              								newLeafNode(otherlv_8, grammarAccess.getXMemberFeatureCallAccess().getFullStopKeyword_1_1_0_0_1_0());
            	              							
            	            }

            	            }
            	            break;
            	        case 2 :
            	            // InternalTableDSL.g:6729:8: ( (lv_nullSafe_9_0= '?.' ) )
            	            {
            	            // InternalTableDSL.g:6729:8: ( (lv_nullSafe_9_0= '?.' ) )
            	            // InternalTableDSL.g:6730:9: (lv_nullSafe_9_0= '?.' )
            	            {
            	            // InternalTableDSL.g:6730:9: (lv_nullSafe_9_0= '?.' )
            	            // InternalTableDSL.g:6731:10: lv_nullSafe_9_0= '?.'
            	            {
            	            lv_nullSafe_9_0=(Token)match(input,135,FOLLOW_89); if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              										newLeafNode(lv_nullSafe_9_0, grammarAccess.getXMemberFeatureCallAccess().getNullSafeQuestionMarkFullStopKeyword_1_1_0_0_1_1_0());
            	              									
            	            }
            	            if ( state.backtracking==0 ) {

            	              										if (current==null) {
            	              											current = createModelElement(grammarAccess.getXMemberFeatureCallRule());
            	              										}
            	              										setWithLastConsumed(current, "nullSafe", true, "?.");
            	              									
            	            }

            	            }


            	            }


            	            }
            	            break;
            	        case 3 :
            	            // InternalTableDSL.g:6744:8: ( (lv_explicitStatic_10_0= '::' ) )
            	            {
            	            // InternalTableDSL.g:6744:8: ( (lv_explicitStatic_10_0= '::' ) )
            	            // InternalTableDSL.g:6745:9: (lv_explicitStatic_10_0= '::' )
            	            {
            	            // InternalTableDSL.g:6745:9: (lv_explicitStatic_10_0= '::' )
            	            // InternalTableDSL.g:6746:10: lv_explicitStatic_10_0= '::'
            	            {
            	            lv_explicitStatic_10_0=(Token)match(input,134,FOLLOW_89); if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              										newLeafNode(lv_explicitStatic_10_0, grammarAccess.getXMemberFeatureCallAccess().getExplicitStaticColonColonKeyword_1_1_0_0_1_2_0());
            	              									
            	            }
            	            if ( state.backtracking==0 ) {

            	              										if (current==null) {
            	              											current = createModelElement(grammarAccess.getXMemberFeatureCallRule());
            	              										}
            	              										setWithLastConsumed(current, "explicitStatic", true, "::");
            	              									
            	            }

            	            }


            	            }


            	            }
            	            break;

            	    }


            	    }


            	    }

            	    // InternalTableDSL.g:6761:5: (otherlv_11= '<' ( (lv_typeArguments_12_0= ruleJvmArgumentTypeReference ) ) (otherlv_13= ',' ( (lv_typeArguments_14_0= ruleJvmArgumentTypeReference ) ) )* otherlv_15= '>' )?
            	    int alt86=2;
            	    int LA86_0 = input.LA(1);

            	    if ( (LA86_0==112) ) {
            	        alt86=1;
            	    }
            	    switch (alt86) {
            	        case 1 :
            	            // InternalTableDSL.g:6762:6: otherlv_11= '<' ( (lv_typeArguments_12_0= ruleJvmArgumentTypeReference ) ) (otherlv_13= ',' ( (lv_typeArguments_14_0= ruleJvmArgumentTypeReference ) ) )* otherlv_15= '>'
            	            {
            	            otherlv_11=(Token)match(input,112,FOLLOW_90); if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              						newLeafNode(otherlv_11, grammarAccess.getXMemberFeatureCallAccess().getLessThanSignKeyword_1_1_1_0());
            	              					
            	            }
            	            // InternalTableDSL.g:6766:6: ( (lv_typeArguments_12_0= ruleJvmArgumentTypeReference ) )
            	            // InternalTableDSL.g:6767:7: (lv_typeArguments_12_0= ruleJvmArgumentTypeReference )
            	            {
            	            // InternalTableDSL.g:6767:7: (lv_typeArguments_12_0= ruleJvmArgumentTypeReference )
            	            // InternalTableDSL.g:6768:8: lv_typeArguments_12_0= ruleJvmArgumentTypeReference
            	            {
            	            if ( state.backtracking==0 ) {

            	              								newCompositeNode(grammarAccess.getXMemberFeatureCallAccess().getTypeArgumentsJvmArgumentTypeReferenceParserRuleCall_1_1_1_1_0());
            	              							
            	            }
            	            pushFollow(FOLLOW_91);
            	            lv_typeArguments_12_0=ruleJvmArgumentTypeReference();

            	            state._fsp--;
            	            if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              								if (current==null) {
            	              									current = createModelElementForParent(grammarAccess.getXMemberFeatureCallRule());
            	              								}
            	              								add(
            	              									current,
            	              									"typeArguments",
            	              									lv_typeArguments_12_0,
            	              									"org.eclipse.xtext.xbase.Xtype.JvmArgumentTypeReference");
            	              								afterParserOrEnumRuleCall();
            	              							
            	            }

            	            }


            	            }

            	            // InternalTableDSL.g:6785:6: (otherlv_13= ',' ( (lv_typeArguments_14_0= ruleJvmArgumentTypeReference ) ) )*
            	            loop85:
            	            do {
            	                int alt85=2;
            	                int LA85_0 = input.LA(1);

            	                if ( (LA85_0==101) ) {
            	                    alt85=1;
            	                }


            	                switch (alt85) {
            	            	case 1 :
            	            	    // InternalTableDSL.g:6786:7: otherlv_13= ',' ( (lv_typeArguments_14_0= ruleJvmArgumentTypeReference ) )
            	            	    {
            	            	    otherlv_13=(Token)match(input,101,FOLLOW_90); if (state.failed) return current;
            	            	    if ( state.backtracking==0 ) {

            	            	      							newLeafNode(otherlv_13, grammarAccess.getXMemberFeatureCallAccess().getCommaKeyword_1_1_1_2_0());
            	            	      						
            	            	    }
            	            	    // InternalTableDSL.g:6790:7: ( (lv_typeArguments_14_0= ruleJvmArgumentTypeReference ) )
            	            	    // InternalTableDSL.g:6791:8: (lv_typeArguments_14_0= ruleJvmArgumentTypeReference )
            	            	    {
            	            	    // InternalTableDSL.g:6791:8: (lv_typeArguments_14_0= ruleJvmArgumentTypeReference )
            	            	    // InternalTableDSL.g:6792:9: lv_typeArguments_14_0= ruleJvmArgumentTypeReference
            	            	    {
            	            	    if ( state.backtracking==0 ) {

            	            	      									newCompositeNode(grammarAccess.getXMemberFeatureCallAccess().getTypeArgumentsJvmArgumentTypeReferenceParserRuleCall_1_1_1_2_1_0());
            	            	      								
            	            	    }
            	            	    pushFollow(FOLLOW_91);
            	            	    lv_typeArguments_14_0=ruleJvmArgumentTypeReference();

            	            	    state._fsp--;
            	            	    if (state.failed) return current;
            	            	    if ( state.backtracking==0 ) {

            	            	      									if (current==null) {
            	            	      										current = createModelElementForParent(grammarAccess.getXMemberFeatureCallRule());
            	            	      									}
            	            	      									add(
            	            	      										current,
            	            	      										"typeArguments",
            	            	      										lv_typeArguments_14_0,
            	            	      										"org.eclipse.xtext.xbase.Xtype.JvmArgumentTypeReference");
            	            	      									afterParserOrEnumRuleCall();
            	            	      								
            	            	    }

            	            	    }


            	            	    }


            	            	    }
            	            	    break;

            	            	default :
            	            	    break loop85;
            	                }
            	            } while (true);

            	            otherlv_15=(Token)match(input,113,FOLLOW_89); if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              						newLeafNode(otherlv_15, grammarAccess.getXMemberFeatureCallAccess().getGreaterThanSignKeyword_1_1_1_3());
            	              					
            	            }

            	            }
            	            break;

            	    }

            	    // InternalTableDSL.g:6815:5: ( ( ruleIdOrSuper ) )
            	    // InternalTableDSL.g:6816:6: ( ruleIdOrSuper )
            	    {
            	    // InternalTableDSL.g:6816:6: ( ruleIdOrSuper )
            	    // InternalTableDSL.g:6817:7: ruleIdOrSuper
            	    {
            	    if ( state.backtracking==0 ) {

            	      							if (current==null) {
            	      								current = createModelElement(grammarAccess.getXMemberFeatureCallRule());
            	      							}
            	      						
            	    }
            	    if ( state.backtracking==0 ) {

            	      							newCompositeNode(grammarAccess.getXMemberFeatureCallAccess().getFeatureJvmIdentifiableElementCrossReference_1_1_2_0());
            	      						
            	    }
            	    pushFollow(FOLLOW_92);
            	    ruleIdOrSuper();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      							afterParserOrEnumRuleCall();
            	      						
            	    }

            	    }


            	    }

            	    // InternalTableDSL.g:6831:5: ( ( ( ( '(' ) )=> (lv_explicitOperationCall_17_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) ) | ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* ) )? otherlv_22= ')' )?
            	    int alt89=2;
            	    alt89 = dfa89.predict(input);
            	    switch (alt89) {
            	        case 1 :
            	            // InternalTableDSL.g:6832:6: ( ( ( '(' ) )=> (lv_explicitOperationCall_17_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) ) | ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* ) )? otherlv_22= ')'
            	            {
            	            // InternalTableDSL.g:6832:6: ( ( ( '(' ) )=> (lv_explicitOperationCall_17_0= '(' ) )
            	            // InternalTableDSL.g:6833:7: ( ( '(' ) )=> (lv_explicitOperationCall_17_0= '(' )
            	            {
            	            // InternalTableDSL.g:6837:7: (lv_explicitOperationCall_17_0= '(' )
            	            // InternalTableDSL.g:6838:8: lv_explicitOperationCall_17_0= '('
            	            {
            	            lv_explicitOperationCall_17_0=(Token)match(input,100,FOLLOW_93); if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              								newLeafNode(lv_explicitOperationCall_17_0, grammarAccess.getXMemberFeatureCallAccess().getExplicitOperationCallLeftParenthesisKeyword_1_1_3_0_0());
            	              							
            	            }
            	            if ( state.backtracking==0 ) {

            	              								if (current==null) {
            	              									current = createModelElement(grammarAccess.getXMemberFeatureCallRule());
            	              								}
            	              								setWithLastConsumed(current, "explicitOperationCall", true, "(");
            	              							
            	            }

            	            }


            	            }

            	            // InternalTableDSL.g:6850:6: ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) ) | ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* ) )?
            	            int alt88=3;
            	            alt88 = dfa88.predict(input);
            	            switch (alt88) {
            	                case 1 :
            	                    // InternalTableDSL.g:6851:7: ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) )
            	                    {
            	                    // InternalTableDSL.g:6851:7: ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) )
            	                    // InternalTableDSL.g:6852:8: ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure )
            	                    {
            	                    // InternalTableDSL.g:6877:8: (lv_memberCallArguments_18_0= ruleXShortClosure )
            	                    // InternalTableDSL.g:6878:9: lv_memberCallArguments_18_0= ruleXShortClosure
            	                    {
            	                    if ( state.backtracking==0 ) {

            	                      									newCompositeNode(grammarAccess.getXMemberFeatureCallAccess().getMemberCallArgumentsXShortClosureParserRuleCall_1_1_3_1_0_0());
            	                      								
            	                    }
            	                    pushFollow(FOLLOW_63);
            	                    lv_memberCallArguments_18_0=ruleXShortClosure();

            	                    state._fsp--;
            	                    if (state.failed) return current;
            	                    if ( state.backtracking==0 ) {

            	                      									if (current==null) {
            	                      										current = createModelElementForParent(grammarAccess.getXMemberFeatureCallRule());
            	                      									}
            	                      									add(
            	                      										current,
            	                      										"memberCallArguments",
            	                      										lv_memberCallArguments_18_0,
            	                      										"org.eclipse.xtext.xbase.Xbase.XShortClosure");
            	                      									afterParserOrEnumRuleCall();
            	                      								
            	                    }

            	                    }


            	                    }


            	                    }
            	                    break;
            	                case 2 :
            	                    // InternalTableDSL.g:6896:7: ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* )
            	                    {
            	                    // InternalTableDSL.g:6896:7: ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* )
            	                    // InternalTableDSL.g:6897:8: ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )*
            	                    {
            	                    // InternalTableDSL.g:6897:8: ( (lv_memberCallArguments_19_0= ruleXExpression ) )
            	                    // InternalTableDSL.g:6898:9: (lv_memberCallArguments_19_0= ruleXExpression )
            	                    {
            	                    // InternalTableDSL.g:6898:9: (lv_memberCallArguments_19_0= ruleXExpression )
            	                    // InternalTableDSL.g:6899:10: lv_memberCallArguments_19_0= ruleXExpression
            	                    {
            	                    if ( state.backtracking==0 ) {

            	                      										newCompositeNode(grammarAccess.getXMemberFeatureCallAccess().getMemberCallArgumentsXExpressionParserRuleCall_1_1_3_1_1_0_0());
            	                      									
            	                    }
            	                    pushFollow(FOLLOW_62);
            	                    lv_memberCallArguments_19_0=ruleXExpression();

            	                    state._fsp--;
            	                    if (state.failed) return current;
            	                    if ( state.backtracking==0 ) {

            	                      										if (current==null) {
            	                      											current = createModelElementForParent(grammarAccess.getXMemberFeatureCallRule());
            	                      										}
            	                      										add(
            	                      											current,
            	                      											"memberCallArguments",
            	                      											lv_memberCallArguments_19_0,
            	                      											"org.eclipse.xtext.xbase.Xbase.XExpression");
            	                      										afterParserOrEnumRuleCall();
            	                      									
            	                    }

            	                    }


            	                    }

            	                    // InternalTableDSL.g:6916:8: (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )*
            	                    loop87:
            	                    do {
            	                        int alt87=2;
            	                        int LA87_0 = input.LA(1);

            	                        if ( (LA87_0==101) ) {
            	                            alt87=1;
            	                        }


            	                        switch (alt87) {
            	                    	case 1 :
            	                    	    // InternalTableDSL.g:6917:9: otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) )
            	                    	    {
            	                    	    otherlv_20=(Token)match(input,101,FOLLOW_65); if (state.failed) return current;
            	                    	    if ( state.backtracking==0 ) {

            	                    	      									newLeafNode(otherlv_20, grammarAccess.getXMemberFeatureCallAccess().getCommaKeyword_1_1_3_1_1_1_0());
            	                    	      								
            	                    	    }
            	                    	    // InternalTableDSL.g:6921:9: ( (lv_memberCallArguments_21_0= ruleXExpression ) )
            	                    	    // InternalTableDSL.g:6922:10: (lv_memberCallArguments_21_0= ruleXExpression )
            	                    	    {
            	                    	    // InternalTableDSL.g:6922:10: (lv_memberCallArguments_21_0= ruleXExpression )
            	                    	    // InternalTableDSL.g:6923:11: lv_memberCallArguments_21_0= ruleXExpression
            	                    	    {
            	                    	    if ( state.backtracking==0 ) {

            	                    	      											newCompositeNode(grammarAccess.getXMemberFeatureCallAccess().getMemberCallArgumentsXExpressionParserRuleCall_1_1_3_1_1_1_1_0());
            	                    	      										
            	                    	    }
            	                    	    pushFollow(FOLLOW_62);
            	                    	    lv_memberCallArguments_21_0=ruleXExpression();

            	                    	    state._fsp--;
            	                    	    if (state.failed) return current;
            	                    	    if ( state.backtracking==0 ) {

            	                    	      											if (current==null) {
            	                    	      												current = createModelElementForParent(grammarAccess.getXMemberFeatureCallRule());
            	                    	      											}
            	                    	      											add(
            	                    	      												current,
            	                    	      												"memberCallArguments",
            	                    	      												lv_memberCallArguments_21_0,
            	                    	      												"org.eclipse.xtext.xbase.Xbase.XExpression");
            	                    	      											afterParserOrEnumRuleCall();
            	                    	      										
            	                    	    }

            	                    	    }


            	                    	    }


            	                    	    }
            	                    	    break;

            	                    	default :
            	                    	    break loop87;
            	                        }
            	                    } while (true);


            	                    }


            	                    }
            	                    break;

            	            }

            	            otherlv_22=(Token)match(input,102,FOLLOW_94); if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              						newLeafNode(otherlv_22, grammarAccess.getXMemberFeatureCallAccess().getRightParenthesisKeyword_1_1_3_2());
            	              					
            	            }

            	            }
            	            break;

            	    }

            	    // InternalTableDSL.g:6948:5: ( ( ( () '[' ) )=> (lv_memberCallArguments_23_0= ruleXClosure ) )?
            	    int alt90=2;
            	    alt90 = dfa90.predict(input);
            	    switch (alt90) {
            	        case 1 :
            	            // InternalTableDSL.g:6949:6: ( ( () '[' ) )=> (lv_memberCallArguments_23_0= ruleXClosure )
            	            {
            	            // InternalTableDSL.g:6955:6: (lv_memberCallArguments_23_0= ruleXClosure )
            	            // InternalTableDSL.g:6956:7: lv_memberCallArguments_23_0= ruleXClosure
            	            {
            	            if ( state.backtracking==0 ) {

            	              							newCompositeNode(grammarAccess.getXMemberFeatureCallAccess().getMemberCallArgumentsXClosureParserRuleCall_1_1_4_0());
            	              						
            	            }
            	            pushFollow(FOLLOW_87);
            	            lv_memberCallArguments_23_0=ruleXClosure();

            	            state._fsp--;
            	            if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              							if (current==null) {
            	              								current = createModelElementForParent(grammarAccess.getXMemberFeatureCallRule());
            	              							}
            	              							add(
            	              								current,
            	              								"memberCallArguments",
            	              								lv_memberCallArguments_23_0,
            	              								"org.eclipse.xtext.xbase.Xbase.XClosure");
            	              							afterParserOrEnumRuleCall();
            	              						
            	            }

            	            }


            	            }
            	            break;

            	    }


            	    }


            	    }
            	    break;

            	default :
            	    break loop91;
                }
            } while (true);


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXMemberFeatureCall"


    // $ANTLR start "entryRuleXPrimaryExpression"
    // InternalTableDSL.g:6979:1: entryRuleXPrimaryExpression returns [EObject current=null] : iv_ruleXPrimaryExpression= ruleXPrimaryExpression EOF ;
    public final EObject entryRuleXPrimaryExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXPrimaryExpression = null;


        try {
            // InternalTableDSL.g:6979:59: (iv_ruleXPrimaryExpression= ruleXPrimaryExpression EOF )
            // InternalTableDSL.g:6980:2: iv_ruleXPrimaryExpression= ruleXPrimaryExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXPrimaryExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXPrimaryExpression=ruleXPrimaryExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXPrimaryExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXPrimaryExpression"


    // $ANTLR start "ruleXPrimaryExpression"
    // InternalTableDSL.g:6986:1: ruleXPrimaryExpression returns [EObject current=null] : (this_XConstructorCall_0= ruleXConstructorCall | this_XBlockExpression_1= ruleXBlockExpression | this_XSwitchExpression_2= ruleXSwitchExpression | ( ( ( () 'synchronized' '(' ) )=>this_XSynchronizedExpression_3= ruleXSynchronizedExpression ) | this_XFeatureCall_4= ruleXFeatureCall | this_XLiteral_5= ruleXLiteral | this_XIfExpression_6= ruleXIfExpression | ( ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=>this_XForLoopExpression_7= ruleXForLoopExpression ) | this_XBasicForLoopExpression_8= ruleXBasicForLoopExpression | this_XWhileExpression_9= ruleXWhileExpression | this_XDoWhileExpression_10= ruleXDoWhileExpression | this_XThrowExpression_11= ruleXThrowExpression | this_XReturnExpression_12= ruleXReturnExpression | this_XTryCatchFinallyExpression_13= ruleXTryCatchFinallyExpression | this_XParenthesizedExpression_14= ruleXParenthesizedExpression ) ;
    public final EObject ruleXPrimaryExpression() throws RecognitionException {
        EObject current = null;

        EObject this_XConstructorCall_0 = null;

        EObject this_XBlockExpression_1 = null;

        EObject this_XSwitchExpression_2 = null;

        EObject this_XSynchronizedExpression_3 = null;

        EObject this_XFeatureCall_4 = null;

        EObject this_XLiteral_5 = null;

        EObject this_XIfExpression_6 = null;

        EObject this_XForLoopExpression_7 = null;

        EObject this_XBasicForLoopExpression_8 = null;

        EObject this_XWhileExpression_9 = null;

        EObject this_XDoWhileExpression_10 = null;

        EObject this_XThrowExpression_11 = null;

        EObject this_XReturnExpression_12 = null;

        EObject this_XTryCatchFinallyExpression_13 = null;

        EObject this_XParenthesizedExpression_14 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:6992:2: ( (this_XConstructorCall_0= ruleXConstructorCall | this_XBlockExpression_1= ruleXBlockExpression | this_XSwitchExpression_2= ruleXSwitchExpression | ( ( ( () 'synchronized' '(' ) )=>this_XSynchronizedExpression_3= ruleXSynchronizedExpression ) | this_XFeatureCall_4= ruleXFeatureCall | this_XLiteral_5= ruleXLiteral | this_XIfExpression_6= ruleXIfExpression | ( ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=>this_XForLoopExpression_7= ruleXForLoopExpression ) | this_XBasicForLoopExpression_8= ruleXBasicForLoopExpression | this_XWhileExpression_9= ruleXWhileExpression | this_XDoWhileExpression_10= ruleXDoWhileExpression | this_XThrowExpression_11= ruleXThrowExpression | this_XReturnExpression_12= ruleXReturnExpression | this_XTryCatchFinallyExpression_13= ruleXTryCatchFinallyExpression | this_XParenthesizedExpression_14= ruleXParenthesizedExpression ) )
            // InternalTableDSL.g:6993:2: (this_XConstructorCall_0= ruleXConstructorCall | this_XBlockExpression_1= ruleXBlockExpression | this_XSwitchExpression_2= ruleXSwitchExpression | ( ( ( () 'synchronized' '(' ) )=>this_XSynchronizedExpression_3= ruleXSynchronizedExpression ) | this_XFeatureCall_4= ruleXFeatureCall | this_XLiteral_5= ruleXLiteral | this_XIfExpression_6= ruleXIfExpression | ( ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=>this_XForLoopExpression_7= ruleXForLoopExpression ) | this_XBasicForLoopExpression_8= ruleXBasicForLoopExpression | this_XWhileExpression_9= ruleXWhileExpression | this_XDoWhileExpression_10= ruleXDoWhileExpression | this_XThrowExpression_11= ruleXThrowExpression | this_XReturnExpression_12= ruleXReturnExpression | this_XTryCatchFinallyExpression_13= ruleXTryCatchFinallyExpression | this_XParenthesizedExpression_14= ruleXParenthesizedExpression )
            {
            // InternalTableDSL.g:6993:2: (this_XConstructorCall_0= ruleXConstructorCall | this_XBlockExpression_1= ruleXBlockExpression | this_XSwitchExpression_2= ruleXSwitchExpression | ( ( ( () 'synchronized' '(' ) )=>this_XSynchronizedExpression_3= ruleXSynchronizedExpression ) | this_XFeatureCall_4= ruleXFeatureCall | this_XLiteral_5= ruleXLiteral | this_XIfExpression_6= ruleXIfExpression | ( ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=>this_XForLoopExpression_7= ruleXForLoopExpression ) | this_XBasicForLoopExpression_8= ruleXBasicForLoopExpression | this_XWhileExpression_9= ruleXWhileExpression | this_XDoWhileExpression_10= ruleXDoWhileExpression | this_XThrowExpression_11= ruleXThrowExpression | this_XReturnExpression_12= ruleXReturnExpression | this_XTryCatchFinallyExpression_13= ruleXTryCatchFinallyExpression | this_XParenthesizedExpression_14= ruleXParenthesizedExpression )
            int alt92=15;
            alt92 = dfa92.predict(input);
            switch (alt92) {
                case 1 :
                    // InternalTableDSL.g:6994:3: this_XConstructorCall_0= ruleXConstructorCall
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXConstructorCallParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XConstructorCall_0=ruleXConstructorCall();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XConstructorCall_0;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:7003:3: this_XBlockExpression_1= ruleXBlockExpression
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXBlockExpressionParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XBlockExpression_1=ruleXBlockExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XBlockExpression_1;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:7012:3: this_XSwitchExpression_2= ruleXSwitchExpression
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXSwitchExpressionParserRuleCall_2());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XSwitchExpression_2=ruleXSwitchExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XSwitchExpression_2;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:7021:3: ( ( ( () 'synchronized' '(' ) )=>this_XSynchronizedExpression_3= ruleXSynchronizedExpression )
                    {
                    // InternalTableDSL.g:7021:3: ( ( ( () 'synchronized' '(' ) )=>this_XSynchronizedExpression_3= ruleXSynchronizedExpression )
                    // InternalTableDSL.g:7022:4: ( ( () 'synchronized' '(' ) )=>this_XSynchronizedExpression_3= ruleXSynchronizedExpression
                    {
                    if ( state.backtracking==0 ) {

                      				newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXSynchronizedExpressionParserRuleCall_3());
                      			
                    }
                    pushFollow(FOLLOW_2);
                    this_XSynchronizedExpression_3=ruleXSynchronizedExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = this_XSynchronizedExpression_3;
                      				afterParserOrEnumRuleCall();
                      			
                    }

                    }


                    }
                    break;
                case 5 :
                    // InternalTableDSL.g:7039:3: this_XFeatureCall_4= ruleXFeatureCall
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXFeatureCallParserRuleCall_4());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XFeatureCall_4=ruleXFeatureCall();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XFeatureCall_4;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 6 :
                    // InternalTableDSL.g:7048:3: this_XLiteral_5= ruleXLiteral
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXLiteralParserRuleCall_5());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XLiteral_5=ruleXLiteral();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XLiteral_5;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 7 :
                    // InternalTableDSL.g:7057:3: this_XIfExpression_6= ruleXIfExpression
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXIfExpressionParserRuleCall_6());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XIfExpression_6=ruleXIfExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XIfExpression_6;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 8 :
                    // InternalTableDSL.g:7066:3: ( ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=>this_XForLoopExpression_7= ruleXForLoopExpression )
                    {
                    // InternalTableDSL.g:7066:3: ( ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=>this_XForLoopExpression_7= ruleXForLoopExpression )
                    // InternalTableDSL.g:7067:4: ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=>this_XForLoopExpression_7= ruleXForLoopExpression
                    {
                    if ( state.backtracking==0 ) {

                      				newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXForLoopExpressionParserRuleCall_7());
                      			
                    }
                    pushFollow(FOLLOW_2);
                    this_XForLoopExpression_7=ruleXForLoopExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = this_XForLoopExpression_7;
                      				afterParserOrEnumRuleCall();
                      			
                    }

                    }


                    }
                    break;
                case 9 :
                    // InternalTableDSL.g:7090:3: this_XBasicForLoopExpression_8= ruleXBasicForLoopExpression
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXBasicForLoopExpressionParserRuleCall_8());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XBasicForLoopExpression_8=ruleXBasicForLoopExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XBasicForLoopExpression_8;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 10 :
                    // InternalTableDSL.g:7099:3: this_XWhileExpression_9= ruleXWhileExpression
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXWhileExpressionParserRuleCall_9());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XWhileExpression_9=ruleXWhileExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XWhileExpression_9;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 11 :
                    // InternalTableDSL.g:7108:3: this_XDoWhileExpression_10= ruleXDoWhileExpression
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXDoWhileExpressionParserRuleCall_10());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XDoWhileExpression_10=ruleXDoWhileExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XDoWhileExpression_10;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 12 :
                    // InternalTableDSL.g:7117:3: this_XThrowExpression_11= ruleXThrowExpression
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXThrowExpressionParserRuleCall_11());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XThrowExpression_11=ruleXThrowExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XThrowExpression_11;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 13 :
                    // InternalTableDSL.g:7126:3: this_XReturnExpression_12= ruleXReturnExpression
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXReturnExpressionParserRuleCall_12());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XReturnExpression_12=ruleXReturnExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XReturnExpression_12;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 14 :
                    // InternalTableDSL.g:7135:3: this_XTryCatchFinallyExpression_13= ruleXTryCatchFinallyExpression
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXTryCatchFinallyExpressionParserRuleCall_13());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XTryCatchFinallyExpression_13=ruleXTryCatchFinallyExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XTryCatchFinallyExpression_13;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 15 :
                    // InternalTableDSL.g:7144:3: this_XParenthesizedExpression_14= ruleXParenthesizedExpression
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXPrimaryExpressionAccess().getXParenthesizedExpressionParserRuleCall_14());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XParenthesizedExpression_14=ruleXParenthesizedExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XParenthesizedExpression_14;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXPrimaryExpression"


    // $ANTLR start "entryRuleXLiteral"
    // InternalTableDSL.g:7156:1: entryRuleXLiteral returns [EObject current=null] : iv_ruleXLiteral= ruleXLiteral EOF ;
    public final EObject entryRuleXLiteral() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXLiteral = null;


        try {
            // InternalTableDSL.g:7156:49: (iv_ruleXLiteral= ruleXLiteral EOF )
            // InternalTableDSL.g:7157:2: iv_ruleXLiteral= ruleXLiteral EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXLiteralRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXLiteral=ruleXLiteral();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXLiteral; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXLiteral"


    // $ANTLR start "ruleXLiteral"
    // InternalTableDSL.g:7163:1: ruleXLiteral returns [EObject current=null] : (this_XCollectionLiteral_0= ruleXCollectionLiteral | ( ( ( () '[' ) )=>this_XClosure_1= ruleXClosure ) | this_XBooleanLiteral_2= ruleXBooleanLiteral | this_XNumberLiteral_3= ruleXNumberLiteral | this_XNullLiteral_4= ruleXNullLiteral | this_XStringLiteral_5= ruleXStringLiteral | this_XTypeLiteral_6= ruleXTypeLiteral ) ;
    public final EObject ruleXLiteral() throws RecognitionException {
        EObject current = null;

        EObject this_XCollectionLiteral_0 = null;

        EObject this_XClosure_1 = null;

        EObject this_XBooleanLiteral_2 = null;

        EObject this_XNumberLiteral_3 = null;

        EObject this_XNullLiteral_4 = null;

        EObject this_XStringLiteral_5 = null;

        EObject this_XTypeLiteral_6 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:7169:2: ( (this_XCollectionLiteral_0= ruleXCollectionLiteral | ( ( ( () '[' ) )=>this_XClosure_1= ruleXClosure ) | this_XBooleanLiteral_2= ruleXBooleanLiteral | this_XNumberLiteral_3= ruleXNumberLiteral | this_XNullLiteral_4= ruleXNullLiteral | this_XStringLiteral_5= ruleXStringLiteral | this_XTypeLiteral_6= ruleXTypeLiteral ) )
            // InternalTableDSL.g:7170:2: (this_XCollectionLiteral_0= ruleXCollectionLiteral | ( ( ( () '[' ) )=>this_XClosure_1= ruleXClosure ) | this_XBooleanLiteral_2= ruleXBooleanLiteral | this_XNumberLiteral_3= ruleXNumberLiteral | this_XNullLiteral_4= ruleXNullLiteral | this_XStringLiteral_5= ruleXStringLiteral | this_XTypeLiteral_6= ruleXTypeLiteral )
            {
            // InternalTableDSL.g:7170:2: (this_XCollectionLiteral_0= ruleXCollectionLiteral | ( ( ( () '[' ) )=>this_XClosure_1= ruleXClosure ) | this_XBooleanLiteral_2= ruleXBooleanLiteral | this_XNumberLiteral_3= ruleXNumberLiteral | this_XNullLiteral_4= ruleXNullLiteral | this_XStringLiteral_5= ruleXStringLiteral | this_XTypeLiteral_6= ruleXTypeLiteral )
            int alt93=7;
            int LA93_0 = input.LA(1);

            if ( (LA93_0==104) ) {
                alt93=1;
            }
            else if ( (LA93_0==105) && (synpred27_InternalTableDSL())) {
                alt93=2;
            }
            else if ( ((LA93_0>=151 && LA93_0<=152)) ) {
                alt93=3;
            }
            else if ( ((LA93_0>=RULE_INT && LA93_0<=RULE_DECIMAL)) ) {
                alt93=4;
            }
            else if ( (LA93_0==153) ) {
                alt93=5;
            }
            else if ( (LA93_0==RULE_STRING) ) {
                alt93=6;
            }
            else if ( (LA93_0==154) ) {
                alt93=7;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 93, 0, input);

                throw nvae;
            }
            switch (alt93) {
                case 1 :
                    // InternalTableDSL.g:7171:3: this_XCollectionLiteral_0= ruleXCollectionLiteral
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXLiteralAccess().getXCollectionLiteralParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XCollectionLiteral_0=ruleXCollectionLiteral();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XCollectionLiteral_0;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:7180:3: ( ( ( () '[' ) )=>this_XClosure_1= ruleXClosure )
                    {
                    // InternalTableDSL.g:7180:3: ( ( ( () '[' ) )=>this_XClosure_1= ruleXClosure )
                    // InternalTableDSL.g:7181:4: ( ( () '[' ) )=>this_XClosure_1= ruleXClosure
                    {
                    if ( state.backtracking==0 ) {

                      				newCompositeNode(grammarAccess.getXLiteralAccess().getXClosureParserRuleCall_1());
                      			
                    }
                    pushFollow(FOLLOW_2);
                    this_XClosure_1=ruleXClosure();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = this_XClosure_1;
                      				afterParserOrEnumRuleCall();
                      			
                    }

                    }


                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:7197:3: this_XBooleanLiteral_2= ruleXBooleanLiteral
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXLiteralAccess().getXBooleanLiteralParserRuleCall_2());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XBooleanLiteral_2=ruleXBooleanLiteral();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XBooleanLiteral_2;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:7206:3: this_XNumberLiteral_3= ruleXNumberLiteral
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXLiteralAccess().getXNumberLiteralParserRuleCall_3());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XNumberLiteral_3=ruleXNumberLiteral();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XNumberLiteral_3;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 5 :
                    // InternalTableDSL.g:7215:3: this_XNullLiteral_4= ruleXNullLiteral
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXLiteralAccess().getXNullLiteralParserRuleCall_4());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XNullLiteral_4=ruleXNullLiteral();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XNullLiteral_4;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 6 :
                    // InternalTableDSL.g:7224:3: this_XStringLiteral_5= ruleXStringLiteral
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXLiteralAccess().getXStringLiteralParserRuleCall_5());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XStringLiteral_5=ruleXStringLiteral();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XStringLiteral_5;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 7 :
                    // InternalTableDSL.g:7233:3: this_XTypeLiteral_6= ruleXTypeLiteral
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXLiteralAccess().getXTypeLiteralParserRuleCall_6());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XTypeLiteral_6=ruleXTypeLiteral();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XTypeLiteral_6;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXLiteral"


    // $ANTLR start "entryRuleXCollectionLiteral"
    // InternalTableDSL.g:7245:1: entryRuleXCollectionLiteral returns [EObject current=null] : iv_ruleXCollectionLiteral= ruleXCollectionLiteral EOF ;
    public final EObject entryRuleXCollectionLiteral() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXCollectionLiteral = null;


        try {
            // InternalTableDSL.g:7245:59: (iv_ruleXCollectionLiteral= ruleXCollectionLiteral EOF )
            // InternalTableDSL.g:7246:2: iv_ruleXCollectionLiteral= ruleXCollectionLiteral EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXCollectionLiteralRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXCollectionLiteral=ruleXCollectionLiteral();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXCollectionLiteral; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXCollectionLiteral"


    // $ANTLR start "ruleXCollectionLiteral"
    // InternalTableDSL.g:7252:1: ruleXCollectionLiteral returns [EObject current=null] : (this_XSetLiteral_0= ruleXSetLiteral | this_XListLiteral_1= ruleXListLiteral ) ;
    public final EObject ruleXCollectionLiteral() throws RecognitionException {
        EObject current = null;

        EObject this_XSetLiteral_0 = null;

        EObject this_XListLiteral_1 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:7258:2: ( (this_XSetLiteral_0= ruleXSetLiteral | this_XListLiteral_1= ruleXListLiteral ) )
            // InternalTableDSL.g:7259:2: (this_XSetLiteral_0= ruleXSetLiteral | this_XListLiteral_1= ruleXListLiteral )
            {
            // InternalTableDSL.g:7259:2: (this_XSetLiteral_0= ruleXSetLiteral | this_XListLiteral_1= ruleXListLiteral )
            int alt94=2;
            int LA94_0 = input.LA(1);

            if ( (LA94_0==104) ) {
                int LA94_1 = input.LA(2);

                if ( (LA94_1==105) ) {
                    alt94=2;
                }
                else if ( (LA94_1==16) ) {
                    alt94=1;
                }
                else {
                    if (state.backtracking>0) {state.failed=true; return current;}
                    NoViableAltException nvae =
                        new NoViableAltException("", 94, 1, input);

                    throw nvae;
                }
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 94, 0, input);

                throw nvae;
            }
            switch (alt94) {
                case 1 :
                    // InternalTableDSL.g:7260:3: this_XSetLiteral_0= ruleXSetLiteral
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXCollectionLiteralAccess().getXSetLiteralParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XSetLiteral_0=ruleXSetLiteral();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XSetLiteral_0;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:7269:3: this_XListLiteral_1= ruleXListLiteral
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXCollectionLiteralAccess().getXListLiteralParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XListLiteral_1=ruleXListLiteral();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XListLiteral_1;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXCollectionLiteral"


    // $ANTLR start "entryRuleXSetLiteral"
    // InternalTableDSL.g:7281:1: entryRuleXSetLiteral returns [EObject current=null] : iv_ruleXSetLiteral= ruleXSetLiteral EOF ;
    public final EObject entryRuleXSetLiteral() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXSetLiteral = null;


        try {
            // InternalTableDSL.g:7281:52: (iv_ruleXSetLiteral= ruleXSetLiteral EOF )
            // InternalTableDSL.g:7282:2: iv_ruleXSetLiteral= ruleXSetLiteral EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXSetLiteralRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXSetLiteral=ruleXSetLiteral();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXSetLiteral; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXSetLiteral"


    // $ANTLR start "ruleXSetLiteral"
    // InternalTableDSL.g:7288:1: ruleXSetLiteral returns [EObject current=null] : ( () otherlv_1= '#' otherlv_2= '{' ( ( (lv_elements_3_0= ruleXExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )* )? otherlv_6= '}' ) ;
    public final EObject ruleXSetLiteral() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token otherlv_4=null;
        Token otherlv_6=null;
        EObject lv_elements_3_0 = null;

        EObject lv_elements_5_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:7294:2: ( ( () otherlv_1= '#' otherlv_2= '{' ( ( (lv_elements_3_0= ruleXExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )* )? otherlv_6= '}' ) )
            // InternalTableDSL.g:7295:2: ( () otherlv_1= '#' otherlv_2= '{' ( ( (lv_elements_3_0= ruleXExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )* )? otherlv_6= '}' )
            {
            // InternalTableDSL.g:7295:2: ( () otherlv_1= '#' otherlv_2= '{' ( ( (lv_elements_3_0= ruleXExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )* )? otherlv_6= '}' )
            // InternalTableDSL.g:7296:3: () otherlv_1= '#' otherlv_2= '{' ( ( (lv_elements_3_0= ruleXExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )* )? otherlv_6= '}'
            {
            // InternalTableDSL.g:7296:3: ()
            // InternalTableDSL.g:7297:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXSetLiteralAccess().getXSetLiteralAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,104,FOLLOW_21); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXSetLiteralAccess().getNumberSignKeyword_1());
              		
            }
            otherlv_2=(Token)match(input,16,FOLLOW_95); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_2, grammarAccess.getXSetLiteralAccess().getLeftCurlyBracketKeyword_2());
              		
            }
            // InternalTableDSL.g:7311:3: ( ( (lv_elements_3_0= ruleXExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )* )?
            int alt96=2;
            int LA96_0 = input.LA(1);

            if ( ((LA96_0>=RULE_ID && LA96_0<=RULE_STRING)||(LA96_0>=RULE_INT && LA96_0<=RULE_DECIMAL)||LA96_0==16||(LA96_0>=91 && LA96_0<=95)||LA96_0==100||(LA96_0>=104 && LA96_0<=105)||LA96_0==112||LA96_0==131||LA96_0==137||LA96_0==139||(LA96_0>=143 && LA96_0<=145)||(LA96_0>=148 && LA96_0<=157)||LA96_0==159) ) {
                alt96=1;
            }
            switch (alt96) {
                case 1 :
                    // InternalTableDSL.g:7312:4: ( (lv_elements_3_0= ruleXExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )*
                    {
                    // InternalTableDSL.g:7312:4: ( (lv_elements_3_0= ruleXExpression ) )
                    // InternalTableDSL.g:7313:5: (lv_elements_3_0= ruleXExpression )
                    {
                    // InternalTableDSL.g:7313:5: (lv_elements_3_0= ruleXExpression )
                    // InternalTableDSL.g:7314:6: lv_elements_3_0= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXSetLiteralAccess().getElementsXExpressionParserRuleCall_3_0_0());
                      					
                    }
                    pushFollow(FOLLOW_96);
                    lv_elements_3_0=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getXSetLiteralRule());
                      						}
                      						add(
                      							current,
                      							"elements",
                      							lv_elements_3_0,
                      							"org.eclipse.xtext.xbase.Xbase.XExpression");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }

                    // InternalTableDSL.g:7331:4: (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )*
                    loop95:
                    do {
                        int alt95=2;
                        int LA95_0 = input.LA(1);

                        if ( (LA95_0==101) ) {
                            alt95=1;
                        }


                        switch (alt95) {
                    	case 1 :
                    	    // InternalTableDSL.g:7332:5: otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) )
                    	    {
                    	    otherlv_4=(Token)match(input,101,FOLLOW_65); if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      					newLeafNode(otherlv_4, grammarAccess.getXSetLiteralAccess().getCommaKeyword_3_1_0());
                    	      				
                    	    }
                    	    // InternalTableDSL.g:7336:5: ( (lv_elements_5_0= ruleXExpression ) )
                    	    // InternalTableDSL.g:7337:6: (lv_elements_5_0= ruleXExpression )
                    	    {
                    	    // InternalTableDSL.g:7337:6: (lv_elements_5_0= ruleXExpression )
                    	    // InternalTableDSL.g:7338:7: lv_elements_5_0= ruleXExpression
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      							newCompositeNode(grammarAccess.getXSetLiteralAccess().getElementsXExpressionParserRuleCall_3_1_1_0());
                    	      						
                    	    }
                    	    pushFollow(FOLLOW_96);
                    	    lv_elements_5_0=ruleXExpression();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      							if (current==null) {
                    	      								current = createModelElementForParent(grammarAccess.getXSetLiteralRule());
                    	      							}
                    	      							add(
                    	      								current,
                    	      								"elements",
                    	      								lv_elements_5_0,
                    	      								"org.eclipse.xtext.xbase.Xbase.XExpression");
                    	      							afterParserOrEnumRuleCall();
                    	      						
                    	    }

                    	    }


                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop95;
                        }
                    } while (true);


                    }
                    break;

            }

            otherlv_6=(Token)match(input,17,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_6, grammarAccess.getXSetLiteralAccess().getRightCurlyBracketKeyword_4());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXSetLiteral"


    // $ANTLR start "entryRuleXListLiteral"
    // InternalTableDSL.g:7365:1: entryRuleXListLiteral returns [EObject current=null] : iv_ruleXListLiteral= ruleXListLiteral EOF ;
    public final EObject entryRuleXListLiteral() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXListLiteral = null;


        try {
            // InternalTableDSL.g:7365:53: (iv_ruleXListLiteral= ruleXListLiteral EOF )
            // InternalTableDSL.g:7366:2: iv_ruleXListLiteral= ruleXListLiteral EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXListLiteralRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXListLiteral=ruleXListLiteral();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXListLiteral; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXListLiteral"


    // $ANTLR start "ruleXListLiteral"
    // InternalTableDSL.g:7372:1: ruleXListLiteral returns [EObject current=null] : ( () otherlv_1= '#' otherlv_2= '[' ( ( (lv_elements_3_0= ruleXExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )* )? otherlv_6= ']' ) ;
    public final EObject ruleXListLiteral() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token otherlv_4=null;
        Token otherlv_6=null;
        EObject lv_elements_3_0 = null;

        EObject lv_elements_5_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:7378:2: ( ( () otherlv_1= '#' otherlv_2= '[' ( ( (lv_elements_3_0= ruleXExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )* )? otherlv_6= ']' ) )
            // InternalTableDSL.g:7379:2: ( () otherlv_1= '#' otherlv_2= '[' ( ( (lv_elements_3_0= ruleXExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )* )? otherlv_6= ']' )
            {
            // InternalTableDSL.g:7379:2: ( () otherlv_1= '#' otherlv_2= '[' ( ( (lv_elements_3_0= ruleXExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )* )? otherlv_6= ']' )
            // InternalTableDSL.g:7380:3: () otherlv_1= '#' otherlv_2= '[' ( ( (lv_elements_3_0= ruleXExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )* )? otherlv_6= ']'
            {
            // InternalTableDSL.g:7380:3: ()
            // InternalTableDSL.g:7381:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXListLiteralAccess().getXListLiteralAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,104,FOLLOW_66); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXListLiteralAccess().getNumberSignKeyword_1());
              		
            }
            otherlv_2=(Token)match(input,105,FOLLOW_67); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_2, grammarAccess.getXListLiteralAccess().getLeftSquareBracketKeyword_2());
              		
            }
            // InternalTableDSL.g:7395:3: ( ( (lv_elements_3_0= ruleXExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )* )?
            int alt98=2;
            int LA98_0 = input.LA(1);

            if ( ((LA98_0>=RULE_ID && LA98_0<=RULE_STRING)||(LA98_0>=RULE_INT && LA98_0<=RULE_DECIMAL)||LA98_0==16||(LA98_0>=91 && LA98_0<=95)||LA98_0==100||(LA98_0>=104 && LA98_0<=105)||LA98_0==112||LA98_0==131||LA98_0==137||LA98_0==139||(LA98_0>=143 && LA98_0<=145)||(LA98_0>=148 && LA98_0<=157)||LA98_0==159) ) {
                alt98=1;
            }
            switch (alt98) {
                case 1 :
                    // InternalTableDSL.g:7396:4: ( (lv_elements_3_0= ruleXExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )*
                    {
                    // InternalTableDSL.g:7396:4: ( (lv_elements_3_0= ruleXExpression ) )
                    // InternalTableDSL.g:7397:5: (lv_elements_3_0= ruleXExpression )
                    {
                    // InternalTableDSL.g:7397:5: (lv_elements_3_0= ruleXExpression )
                    // InternalTableDSL.g:7398:6: lv_elements_3_0= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXListLiteralAccess().getElementsXExpressionParserRuleCall_3_0_0());
                      					
                    }
                    pushFollow(FOLLOW_68);
                    lv_elements_3_0=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getXListLiteralRule());
                      						}
                      						add(
                      							current,
                      							"elements",
                      							lv_elements_3_0,
                      							"org.eclipse.xtext.xbase.Xbase.XExpression");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }

                    // InternalTableDSL.g:7415:4: (otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) ) )*
                    loop97:
                    do {
                        int alt97=2;
                        int LA97_0 = input.LA(1);

                        if ( (LA97_0==101) ) {
                            alt97=1;
                        }


                        switch (alt97) {
                    	case 1 :
                    	    // InternalTableDSL.g:7416:5: otherlv_4= ',' ( (lv_elements_5_0= ruleXExpression ) )
                    	    {
                    	    otherlv_4=(Token)match(input,101,FOLLOW_65); if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      					newLeafNode(otherlv_4, grammarAccess.getXListLiteralAccess().getCommaKeyword_3_1_0());
                    	      				
                    	    }
                    	    // InternalTableDSL.g:7420:5: ( (lv_elements_5_0= ruleXExpression ) )
                    	    // InternalTableDSL.g:7421:6: (lv_elements_5_0= ruleXExpression )
                    	    {
                    	    // InternalTableDSL.g:7421:6: (lv_elements_5_0= ruleXExpression )
                    	    // InternalTableDSL.g:7422:7: lv_elements_5_0= ruleXExpression
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      							newCompositeNode(grammarAccess.getXListLiteralAccess().getElementsXExpressionParserRuleCall_3_1_1_0());
                    	      						
                    	    }
                    	    pushFollow(FOLLOW_68);
                    	    lv_elements_5_0=ruleXExpression();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      							if (current==null) {
                    	      								current = createModelElementForParent(grammarAccess.getXListLiteralRule());
                    	      							}
                    	      							add(
                    	      								current,
                    	      								"elements",
                    	      								lv_elements_5_0,
                    	      								"org.eclipse.xtext.xbase.Xbase.XExpression");
                    	      							afterParserOrEnumRuleCall();
                    	      						
                    	    }

                    	    }


                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop97;
                        }
                    } while (true);


                    }
                    break;

            }

            otherlv_6=(Token)match(input,106,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_6, grammarAccess.getXListLiteralAccess().getRightSquareBracketKeyword_4());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXListLiteral"


    // $ANTLR start "entryRuleXClosure"
    // InternalTableDSL.g:7449:1: entryRuleXClosure returns [EObject current=null] : iv_ruleXClosure= ruleXClosure EOF ;
    public final EObject entryRuleXClosure() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXClosure = null;


        try {
            // InternalTableDSL.g:7449:49: (iv_ruleXClosure= ruleXClosure EOF )
            // InternalTableDSL.g:7450:2: iv_ruleXClosure= ruleXClosure EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXClosureRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXClosure=ruleXClosure();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXClosure; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXClosure"


    // $ANTLR start "ruleXClosure"
    // InternalTableDSL.g:7456:1: ruleXClosure returns [EObject current=null] : ( ( ( ( () '[' ) )=> ( () otherlv_1= '[' ) ) ( ( ( ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( ( ( (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter ) ) (otherlv_3= ',' ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_5_0= '|' ) ) ) )? ( (lv_expression_6_0= ruleXExpressionInClosure ) ) otherlv_7= ']' ) ;
    public final EObject ruleXClosure() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_3=null;
        Token lv_explicitSyntax_5_0=null;
        Token otherlv_7=null;
        EObject lv_declaredFormalParameters_2_0 = null;

        EObject lv_declaredFormalParameters_4_0 = null;

        EObject lv_expression_6_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:7462:2: ( ( ( ( ( () '[' ) )=> ( () otherlv_1= '[' ) ) ( ( ( ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( ( ( (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter ) ) (otherlv_3= ',' ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_5_0= '|' ) ) ) )? ( (lv_expression_6_0= ruleXExpressionInClosure ) ) otherlv_7= ']' ) )
            // InternalTableDSL.g:7463:2: ( ( ( ( () '[' ) )=> ( () otherlv_1= '[' ) ) ( ( ( ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( ( ( (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter ) ) (otherlv_3= ',' ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_5_0= '|' ) ) ) )? ( (lv_expression_6_0= ruleXExpressionInClosure ) ) otherlv_7= ']' )
            {
            // InternalTableDSL.g:7463:2: ( ( ( ( () '[' ) )=> ( () otherlv_1= '[' ) ) ( ( ( ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( ( ( (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter ) ) (otherlv_3= ',' ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_5_0= '|' ) ) ) )? ( (lv_expression_6_0= ruleXExpressionInClosure ) ) otherlv_7= ']' )
            // InternalTableDSL.g:7464:3: ( ( ( () '[' ) )=> ( () otherlv_1= '[' ) ) ( ( ( ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( ( ( (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter ) ) (otherlv_3= ',' ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_5_0= '|' ) ) ) )? ( (lv_expression_6_0= ruleXExpressionInClosure ) ) otherlv_7= ']'
            {
            // InternalTableDSL.g:7464:3: ( ( ( () '[' ) )=> ( () otherlv_1= '[' ) )
            // InternalTableDSL.g:7465:4: ( ( () '[' ) )=> ( () otherlv_1= '[' )
            {
            // InternalTableDSL.g:7471:4: ( () otherlv_1= '[' )
            // InternalTableDSL.g:7472:5: () otherlv_1= '['
            {
            // InternalTableDSL.g:7472:5: ()
            // InternalTableDSL.g:7473:6: 
            {
            if ( state.backtracking==0 ) {

              						current = forceCreateModelElement(
              							grammarAccess.getXClosureAccess().getXClosureAction_0_0_0(),
              							current);
              					
            }

            }

            otherlv_1=(Token)match(input,105,FOLLOW_97); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_1, grammarAccess.getXClosureAccess().getLeftSquareBracketKeyword_0_0_1());
              				
            }

            }


            }

            // InternalTableDSL.g:7485:3: ( ( ( ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( ( ( (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter ) ) (otherlv_3= ',' ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_5_0= '|' ) ) ) )?
            int alt101=2;
            alt101 = dfa101.predict(input);
            switch (alt101) {
                case 1 :
                    // InternalTableDSL.g:7486:4: ( ( ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( ( ( (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter ) ) (otherlv_3= ',' ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_5_0= '|' ) ) )
                    {
                    // InternalTableDSL.g:7509:4: ( ( ( (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter ) ) (otherlv_3= ',' ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_5_0= '|' ) ) )
                    // InternalTableDSL.g:7510:5: ( ( (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter ) ) (otherlv_3= ',' ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_5_0= '|' ) )
                    {
                    // InternalTableDSL.g:7510:5: ( ( (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter ) ) (otherlv_3= ',' ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) ) )* )?
                    int alt100=2;
                    int LA100_0 = input.LA(1);

                    if ( (LA100_0==RULE_ID||LA100_0==100||LA100_0==125) ) {
                        alt100=1;
                    }
                    switch (alt100) {
                        case 1 :
                            // InternalTableDSL.g:7511:6: ( (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter ) ) (otherlv_3= ',' ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) ) )*
                            {
                            // InternalTableDSL.g:7511:6: ( (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter ) )
                            // InternalTableDSL.g:7512:7: (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter )
                            {
                            // InternalTableDSL.g:7512:7: (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter )
                            // InternalTableDSL.g:7513:8: lv_declaredFormalParameters_2_0= ruleJvmFormalParameter
                            {
                            if ( state.backtracking==0 ) {

                              								newCompositeNode(grammarAccess.getXClosureAccess().getDeclaredFormalParametersJvmFormalParameterParserRuleCall_1_0_0_0_0());
                              							
                            }
                            pushFollow(FOLLOW_98);
                            lv_declaredFormalParameters_2_0=ruleJvmFormalParameter();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              								if (current==null) {
                              									current = createModelElementForParent(grammarAccess.getXClosureRule());
                              								}
                              								add(
                              									current,
                              									"declaredFormalParameters",
                              									lv_declaredFormalParameters_2_0,
                              									"org.eclipse.xtext.xbase.Xbase.JvmFormalParameter");
                              								afterParserOrEnumRuleCall();
                              							
                            }

                            }


                            }

                            // InternalTableDSL.g:7530:6: (otherlv_3= ',' ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) ) )*
                            loop99:
                            do {
                                int alt99=2;
                                int LA99_0 = input.LA(1);

                                if ( (LA99_0==101) ) {
                                    alt99=1;
                                }


                                switch (alt99) {
                            	case 1 :
                            	    // InternalTableDSL.g:7531:7: otherlv_3= ',' ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) )
                            	    {
                            	    otherlv_3=(Token)match(input,101,FOLLOW_78); if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      							newLeafNode(otherlv_3, grammarAccess.getXClosureAccess().getCommaKeyword_1_0_0_1_0());
                            	      						
                            	    }
                            	    // InternalTableDSL.g:7535:7: ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) )
                            	    // InternalTableDSL.g:7536:8: (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter )
                            	    {
                            	    // InternalTableDSL.g:7536:8: (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter )
                            	    // InternalTableDSL.g:7537:9: lv_declaredFormalParameters_4_0= ruleJvmFormalParameter
                            	    {
                            	    if ( state.backtracking==0 ) {

                            	      									newCompositeNode(grammarAccess.getXClosureAccess().getDeclaredFormalParametersJvmFormalParameterParserRuleCall_1_0_0_1_1_0());
                            	      								
                            	    }
                            	    pushFollow(FOLLOW_98);
                            	    lv_declaredFormalParameters_4_0=ruleJvmFormalParameter();

                            	    state._fsp--;
                            	    if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      									if (current==null) {
                            	      										current = createModelElementForParent(grammarAccess.getXClosureRule());
                            	      									}
                            	      									add(
                            	      										current,
                            	      										"declaredFormalParameters",
                            	      										lv_declaredFormalParameters_4_0,
                            	      										"org.eclipse.xtext.xbase.Xbase.JvmFormalParameter");
                            	      									afterParserOrEnumRuleCall();
                            	      								
                            	    }

                            	    }


                            	    }


                            	    }
                            	    break;

                            	default :
                            	    break loop99;
                                }
                            } while (true);


                            }
                            break;

                    }

                    // InternalTableDSL.g:7556:5: ( (lv_explicitSyntax_5_0= '|' ) )
                    // InternalTableDSL.g:7557:6: (lv_explicitSyntax_5_0= '|' )
                    {
                    // InternalTableDSL.g:7557:6: (lv_explicitSyntax_5_0= '|' )
                    // InternalTableDSL.g:7558:7: lv_explicitSyntax_5_0= '|'
                    {
                    lv_explicitSyntax_5_0=(Token)match(input,136,FOLLOW_99); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      							newLeafNode(lv_explicitSyntax_5_0, grammarAccess.getXClosureAccess().getExplicitSyntaxVerticalLineKeyword_1_0_1_0());
                      						
                    }
                    if ( state.backtracking==0 ) {

                      							if (current==null) {
                      								current = createModelElement(grammarAccess.getXClosureRule());
                      							}
                      							setWithLastConsumed(current, "explicitSyntax", true, "|");
                      						
                    }

                    }


                    }


                    }


                    }
                    break;

            }

            // InternalTableDSL.g:7572:3: ( (lv_expression_6_0= ruleXExpressionInClosure ) )
            // InternalTableDSL.g:7573:4: (lv_expression_6_0= ruleXExpressionInClosure )
            {
            // InternalTableDSL.g:7573:4: (lv_expression_6_0= ruleXExpressionInClosure )
            // InternalTableDSL.g:7574:5: lv_expression_6_0= ruleXExpressionInClosure
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXClosureAccess().getExpressionXExpressionInClosureParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_100);
            lv_expression_6_0=ruleXExpressionInClosure();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXClosureRule());
              					}
              					set(
              						current,
              						"expression",
              						lv_expression_6_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpressionInClosure");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            otherlv_7=(Token)match(input,106,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_7, grammarAccess.getXClosureAccess().getRightSquareBracketKeyword_3());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXClosure"


    // $ANTLR start "entryRuleXExpressionInClosure"
    // InternalTableDSL.g:7599:1: entryRuleXExpressionInClosure returns [EObject current=null] : iv_ruleXExpressionInClosure= ruleXExpressionInClosure EOF ;
    public final EObject entryRuleXExpressionInClosure() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXExpressionInClosure = null;


        try {
            // InternalTableDSL.g:7599:61: (iv_ruleXExpressionInClosure= ruleXExpressionInClosure EOF )
            // InternalTableDSL.g:7600:2: iv_ruleXExpressionInClosure= ruleXExpressionInClosure EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXExpressionInClosureRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXExpressionInClosure=ruleXExpressionInClosure();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXExpressionInClosure; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXExpressionInClosure"


    // $ANTLR start "ruleXExpressionInClosure"
    // InternalTableDSL.g:7606:1: ruleXExpressionInClosure returns [EObject current=null] : ( () ( ( (lv_expressions_1_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_2= ';' )? )* ) ;
    public final EObject ruleXExpressionInClosure() throws RecognitionException {
        EObject current = null;

        Token otherlv_2=null;
        EObject lv_expressions_1_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:7612:2: ( ( () ( ( (lv_expressions_1_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_2= ';' )? )* ) )
            // InternalTableDSL.g:7613:2: ( () ( ( (lv_expressions_1_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_2= ';' )? )* )
            {
            // InternalTableDSL.g:7613:2: ( () ( ( (lv_expressions_1_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_2= ';' )? )* )
            // InternalTableDSL.g:7614:3: () ( ( (lv_expressions_1_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_2= ';' )? )*
            {
            // InternalTableDSL.g:7614:3: ()
            // InternalTableDSL.g:7615:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXExpressionInClosureAccess().getXBlockExpressionAction_0(),
              					current);
              			
            }

            }

            // InternalTableDSL.g:7621:3: ( ( (lv_expressions_1_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_2= ';' )? )*
            loop103:
            do {
                int alt103=2;
                int LA103_0 = input.LA(1);

                if ( ((LA103_0>=RULE_ID && LA103_0<=RULE_STRING)||(LA103_0>=RULE_INT && LA103_0<=RULE_DECIMAL)||LA103_0==16||(LA103_0>=91 && LA103_0<=95)||LA103_0==100||(LA103_0>=104 && LA103_0<=105)||LA103_0==112||LA103_0==131||LA103_0==137||LA103_0==139||(LA103_0>=143 && LA103_0<=157)||LA103_0==159) ) {
                    alt103=1;
                }


                switch (alt103) {
            	case 1 :
            	    // InternalTableDSL.g:7622:4: ( (lv_expressions_1_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_2= ';' )?
            	    {
            	    // InternalTableDSL.g:7622:4: ( (lv_expressions_1_0= ruleXExpressionOrVarDeclaration ) )
            	    // InternalTableDSL.g:7623:5: (lv_expressions_1_0= ruleXExpressionOrVarDeclaration )
            	    {
            	    // InternalTableDSL.g:7623:5: (lv_expressions_1_0= ruleXExpressionOrVarDeclaration )
            	    // InternalTableDSL.g:7624:6: lv_expressions_1_0= ruleXExpressionOrVarDeclaration
            	    {
            	    if ( state.backtracking==0 ) {

            	      						newCompositeNode(grammarAccess.getXExpressionInClosureAccess().getExpressionsXExpressionOrVarDeclarationParserRuleCall_1_0_0());
            	      					
            	    }
            	    pushFollow(FOLLOW_101);
            	    lv_expressions_1_0=ruleXExpressionOrVarDeclaration();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      						if (current==null) {
            	      							current = createModelElementForParent(grammarAccess.getXExpressionInClosureRule());
            	      						}
            	      						add(
            	      							current,
            	      							"expressions",
            	      							lv_expressions_1_0,
            	      							"org.eclipse.xtext.xbase.Xbase.XExpressionOrVarDeclaration");
            	      						afterParserOrEnumRuleCall();
            	      					
            	    }

            	    }


            	    }

            	    // InternalTableDSL.g:7641:4: (otherlv_2= ';' )?
            	    int alt102=2;
            	    int LA102_0 = input.LA(1);

            	    if ( (LA102_0==98) ) {
            	        alt102=1;
            	    }
            	    switch (alt102) {
            	        case 1 :
            	            // InternalTableDSL.g:7642:5: otherlv_2= ';'
            	            {
            	            otherlv_2=(Token)match(input,98,FOLLOW_102); if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              					newLeafNode(otherlv_2, grammarAccess.getXExpressionInClosureAccess().getSemicolonKeyword_1_1());
            	              				
            	            }

            	            }
            	            break;

            	    }


            	    }
            	    break;

            	default :
            	    break loop103;
                }
            } while (true);


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXExpressionInClosure"


    // $ANTLR start "entryRuleXShortClosure"
    // InternalTableDSL.g:7652:1: entryRuleXShortClosure returns [EObject current=null] : iv_ruleXShortClosure= ruleXShortClosure EOF ;
    public final EObject entryRuleXShortClosure() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXShortClosure = null;


        try {
            // InternalTableDSL.g:7652:54: (iv_ruleXShortClosure= ruleXShortClosure EOF )
            // InternalTableDSL.g:7653:2: iv_ruleXShortClosure= ruleXShortClosure EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXShortClosureRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXShortClosure=ruleXShortClosure();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXShortClosure; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXShortClosure"


    // $ANTLR start "ruleXShortClosure"
    // InternalTableDSL.g:7659:1: ruleXShortClosure returns [EObject current=null] : ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( () ( ( (lv_declaredFormalParameters_1_0= ruleJvmFormalParameter ) ) (otherlv_2= ',' ( (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_4_0= '|' ) ) ) ) ( (lv_expression_5_0= ruleXExpression ) ) ) ;
    public final EObject ruleXShortClosure() throws RecognitionException {
        EObject current = null;

        Token otherlv_2=null;
        Token lv_explicitSyntax_4_0=null;
        EObject lv_declaredFormalParameters_1_0 = null;

        EObject lv_declaredFormalParameters_3_0 = null;

        EObject lv_expression_5_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:7665:2: ( ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( () ( ( (lv_declaredFormalParameters_1_0= ruleJvmFormalParameter ) ) (otherlv_2= ',' ( (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_4_0= '|' ) ) ) ) ( (lv_expression_5_0= ruleXExpression ) ) ) )
            // InternalTableDSL.g:7666:2: ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( () ( ( (lv_declaredFormalParameters_1_0= ruleJvmFormalParameter ) ) (otherlv_2= ',' ( (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_4_0= '|' ) ) ) ) ( (lv_expression_5_0= ruleXExpression ) ) )
            {
            // InternalTableDSL.g:7666:2: ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( () ( ( (lv_declaredFormalParameters_1_0= ruleJvmFormalParameter ) ) (otherlv_2= ',' ( (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_4_0= '|' ) ) ) ) ( (lv_expression_5_0= ruleXExpression ) ) )
            // InternalTableDSL.g:7667:3: ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( () ( ( (lv_declaredFormalParameters_1_0= ruleJvmFormalParameter ) ) (otherlv_2= ',' ( (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_4_0= '|' ) ) ) ) ( (lv_expression_5_0= ruleXExpression ) )
            {
            // InternalTableDSL.g:7667:3: ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( () ( ( (lv_declaredFormalParameters_1_0= ruleJvmFormalParameter ) ) (otherlv_2= ',' ( (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_4_0= '|' ) ) ) )
            // InternalTableDSL.g:7668:4: ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( () ( ( (lv_declaredFormalParameters_1_0= ruleJvmFormalParameter ) ) (otherlv_2= ',' ( (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_4_0= '|' ) ) )
            {
            // InternalTableDSL.g:7693:4: ( () ( ( (lv_declaredFormalParameters_1_0= ruleJvmFormalParameter ) ) (otherlv_2= ',' ( (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_4_0= '|' ) ) )
            // InternalTableDSL.g:7694:5: () ( ( (lv_declaredFormalParameters_1_0= ruleJvmFormalParameter ) ) (otherlv_2= ',' ( (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_4_0= '|' ) )
            {
            // InternalTableDSL.g:7694:5: ()
            // InternalTableDSL.g:7695:6: 
            {
            if ( state.backtracking==0 ) {

              						current = forceCreateModelElement(
              							grammarAccess.getXShortClosureAccess().getXClosureAction_0_0_0(),
              							current);
              					
            }

            }

            // InternalTableDSL.g:7701:5: ( ( (lv_declaredFormalParameters_1_0= ruleJvmFormalParameter ) ) (otherlv_2= ',' ( (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter ) ) )* )?
            int alt105=2;
            int LA105_0 = input.LA(1);

            if ( (LA105_0==RULE_ID||LA105_0==100||LA105_0==125) ) {
                alt105=1;
            }
            switch (alt105) {
                case 1 :
                    // InternalTableDSL.g:7702:6: ( (lv_declaredFormalParameters_1_0= ruleJvmFormalParameter ) ) (otherlv_2= ',' ( (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter ) ) )*
                    {
                    // InternalTableDSL.g:7702:6: ( (lv_declaredFormalParameters_1_0= ruleJvmFormalParameter ) )
                    // InternalTableDSL.g:7703:7: (lv_declaredFormalParameters_1_0= ruleJvmFormalParameter )
                    {
                    // InternalTableDSL.g:7703:7: (lv_declaredFormalParameters_1_0= ruleJvmFormalParameter )
                    // InternalTableDSL.g:7704:8: lv_declaredFormalParameters_1_0= ruleJvmFormalParameter
                    {
                    if ( state.backtracking==0 ) {

                      								newCompositeNode(grammarAccess.getXShortClosureAccess().getDeclaredFormalParametersJvmFormalParameterParserRuleCall_0_0_1_0_0());
                      							
                    }
                    pushFollow(FOLLOW_98);
                    lv_declaredFormalParameters_1_0=ruleJvmFormalParameter();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      								if (current==null) {
                      									current = createModelElementForParent(grammarAccess.getXShortClosureRule());
                      								}
                      								add(
                      									current,
                      									"declaredFormalParameters",
                      									lv_declaredFormalParameters_1_0,
                      									"org.eclipse.xtext.xbase.Xbase.JvmFormalParameter");
                      								afterParserOrEnumRuleCall();
                      							
                    }

                    }


                    }

                    // InternalTableDSL.g:7721:6: (otherlv_2= ',' ( (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter ) ) )*
                    loop104:
                    do {
                        int alt104=2;
                        int LA104_0 = input.LA(1);

                        if ( (LA104_0==101) ) {
                            alt104=1;
                        }


                        switch (alt104) {
                    	case 1 :
                    	    // InternalTableDSL.g:7722:7: otherlv_2= ',' ( (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter ) )
                    	    {
                    	    otherlv_2=(Token)match(input,101,FOLLOW_78); if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      							newLeafNode(otherlv_2, grammarAccess.getXShortClosureAccess().getCommaKeyword_0_0_1_1_0());
                    	      						
                    	    }
                    	    // InternalTableDSL.g:7726:7: ( (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter ) )
                    	    // InternalTableDSL.g:7727:8: (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter )
                    	    {
                    	    // InternalTableDSL.g:7727:8: (lv_declaredFormalParameters_3_0= ruleJvmFormalParameter )
                    	    // InternalTableDSL.g:7728:9: lv_declaredFormalParameters_3_0= ruleJvmFormalParameter
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      									newCompositeNode(grammarAccess.getXShortClosureAccess().getDeclaredFormalParametersJvmFormalParameterParserRuleCall_0_0_1_1_1_0());
                    	      								
                    	    }
                    	    pushFollow(FOLLOW_98);
                    	    lv_declaredFormalParameters_3_0=ruleJvmFormalParameter();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      									if (current==null) {
                    	      										current = createModelElementForParent(grammarAccess.getXShortClosureRule());
                    	      									}
                    	      									add(
                    	      										current,
                    	      										"declaredFormalParameters",
                    	      										lv_declaredFormalParameters_3_0,
                    	      										"org.eclipse.xtext.xbase.Xbase.JvmFormalParameter");
                    	      									afterParserOrEnumRuleCall();
                    	      								
                    	    }

                    	    }


                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop104;
                        }
                    } while (true);


                    }
                    break;

            }

            // InternalTableDSL.g:7747:5: ( (lv_explicitSyntax_4_0= '|' ) )
            // InternalTableDSL.g:7748:6: (lv_explicitSyntax_4_0= '|' )
            {
            // InternalTableDSL.g:7748:6: (lv_explicitSyntax_4_0= '|' )
            // InternalTableDSL.g:7749:7: lv_explicitSyntax_4_0= '|'
            {
            lv_explicitSyntax_4_0=(Token)match(input,136,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              							newLeafNode(lv_explicitSyntax_4_0, grammarAccess.getXShortClosureAccess().getExplicitSyntaxVerticalLineKeyword_0_0_2_0());
              						
            }
            if ( state.backtracking==0 ) {

              							if (current==null) {
              								current = createModelElement(grammarAccess.getXShortClosureRule());
              							}
              							setWithLastConsumed(current, "explicitSyntax", true, "|");
              						
            }

            }


            }


            }


            }

            // InternalTableDSL.g:7763:3: ( (lv_expression_5_0= ruleXExpression ) )
            // InternalTableDSL.g:7764:4: (lv_expression_5_0= ruleXExpression )
            {
            // InternalTableDSL.g:7764:4: (lv_expression_5_0= ruleXExpression )
            // InternalTableDSL.g:7765:5: lv_expression_5_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXShortClosureAccess().getExpressionXExpressionParserRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_expression_5_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXShortClosureRule());
              					}
              					set(
              						current,
              						"expression",
              						lv_expression_5_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXShortClosure"


    // $ANTLR start "entryRuleXParenthesizedExpression"
    // InternalTableDSL.g:7786:1: entryRuleXParenthesizedExpression returns [EObject current=null] : iv_ruleXParenthesizedExpression= ruleXParenthesizedExpression EOF ;
    public final EObject entryRuleXParenthesizedExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXParenthesizedExpression = null;


        try {
            // InternalTableDSL.g:7786:65: (iv_ruleXParenthesizedExpression= ruleXParenthesizedExpression EOF )
            // InternalTableDSL.g:7787:2: iv_ruleXParenthesizedExpression= ruleXParenthesizedExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXParenthesizedExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXParenthesizedExpression=ruleXParenthesizedExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXParenthesizedExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXParenthesizedExpression"


    // $ANTLR start "ruleXParenthesizedExpression"
    // InternalTableDSL.g:7793:1: ruleXParenthesizedExpression returns [EObject current=null] : (otherlv_0= '(' this_XExpression_1= ruleXExpression otherlv_2= ')' ) ;
    public final EObject ruleXParenthesizedExpression() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token otherlv_2=null;
        EObject this_XExpression_1 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:7799:2: ( (otherlv_0= '(' this_XExpression_1= ruleXExpression otherlv_2= ')' ) )
            // InternalTableDSL.g:7800:2: (otherlv_0= '(' this_XExpression_1= ruleXExpression otherlv_2= ')' )
            {
            // InternalTableDSL.g:7800:2: (otherlv_0= '(' this_XExpression_1= ruleXExpression otherlv_2= ')' )
            // InternalTableDSL.g:7801:3: otherlv_0= '(' this_XExpression_1= ruleXExpression otherlv_2= ')'
            {
            otherlv_0=(Token)match(input,100,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getXParenthesizedExpressionAccess().getLeftParenthesisKeyword_0());
              		
            }
            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getXParenthesizedExpressionAccess().getXExpressionParserRuleCall_1());
              		
            }
            pushFollow(FOLLOW_63);
            this_XExpression_1=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current = this_XExpression_1;
              			afterParserOrEnumRuleCall();
              		
            }
            otherlv_2=(Token)match(input,102,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_2, grammarAccess.getXParenthesizedExpressionAccess().getRightParenthesisKeyword_2());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXParenthesizedExpression"


    // $ANTLR start "entryRuleXIfExpression"
    // InternalTableDSL.g:7821:1: entryRuleXIfExpression returns [EObject current=null] : iv_ruleXIfExpression= ruleXIfExpression EOF ;
    public final EObject entryRuleXIfExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXIfExpression = null;


        try {
            // InternalTableDSL.g:7821:54: (iv_ruleXIfExpression= ruleXIfExpression EOF )
            // InternalTableDSL.g:7822:2: iv_ruleXIfExpression= ruleXIfExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXIfExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXIfExpression=ruleXIfExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXIfExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXIfExpression"


    // $ANTLR start "ruleXIfExpression"
    // InternalTableDSL.g:7828:1: ruleXIfExpression returns [EObject current=null] : ( () otherlv_1= 'if' otherlv_2= '(' ( (lv_if_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_then_5_0= ruleXExpression ) ) ( ( ( 'else' )=>otherlv_6= 'else' ) ( (lv_else_7_0= ruleXExpression ) ) )? ) ;
    public final EObject ruleXIfExpression() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token otherlv_4=null;
        Token otherlv_6=null;
        EObject lv_if_3_0 = null;

        EObject lv_then_5_0 = null;

        EObject lv_else_7_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:7834:2: ( ( () otherlv_1= 'if' otherlv_2= '(' ( (lv_if_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_then_5_0= ruleXExpression ) ) ( ( ( 'else' )=>otherlv_6= 'else' ) ( (lv_else_7_0= ruleXExpression ) ) )? ) )
            // InternalTableDSL.g:7835:2: ( () otherlv_1= 'if' otherlv_2= '(' ( (lv_if_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_then_5_0= ruleXExpression ) ) ( ( ( 'else' )=>otherlv_6= 'else' ) ( (lv_else_7_0= ruleXExpression ) ) )? )
            {
            // InternalTableDSL.g:7835:2: ( () otherlv_1= 'if' otherlv_2= '(' ( (lv_if_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_then_5_0= ruleXExpression ) ) ( ( ( 'else' )=>otherlv_6= 'else' ) ( (lv_else_7_0= ruleXExpression ) ) )? )
            // InternalTableDSL.g:7836:3: () otherlv_1= 'if' otherlv_2= '(' ( (lv_if_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_then_5_0= ruleXExpression ) ) ( ( ( 'else' )=>otherlv_6= 'else' ) ( (lv_else_7_0= ruleXExpression ) ) )?
            {
            // InternalTableDSL.g:7836:3: ()
            // InternalTableDSL.g:7837:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXIfExpressionAccess().getXIfExpressionAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,137,FOLLOW_103); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXIfExpressionAccess().getIfKeyword_1());
              		
            }
            otherlv_2=(Token)match(input,100,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_2, grammarAccess.getXIfExpressionAccess().getLeftParenthesisKeyword_2());
              		
            }
            // InternalTableDSL.g:7851:3: ( (lv_if_3_0= ruleXExpression ) )
            // InternalTableDSL.g:7852:4: (lv_if_3_0= ruleXExpression )
            {
            // InternalTableDSL.g:7852:4: (lv_if_3_0= ruleXExpression )
            // InternalTableDSL.g:7853:5: lv_if_3_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXIfExpressionAccess().getIfXExpressionParserRuleCall_3_0());
              				
            }
            pushFollow(FOLLOW_63);
            lv_if_3_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXIfExpressionRule());
              					}
              					set(
              						current,
              						"if",
              						lv_if_3_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            otherlv_4=(Token)match(input,102,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_4, grammarAccess.getXIfExpressionAccess().getRightParenthesisKeyword_4());
              		
            }
            // InternalTableDSL.g:7874:3: ( (lv_then_5_0= ruleXExpression ) )
            // InternalTableDSL.g:7875:4: (lv_then_5_0= ruleXExpression )
            {
            // InternalTableDSL.g:7875:4: (lv_then_5_0= ruleXExpression )
            // InternalTableDSL.g:7876:5: lv_then_5_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXIfExpressionAccess().getThenXExpressionParserRuleCall_5_0());
              				
            }
            pushFollow(FOLLOW_104);
            lv_then_5_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXIfExpressionRule());
              					}
              					set(
              						current,
              						"then",
              						lv_then_5_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:7893:3: ( ( ( 'else' )=>otherlv_6= 'else' ) ( (lv_else_7_0= ruleXExpression ) ) )?
            int alt106=2;
            int LA106_0 = input.LA(1);

            if ( (LA106_0==138) ) {
                int LA106_1 = input.LA(2);

                if ( (synpred31_InternalTableDSL()) ) {
                    alt106=1;
                }
            }
            switch (alt106) {
                case 1 :
                    // InternalTableDSL.g:7894:4: ( ( 'else' )=>otherlv_6= 'else' ) ( (lv_else_7_0= ruleXExpression ) )
                    {
                    // InternalTableDSL.g:7894:4: ( ( 'else' )=>otherlv_6= 'else' )
                    // InternalTableDSL.g:7895:5: ( 'else' )=>otherlv_6= 'else'
                    {
                    otherlv_6=(Token)match(input,138,FOLLOW_65); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					newLeafNode(otherlv_6, grammarAccess.getXIfExpressionAccess().getElseKeyword_6_0());
                      				
                    }

                    }

                    // InternalTableDSL.g:7901:4: ( (lv_else_7_0= ruleXExpression ) )
                    // InternalTableDSL.g:7902:5: (lv_else_7_0= ruleXExpression )
                    {
                    // InternalTableDSL.g:7902:5: (lv_else_7_0= ruleXExpression )
                    // InternalTableDSL.g:7903:6: lv_else_7_0= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXIfExpressionAccess().getElseXExpressionParserRuleCall_6_1_0());
                      					
                    }
                    pushFollow(FOLLOW_2);
                    lv_else_7_0=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getXIfExpressionRule());
                      						}
                      						set(
                      							current,
                      							"else",
                      							lv_else_7_0,
                      							"org.eclipse.xtext.xbase.Xbase.XExpression");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXIfExpression"


    // $ANTLR start "entryRuleXSwitchExpression"
    // InternalTableDSL.g:7925:1: entryRuleXSwitchExpression returns [EObject current=null] : iv_ruleXSwitchExpression= ruleXSwitchExpression EOF ;
    public final EObject entryRuleXSwitchExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXSwitchExpression = null;


        try {
            // InternalTableDSL.g:7925:58: (iv_ruleXSwitchExpression= ruleXSwitchExpression EOF )
            // InternalTableDSL.g:7926:2: iv_ruleXSwitchExpression= ruleXSwitchExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXSwitchExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXSwitchExpression=ruleXSwitchExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXSwitchExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXSwitchExpression"


    // $ANTLR start "ruleXSwitchExpression"
    // InternalTableDSL.g:7932:1: ruleXSwitchExpression returns [EObject current=null] : ( () otherlv_1= 'switch' ( ( ( ( ( '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> (otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_switch_5_0= ruleXExpression ) ) otherlv_6= ')' ) | ( ( ( ( ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':' ) )? ( (lv_switch_9_0= ruleXExpression ) ) ) ) otherlv_10= '{' ( (lv_cases_11_0= ruleXCasePart ) )* (otherlv_12= 'default' otherlv_13= ':' ( (lv_default_14_0= ruleXExpression ) ) )? otherlv_15= '}' ) ;
    public final EObject ruleXSwitchExpression() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token otherlv_4=null;
        Token otherlv_6=null;
        Token otherlv_8=null;
        Token otherlv_10=null;
        Token otherlv_12=null;
        Token otherlv_13=null;
        Token otherlv_15=null;
        EObject lv_declaredParam_3_0 = null;

        EObject lv_switch_5_0 = null;

        EObject lv_declaredParam_7_0 = null;

        EObject lv_switch_9_0 = null;

        EObject lv_cases_11_0 = null;

        EObject lv_default_14_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:7938:2: ( ( () otherlv_1= 'switch' ( ( ( ( ( '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> (otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_switch_5_0= ruleXExpression ) ) otherlv_6= ')' ) | ( ( ( ( ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':' ) )? ( (lv_switch_9_0= ruleXExpression ) ) ) ) otherlv_10= '{' ( (lv_cases_11_0= ruleXCasePart ) )* (otherlv_12= 'default' otherlv_13= ':' ( (lv_default_14_0= ruleXExpression ) ) )? otherlv_15= '}' ) )
            // InternalTableDSL.g:7939:2: ( () otherlv_1= 'switch' ( ( ( ( ( '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> (otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_switch_5_0= ruleXExpression ) ) otherlv_6= ')' ) | ( ( ( ( ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':' ) )? ( (lv_switch_9_0= ruleXExpression ) ) ) ) otherlv_10= '{' ( (lv_cases_11_0= ruleXCasePart ) )* (otherlv_12= 'default' otherlv_13= ':' ( (lv_default_14_0= ruleXExpression ) ) )? otherlv_15= '}' )
            {
            // InternalTableDSL.g:7939:2: ( () otherlv_1= 'switch' ( ( ( ( ( '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> (otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_switch_5_0= ruleXExpression ) ) otherlv_6= ')' ) | ( ( ( ( ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':' ) )? ( (lv_switch_9_0= ruleXExpression ) ) ) ) otherlv_10= '{' ( (lv_cases_11_0= ruleXCasePart ) )* (otherlv_12= 'default' otherlv_13= ':' ( (lv_default_14_0= ruleXExpression ) ) )? otherlv_15= '}' )
            // InternalTableDSL.g:7940:3: () otherlv_1= 'switch' ( ( ( ( ( '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> (otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_switch_5_0= ruleXExpression ) ) otherlv_6= ')' ) | ( ( ( ( ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':' ) )? ( (lv_switch_9_0= ruleXExpression ) ) ) ) otherlv_10= '{' ( (lv_cases_11_0= ruleXCasePart ) )* (otherlv_12= 'default' otherlv_13= ':' ( (lv_default_14_0= ruleXExpression ) ) )? otherlv_15= '}'
            {
            // InternalTableDSL.g:7940:3: ()
            // InternalTableDSL.g:7941:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXSwitchExpressionAccess().getXSwitchExpressionAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,139,FOLLOW_105); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXSwitchExpressionAccess().getSwitchKeyword_1());
              		
            }
            // InternalTableDSL.g:7951:3: ( ( ( ( ( '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> (otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_switch_5_0= ruleXExpression ) ) otherlv_6= ')' ) | ( ( ( ( ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':' ) )? ( (lv_switch_9_0= ruleXExpression ) ) ) )
            int alt108=2;
            alt108 = dfa108.predict(input);
            switch (alt108) {
                case 1 :
                    // InternalTableDSL.g:7952:4: ( ( ( ( '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> (otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_switch_5_0= ruleXExpression ) ) otherlv_6= ')' )
                    {
                    // InternalTableDSL.g:7952:4: ( ( ( ( '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> (otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_switch_5_0= ruleXExpression ) ) otherlv_6= ')' )
                    // InternalTableDSL.g:7953:5: ( ( ( '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> (otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_switch_5_0= ruleXExpression ) ) otherlv_6= ')'
                    {
                    // InternalTableDSL.g:7953:5: ( ( ( '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> (otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) )
                    // InternalTableDSL.g:7954:6: ( ( '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> (otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' )
                    {
                    // InternalTableDSL.g:7964:6: (otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' )
                    // InternalTableDSL.g:7965:7: otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':'
                    {
                    otherlv_2=(Token)match(input,100,FOLLOW_78); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      							newLeafNode(otherlv_2, grammarAccess.getXSwitchExpressionAccess().getLeftParenthesisKeyword_2_0_0_0_0());
                      						
                    }
                    // InternalTableDSL.g:7969:7: ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) )
                    // InternalTableDSL.g:7970:8: (lv_declaredParam_3_0= ruleJvmFormalParameter )
                    {
                    // InternalTableDSL.g:7970:8: (lv_declaredParam_3_0= ruleJvmFormalParameter )
                    // InternalTableDSL.g:7971:9: lv_declaredParam_3_0= ruleJvmFormalParameter
                    {
                    if ( state.backtracking==0 ) {

                      									newCompositeNode(grammarAccess.getXSwitchExpressionAccess().getDeclaredParamJvmFormalParameterParserRuleCall_2_0_0_0_1_0());
                      								
                    }
                    pushFollow(FOLLOW_106);
                    lv_declaredParam_3_0=ruleJvmFormalParameter();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      									if (current==null) {
                      										current = createModelElementForParent(grammarAccess.getXSwitchExpressionRule());
                      									}
                      									set(
                      										current,
                      										"declaredParam",
                      										lv_declaredParam_3_0,
                      										"org.eclipse.xtext.xbase.Xbase.JvmFormalParameter");
                      									afterParserOrEnumRuleCall();
                      								
                    }

                    }


                    }

                    otherlv_4=(Token)match(input,140,FOLLOW_65); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      							newLeafNode(otherlv_4, grammarAccess.getXSwitchExpressionAccess().getColonKeyword_2_0_0_0_2());
                      						
                    }

                    }


                    }

                    // InternalTableDSL.g:7994:5: ( (lv_switch_5_0= ruleXExpression ) )
                    // InternalTableDSL.g:7995:6: (lv_switch_5_0= ruleXExpression )
                    {
                    // InternalTableDSL.g:7995:6: (lv_switch_5_0= ruleXExpression )
                    // InternalTableDSL.g:7996:7: lv_switch_5_0= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      							newCompositeNode(grammarAccess.getXSwitchExpressionAccess().getSwitchXExpressionParserRuleCall_2_0_1_0());
                      						
                    }
                    pushFollow(FOLLOW_63);
                    lv_switch_5_0=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      							if (current==null) {
                      								current = createModelElementForParent(grammarAccess.getXSwitchExpressionRule());
                      							}
                      							set(
                      								current,
                      								"switch",
                      								lv_switch_5_0,
                      								"org.eclipse.xtext.xbase.Xbase.XExpression");
                      							afterParserOrEnumRuleCall();
                      						
                    }

                    }


                    }

                    otherlv_6=(Token)match(input,102,FOLLOW_21); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					newLeafNode(otherlv_6, grammarAccess.getXSwitchExpressionAccess().getRightParenthesisKeyword_2_0_2());
                      				
                    }

                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:8019:4: ( ( ( ( ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':' ) )? ( (lv_switch_9_0= ruleXExpression ) ) )
                    {
                    // InternalTableDSL.g:8019:4: ( ( ( ( ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':' ) )? ( (lv_switch_9_0= ruleXExpression ) ) )
                    // InternalTableDSL.g:8020:5: ( ( ( ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':' ) )? ( (lv_switch_9_0= ruleXExpression ) )
                    {
                    // InternalTableDSL.g:8020:5: ( ( ( ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':' ) )?
                    int alt107=2;
                    alt107 = dfa107.predict(input);
                    switch (alt107) {
                        case 1 :
                            // InternalTableDSL.g:8021:6: ( ( ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':' )
                            {
                            // InternalTableDSL.g:8030:6: ( ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':' )
                            // InternalTableDSL.g:8031:7: ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':'
                            {
                            // InternalTableDSL.g:8031:7: ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) )
                            // InternalTableDSL.g:8032:8: (lv_declaredParam_7_0= ruleJvmFormalParameter )
                            {
                            // InternalTableDSL.g:8032:8: (lv_declaredParam_7_0= ruleJvmFormalParameter )
                            // InternalTableDSL.g:8033:9: lv_declaredParam_7_0= ruleJvmFormalParameter
                            {
                            if ( state.backtracking==0 ) {

                              									newCompositeNode(grammarAccess.getXSwitchExpressionAccess().getDeclaredParamJvmFormalParameterParserRuleCall_2_1_0_0_0_0());
                              								
                            }
                            pushFollow(FOLLOW_106);
                            lv_declaredParam_7_0=ruleJvmFormalParameter();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              									if (current==null) {
                              										current = createModelElementForParent(grammarAccess.getXSwitchExpressionRule());
                              									}
                              									set(
                              										current,
                              										"declaredParam",
                              										lv_declaredParam_7_0,
                              										"org.eclipse.xtext.xbase.Xbase.JvmFormalParameter");
                              									afterParserOrEnumRuleCall();
                              								
                            }

                            }


                            }

                            otherlv_8=(Token)match(input,140,FOLLOW_65); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              							newLeafNode(otherlv_8, grammarAccess.getXSwitchExpressionAccess().getColonKeyword_2_1_0_0_1());
                              						
                            }

                            }


                            }
                            break;

                    }

                    // InternalTableDSL.g:8056:5: ( (lv_switch_9_0= ruleXExpression ) )
                    // InternalTableDSL.g:8057:6: (lv_switch_9_0= ruleXExpression )
                    {
                    // InternalTableDSL.g:8057:6: (lv_switch_9_0= ruleXExpression )
                    // InternalTableDSL.g:8058:7: lv_switch_9_0= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      							newCompositeNode(grammarAccess.getXSwitchExpressionAccess().getSwitchXExpressionParserRuleCall_2_1_1_0());
                      						
                    }
                    pushFollow(FOLLOW_21);
                    lv_switch_9_0=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      							if (current==null) {
                      								current = createModelElementForParent(grammarAccess.getXSwitchExpressionRule());
                      							}
                      							set(
                      								current,
                      								"switch",
                      								lv_switch_9_0,
                      								"org.eclipse.xtext.xbase.Xbase.XExpression");
                      							afterParserOrEnumRuleCall();
                      						
                    }

                    }


                    }


                    }


                    }
                    break;

            }

            otherlv_10=(Token)match(input,16,FOLLOW_107); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_10, grammarAccess.getXSwitchExpressionAccess().getLeftCurlyBracketKeyword_3());
              		
            }
            // InternalTableDSL.g:8081:3: ( (lv_cases_11_0= ruleXCasePart ) )*
            loop109:
            do {
                int alt109=2;
                int LA109_0 = input.LA(1);

                if ( (LA109_0==RULE_ID||(LA109_0>=100 && LA109_0<=101)||LA109_0==125||LA109_0==140||LA109_0==142) ) {
                    alt109=1;
                }


                switch (alt109) {
            	case 1 :
            	    // InternalTableDSL.g:8082:4: (lv_cases_11_0= ruleXCasePart )
            	    {
            	    // InternalTableDSL.g:8082:4: (lv_cases_11_0= ruleXCasePart )
            	    // InternalTableDSL.g:8083:5: lv_cases_11_0= ruleXCasePart
            	    {
            	    if ( state.backtracking==0 ) {

            	      					newCompositeNode(grammarAccess.getXSwitchExpressionAccess().getCasesXCasePartParserRuleCall_4_0());
            	      				
            	    }
            	    pushFollow(FOLLOW_107);
            	    lv_cases_11_0=ruleXCasePart();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      					if (current==null) {
            	      						current = createModelElementForParent(grammarAccess.getXSwitchExpressionRule());
            	      					}
            	      					add(
            	      						current,
            	      						"cases",
            	      						lv_cases_11_0,
            	      						"org.eclipse.xtext.xbase.Xbase.XCasePart");
            	      					afterParserOrEnumRuleCall();
            	      				
            	    }

            	    }


            	    }
            	    break;

            	default :
            	    break loop109;
                }
            } while (true);

            // InternalTableDSL.g:8100:3: (otherlv_12= 'default' otherlv_13= ':' ( (lv_default_14_0= ruleXExpression ) ) )?
            int alt110=2;
            int LA110_0 = input.LA(1);

            if ( (LA110_0==141) ) {
                alt110=1;
            }
            switch (alt110) {
                case 1 :
                    // InternalTableDSL.g:8101:4: otherlv_12= 'default' otherlv_13= ':' ( (lv_default_14_0= ruleXExpression ) )
                    {
                    otherlv_12=(Token)match(input,141,FOLLOW_106); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_12, grammarAccess.getXSwitchExpressionAccess().getDefaultKeyword_5_0());
                      			
                    }
                    otherlv_13=(Token)match(input,140,FOLLOW_65); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_13, grammarAccess.getXSwitchExpressionAccess().getColonKeyword_5_1());
                      			
                    }
                    // InternalTableDSL.g:8109:4: ( (lv_default_14_0= ruleXExpression ) )
                    // InternalTableDSL.g:8110:5: (lv_default_14_0= ruleXExpression )
                    {
                    // InternalTableDSL.g:8110:5: (lv_default_14_0= ruleXExpression )
                    // InternalTableDSL.g:8111:6: lv_default_14_0= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXSwitchExpressionAccess().getDefaultXExpressionParserRuleCall_5_2_0());
                      					
                    }
                    pushFollow(FOLLOW_108);
                    lv_default_14_0=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getXSwitchExpressionRule());
                      						}
                      						set(
                      							current,
                      							"default",
                      							lv_default_14_0,
                      							"org.eclipse.xtext.xbase.Xbase.XExpression");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }


                    }
                    break;

            }

            otherlv_15=(Token)match(input,17,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_15, grammarAccess.getXSwitchExpressionAccess().getRightCurlyBracketKeyword_6());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXSwitchExpression"


    // $ANTLR start "entryRuleXCasePart"
    // InternalTableDSL.g:8137:1: entryRuleXCasePart returns [EObject current=null] : iv_ruleXCasePart= ruleXCasePart EOF ;
    public final EObject entryRuleXCasePart() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXCasePart = null;


        try {
            // InternalTableDSL.g:8137:50: (iv_ruleXCasePart= ruleXCasePart EOF )
            // InternalTableDSL.g:8138:2: iv_ruleXCasePart= ruleXCasePart EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXCasePartRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXCasePart=ruleXCasePart();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXCasePart; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXCasePart"


    // $ANTLR start "ruleXCasePart"
    // InternalTableDSL.g:8144:1: ruleXCasePart returns [EObject current=null] : ( () ( (lv_typeGuard_1_0= ruleJvmTypeReference ) )? (otherlv_2= 'case' ( (lv_case_3_0= ruleXExpression ) ) )? ( (otherlv_4= ':' ( (lv_then_5_0= ruleXExpression ) ) ) | ( (lv_fallThrough_6_0= ',' ) ) ) ) ;
    public final EObject ruleXCasePart() throws RecognitionException {
        EObject current = null;

        Token otherlv_2=null;
        Token otherlv_4=null;
        Token lv_fallThrough_6_0=null;
        EObject lv_typeGuard_1_0 = null;

        EObject lv_case_3_0 = null;

        EObject lv_then_5_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:8150:2: ( ( () ( (lv_typeGuard_1_0= ruleJvmTypeReference ) )? (otherlv_2= 'case' ( (lv_case_3_0= ruleXExpression ) ) )? ( (otherlv_4= ':' ( (lv_then_5_0= ruleXExpression ) ) ) | ( (lv_fallThrough_6_0= ',' ) ) ) ) )
            // InternalTableDSL.g:8151:2: ( () ( (lv_typeGuard_1_0= ruleJvmTypeReference ) )? (otherlv_2= 'case' ( (lv_case_3_0= ruleXExpression ) ) )? ( (otherlv_4= ':' ( (lv_then_5_0= ruleXExpression ) ) ) | ( (lv_fallThrough_6_0= ',' ) ) ) )
            {
            // InternalTableDSL.g:8151:2: ( () ( (lv_typeGuard_1_0= ruleJvmTypeReference ) )? (otherlv_2= 'case' ( (lv_case_3_0= ruleXExpression ) ) )? ( (otherlv_4= ':' ( (lv_then_5_0= ruleXExpression ) ) ) | ( (lv_fallThrough_6_0= ',' ) ) ) )
            // InternalTableDSL.g:8152:3: () ( (lv_typeGuard_1_0= ruleJvmTypeReference ) )? (otherlv_2= 'case' ( (lv_case_3_0= ruleXExpression ) ) )? ( (otherlv_4= ':' ( (lv_then_5_0= ruleXExpression ) ) ) | ( (lv_fallThrough_6_0= ',' ) ) )
            {
            // InternalTableDSL.g:8152:3: ()
            // InternalTableDSL.g:8153:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXCasePartAccess().getXCasePartAction_0(),
              					current);
              			
            }

            }

            // InternalTableDSL.g:8159:3: ( (lv_typeGuard_1_0= ruleJvmTypeReference ) )?
            int alt111=2;
            int LA111_0 = input.LA(1);

            if ( (LA111_0==RULE_ID||LA111_0==100||LA111_0==125) ) {
                alt111=1;
            }
            switch (alt111) {
                case 1 :
                    // InternalTableDSL.g:8160:4: (lv_typeGuard_1_0= ruleJvmTypeReference )
                    {
                    // InternalTableDSL.g:8160:4: (lv_typeGuard_1_0= ruleJvmTypeReference )
                    // InternalTableDSL.g:8161:5: lv_typeGuard_1_0= ruleJvmTypeReference
                    {
                    if ( state.backtracking==0 ) {

                      					newCompositeNode(grammarAccess.getXCasePartAccess().getTypeGuardJvmTypeReferenceParserRuleCall_1_0());
                      				
                    }
                    pushFollow(FOLLOW_109);
                    lv_typeGuard_1_0=ruleJvmTypeReference();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					if (current==null) {
                      						current = createModelElementForParent(grammarAccess.getXCasePartRule());
                      					}
                      					set(
                      						current,
                      						"typeGuard",
                      						lv_typeGuard_1_0,
                      						"org.eclipse.xtext.xbase.Xtype.JvmTypeReference");
                      					afterParserOrEnumRuleCall();
                      				
                    }

                    }


                    }
                    break;

            }

            // InternalTableDSL.g:8178:3: (otherlv_2= 'case' ( (lv_case_3_0= ruleXExpression ) ) )?
            int alt112=2;
            int LA112_0 = input.LA(1);

            if ( (LA112_0==142) ) {
                alt112=1;
            }
            switch (alt112) {
                case 1 :
                    // InternalTableDSL.g:8179:4: otherlv_2= 'case' ( (lv_case_3_0= ruleXExpression ) )
                    {
                    otherlv_2=(Token)match(input,142,FOLLOW_65); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_2, grammarAccess.getXCasePartAccess().getCaseKeyword_2_0());
                      			
                    }
                    // InternalTableDSL.g:8183:4: ( (lv_case_3_0= ruleXExpression ) )
                    // InternalTableDSL.g:8184:5: (lv_case_3_0= ruleXExpression )
                    {
                    // InternalTableDSL.g:8184:5: (lv_case_3_0= ruleXExpression )
                    // InternalTableDSL.g:8185:6: lv_case_3_0= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXCasePartAccess().getCaseXExpressionParserRuleCall_2_1_0());
                      					
                    }
                    pushFollow(FOLLOW_110);
                    lv_case_3_0=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getXCasePartRule());
                      						}
                      						set(
                      							current,
                      							"case",
                      							lv_case_3_0,
                      							"org.eclipse.xtext.xbase.Xbase.XExpression");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }


                    }
                    break;

            }

            // InternalTableDSL.g:8203:3: ( (otherlv_4= ':' ( (lv_then_5_0= ruleXExpression ) ) ) | ( (lv_fallThrough_6_0= ',' ) ) )
            int alt113=2;
            int LA113_0 = input.LA(1);

            if ( (LA113_0==140) ) {
                alt113=1;
            }
            else if ( (LA113_0==101) ) {
                alt113=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 113, 0, input);

                throw nvae;
            }
            switch (alt113) {
                case 1 :
                    // InternalTableDSL.g:8204:4: (otherlv_4= ':' ( (lv_then_5_0= ruleXExpression ) ) )
                    {
                    // InternalTableDSL.g:8204:4: (otherlv_4= ':' ( (lv_then_5_0= ruleXExpression ) ) )
                    // InternalTableDSL.g:8205:5: otherlv_4= ':' ( (lv_then_5_0= ruleXExpression ) )
                    {
                    otherlv_4=(Token)match(input,140,FOLLOW_65); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					newLeafNode(otherlv_4, grammarAccess.getXCasePartAccess().getColonKeyword_3_0_0());
                      				
                    }
                    // InternalTableDSL.g:8209:5: ( (lv_then_5_0= ruleXExpression ) )
                    // InternalTableDSL.g:8210:6: (lv_then_5_0= ruleXExpression )
                    {
                    // InternalTableDSL.g:8210:6: (lv_then_5_0= ruleXExpression )
                    // InternalTableDSL.g:8211:7: lv_then_5_0= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      							newCompositeNode(grammarAccess.getXCasePartAccess().getThenXExpressionParserRuleCall_3_0_1_0());
                      						
                    }
                    pushFollow(FOLLOW_2);
                    lv_then_5_0=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      							if (current==null) {
                      								current = createModelElementForParent(grammarAccess.getXCasePartRule());
                      							}
                      							set(
                      								current,
                      								"then",
                      								lv_then_5_0,
                      								"org.eclipse.xtext.xbase.Xbase.XExpression");
                      							afterParserOrEnumRuleCall();
                      						
                    }

                    }


                    }


                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:8230:4: ( (lv_fallThrough_6_0= ',' ) )
                    {
                    // InternalTableDSL.g:8230:4: ( (lv_fallThrough_6_0= ',' ) )
                    // InternalTableDSL.g:8231:5: (lv_fallThrough_6_0= ',' )
                    {
                    // InternalTableDSL.g:8231:5: (lv_fallThrough_6_0= ',' )
                    // InternalTableDSL.g:8232:6: lv_fallThrough_6_0= ','
                    {
                    lv_fallThrough_6_0=(Token)match(input,101,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						newLeafNode(lv_fallThrough_6_0, grammarAccess.getXCasePartAccess().getFallThroughCommaKeyword_3_1_0());
                      					
                    }
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElement(grammarAccess.getXCasePartRule());
                      						}
                      						setWithLastConsumed(current, "fallThrough", true, ",");
                      					
                    }

                    }


                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXCasePart"


    // $ANTLR start "entryRuleXForLoopExpression"
    // InternalTableDSL.g:8249:1: entryRuleXForLoopExpression returns [EObject current=null] : iv_ruleXForLoopExpression= ruleXForLoopExpression EOF ;
    public final EObject entryRuleXForLoopExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXForLoopExpression = null;


        try {
            // InternalTableDSL.g:8249:59: (iv_ruleXForLoopExpression= ruleXForLoopExpression EOF )
            // InternalTableDSL.g:8250:2: iv_ruleXForLoopExpression= ruleXForLoopExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXForLoopExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXForLoopExpression=ruleXForLoopExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXForLoopExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXForLoopExpression"


    // $ANTLR start "ruleXForLoopExpression"
    // InternalTableDSL.g:8256:1: ruleXForLoopExpression returns [EObject current=null] : ( ( ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( () otherlv_1= 'for' otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_forExpression_5_0= ruleXExpression ) ) otherlv_6= ')' ( (lv_eachExpression_7_0= ruleXExpression ) ) ) ;
    public final EObject ruleXForLoopExpression() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token otherlv_4=null;
        Token otherlv_6=null;
        EObject lv_declaredParam_3_0 = null;

        EObject lv_forExpression_5_0 = null;

        EObject lv_eachExpression_7_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:8262:2: ( ( ( ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( () otherlv_1= 'for' otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_forExpression_5_0= ruleXExpression ) ) otherlv_6= ')' ( (lv_eachExpression_7_0= ruleXExpression ) ) ) )
            // InternalTableDSL.g:8263:2: ( ( ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( () otherlv_1= 'for' otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_forExpression_5_0= ruleXExpression ) ) otherlv_6= ')' ( (lv_eachExpression_7_0= ruleXExpression ) ) )
            {
            // InternalTableDSL.g:8263:2: ( ( ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( () otherlv_1= 'for' otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_forExpression_5_0= ruleXExpression ) ) otherlv_6= ')' ( (lv_eachExpression_7_0= ruleXExpression ) ) )
            // InternalTableDSL.g:8264:3: ( ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( () otherlv_1= 'for' otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_forExpression_5_0= ruleXExpression ) ) otherlv_6= ')' ( (lv_eachExpression_7_0= ruleXExpression ) )
            {
            // InternalTableDSL.g:8264:3: ( ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( () otherlv_1= 'for' otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) )
            // InternalTableDSL.g:8265:4: ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( () otherlv_1= 'for' otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' )
            {
            // InternalTableDSL.g:8278:4: ( () otherlv_1= 'for' otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' )
            // InternalTableDSL.g:8279:5: () otherlv_1= 'for' otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':'
            {
            // InternalTableDSL.g:8279:5: ()
            // InternalTableDSL.g:8280:6: 
            {
            if ( state.backtracking==0 ) {

              						current = forceCreateModelElement(
              							grammarAccess.getXForLoopExpressionAccess().getXForLoopExpressionAction_0_0_0(),
              							current);
              					
            }

            }

            otherlv_1=(Token)match(input,143,FOLLOW_103); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_1, grammarAccess.getXForLoopExpressionAccess().getForKeyword_0_0_1());
              				
            }
            otherlv_2=(Token)match(input,100,FOLLOW_78); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_2, grammarAccess.getXForLoopExpressionAccess().getLeftParenthesisKeyword_0_0_2());
              				
            }
            // InternalTableDSL.g:8294:5: ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) )
            // InternalTableDSL.g:8295:6: (lv_declaredParam_3_0= ruleJvmFormalParameter )
            {
            // InternalTableDSL.g:8295:6: (lv_declaredParam_3_0= ruleJvmFormalParameter )
            // InternalTableDSL.g:8296:7: lv_declaredParam_3_0= ruleJvmFormalParameter
            {
            if ( state.backtracking==0 ) {

              							newCompositeNode(grammarAccess.getXForLoopExpressionAccess().getDeclaredParamJvmFormalParameterParserRuleCall_0_0_3_0());
              						
            }
            pushFollow(FOLLOW_106);
            lv_declaredParam_3_0=ruleJvmFormalParameter();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              							if (current==null) {
              								current = createModelElementForParent(grammarAccess.getXForLoopExpressionRule());
              							}
              							set(
              								current,
              								"declaredParam",
              								lv_declaredParam_3_0,
              								"org.eclipse.xtext.xbase.Xbase.JvmFormalParameter");
              							afterParserOrEnumRuleCall();
              						
            }

            }


            }

            otherlv_4=(Token)match(input,140,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_4, grammarAccess.getXForLoopExpressionAccess().getColonKeyword_0_0_4());
              				
            }

            }


            }

            // InternalTableDSL.g:8319:3: ( (lv_forExpression_5_0= ruleXExpression ) )
            // InternalTableDSL.g:8320:4: (lv_forExpression_5_0= ruleXExpression )
            {
            // InternalTableDSL.g:8320:4: (lv_forExpression_5_0= ruleXExpression )
            // InternalTableDSL.g:8321:5: lv_forExpression_5_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXForLoopExpressionAccess().getForExpressionXExpressionParserRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_63);
            lv_forExpression_5_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXForLoopExpressionRule());
              					}
              					set(
              						current,
              						"forExpression",
              						lv_forExpression_5_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            otherlv_6=(Token)match(input,102,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_6, grammarAccess.getXForLoopExpressionAccess().getRightParenthesisKeyword_2());
              		
            }
            // InternalTableDSL.g:8342:3: ( (lv_eachExpression_7_0= ruleXExpression ) )
            // InternalTableDSL.g:8343:4: (lv_eachExpression_7_0= ruleXExpression )
            {
            // InternalTableDSL.g:8343:4: (lv_eachExpression_7_0= ruleXExpression )
            // InternalTableDSL.g:8344:5: lv_eachExpression_7_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXForLoopExpressionAccess().getEachExpressionXExpressionParserRuleCall_3_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_eachExpression_7_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXForLoopExpressionRule());
              					}
              					set(
              						current,
              						"eachExpression",
              						lv_eachExpression_7_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXForLoopExpression"


    // $ANTLR start "entryRuleXBasicForLoopExpression"
    // InternalTableDSL.g:8365:1: entryRuleXBasicForLoopExpression returns [EObject current=null] : iv_ruleXBasicForLoopExpression= ruleXBasicForLoopExpression EOF ;
    public final EObject entryRuleXBasicForLoopExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXBasicForLoopExpression = null;


        try {
            // InternalTableDSL.g:8365:64: (iv_ruleXBasicForLoopExpression= ruleXBasicForLoopExpression EOF )
            // InternalTableDSL.g:8366:2: iv_ruleXBasicForLoopExpression= ruleXBasicForLoopExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXBasicForLoopExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXBasicForLoopExpression=ruleXBasicForLoopExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXBasicForLoopExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXBasicForLoopExpression"


    // $ANTLR start "ruleXBasicForLoopExpression"
    // InternalTableDSL.g:8372:1: ruleXBasicForLoopExpression returns [EObject current=null] : ( () otherlv_1= 'for' otherlv_2= '(' ( ( (lv_initExpressions_3_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_4= ',' ( (lv_initExpressions_5_0= ruleXExpressionOrVarDeclaration ) ) )* )? otherlv_6= ';' ( (lv_expression_7_0= ruleXExpression ) )? otherlv_8= ';' ( ( (lv_updateExpressions_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_updateExpressions_11_0= ruleXExpression ) ) )* )? otherlv_12= ')' ( (lv_eachExpression_13_0= ruleXExpression ) ) ) ;
    public final EObject ruleXBasicForLoopExpression() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token otherlv_4=null;
        Token otherlv_6=null;
        Token otherlv_8=null;
        Token otherlv_10=null;
        Token otherlv_12=null;
        EObject lv_initExpressions_3_0 = null;

        EObject lv_initExpressions_5_0 = null;

        EObject lv_expression_7_0 = null;

        EObject lv_updateExpressions_9_0 = null;

        EObject lv_updateExpressions_11_0 = null;

        EObject lv_eachExpression_13_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:8378:2: ( ( () otherlv_1= 'for' otherlv_2= '(' ( ( (lv_initExpressions_3_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_4= ',' ( (lv_initExpressions_5_0= ruleXExpressionOrVarDeclaration ) ) )* )? otherlv_6= ';' ( (lv_expression_7_0= ruleXExpression ) )? otherlv_8= ';' ( ( (lv_updateExpressions_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_updateExpressions_11_0= ruleXExpression ) ) )* )? otherlv_12= ')' ( (lv_eachExpression_13_0= ruleXExpression ) ) ) )
            // InternalTableDSL.g:8379:2: ( () otherlv_1= 'for' otherlv_2= '(' ( ( (lv_initExpressions_3_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_4= ',' ( (lv_initExpressions_5_0= ruleXExpressionOrVarDeclaration ) ) )* )? otherlv_6= ';' ( (lv_expression_7_0= ruleXExpression ) )? otherlv_8= ';' ( ( (lv_updateExpressions_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_updateExpressions_11_0= ruleXExpression ) ) )* )? otherlv_12= ')' ( (lv_eachExpression_13_0= ruleXExpression ) ) )
            {
            // InternalTableDSL.g:8379:2: ( () otherlv_1= 'for' otherlv_2= '(' ( ( (lv_initExpressions_3_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_4= ',' ( (lv_initExpressions_5_0= ruleXExpressionOrVarDeclaration ) ) )* )? otherlv_6= ';' ( (lv_expression_7_0= ruleXExpression ) )? otherlv_8= ';' ( ( (lv_updateExpressions_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_updateExpressions_11_0= ruleXExpression ) ) )* )? otherlv_12= ')' ( (lv_eachExpression_13_0= ruleXExpression ) ) )
            // InternalTableDSL.g:8380:3: () otherlv_1= 'for' otherlv_2= '(' ( ( (lv_initExpressions_3_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_4= ',' ( (lv_initExpressions_5_0= ruleXExpressionOrVarDeclaration ) ) )* )? otherlv_6= ';' ( (lv_expression_7_0= ruleXExpression ) )? otherlv_8= ';' ( ( (lv_updateExpressions_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_updateExpressions_11_0= ruleXExpression ) ) )* )? otherlv_12= ')' ( (lv_eachExpression_13_0= ruleXExpression ) )
            {
            // InternalTableDSL.g:8380:3: ()
            // InternalTableDSL.g:8381:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXBasicForLoopExpressionAccess().getXBasicForLoopExpressionAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,143,FOLLOW_103); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXBasicForLoopExpressionAccess().getForKeyword_1());
              		
            }
            otherlv_2=(Token)match(input,100,FOLLOW_111); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_2, grammarAccess.getXBasicForLoopExpressionAccess().getLeftParenthesisKeyword_2());
              		
            }
            // InternalTableDSL.g:8395:3: ( ( (lv_initExpressions_3_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_4= ',' ( (lv_initExpressions_5_0= ruleXExpressionOrVarDeclaration ) ) )* )?
            int alt115=2;
            int LA115_0 = input.LA(1);

            if ( ((LA115_0>=RULE_ID && LA115_0<=RULE_STRING)||(LA115_0>=RULE_INT && LA115_0<=RULE_DECIMAL)||LA115_0==16||(LA115_0>=91 && LA115_0<=95)||LA115_0==100||(LA115_0>=104 && LA115_0<=105)||LA115_0==112||LA115_0==131||LA115_0==137||LA115_0==139||(LA115_0>=143 && LA115_0<=157)||LA115_0==159) ) {
                alt115=1;
            }
            switch (alt115) {
                case 1 :
                    // InternalTableDSL.g:8396:4: ( (lv_initExpressions_3_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_4= ',' ( (lv_initExpressions_5_0= ruleXExpressionOrVarDeclaration ) ) )*
                    {
                    // InternalTableDSL.g:8396:4: ( (lv_initExpressions_3_0= ruleXExpressionOrVarDeclaration ) )
                    // InternalTableDSL.g:8397:5: (lv_initExpressions_3_0= ruleXExpressionOrVarDeclaration )
                    {
                    // InternalTableDSL.g:8397:5: (lv_initExpressions_3_0= ruleXExpressionOrVarDeclaration )
                    // InternalTableDSL.g:8398:6: lv_initExpressions_3_0= ruleXExpressionOrVarDeclaration
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXBasicForLoopExpressionAccess().getInitExpressionsXExpressionOrVarDeclarationParserRuleCall_3_0_0());
                      					
                    }
                    pushFollow(FOLLOW_112);
                    lv_initExpressions_3_0=ruleXExpressionOrVarDeclaration();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getXBasicForLoopExpressionRule());
                      						}
                      						add(
                      							current,
                      							"initExpressions",
                      							lv_initExpressions_3_0,
                      							"org.eclipse.xtext.xbase.Xbase.XExpressionOrVarDeclaration");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }

                    // InternalTableDSL.g:8415:4: (otherlv_4= ',' ( (lv_initExpressions_5_0= ruleXExpressionOrVarDeclaration ) ) )*
                    loop114:
                    do {
                        int alt114=2;
                        int LA114_0 = input.LA(1);

                        if ( (LA114_0==101) ) {
                            alt114=1;
                        }


                        switch (alt114) {
                    	case 1 :
                    	    // InternalTableDSL.g:8416:5: otherlv_4= ',' ( (lv_initExpressions_5_0= ruleXExpressionOrVarDeclaration ) )
                    	    {
                    	    otherlv_4=(Token)match(input,101,FOLLOW_113); if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      					newLeafNode(otherlv_4, grammarAccess.getXBasicForLoopExpressionAccess().getCommaKeyword_3_1_0());
                    	      				
                    	    }
                    	    // InternalTableDSL.g:8420:5: ( (lv_initExpressions_5_0= ruleXExpressionOrVarDeclaration ) )
                    	    // InternalTableDSL.g:8421:6: (lv_initExpressions_5_0= ruleXExpressionOrVarDeclaration )
                    	    {
                    	    // InternalTableDSL.g:8421:6: (lv_initExpressions_5_0= ruleXExpressionOrVarDeclaration )
                    	    // InternalTableDSL.g:8422:7: lv_initExpressions_5_0= ruleXExpressionOrVarDeclaration
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      							newCompositeNode(grammarAccess.getXBasicForLoopExpressionAccess().getInitExpressionsXExpressionOrVarDeclarationParserRuleCall_3_1_1_0());
                    	      						
                    	    }
                    	    pushFollow(FOLLOW_112);
                    	    lv_initExpressions_5_0=ruleXExpressionOrVarDeclaration();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      							if (current==null) {
                    	      								current = createModelElementForParent(grammarAccess.getXBasicForLoopExpressionRule());
                    	      							}
                    	      							add(
                    	      								current,
                    	      								"initExpressions",
                    	      								lv_initExpressions_5_0,
                    	      								"org.eclipse.xtext.xbase.Xbase.XExpressionOrVarDeclaration");
                    	      							afterParserOrEnumRuleCall();
                    	      						
                    	    }

                    	    }


                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop114;
                        }
                    } while (true);


                    }
                    break;

            }

            otherlv_6=(Token)match(input,98,FOLLOW_114); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_6, grammarAccess.getXBasicForLoopExpressionAccess().getSemicolonKeyword_4());
              		
            }
            // InternalTableDSL.g:8445:3: ( (lv_expression_7_0= ruleXExpression ) )?
            int alt116=2;
            int LA116_0 = input.LA(1);

            if ( ((LA116_0>=RULE_ID && LA116_0<=RULE_STRING)||(LA116_0>=RULE_INT && LA116_0<=RULE_DECIMAL)||LA116_0==16||(LA116_0>=91 && LA116_0<=95)||LA116_0==100||(LA116_0>=104 && LA116_0<=105)||LA116_0==112||LA116_0==131||LA116_0==137||LA116_0==139||(LA116_0>=143 && LA116_0<=145)||(LA116_0>=148 && LA116_0<=157)||LA116_0==159) ) {
                alt116=1;
            }
            switch (alt116) {
                case 1 :
                    // InternalTableDSL.g:8446:4: (lv_expression_7_0= ruleXExpression )
                    {
                    // InternalTableDSL.g:8446:4: (lv_expression_7_0= ruleXExpression )
                    // InternalTableDSL.g:8447:5: lv_expression_7_0= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      					newCompositeNode(grammarAccess.getXBasicForLoopExpressionAccess().getExpressionXExpressionParserRuleCall_5_0());
                      				
                    }
                    pushFollow(FOLLOW_115);
                    lv_expression_7_0=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					if (current==null) {
                      						current = createModelElementForParent(grammarAccess.getXBasicForLoopExpressionRule());
                      					}
                      					set(
                      						current,
                      						"expression",
                      						lv_expression_7_0,
                      						"org.eclipse.xtext.xbase.Xbase.XExpression");
                      					afterParserOrEnumRuleCall();
                      				
                    }

                    }


                    }
                    break;

            }

            otherlv_8=(Token)match(input,98,FOLLOW_61); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_8, grammarAccess.getXBasicForLoopExpressionAccess().getSemicolonKeyword_6());
              		
            }
            // InternalTableDSL.g:8468:3: ( ( (lv_updateExpressions_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_updateExpressions_11_0= ruleXExpression ) ) )* )?
            int alt118=2;
            int LA118_0 = input.LA(1);

            if ( ((LA118_0>=RULE_ID && LA118_0<=RULE_STRING)||(LA118_0>=RULE_INT && LA118_0<=RULE_DECIMAL)||LA118_0==16||(LA118_0>=91 && LA118_0<=95)||LA118_0==100||(LA118_0>=104 && LA118_0<=105)||LA118_0==112||LA118_0==131||LA118_0==137||LA118_0==139||(LA118_0>=143 && LA118_0<=145)||(LA118_0>=148 && LA118_0<=157)||LA118_0==159) ) {
                alt118=1;
            }
            switch (alt118) {
                case 1 :
                    // InternalTableDSL.g:8469:4: ( (lv_updateExpressions_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_updateExpressions_11_0= ruleXExpression ) ) )*
                    {
                    // InternalTableDSL.g:8469:4: ( (lv_updateExpressions_9_0= ruleXExpression ) )
                    // InternalTableDSL.g:8470:5: (lv_updateExpressions_9_0= ruleXExpression )
                    {
                    // InternalTableDSL.g:8470:5: (lv_updateExpressions_9_0= ruleXExpression )
                    // InternalTableDSL.g:8471:6: lv_updateExpressions_9_0= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXBasicForLoopExpressionAccess().getUpdateExpressionsXExpressionParserRuleCall_7_0_0());
                      					
                    }
                    pushFollow(FOLLOW_62);
                    lv_updateExpressions_9_0=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getXBasicForLoopExpressionRule());
                      						}
                      						add(
                      							current,
                      							"updateExpressions",
                      							lv_updateExpressions_9_0,
                      							"org.eclipse.xtext.xbase.Xbase.XExpression");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }

                    // InternalTableDSL.g:8488:4: (otherlv_10= ',' ( (lv_updateExpressions_11_0= ruleXExpression ) ) )*
                    loop117:
                    do {
                        int alt117=2;
                        int LA117_0 = input.LA(1);

                        if ( (LA117_0==101) ) {
                            alt117=1;
                        }


                        switch (alt117) {
                    	case 1 :
                    	    // InternalTableDSL.g:8489:5: otherlv_10= ',' ( (lv_updateExpressions_11_0= ruleXExpression ) )
                    	    {
                    	    otherlv_10=(Token)match(input,101,FOLLOW_65); if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      					newLeafNode(otherlv_10, grammarAccess.getXBasicForLoopExpressionAccess().getCommaKeyword_7_1_0());
                    	      				
                    	    }
                    	    // InternalTableDSL.g:8493:5: ( (lv_updateExpressions_11_0= ruleXExpression ) )
                    	    // InternalTableDSL.g:8494:6: (lv_updateExpressions_11_0= ruleXExpression )
                    	    {
                    	    // InternalTableDSL.g:8494:6: (lv_updateExpressions_11_0= ruleXExpression )
                    	    // InternalTableDSL.g:8495:7: lv_updateExpressions_11_0= ruleXExpression
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      							newCompositeNode(grammarAccess.getXBasicForLoopExpressionAccess().getUpdateExpressionsXExpressionParserRuleCall_7_1_1_0());
                    	      						
                    	    }
                    	    pushFollow(FOLLOW_62);
                    	    lv_updateExpressions_11_0=ruleXExpression();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      							if (current==null) {
                    	      								current = createModelElementForParent(grammarAccess.getXBasicForLoopExpressionRule());
                    	      							}
                    	      							add(
                    	      								current,
                    	      								"updateExpressions",
                    	      								lv_updateExpressions_11_0,
                    	      								"org.eclipse.xtext.xbase.Xbase.XExpression");
                    	      							afterParserOrEnumRuleCall();
                    	      						
                    	    }

                    	    }


                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop117;
                        }
                    } while (true);


                    }
                    break;

            }

            otherlv_12=(Token)match(input,102,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_12, grammarAccess.getXBasicForLoopExpressionAccess().getRightParenthesisKeyword_8());
              		
            }
            // InternalTableDSL.g:8518:3: ( (lv_eachExpression_13_0= ruleXExpression ) )
            // InternalTableDSL.g:8519:4: (lv_eachExpression_13_0= ruleXExpression )
            {
            // InternalTableDSL.g:8519:4: (lv_eachExpression_13_0= ruleXExpression )
            // InternalTableDSL.g:8520:5: lv_eachExpression_13_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXBasicForLoopExpressionAccess().getEachExpressionXExpressionParserRuleCall_9_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_eachExpression_13_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXBasicForLoopExpressionRule());
              					}
              					set(
              						current,
              						"eachExpression",
              						lv_eachExpression_13_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXBasicForLoopExpression"


    // $ANTLR start "entryRuleXWhileExpression"
    // InternalTableDSL.g:8541:1: entryRuleXWhileExpression returns [EObject current=null] : iv_ruleXWhileExpression= ruleXWhileExpression EOF ;
    public final EObject entryRuleXWhileExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXWhileExpression = null;


        try {
            // InternalTableDSL.g:8541:57: (iv_ruleXWhileExpression= ruleXWhileExpression EOF )
            // InternalTableDSL.g:8542:2: iv_ruleXWhileExpression= ruleXWhileExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXWhileExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXWhileExpression=ruleXWhileExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXWhileExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXWhileExpression"


    // $ANTLR start "ruleXWhileExpression"
    // InternalTableDSL.g:8548:1: ruleXWhileExpression returns [EObject current=null] : ( () otherlv_1= 'while' otherlv_2= '(' ( (lv_predicate_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_body_5_0= ruleXExpression ) ) ) ;
    public final EObject ruleXWhileExpression() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token otherlv_4=null;
        EObject lv_predicate_3_0 = null;

        EObject lv_body_5_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:8554:2: ( ( () otherlv_1= 'while' otherlv_2= '(' ( (lv_predicate_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_body_5_0= ruleXExpression ) ) ) )
            // InternalTableDSL.g:8555:2: ( () otherlv_1= 'while' otherlv_2= '(' ( (lv_predicate_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_body_5_0= ruleXExpression ) ) )
            {
            // InternalTableDSL.g:8555:2: ( () otherlv_1= 'while' otherlv_2= '(' ( (lv_predicate_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_body_5_0= ruleXExpression ) ) )
            // InternalTableDSL.g:8556:3: () otherlv_1= 'while' otherlv_2= '(' ( (lv_predicate_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_body_5_0= ruleXExpression ) )
            {
            // InternalTableDSL.g:8556:3: ()
            // InternalTableDSL.g:8557:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXWhileExpressionAccess().getXWhileExpressionAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,144,FOLLOW_103); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXWhileExpressionAccess().getWhileKeyword_1());
              		
            }
            otherlv_2=(Token)match(input,100,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_2, grammarAccess.getXWhileExpressionAccess().getLeftParenthesisKeyword_2());
              		
            }
            // InternalTableDSL.g:8571:3: ( (lv_predicate_3_0= ruleXExpression ) )
            // InternalTableDSL.g:8572:4: (lv_predicate_3_0= ruleXExpression )
            {
            // InternalTableDSL.g:8572:4: (lv_predicate_3_0= ruleXExpression )
            // InternalTableDSL.g:8573:5: lv_predicate_3_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXWhileExpressionAccess().getPredicateXExpressionParserRuleCall_3_0());
              				
            }
            pushFollow(FOLLOW_63);
            lv_predicate_3_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXWhileExpressionRule());
              					}
              					set(
              						current,
              						"predicate",
              						lv_predicate_3_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            otherlv_4=(Token)match(input,102,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_4, grammarAccess.getXWhileExpressionAccess().getRightParenthesisKeyword_4());
              		
            }
            // InternalTableDSL.g:8594:3: ( (lv_body_5_0= ruleXExpression ) )
            // InternalTableDSL.g:8595:4: (lv_body_5_0= ruleXExpression )
            {
            // InternalTableDSL.g:8595:4: (lv_body_5_0= ruleXExpression )
            // InternalTableDSL.g:8596:5: lv_body_5_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXWhileExpressionAccess().getBodyXExpressionParserRuleCall_5_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_body_5_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXWhileExpressionRule());
              					}
              					set(
              						current,
              						"body",
              						lv_body_5_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXWhileExpression"


    // $ANTLR start "entryRuleXDoWhileExpression"
    // InternalTableDSL.g:8617:1: entryRuleXDoWhileExpression returns [EObject current=null] : iv_ruleXDoWhileExpression= ruleXDoWhileExpression EOF ;
    public final EObject entryRuleXDoWhileExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXDoWhileExpression = null;


        try {
            // InternalTableDSL.g:8617:59: (iv_ruleXDoWhileExpression= ruleXDoWhileExpression EOF )
            // InternalTableDSL.g:8618:2: iv_ruleXDoWhileExpression= ruleXDoWhileExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXDoWhileExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXDoWhileExpression=ruleXDoWhileExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXDoWhileExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXDoWhileExpression"


    // $ANTLR start "ruleXDoWhileExpression"
    // InternalTableDSL.g:8624:1: ruleXDoWhileExpression returns [EObject current=null] : ( () otherlv_1= 'do' ( (lv_body_2_0= ruleXExpression ) ) otherlv_3= 'while' otherlv_4= '(' ( (lv_predicate_5_0= ruleXExpression ) ) otherlv_6= ')' ) ;
    public final EObject ruleXDoWhileExpression() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_3=null;
        Token otherlv_4=null;
        Token otherlv_6=null;
        EObject lv_body_2_0 = null;

        EObject lv_predicate_5_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:8630:2: ( ( () otherlv_1= 'do' ( (lv_body_2_0= ruleXExpression ) ) otherlv_3= 'while' otherlv_4= '(' ( (lv_predicate_5_0= ruleXExpression ) ) otherlv_6= ')' ) )
            // InternalTableDSL.g:8631:2: ( () otherlv_1= 'do' ( (lv_body_2_0= ruleXExpression ) ) otherlv_3= 'while' otherlv_4= '(' ( (lv_predicate_5_0= ruleXExpression ) ) otherlv_6= ')' )
            {
            // InternalTableDSL.g:8631:2: ( () otherlv_1= 'do' ( (lv_body_2_0= ruleXExpression ) ) otherlv_3= 'while' otherlv_4= '(' ( (lv_predicate_5_0= ruleXExpression ) ) otherlv_6= ')' )
            // InternalTableDSL.g:8632:3: () otherlv_1= 'do' ( (lv_body_2_0= ruleXExpression ) ) otherlv_3= 'while' otherlv_4= '(' ( (lv_predicate_5_0= ruleXExpression ) ) otherlv_6= ')'
            {
            // InternalTableDSL.g:8632:3: ()
            // InternalTableDSL.g:8633:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXDoWhileExpressionAccess().getXDoWhileExpressionAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,145,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXDoWhileExpressionAccess().getDoKeyword_1());
              		
            }
            // InternalTableDSL.g:8643:3: ( (lv_body_2_0= ruleXExpression ) )
            // InternalTableDSL.g:8644:4: (lv_body_2_0= ruleXExpression )
            {
            // InternalTableDSL.g:8644:4: (lv_body_2_0= ruleXExpression )
            // InternalTableDSL.g:8645:5: lv_body_2_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXDoWhileExpressionAccess().getBodyXExpressionParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_116);
            lv_body_2_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXDoWhileExpressionRule());
              					}
              					set(
              						current,
              						"body",
              						lv_body_2_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            otherlv_3=(Token)match(input,144,FOLLOW_103); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_3, grammarAccess.getXDoWhileExpressionAccess().getWhileKeyword_3());
              		
            }
            otherlv_4=(Token)match(input,100,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_4, grammarAccess.getXDoWhileExpressionAccess().getLeftParenthesisKeyword_4());
              		
            }
            // InternalTableDSL.g:8670:3: ( (lv_predicate_5_0= ruleXExpression ) )
            // InternalTableDSL.g:8671:4: (lv_predicate_5_0= ruleXExpression )
            {
            // InternalTableDSL.g:8671:4: (lv_predicate_5_0= ruleXExpression )
            // InternalTableDSL.g:8672:5: lv_predicate_5_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXDoWhileExpressionAccess().getPredicateXExpressionParserRuleCall_5_0());
              				
            }
            pushFollow(FOLLOW_63);
            lv_predicate_5_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXDoWhileExpressionRule());
              					}
              					set(
              						current,
              						"predicate",
              						lv_predicate_5_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            otherlv_6=(Token)match(input,102,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_6, grammarAccess.getXDoWhileExpressionAccess().getRightParenthesisKeyword_6());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXDoWhileExpression"


    // $ANTLR start "entryRuleXBlockExpression"
    // InternalTableDSL.g:8697:1: entryRuleXBlockExpression returns [EObject current=null] : iv_ruleXBlockExpression= ruleXBlockExpression EOF ;
    public final EObject entryRuleXBlockExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXBlockExpression = null;


        try {
            // InternalTableDSL.g:8697:57: (iv_ruleXBlockExpression= ruleXBlockExpression EOF )
            // InternalTableDSL.g:8698:2: iv_ruleXBlockExpression= ruleXBlockExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXBlockExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXBlockExpression=ruleXBlockExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXBlockExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXBlockExpression"


    // $ANTLR start "ruleXBlockExpression"
    // InternalTableDSL.g:8704:1: ruleXBlockExpression returns [EObject current=null] : ( () otherlv_1= '{' ( ( (lv_expressions_2_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_3= ';' )? )* otherlv_4= '}' ) ;
    public final EObject ruleXBlockExpression() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_3=null;
        Token otherlv_4=null;
        EObject lv_expressions_2_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:8710:2: ( ( () otherlv_1= '{' ( ( (lv_expressions_2_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_3= ';' )? )* otherlv_4= '}' ) )
            // InternalTableDSL.g:8711:2: ( () otherlv_1= '{' ( ( (lv_expressions_2_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_3= ';' )? )* otherlv_4= '}' )
            {
            // InternalTableDSL.g:8711:2: ( () otherlv_1= '{' ( ( (lv_expressions_2_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_3= ';' )? )* otherlv_4= '}' )
            // InternalTableDSL.g:8712:3: () otherlv_1= '{' ( ( (lv_expressions_2_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_3= ';' )? )* otherlv_4= '}'
            {
            // InternalTableDSL.g:8712:3: ()
            // InternalTableDSL.g:8713:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXBlockExpressionAccess().getXBlockExpressionAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,16,FOLLOW_117); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXBlockExpressionAccess().getLeftCurlyBracketKeyword_1());
              		
            }
            // InternalTableDSL.g:8723:3: ( ( (lv_expressions_2_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_3= ';' )? )*
            loop120:
            do {
                int alt120=2;
                int LA120_0 = input.LA(1);

                if ( ((LA120_0>=RULE_ID && LA120_0<=RULE_STRING)||(LA120_0>=RULE_INT && LA120_0<=RULE_DECIMAL)||LA120_0==16||(LA120_0>=91 && LA120_0<=95)||LA120_0==100||(LA120_0>=104 && LA120_0<=105)||LA120_0==112||LA120_0==131||LA120_0==137||LA120_0==139||(LA120_0>=143 && LA120_0<=157)||LA120_0==159) ) {
                    alt120=1;
                }


                switch (alt120) {
            	case 1 :
            	    // InternalTableDSL.g:8724:4: ( (lv_expressions_2_0= ruleXExpressionOrVarDeclaration ) ) (otherlv_3= ';' )?
            	    {
            	    // InternalTableDSL.g:8724:4: ( (lv_expressions_2_0= ruleXExpressionOrVarDeclaration ) )
            	    // InternalTableDSL.g:8725:5: (lv_expressions_2_0= ruleXExpressionOrVarDeclaration )
            	    {
            	    // InternalTableDSL.g:8725:5: (lv_expressions_2_0= ruleXExpressionOrVarDeclaration )
            	    // InternalTableDSL.g:8726:6: lv_expressions_2_0= ruleXExpressionOrVarDeclaration
            	    {
            	    if ( state.backtracking==0 ) {

            	      						newCompositeNode(grammarAccess.getXBlockExpressionAccess().getExpressionsXExpressionOrVarDeclarationParserRuleCall_2_0_0());
            	      					
            	    }
            	    pushFollow(FOLLOW_118);
            	    lv_expressions_2_0=ruleXExpressionOrVarDeclaration();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      						if (current==null) {
            	      							current = createModelElementForParent(grammarAccess.getXBlockExpressionRule());
            	      						}
            	      						add(
            	      							current,
            	      							"expressions",
            	      							lv_expressions_2_0,
            	      							"org.eclipse.xtext.xbase.Xbase.XExpressionOrVarDeclaration");
            	      						afterParserOrEnumRuleCall();
            	      					
            	    }

            	    }


            	    }

            	    // InternalTableDSL.g:8743:4: (otherlv_3= ';' )?
            	    int alt119=2;
            	    int LA119_0 = input.LA(1);

            	    if ( (LA119_0==98) ) {
            	        alt119=1;
            	    }
            	    switch (alt119) {
            	        case 1 :
            	            // InternalTableDSL.g:8744:5: otherlv_3= ';'
            	            {
            	            otherlv_3=(Token)match(input,98,FOLLOW_117); if (state.failed) return current;
            	            if ( state.backtracking==0 ) {

            	              					newLeafNode(otherlv_3, grammarAccess.getXBlockExpressionAccess().getSemicolonKeyword_2_1());
            	              				
            	            }

            	            }
            	            break;

            	    }


            	    }
            	    break;

            	default :
            	    break loop120;
                }
            } while (true);

            otherlv_4=(Token)match(input,17,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_4, grammarAccess.getXBlockExpressionAccess().getRightCurlyBracketKeyword_3());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXBlockExpression"


    // $ANTLR start "entryRuleXExpressionOrVarDeclaration"
    // InternalTableDSL.g:8758:1: entryRuleXExpressionOrVarDeclaration returns [EObject current=null] : iv_ruleXExpressionOrVarDeclaration= ruleXExpressionOrVarDeclaration EOF ;
    public final EObject entryRuleXExpressionOrVarDeclaration() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXExpressionOrVarDeclaration = null;


        try {
            // InternalTableDSL.g:8758:68: (iv_ruleXExpressionOrVarDeclaration= ruleXExpressionOrVarDeclaration EOF )
            // InternalTableDSL.g:8759:2: iv_ruleXExpressionOrVarDeclaration= ruleXExpressionOrVarDeclaration EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXExpressionOrVarDeclarationRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXExpressionOrVarDeclaration=ruleXExpressionOrVarDeclaration();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXExpressionOrVarDeclaration; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXExpressionOrVarDeclaration"


    // $ANTLR start "ruleXExpressionOrVarDeclaration"
    // InternalTableDSL.g:8765:1: ruleXExpressionOrVarDeclaration returns [EObject current=null] : (this_XVariableDeclaration_0= ruleXVariableDeclaration | this_XExpression_1= ruleXExpression ) ;
    public final EObject ruleXExpressionOrVarDeclaration() throws RecognitionException {
        EObject current = null;

        EObject this_XVariableDeclaration_0 = null;

        EObject this_XExpression_1 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:8771:2: ( (this_XVariableDeclaration_0= ruleXVariableDeclaration | this_XExpression_1= ruleXExpression ) )
            // InternalTableDSL.g:8772:2: (this_XVariableDeclaration_0= ruleXVariableDeclaration | this_XExpression_1= ruleXExpression )
            {
            // InternalTableDSL.g:8772:2: (this_XVariableDeclaration_0= ruleXVariableDeclaration | this_XExpression_1= ruleXExpression )
            int alt121=2;
            int LA121_0 = input.LA(1);

            if ( ((LA121_0>=146 && LA121_0<=147)) ) {
                alt121=1;
            }
            else if ( ((LA121_0>=RULE_ID && LA121_0<=RULE_STRING)||(LA121_0>=RULE_INT && LA121_0<=RULE_DECIMAL)||LA121_0==16||(LA121_0>=91 && LA121_0<=95)||LA121_0==100||(LA121_0>=104 && LA121_0<=105)||LA121_0==112||LA121_0==131||LA121_0==137||LA121_0==139||(LA121_0>=143 && LA121_0<=145)||(LA121_0>=148 && LA121_0<=157)||LA121_0==159) ) {
                alt121=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 121, 0, input);

                throw nvae;
            }
            switch (alt121) {
                case 1 :
                    // InternalTableDSL.g:8773:3: this_XVariableDeclaration_0= ruleXVariableDeclaration
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXExpressionOrVarDeclarationAccess().getXVariableDeclarationParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XVariableDeclaration_0=ruleXVariableDeclaration();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XVariableDeclaration_0;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:8782:3: this_XExpression_1= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getXExpressionOrVarDeclarationAccess().getXExpressionParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XExpression_1=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XExpression_1;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXExpressionOrVarDeclaration"


    // $ANTLR start "entryRuleXVariableDeclaration"
    // InternalTableDSL.g:8794:1: entryRuleXVariableDeclaration returns [EObject current=null] : iv_ruleXVariableDeclaration= ruleXVariableDeclaration EOF ;
    public final EObject entryRuleXVariableDeclaration() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXVariableDeclaration = null;


        try {
            // InternalTableDSL.g:8794:61: (iv_ruleXVariableDeclaration= ruleXVariableDeclaration EOF )
            // InternalTableDSL.g:8795:2: iv_ruleXVariableDeclaration= ruleXVariableDeclaration EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXVariableDeclarationRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXVariableDeclaration=ruleXVariableDeclaration();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXVariableDeclaration; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXVariableDeclaration"


    // $ANTLR start "ruleXVariableDeclaration"
    // InternalTableDSL.g:8801:1: ruleXVariableDeclaration returns [EObject current=null] : ( () ( ( (lv_writeable_1_0= 'var' ) ) | otherlv_2= 'val' ) ( ( ( ( ( ( ruleJvmTypeReference ) ) ( ( ruleValidID ) ) ) )=> ( ( (lv_type_3_0= ruleJvmTypeReference ) ) ( (lv_name_4_0= ruleValidID ) ) ) ) | ( (lv_name_5_0= ruleValidID ) ) ) (otherlv_6= '=' ( (lv_right_7_0= ruleXExpression ) ) )? ) ;
    public final EObject ruleXVariableDeclaration() throws RecognitionException {
        EObject current = null;

        Token lv_writeable_1_0=null;
        Token otherlv_2=null;
        Token otherlv_6=null;
        EObject lv_type_3_0 = null;

        AntlrDatatypeRuleToken lv_name_4_0 = null;

        AntlrDatatypeRuleToken lv_name_5_0 = null;

        EObject lv_right_7_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:8807:2: ( ( () ( ( (lv_writeable_1_0= 'var' ) ) | otherlv_2= 'val' ) ( ( ( ( ( ( ruleJvmTypeReference ) ) ( ( ruleValidID ) ) ) )=> ( ( (lv_type_3_0= ruleJvmTypeReference ) ) ( (lv_name_4_0= ruleValidID ) ) ) ) | ( (lv_name_5_0= ruleValidID ) ) ) (otherlv_6= '=' ( (lv_right_7_0= ruleXExpression ) ) )? ) )
            // InternalTableDSL.g:8808:2: ( () ( ( (lv_writeable_1_0= 'var' ) ) | otherlv_2= 'val' ) ( ( ( ( ( ( ruleJvmTypeReference ) ) ( ( ruleValidID ) ) ) )=> ( ( (lv_type_3_0= ruleJvmTypeReference ) ) ( (lv_name_4_0= ruleValidID ) ) ) ) | ( (lv_name_5_0= ruleValidID ) ) ) (otherlv_6= '=' ( (lv_right_7_0= ruleXExpression ) ) )? )
            {
            // InternalTableDSL.g:8808:2: ( () ( ( (lv_writeable_1_0= 'var' ) ) | otherlv_2= 'val' ) ( ( ( ( ( ( ruleJvmTypeReference ) ) ( ( ruleValidID ) ) ) )=> ( ( (lv_type_3_0= ruleJvmTypeReference ) ) ( (lv_name_4_0= ruleValidID ) ) ) ) | ( (lv_name_5_0= ruleValidID ) ) ) (otherlv_6= '=' ( (lv_right_7_0= ruleXExpression ) ) )? )
            // InternalTableDSL.g:8809:3: () ( ( (lv_writeable_1_0= 'var' ) ) | otherlv_2= 'val' ) ( ( ( ( ( ( ruleJvmTypeReference ) ) ( ( ruleValidID ) ) ) )=> ( ( (lv_type_3_0= ruleJvmTypeReference ) ) ( (lv_name_4_0= ruleValidID ) ) ) ) | ( (lv_name_5_0= ruleValidID ) ) ) (otherlv_6= '=' ( (lv_right_7_0= ruleXExpression ) ) )?
            {
            // InternalTableDSL.g:8809:3: ()
            // InternalTableDSL.g:8810:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXVariableDeclarationAccess().getXVariableDeclarationAction_0(),
              					current);
              			
            }

            }

            // InternalTableDSL.g:8816:3: ( ( (lv_writeable_1_0= 'var' ) ) | otherlv_2= 'val' )
            int alt122=2;
            int LA122_0 = input.LA(1);

            if ( (LA122_0==146) ) {
                alt122=1;
            }
            else if ( (LA122_0==147) ) {
                alt122=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 122, 0, input);

                throw nvae;
            }
            switch (alt122) {
                case 1 :
                    // InternalTableDSL.g:8817:4: ( (lv_writeable_1_0= 'var' ) )
                    {
                    // InternalTableDSL.g:8817:4: ( (lv_writeable_1_0= 'var' ) )
                    // InternalTableDSL.g:8818:5: (lv_writeable_1_0= 'var' )
                    {
                    // InternalTableDSL.g:8818:5: (lv_writeable_1_0= 'var' )
                    // InternalTableDSL.g:8819:6: lv_writeable_1_0= 'var'
                    {
                    lv_writeable_1_0=(Token)match(input,146,FOLLOW_78); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						newLeafNode(lv_writeable_1_0, grammarAccess.getXVariableDeclarationAccess().getWriteableVarKeyword_1_0_0());
                      					
                    }
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElement(grammarAccess.getXVariableDeclarationRule());
                      						}
                      						setWithLastConsumed(current, "writeable", true, "var");
                      					
                    }

                    }


                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:8832:4: otherlv_2= 'val'
                    {
                    otherlv_2=(Token)match(input,147,FOLLOW_78); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_2, grammarAccess.getXVariableDeclarationAccess().getValKeyword_1_1());
                      			
                    }

                    }
                    break;

            }

            // InternalTableDSL.g:8837:3: ( ( ( ( ( ( ruleJvmTypeReference ) ) ( ( ruleValidID ) ) ) )=> ( ( (lv_type_3_0= ruleJvmTypeReference ) ) ( (lv_name_4_0= ruleValidID ) ) ) ) | ( (lv_name_5_0= ruleValidID ) ) )
            int alt123=2;
            int LA123_0 = input.LA(1);

            if ( (LA123_0==RULE_ID) ) {
                int LA123_1 = input.LA(2);

                if ( (synpred35_InternalTableDSL()) ) {
                    alt123=1;
                }
                else if ( (true) ) {
                    alt123=2;
                }
                else {
                    if (state.backtracking>0) {state.failed=true; return current;}
                    NoViableAltException nvae =
                        new NoViableAltException("", 123, 1, input);

                    throw nvae;
                }
            }
            else if ( (LA123_0==100) && (synpred35_InternalTableDSL())) {
                alt123=1;
            }
            else if ( (LA123_0==125) && (synpred35_InternalTableDSL())) {
                alt123=1;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 123, 0, input);

                throw nvae;
            }
            switch (alt123) {
                case 1 :
                    // InternalTableDSL.g:8838:4: ( ( ( ( ( ruleJvmTypeReference ) ) ( ( ruleValidID ) ) ) )=> ( ( (lv_type_3_0= ruleJvmTypeReference ) ) ( (lv_name_4_0= ruleValidID ) ) ) )
                    {
                    // InternalTableDSL.g:8838:4: ( ( ( ( ( ruleJvmTypeReference ) ) ( ( ruleValidID ) ) ) )=> ( ( (lv_type_3_0= ruleJvmTypeReference ) ) ( (lv_name_4_0= ruleValidID ) ) ) )
                    // InternalTableDSL.g:8839:5: ( ( ( ( ruleJvmTypeReference ) ) ( ( ruleValidID ) ) ) )=> ( ( (lv_type_3_0= ruleJvmTypeReference ) ) ( (lv_name_4_0= ruleValidID ) ) )
                    {
                    // InternalTableDSL.g:8852:5: ( ( (lv_type_3_0= ruleJvmTypeReference ) ) ( (lv_name_4_0= ruleValidID ) ) )
                    // InternalTableDSL.g:8853:6: ( (lv_type_3_0= ruleJvmTypeReference ) ) ( (lv_name_4_0= ruleValidID ) )
                    {
                    // InternalTableDSL.g:8853:6: ( (lv_type_3_0= ruleJvmTypeReference ) )
                    // InternalTableDSL.g:8854:7: (lv_type_3_0= ruleJvmTypeReference )
                    {
                    // InternalTableDSL.g:8854:7: (lv_type_3_0= ruleJvmTypeReference )
                    // InternalTableDSL.g:8855:8: lv_type_3_0= ruleJvmTypeReference
                    {
                    if ( state.backtracking==0 ) {

                      								newCompositeNode(grammarAccess.getXVariableDeclarationAccess().getTypeJvmTypeReferenceParserRuleCall_2_0_0_0_0());
                      							
                    }
                    pushFollow(FOLLOW_4);
                    lv_type_3_0=ruleJvmTypeReference();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      								if (current==null) {
                      									current = createModelElementForParent(grammarAccess.getXVariableDeclarationRule());
                      								}
                      								set(
                      									current,
                      									"type",
                      									lv_type_3_0,
                      									"org.eclipse.xtext.xbase.Xtype.JvmTypeReference");
                      								afterParserOrEnumRuleCall();
                      							
                    }

                    }


                    }

                    // InternalTableDSL.g:8872:6: ( (lv_name_4_0= ruleValidID ) )
                    // InternalTableDSL.g:8873:7: (lv_name_4_0= ruleValidID )
                    {
                    // InternalTableDSL.g:8873:7: (lv_name_4_0= ruleValidID )
                    // InternalTableDSL.g:8874:8: lv_name_4_0= ruleValidID
                    {
                    if ( state.backtracking==0 ) {

                      								newCompositeNode(grammarAccess.getXVariableDeclarationAccess().getNameValidIDParserRuleCall_2_0_0_1_0());
                      							
                    }
                    pushFollow(FOLLOW_119);
                    lv_name_4_0=ruleValidID();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      								if (current==null) {
                      									current = createModelElementForParent(grammarAccess.getXVariableDeclarationRule());
                      								}
                      								set(
                      									current,
                      									"name",
                      									lv_name_4_0,
                      									"org.eclipse.xtext.xbase.Xtype.ValidID");
                      								afterParserOrEnumRuleCall();
                      							
                    }

                    }


                    }


                    }


                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:8894:4: ( (lv_name_5_0= ruleValidID ) )
                    {
                    // InternalTableDSL.g:8894:4: ( (lv_name_5_0= ruleValidID ) )
                    // InternalTableDSL.g:8895:5: (lv_name_5_0= ruleValidID )
                    {
                    // InternalTableDSL.g:8895:5: (lv_name_5_0= ruleValidID )
                    // InternalTableDSL.g:8896:6: lv_name_5_0= ruleValidID
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXVariableDeclarationAccess().getNameValidIDParserRuleCall_2_1_0());
                      					
                    }
                    pushFollow(FOLLOW_119);
                    lv_name_5_0=ruleValidID();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getXVariableDeclarationRule());
                      						}
                      						set(
                      							current,
                      							"name",
                      							lv_name_5_0,
                      							"org.eclipse.xtext.xbase.Xtype.ValidID");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }


                    }
                    break;

            }

            // InternalTableDSL.g:8914:3: (otherlv_6= '=' ( (lv_right_7_0= ruleXExpression ) ) )?
            int alt124=2;
            int LA124_0 = input.LA(1);

            if ( (LA124_0==103) ) {
                alt124=1;
            }
            switch (alt124) {
                case 1 :
                    // InternalTableDSL.g:8915:4: otherlv_6= '=' ( (lv_right_7_0= ruleXExpression ) )
                    {
                    otherlv_6=(Token)match(input,103,FOLLOW_65); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_6, grammarAccess.getXVariableDeclarationAccess().getEqualsSignKeyword_3_0());
                      			
                    }
                    // InternalTableDSL.g:8919:4: ( (lv_right_7_0= ruleXExpression ) )
                    // InternalTableDSL.g:8920:5: (lv_right_7_0= ruleXExpression )
                    {
                    // InternalTableDSL.g:8920:5: (lv_right_7_0= ruleXExpression )
                    // InternalTableDSL.g:8921:6: lv_right_7_0= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXVariableDeclarationAccess().getRightXExpressionParserRuleCall_3_1_0());
                      					
                    }
                    pushFollow(FOLLOW_2);
                    lv_right_7_0=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getXVariableDeclarationRule());
                      						}
                      						set(
                      							current,
                      							"right",
                      							lv_right_7_0,
                      							"org.eclipse.xtext.xbase.Xbase.XExpression");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXVariableDeclaration"


    // $ANTLR start "entryRuleJvmFormalParameter"
    // InternalTableDSL.g:8943:1: entryRuleJvmFormalParameter returns [EObject current=null] : iv_ruleJvmFormalParameter= ruleJvmFormalParameter EOF ;
    public final EObject entryRuleJvmFormalParameter() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleJvmFormalParameter = null;


        try {
            // InternalTableDSL.g:8943:59: (iv_ruleJvmFormalParameter= ruleJvmFormalParameter EOF )
            // InternalTableDSL.g:8944:2: iv_ruleJvmFormalParameter= ruleJvmFormalParameter EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getJvmFormalParameterRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleJvmFormalParameter=ruleJvmFormalParameter();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleJvmFormalParameter; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleJvmFormalParameter"


    // $ANTLR start "ruleJvmFormalParameter"
    // InternalTableDSL.g:8950:1: ruleJvmFormalParameter returns [EObject current=null] : ( ( (lv_parameterType_0_0= ruleJvmTypeReference ) )? ( (lv_name_1_0= ruleValidID ) ) ) ;
    public final EObject ruleJvmFormalParameter() throws RecognitionException {
        EObject current = null;

        EObject lv_parameterType_0_0 = null;

        AntlrDatatypeRuleToken lv_name_1_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:8956:2: ( ( ( (lv_parameterType_0_0= ruleJvmTypeReference ) )? ( (lv_name_1_0= ruleValidID ) ) ) )
            // InternalTableDSL.g:8957:2: ( ( (lv_parameterType_0_0= ruleJvmTypeReference ) )? ( (lv_name_1_0= ruleValidID ) ) )
            {
            // InternalTableDSL.g:8957:2: ( ( (lv_parameterType_0_0= ruleJvmTypeReference ) )? ( (lv_name_1_0= ruleValidID ) ) )
            // InternalTableDSL.g:8958:3: ( (lv_parameterType_0_0= ruleJvmTypeReference ) )? ( (lv_name_1_0= ruleValidID ) )
            {
            // InternalTableDSL.g:8958:3: ( (lv_parameterType_0_0= ruleJvmTypeReference ) )?
            int alt125=2;
            int LA125_0 = input.LA(1);

            if ( (LA125_0==RULE_ID) ) {
                int LA125_1 = input.LA(2);

                if ( (LA125_1==RULE_ID||LA125_1==74||LA125_1==105||LA125_1==112) ) {
                    alt125=1;
                }
            }
            else if ( (LA125_0==100||LA125_0==125) ) {
                alt125=1;
            }
            switch (alt125) {
                case 1 :
                    // InternalTableDSL.g:8959:4: (lv_parameterType_0_0= ruleJvmTypeReference )
                    {
                    // InternalTableDSL.g:8959:4: (lv_parameterType_0_0= ruleJvmTypeReference )
                    // InternalTableDSL.g:8960:5: lv_parameterType_0_0= ruleJvmTypeReference
                    {
                    if ( state.backtracking==0 ) {

                      					newCompositeNode(grammarAccess.getJvmFormalParameterAccess().getParameterTypeJvmTypeReferenceParserRuleCall_0_0());
                      				
                    }
                    pushFollow(FOLLOW_4);
                    lv_parameterType_0_0=ruleJvmTypeReference();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					if (current==null) {
                      						current = createModelElementForParent(grammarAccess.getJvmFormalParameterRule());
                      					}
                      					set(
                      						current,
                      						"parameterType",
                      						lv_parameterType_0_0,
                      						"org.eclipse.xtext.xbase.Xtype.JvmTypeReference");
                      					afterParserOrEnumRuleCall();
                      				
                    }

                    }


                    }
                    break;

            }

            // InternalTableDSL.g:8977:3: ( (lv_name_1_0= ruleValidID ) )
            // InternalTableDSL.g:8978:4: (lv_name_1_0= ruleValidID )
            {
            // InternalTableDSL.g:8978:4: (lv_name_1_0= ruleValidID )
            // InternalTableDSL.g:8979:5: lv_name_1_0= ruleValidID
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getJvmFormalParameterAccess().getNameValidIDParserRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_name_1_0=ruleValidID();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getJvmFormalParameterRule());
              					}
              					set(
              						current,
              						"name",
              						lv_name_1_0,
              						"org.eclipse.xtext.xbase.Xtype.ValidID");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleJvmFormalParameter"


    // $ANTLR start "entryRuleFullJvmFormalParameter"
    // InternalTableDSL.g:9000:1: entryRuleFullJvmFormalParameter returns [EObject current=null] : iv_ruleFullJvmFormalParameter= ruleFullJvmFormalParameter EOF ;
    public final EObject entryRuleFullJvmFormalParameter() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleFullJvmFormalParameter = null;


        try {
            // InternalTableDSL.g:9000:63: (iv_ruleFullJvmFormalParameter= ruleFullJvmFormalParameter EOF )
            // InternalTableDSL.g:9001:2: iv_ruleFullJvmFormalParameter= ruleFullJvmFormalParameter EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getFullJvmFormalParameterRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleFullJvmFormalParameter=ruleFullJvmFormalParameter();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleFullJvmFormalParameter; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleFullJvmFormalParameter"


    // $ANTLR start "ruleFullJvmFormalParameter"
    // InternalTableDSL.g:9007:1: ruleFullJvmFormalParameter returns [EObject current=null] : ( ( (lv_parameterType_0_0= ruleJvmTypeReference ) ) ( (lv_name_1_0= ruleValidID ) ) ) ;
    public final EObject ruleFullJvmFormalParameter() throws RecognitionException {
        EObject current = null;

        EObject lv_parameterType_0_0 = null;

        AntlrDatatypeRuleToken lv_name_1_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:9013:2: ( ( ( (lv_parameterType_0_0= ruleJvmTypeReference ) ) ( (lv_name_1_0= ruleValidID ) ) ) )
            // InternalTableDSL.g:9014:2: ( ( (lv_parameterType_0_0= ruleJvmTypeReference ) ) ( (lv_name_1_0= ruleValidID ) ) )
            {
            // InternalTableDSL.g:9014:2: ( ( (lv_parameterType_0_0= ruleJvmTypeReference ) ) ( (lv_name_1_0= ruleValidID ) ) )
            // InternalTableDSL.g:9015:3: ( (lv_parameterType_0_0= ruleJvmTypeReference ) ) ( (lv_name_1_0= ruleValidID ) )
            {
            // InternalTableDSL.g:9015:3: ( (lv_parameterType_0_0= ruleJvmTypeReference ) )
            // InternalTableDSL.g:9016:4: (lv_parameterType_0_0= ruleJvmTypeReference )
            {
            // InternalTableDSL.g:9016:4: (lv_parameterType_0_0= ruleJvmTypeReference )
            // InternalTableDSL.g:9017:5: lv_parameterType_0_0= ruleJvmTypeReference
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getFullJvmFormalParameterAccess().getParameterTypeJvmTypeReferenceParserRuleCall_0_0());
              				
            }
            pushFollow(FOLLOW_4);
            lv_parameterType_0_0=ruleJvmTypeReference();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getFullJvmFormalParameterRule());
              					}
              					set(
              						current,
              						"parameterType",
              						lv_parameterType_0_0,
              						"org.eclipse.xtext.xbase.Xtype.JvmTypeReference");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:9034:3: ( (lv_name_1_0= ruleValidID ) )
            // InternalTableDSL.g:9035:4: (lv_name_1_0= ruleValidID )
            {
            // InternalTableDSL.g:9035:4: (lv_name_1_0= ruleValidID )
            // InternalTableDSL.g:9036:5: lv_name_1_0= ruleValidID
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getFullJvmFormalParameterAccess().getNameValidIDParserRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_name_1_0=ruleValidID();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getFullJvmFormalParameterRule());
              					}
              					set(
              						current,
              						"name",
              						lv_name_1_0,
              						"org.eclipse.xtext.xbase.Xtype.ValidID");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleFullJvmFormalParameter"


    // $ANTLR start "entryRuleXFeatureCall"
    // InternalTableDSL.g:9057:1: entryRuleXFeatureCall returns [EObject current=null] : iv_ruleXFeatureCall= ruleXFeatureCall EOF ;
    public final EObject entryRuleXFeatureCall() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXFeatureCall = null;


        try {
            // InternalTableDSL.g:9057:53: (iv_ruleXFeatureCall= ruleXFeatureCall EOF )
            // InternalTableDSL.g:9058:2: iv_ruleXFeatureCall= ruleXFeatureCall EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXFeatureCallRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXFeatureCall=ruleXFeatureCall();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXFeatureCall; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXFeatureCall"


    // $ANTLR start "ruleXFeatureCall"
    // InternalTableDSL.g:9064:1: ruleXFeatureCall returns [EObject current=null] : ( () (otherlv_1= '<' ( (lv_typeArguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>' )? ( ( ruleIdOrSuper ) ) ( ( ( ( '(' ) )=> (lv_explicitOperationCall_7_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_featureCallArguments_8_0= ruleXShortClosure ) ) | ( ( (lv_featureCallArguments_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) ) )* ) )? otherlv_12= ')' )? ( ( ( () '[' ) )=> (lv_featureCallArguments_13_0= ruleXClosure ) )? ) ;
    public final EObject ruleXFeatureCall() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_3=null;
        Token otherlv_5=null;
        Token lv_explicitOperationCall_7_0=null;
        Token otherlv_10=null;
        Token otherlv_12=null;
        EObject lv_typeArguments_2_0 = null;

        EObject lv_typeArguments_4_0 = null;

        EObject lv_featureCallArguments_8_0 = null;

        EObject lv_featureCallArguments_9_0 = null;

        EObject lv_featureCallArguments_11_0 = null;

        EObject lv_featureCallArguments_13_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:9070:2: ( ( () (otherlv_1= '<' ( (lv_typeArguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>' )? ( ( ruleIdOrSuper ) ) ( ( ( ( '(' ) )=> (lv_explicitOperationCall_7_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_featureCallArguments_8_0= ruleXShortClosure ) ) | ( ( (lv_featureCallArguments_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) ) )* ) )? otherlv_12= ')' )? ( ( ( () '[' ) )=> (lv_featureCallArguments_13_0= ruleXClosure ) )? ) )
            // InternalTableDSL.g:9071:2: ( () (otherlv_1= '<' ( (lv_typeArguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>' )? ( ( ruleIdOrSuper ) ) ( ( ( ( '(' ) )=> (lv_explicitOperationCall_7_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_featureCallArguments_8_0= ruleXShortClosure ) ) | ( ( (lv_featureCallArguments_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) ) )* ) )? otherlv_12= ')' )? ( ( ( () '[' ) )=> (lv_featureCallArguments_13_0= ruleXClosure ) )? )
            {
            // InternalTableDSL.g:9071:2: ( () (otherlv_1= '<' ( (lv_typeArguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>' )? ( ( ruleIdOrSuper ) ) ( ( ( ( '(' ) )=> (lv_explicitOperationCall_7_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_featureCallArguments_8_0= ruleXShortClosure ) ) | ( ( (lv_featureCallArguments_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) ) )* ) )? otherlv_12= ')' )? ( ( ( () '[' ) )=> (lv_featureCallArguments_13_0= ruleXClosure ) )? )
            // InternalTableDSL.g:9072:3: () (otherlv_1= '<' ( (lv_typeArguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>' )? ( ( ruleIdOrSuper ) ) ( ( ( ( '(' ) )=> (lv_explicitOperationCall_7_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_featureCallArguments_8_0= ruleXShortClosure ) ) | ( ( (lv_featureCallArguments_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) ) )* ) )? otherlv_12= ')' )? ( ( ( () '[' ) )=> (lv_featureCallArguments_13_0= ruleXClosure ) )?
            {
            // InternalTableDSL.g:9072:3: ()
            // InternalTableDSL.g:9073:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXFeatureCallAccess().getXFeatureCallAction_0(),
              					current);
              			
            }

            }

            // InternalTableDSL.g:9079:3: (otherlv_1= '<' ( (lv_typeArguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>' )?
            int alt127=2;
            int LA127_0 = input.LA(1);

            if ( (LA127_0==112) ) {
                alt127=1;
            }
            switch (alt127) {
                case 1 :
                    // InternalTableDSL.g:9080:4: otherlv_1= '<' ( (lv_typeArguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>'
                    {
                    otherlv_1=(Token)match(input,112,FOLLOW_90); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_1, grammarAccess.getXFeatureCallAccess().getLessThanSignKeyword_1_0());
                      			
                    }
                    // InternalTableDSL.g:9084:4: ( (lv_typeArguments_2_0= ruleJvmArgumentTypeReference ) )
                    // InternalTableDSL.g:9085:5: (lv_typeArguments_2_0= ruleJvmArgumentTypeReference )
                    {
                    // InternalTableDSL.g:9085:5: (lv_typeArguments_2_0= ruleJvmArgumentTypeReference )
                    // InternalTableDSL.g:9086:6: lv_typeArguments_2_0= ruleJvmArgumentTypeReference
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXFeatureCallAccess().getTypeArgumentsJvmArgumentTypeReferenceParserRuleCall_1_1_0());
                      					
                    }
                    pushFollow(FOLLOW_91);
                    lv_typeArguments_2_0=ruleJvmArgumentTypeReference();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getXFeatureCallRule());
                      						}
                      						add(
                      							current,
                      							"typeArguments",
                      							lv_typeArguments_2_0,
                      							"org.eclipse.xtext.xbase.Xtype.JvmArgumentTypeReference");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }

                    // InternalTableDSL.g:9103:4: (otherlv_3= ',' ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) )*
                    loop126:
                    do {
                        int alt126=2;
                        int LA126_0 = input.LA(1);

                        if ( (LA126_0==101) ) {
                            alt126=1;
                        }


                        switch (alt126) {
                    	case 1 :
                    	    // InternalTableDSL.g:9104:5: otherlv_3= ',' ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) )
                    	    {
                    	    otherlv_3=(Token)match(input,101,FOLLOW_90); if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      					newLeafNode(otherlv_3, grammarAccess.getXFeatureCallAccess().getCommaKeyword_1_2_0());
                    	      				
                    	    }
                    	    // InternalTableDSL.g:9108:5: ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) )
                    	    // InternalTableDSL.g:9109:6: (lv_typeArguments_4_0= ruleJvmArgumentTypeReference )
                    	    {
                    	    // InternalTableDSL.g:9109:6: (lv_typeArguments_4_0= ruleJvmArgumentTypeReference )
                    	    // InternalTableDSL.g:9110:7: lv_typeArguments_4_0= ruleJvmArgumentTypeReference
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      							newCompositeNode(grammarAccess.getXFeatureCallAccess().getTypeArgumentsJvmArgumentTypeReferenceParserRuleCall_1_2_1_0());
                    	      						
                    	    }
                    	    pushFollow(FOLLOW_91);
                    	    lv_typeArguments_4_0=ruleJvmArgumentTypeReference();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      							if (current==null) {
                    	      								current = createModelElementForParent(grammarAccess.getXFeatureCallRule());
                    	      							}
                    	      							add(
                    	      								current,
                    	      								"typeArguments",
                    	      								lv_typeArguments_4_0,
                    	      								"org.eclipse.xtext.xbase.Xtype.JvmArgumentTypeReference");
                    	      							afterParserOrEnumRuleCall();
                    	      						
                    	    }

                    	    }


                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop126;
                        }
                    } while (true);

                    otherlv_5=(Token)match(input,113,FOLLOW_89); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_5, grammarAccess.getXFeatureCallAccess().getGreaterThanSignKeyword_1_3());
                      			
                    }

                    }
                    break;

            }

            // InternalTableDSL.g:9133:3: ( ( ruleIdOrSuper ) )
            // InternalTableDSL.g:9134:4: ( ruleIdOrSuper )
            {
            // InternalTableDSL.g:9134:4: ( ruleIdOrSuper )
            // InternalTableDSL.g:9135:5: ruleIdOrSuper
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getXFeatureCallRule());
              					}
              				
            }
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXFeatureCallAccess().getFeatureJvmIdentifiableElementCrossReference_2_0());
              				
            }
            pushFollow(FOLLOW_120);
            ruleIdOrSuper();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:9149:3: ( ( ( ( '(' ) )=> (lv_explicitOperationCall_7_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_featureCallArguments_8_0= ruleXShortClosure ) ) | ( ( (lv_featureCallArguments_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) ) )* ) )? otherlv_12= ')' )?
            int alt130=2;
            alt130 = dfa130.predict(input);
            switch (alt130) {
                case 1 :
                    // InternalTableDSL.g:9150:4: ( ( ( '(' ) )=> (lv_explicitOperationCall_7_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_featureCallArguments_8_0= ruleXShortClosure ) ) | ( ( (lv_featureCallArguments_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) ) )* ) )? otherlv_12= ')'
                    {
                    // InternalTableDSL.g:9150:4: ( ( ( '(' ) )=> (lv_explicitOperationCall_7_0= '(' ) )
                    // InternalTableDSL.g:9151:5: ( ( '(' ) )=> (lv_explicitOperationCall_7_0= '(' )
                    {
                    // InternalTableDSL.g:9155:5: (lv_explicitOperationCall_7_0= '(' )
                    // InternalTableDSL.g:9156:6: lv_explicitOperationCall_7_0= '('
                    {
                    lv_explicitOperationCall_7_0=(Token)match(input,100,FOLLOW_93); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						newLeafNode(lv_explicitOperationCall_7_0, grammarAccess.getXFeatureCallAccess().getExplicitOperationCallLeftParenthesisKeyword_3_0_0());
                      					
                    }
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElement(grammarAccess.getXFeatureCallRule());
                      						}
                      						setWithLastConsumed(current, "explicitOperationCall", true, "(");
                      					
                    }

                    }


                    }

                    // InternalTableDSL.g:9168:4: ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_featureCallArguments_8_0= ruleXShortClosure ) ) | ( ( (lv_featureCallArguments_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) ) )* ) )?
                    int alt129=3;
                    alt129 = dfa129.predict(input);
                    switch (alt129) {
                        case 1 :
                            // InternalTableDSL.g:9169:5: ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_featureCallArguments_8_0= ruleXShortClosure ) )
                            {
                            // InternalTableDSL.g:9169:5: ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_featureCallArguments_8_0= ruleXShortClosure ) )
                            // InternalTableDSL.g:9170:6: ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_featureCallArguments_8_0= ruleXShortClosure )
                            {
                            // InternalTableDSL.g:9195:6: (lv_featureCallArguments_8_0= ruleXShortClosure )
                            // InternalTableDSL.g:9196:7: lv_featureCallArguments_8_0= ruleXShortClosure
                            {
                            if ( state.backtracking==0 ) {

                              							newCompositeNode(grammarAccess.getXFeatureCallAccess().getFeatureCallArgumentsXShortClosureParserRuleCall_3_1_0_0());
                              						
                            }
                            pushFollow(FOLLOW_63);
                            lv_featureCallArguments_8_0=ruleXShortClosure();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              							if (current==null) {
                              								current = createModelElementForParent(grammarAccess.getXFeatureCallRule());
                              							}
                              							add(
                              								current,
                              								"featureCallArguments",
                              								lv_featureCallArguments_8_0,
                              								"org.eclipse.xtext.xbase.Xbase.XShortClosure");
                              							afterParserOrEnumRuleCall();
                              						
                            }

                            }


                            }


                            }
                            break;
                        case 2 :
                            // InternalTableDSL.g:9214:5: ( ( (lv_featureCallArguments_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) ) )* )
                            {
                            // InternalTableDSL.g:9214:5: ( ( (lv_featureCallArguments_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) ) )* )
                            // InternalTableDSL.g:9215:6: ( (lv_featureCallArguments_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) ) )*
                            {
                            // InternalTableDSL.g:9215:6: ( (lv_featureCallArguments_9_0= ruleXExpression ) )
                            // InternalTableDSL.g:9216:7: (lv_featureCallArguments_9_0= ruleXExpression )
                            {
                            // InternalTableDSL.g:9216:7: (lv_featureCallArguments_9_0= ruleXExpression )
                            // InternalTableDSL.g:9217:8: lv_featureCallArguments_9_0= ruleXExpression
                            {
                            if ( state.backtracking==0 ) {

                              								newCompositeNode(grammarAccess.getXFeatureCallAccess().getFeatureCallArgumentsXExpressionParserRuleCall_3_1_1_0_0());
                              							
                            }
                            pushFollow(FOLLOW_62);
                            lv_featureCallArguments_9_0=ruleXExpression();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              								if (current==null) {
                              									current = createModelElementForParent(grammarAccess.getXFeatureCallRule());
                              								}
                              								add(
                              									current,
                              									"featureCallArguments",
                              									lv_featureCallArguments_9_0,
                              									"org.eclipse.xtext.xbase.Xbase.XExpression");
                              								afterParserOrEnumRuleCall();
                              							
                            }

                            }


                            }

                            // InternalTableDSL.g:9234:6: (otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) ) )*
                            loop128:
                            do {
                                int alt128=2;
                                int LA128_0 = input.LA(1);

                                if ( (LA128_0==101) ) {
                                    alt128=1;
                                }


                                switch (alt128) {
                            	case 1 :
                            	    // InternalTableDSL.g:9235:7: otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) )
                            	    {
                            	    otherlv_10=(Token)match(input,101,FOLLOW_65); if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      							newLeafNode(otherlv_10, grammarAccess.getXFeatureCallAccess().getCommaKeyword_3_1_1_1_0());
                            	      						
                            	    }
                            	    // InternalTableDSL.g:9239:7: ( (lv_featureCallArguments_11_0= ruleXExpression ) )
                            	    // InternalTableDSL.g:9240:8: (lv_featureCallArguments_11_0= ruleXExpression )
                            	    {
                            	    // InternalTableDSL.g:9240:8: (lv_featureCallArguments_11_0= ruleXExpression )
                            	    // InternalTableDSL.g:9241:9: lv_featureCallArguments_11_0= ruleXExpression
                            	    {
                            	    if ( state.backtracking==0 ) {

                            	      									newCompositeNode(grammarAccess.getXFeatureCallAccess().getFeatureCallArgumentsXExpressionParserRuleCall_3_1_1_1_1_0());
                            	      								
                            	    }
                            	    pushFollow(FOLLOW_62);
                            	    lv_featureCallArguments_11_0=ruleXExpression();

                            	    state._fsp--;
                            	    if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      									if (current==null) {
                            	      										current = createModelElementForParent(grammarAccess.getXFeatureCallRule());
                            	      									}
                            	      									add(
                            	      										current,
                            	      										"featureCallArguments",
                            	      										lv_featureCallArguments_11_0,
                            	      										"org.eclipse.xtext.xbase.Xbase.XExpression");
                            	      									afterParserOrEnumRuleCall();
                            	      								
                            	    }

                            	    }


                            	    }


                            	    }
                            	    break;

                            	default :
                            	    break loop128;
                                }
                            } while (true);


                            }


                            }
                            break;

                    }

                    otherlv_12=(Token)match(input,102,FOLLOW_121); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_12, grammarAccess.getXFeatureCallAccess().getRightParenthesisKeyword_3_2());
                      			
                    }

                    }
                    break;

            }

            // InternalTableDSL.g:9266:3: ( ( ( () '[' ) )=> (lv_featureCallArguments_13_0= ruleXClosure ) )?
            int alt131=2;
            alt131 = dfa131.predict(input);
            switch (alt131) {
                case 1 :
                    // InternalTableDSL.g:9267:4: ( ( () '[' ) )=> (lv_featureCallArguments_13_0= ruleXClosure )
                    {
                    // InternalTableDSL.g:9273:4: (lv_featureCallArguments_13_0= ruleXClosure )
                    // InternalTableDSL.g:9274:5: lv_featureCallArguments_13_0= ruleXClosure
                    {
                    if ( state.backtracking==0 ) {

                      					newCompositeNode(grammarAccess.getXFeatureCallAccess().getFeatureCallArgumentsXClosureParserRuleCall_4_0());
                      				
                    }
                    pushFollow(FOLLOW_2);
                    lv_featureCallArguments_13_0=ruleXClosure();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					if (current==null) {
                      						current = createModelElementForParent(grammarAccess.getXFeatureCallRule());
                      					}
                      					add(
                      						current,
                      						"featureCallArguments",
                      						lv_featureCallArguments_13_0,
                      						"org.eclipse.xtext.xbase.Xbase.XClosure");
                      					afterParserOrEnumRuleCall();
                      				
                    }

                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXFeatureCall"


    // $ANTLR start "entryRuleFeatureCallID"
    // InternalTableDSL.g:9295:1: entryRuleFeatureCallID returns [String current=null] : iv_ruleFeatureCallID= ruleFeatureCallID EOF ;
    public final String entryRuleFeatureCallID() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleFeatureCallID = null;


        try {
            // InternalTableDSL.g:9295:53: (iv_ruleFeatureCallID= ruleFeatureCallID EOF )
            // InternalTableDSL.g:9296:2: iv_ruleFeatureCallID= ruleFeatureCallID EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getFeatureCallIDRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleFeatureCallID=ruleFeatureCallID();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleFeatureCallID.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleFeatureCallID"


    // $ANTLR start "ruleFeatureCallID"
    // InternalTableDSL.g:9302:1: ruleFeatureCallID returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (this_ValidID_0= ruleValidID | kw= 'extends' | kw= 'static' | kw= 'import' | kw= 'extension' ) ;
    public final AntlrDatatypeRuleToken ruleFeatureCallID() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;
        AntlrDatatypeRuleToken this_ValidID_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:9308:2: ( (this_ValidID_0= ruleValidID | kw= 'extends' | kw= 'static' | kw= 'import' | kw= 'extension' ) )
            // InternalTableDSL.g:9309:2: (this_ValidID_0= ruleValidID | kw= 'extends' | kw= 'static' | kw= 'import' | kw= 'extension' )
            {
            // InternalTableDSL.g:9309:2: (this_ValidID_0= ruleValidID | kw= 'extends' | kw= 'static' | kw= 'import' | kw= 'extension' )
            int alt132=5;
            switch ( input.LA(1) ) {
            case RULE_ID:
                {
                alt132=1;
                }
                break;
            case 148:
                {
                alt132=2;
                }
                break;
            case 94:
                {
                alt132=3;
                }
                break;
            case 93:
                {
                alt132=4;
                }
                break;
            case 95:
                {
                alt132=5;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 132, 0, input);

                throw nvae;
            }

            switch (alt132) {
                case 1 :
                    // InternalTableDSL.g:9310:3: this_ValidID_0= ruleValidID
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getFeatureCallIDAccess().getValidIDParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_ValidID_0=ruleValidID();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(this_ValidID_0);
                      		
                    }
                    if ( state.backtracking==0 ) {

                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:9321:3: kw= 'extends'
                    {
                    kw=(Token)match(input,148,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getFeatureCallIDAccess().getExtendsKeyword_1());
                      		
                    }

                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:9327:3: kw= 'static'
                    {
                    kw=(Token)match(input,94,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getFeatureCallIDAccess().getStaticKeyword_2());
                      		
                    }

                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:9333:3: kw= 'import'
                    {
                    kw=(Token)match(input,93,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getFeatureCallIDAccess().getImportKeyword_3());
                      		
                    }

                    }
                    break;
                case 5 :
                    // InternalTableDSL.g:9339:3: kw= 'extension'
                    {
                    kw=(Token)match(input,95,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getFeatureCallIDAccess().getExtensionKeyword_4());
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleFeatureCallID"


    // $ANTLR start "entryRuleIdOrSuper"
    // InternalTableDSL.g:9348:1: entryRuleIdOrSuper returns [String current=null] : iv_ruleIdOrSuper= ruleIdOrSuper EOF ;
    public final String entryRuleIdOrSuper() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleIdOrSuper = null;


        try {
            // InternalTableDSL.g:9348:49: (iv_ruleIdOrSuper= ruleIdOrSuper EOF )
            // InternalTableDSL.g:9349:2: iv_ruleIdOrSuper= ruleIdOrSuper EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getIdOrSuperRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleIdOrSuper=ruleIdOrSuper();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleIdOrSuper.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleIdOrSuper"


    // $ANTLR start "ruleIdOrSuper"
    // InternalTableDSL.g:9355:1: ruleIdOrSuper returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (this_FeatureCallID_0= ruleFeatureCallID | kw= 'super' ) ;
    public final AntlrDatatypeRuleToken ruleIdOrSuper() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;
        AntlrDatatypeRuleToken this_FeatureCallID_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:9361:2: ( (this_FeatureCallID_0= ruleFeatureCallID | kw= 'super' ) )
            // InternalTableDSL.g:9362:2: (this_FeatureCallID_0= ruleFeatureCallID | kw= 'super' )
            {
            // InternalTableDSL.g:9362:2: (this_FeatureCallID_0= ruleFeatureCallID | kw= 'super' )
            int alt133=2;
            int LA133_0 = input.LA(1);

            if ( (LA133_0==RULE_ID||(LA133_0>=93 && LA133_0<=95)||LA133_0==148) ) {
                alt133=1;
            }
            else if ( (LA133_0==149) ) {
                alt133=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 133, 0, input);

                throw nvae;
            }
            switch (alt133) {
                case 1 :
                    // InternalTableDSL.g:9363:3: this_FeatureCallID_0= ruleFeatureCallID
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getIdOrSuperAccess().getFeatureCallIDParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_FeatureCallID_0=ruleFeatureCallID();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(this_FeatureCallID_0);
                      		
                    }
                    if ( state.backtracking==0 ) {

                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:9374:3: kw= 'super'
                    {
                    kw=(Token)match(input,149,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(kw);
                      			newLeafNode(kw, grammarAccess.getIdOrSuperAccess().getSuperKeyword_1());
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleIdOrSuper"


    // $ANTLR start "entryRuleXConstructorCall"
    // InternalTableDSL.g:9383:1: entryRuleXConstructorCall returns [EObject current=null] : iv_ruleXConstructorCall= ruleXConstructorCall EOF ;
    public final EObject entryRuleXConstructorCall() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXConstructorCall = null;


        try {
            // InternalTableDSL.g:9383:57: (iv_ruleXConstructorCall= ruleXConstructorCall EOF )
            // InternalTableDSL.g:9384:2: iv_ruleXConstructorCall= ruleXConstructorCall EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXConstructorCallRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXConstructorCall=ruleXConstructorCall();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXConstructorCall; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXConstructorCall"


    // $ANTLR start "ruleXConstructorCall"
    // InternalTableDSL.g:9390:1: ruleXConstructorCall returns [EObject current=null] : ( () otherlv_1= 'new' ( ( ruleQualifiedName ) ) ( ( ( '<' )=>otherlv_3= '<' ) ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) (otherlv_5= ',' ( (lv_typeArguments_6_0= ruleJvmArgumentTypeReference ) ) )* otherlv_7= '>' )? ( ( ( ( '(' ) )=> (lv_explicitConstructorCall_8_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_arguments_9_0= ruleXShortClosure ) ) | ( ( (lv_arguments_10_0= ruleXExpression ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) ) )* ) )? otherlv_13= ')' )? ( ( ( () '[' ) )=> (lv_arguments_14_0= ruleXClosure ) )? ) ;
    public final EObject ruleXConstructorCall() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_3=null;
        Token otherlv_5=null;
        Token otherlv_7=null;
        Token lv_explicitConstructorCall_8_0=null;
        Token otherlv_11=null;
        Token otherlv_13=null;
        EObject lv_typeArguments_4_0 = null;

        EObject lv_typeArguments_6_0 = null;

        EObject lv_arguments_9_0 = null;

        EObject lv_arguments_10_0 = null;

        EObject lv_arguments_12_0 = null;

        EObject lv_arguments_14_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:9396:2: ( ( () otherlv_1= 'new' ( ( ruleQualifiedName ) ) ( ( ( '<' )=>otherlv_3= '<' ) ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) (otherlv_5= ',' ( (lv_typeArguments_6_0= ruleJvmArgumentTypeReference ) ) )* otherlv_7= '>' )? ( ( ( ( '(' ) )=> (lv_explicitConstructorCall_8_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_arguments_9_0= ruleXShortClosure ) ) | ( ( (lv_arguments_10_0= ruleXExpression ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) ) )* ) )? otherlv_13= ')' )? ( ( ( () '[' ) )=> (lv_arguments_14_0= ruleXClosure ) )? ) )
            // InternalTableDSL.g:9397:2: ( () otherlv_1= 'new' ( ( ruleQualifiedName ) ) ( ( ( '<' )=>otherlv_3= '<' ) ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) (otherlv_5= ',' ( (lv_typeArguments_6_0= ruleJvmArgumentTypeReference ) ) )* otherlv_7= '>' )? ( ( ( ( '(' ) )=> (lv_explicitConstructorCall_8_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_arguments_9_0= ruleXShortClosure ) ) | ( ( (lv_arguments_10_0= ruleXExpression ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) ) )* ) )? otherlv_13= ')' )? ( ( ( () '[' ) )=> (lv_arguments_14_0= ruleXClosure ) )? )
            {
            // InternalTableDSL.g:9397:2: ( () otherlv_1= 'new' ( ( ruleQualifiedName ) ) ( ( ( '<' )=>otherlv_3= '<' ) ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) (otherlv_5= ',' ( (lv_typeArguments_6_0= ruleJvmArgumentTypeReference ) ) )* otherlv_7= '>' )? ( ( ( ( '(' ) )=> (lv_explicitConstructorCall_8_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_arguments_9_0= ruleXShortClosure ) ) | ( ( (lv_arguments_10_0= ruleXExpression ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) ) )* ) )? otherlv_13= ')' )? ( ( ( () '[' ) )=> (lv_arguments_14_0= ruleXClosure ) )? )
            // InternalTableDSL.g:9398:3: () otherlv_1= 'new' ( ( ruleQualifiedName ) ) ( ( ( '<' )=>otherlv_3= '<' ) ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) (otherlv_5= ',' ( (lv_typeArguments_6_0= ruleJvmArgumentTypeReference ) ) )* otherlv_7= '>' )? ( ( ( ( '(' ) )=> (lv_explicitConstructorCall_8_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_arguments_9_0= ruleXShortClosure ) ) | ( ( (lv_arguments_10_0= ruleXExpression ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) ) )* ) )? otherlv_13= ')' )? ( ( ( () '[' ) )=> (lv_arguments_14_0= ruleXClosure ) )?
            {
            // InternalTableDSL.g:9398:3: ()
            // InternalTableDSL.g:9399:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXConstructorCallAccess().getXConstructorCallAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,150,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXConstructorCallAccess().getNewKeyword_1());
              		
            }
            // InternalTableDSL.g:9409:3: ( ( ruleQualifiedName ) )
            // InternalTableDSL.g:9410:4: ( ruleQualifiedName )
            {
            // InternalTableDSL.g:9410:4: ( ruleQualifiedName )
            // InternalTableDSL.g:9411:5: ruleQualifiedName
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getXConstructorCallRule());
              					}
              				
            }
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXConstructorCallAccess().getConstructorJvmConstructorCrossReference_2_0());
              				
            }
            pushFollow(FOLLOW_122);
            ruleQualifiedName();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:9425:3: ( ( ( '<' )=>otherlv_3= '<' ) ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) (otherlv_5= ',' ( (lv_typeArguments_6_0= ruleJvmArgumentTypeReference ) ) )* otherlv_7= '>' )?
            int alt135=2;
            alt135 = dfa135.predict(input);
            switch (alt135) {
                case 1 :
                    // InternalTableDSL.g:9426:4: ( ( '<' )=>otherlv_3= '<' ) ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) (otherlv_5= ',' ( (lv_typeArguments_6_0= ruleJvmArgumentTypeReference ) ) )* otherlv_7= '>'
                    {
                    // InternalTableDSL.g:9426:4: ( ( '<' )=>otherlv_3= '<' )
                    // InternalTableDSL.g:9427:5: ( '<' )=>otherlv_3= '<'
                    {
                    otherlv_3=(Token)match(input,112,FOLLOW_90); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					newLeafNode(otherlv_3, grammarAccess.getXConstructorCallAccess().getLessThanSignKeyword_3_0());
                      				
                    }

                    }

                    // InternalTableDSL.g:9433:4: ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) )
                    // InternalTableDSL.g:9434:5: (lv_typeArguments_4_0= ruleJvmArgumentTypeReference )
                    {
                    // InternalTableDSL.g:9434:5: (lv_typeArguments_4_0= ruleJvmArgumentTypeReference )
                    // InternalTableDSL.g:9435:6: lv_typeArguments_4_0= ruleJvmArgumentTypeReference
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getXConstructorCallAccess().getTypeArgumentsJvmArgumentTypeReferenceParserRuleCall_3_1_0());
                      					
                    }
                    pushFollow(FOLLOW_91);
                    lv_typeArguments_4_0=ruleJvmArgumentTypeReference();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getXConstructorCallRule());
                      						}
                      						add(
                      							current,
                      							"typeArguments",
                      							lv_typeArguments_4_0,
                      							"org.eclipse.xtext.xbase.Xtype.JvmArgumentTypeReference");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }

                    // InternalTableDSL.g:9452:4: (otherlv_5= ',' ( (lv_typeArguments_6_0= ruleJvmArgumentTypeReference ) ) )*
                    loop134:
                    do {
                        int alt134=2;
                        int LA134_0 = input.LA(1);

                        if ( (LA134_0==101) ) {
                            alt134=1;
                        }


                        switch (alt134) {
                    	case 1 :
                    	    // InternalTableDSL.g:9453:5: otherlv_5= ',' ( (lv_typeArguments_6_0= ruleJvmArgumentTypeReference ) )
                    	    {
                    	    otherlv_5=(Token)match(input,101,FOLLOW_90); if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      					newLeafNode(otherlv_5, grammarAccess.getXConstructorCallAccess().getCommaKeyword_3_2_0());
                    	      				
                    	    }
                    	    // InternalTableDSL.g:9457:5: ( (lv_typeArguments_6_0= ruleJvmArgumentTypeReference ) )
                    	    // InternalTableDSL.g:9458:6: (lv_typeArguments_6_0= ruleJvmArgumentTypeReference )
                    	    {
                    	    // InternalTableDSL.g:9458:6: (lv_typeArguments_6_0= ruleJvmArgumentTypeReference )
                    	    // InternalTableDSL.g:9459:7: lv_typeArguments_6_0= ruleJvmArgumentTypeReference
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      							newCompositeNode(grammarAccess.getXConstructorCallAccess().getTypeArgumentsJvmArgumentTypeReferenceParserRuleCall_3_2_1_0());
                    	      						
                    	    }
                    	    pushFollow(FOLLOW_91);
                    	    lv_typeArguments_6_0=ruleJvmArgumentTypeReference();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      							if (current==null) {
                    	      								current = createModelElementForParent(grammarAccess.getXConstructorCallRule());
                    	      							}
                    	      							add(
                    	      								current,
                    	      								"typeArguments",
                    	      								lv_typeArguments_6_0,
                    	      								"org.eclipse.xtext.xbase.Xtype.JvmArgumentTypeReference");
                    	      							afterParserOrEnumRuleCall();
                    	      						
                    	    }

                    	    }


                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop134;
                        }
                    } while (true);

                    otherlv_7=(Token)match(input,113,FOLLOW_120); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_7, grammarAccess.getXConstructorCallAccess().getGreaterThanSignKeyword_3_3());
                      			
                    }

                    }
                    break;

            }

            // InternalTableDSL.g:9482:3: ( ( ( ( '(' ) )=> (lv_explicitConstructorCall_8_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_arguments_9_0= ruleXShortClosure ) ) | ( ( (lv_arguments_10_0= ruleXExpression ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) ) )* ) )? otherlv_13= ')' )?
            int alt138=2;
            alt138 = dfa138.predict(input);
            switch (alt138) {
                case 1 :
                    // InternalTableDSL.g:9483:4: ( ( ( '(' ) )=> (lv_explicitConstructorCall_8_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_arguments_9_0= ruleXShortClosure ) ) | ( ( (lv_arguments_10_0= ruleXExpression ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) ) )* ) )? otherlv_13= ')'
                    {
                    // InternalTableDSL.g:9483:4: ( ( ( '(' ) )=> (lv_explicitConstructorCall_8_0= '(' ) )
                    // InternalTableDSL.g:9484:5: ( ( '(' ) )=> (lv_explicitConstructorCall_8_0= '(' )
                    {
                    // InternalTableDSL.g:9488:5: (lv_explicitConstructorCall_8_0= '(' )
                    // InternalTableDSL.g:9489:6: lv_explicitConstructorCall_8_0= '('
                    {
                    lv_explicitConstructorCall_8_0=(Token)match(input,100,FOLLOW_93); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						newLeafNode(lv_explicitConstructorCall_8_0, grammarAccess.getXConstructorCallAccess().getExplicitConstructorCallLeftParenthesisKeyword_4_0_0());
                      					
                    }
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElement(grammarAccess.getXConstructorCallRule());
                      						}
                      						setWithLastConsumed(current, "explicitConstructorCall", true, "(");
                      					
                    }

                    }


                    }

                    // InternalTableDSL.g:9501:4: ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_arguments_9_0= ruleXShortClosure ) ) | ( ( (lv_arguments_10_0= ruleXExpression ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) ) )* ) )?
                    int alt137=3;
                    alt137 = dfa137.predict(input);
                    switch (alt137) {
                        case 1 :
                            // InternalTableDSL.g:9502:5: ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_arguments_9_0= ruleXShortClosure ) )
                            {
                            // InternalTableDSL.g:9502:5: ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_arguments_9_0= ruleXShortClosure ) )
                            // InternalTableDSL.g:9503:6: ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_arguments_9_0= ruleXShortClosure )
                            {
                            // InternalTableDSL.g:9528:6: (lv_arguments_9_0= ruleXShortClosure )
                            // InternalTableDSL.g:9529:7: lv_arguments_9_0= ruleXShortClosure
                            {
                            if ( state.backtracking==0 ) {

                              							newCompositeNode(grammarAccess.getXConstructorCallAccess().getArgumentsXShortClosureParserRuleCall_4_1_0_0());
                              						
                            }
                            pushFollow(FOLLOW_63);
                            lv_arguments_9_0=ruleXShortClosure();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              							if (current==null) {
                              								current = createModelElementForParent(grammarAccess.getXConstructorCallRule());
                              							}
                              							add(
                              								current,
                              								"arguments",
                              								lv_arguments_9_0,
                              								"org.eclipse.xtext.xbase.Xbase.XShortClosure");
                              							afterParserOrEnumRuleCall();
                              						
                            }

                            }


                            }


                            }
                            break;
                        case 2 :
                            // InternalTableDSL.g:9547:5: ( ( (lv_arguments_10_0= ruleXExpression ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) ) )* )
                            {
                            // InternalTableDSL.g:9547:5: ( ( (lv_arguments_10_0= ruleXExpression ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) ) )* )
                            // InternalTableDSL.g:9548:6: ( (lv_arguments_10_0= ruleXExpression ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) ) )*
                            {
                            // InternalTableDSL.g:9548:6: ( (lv_arguments_10_0= ruleXExpression ) )
                            // InternalTableDSL.g:9549:7: (lv_arguments_10_0= ruleXExpression )
                            {
                            // InternalTableDSL.g:9549:7: (lv_arguments_10_0= ruleXExpression )
                            // InternalTableDSL.g:9550:8: lv_arguments_10_0= ruleXExpression
                            {
                            if ( state.backtracking==0 ) {

                              								newCompositeNode(grammarAccess.getXConstructorCallAccess().getArgumentsXExpressionParserRuleCall_4_1_1_0_0());
                              							
                            }
                            pushFollow(FOLLOW_62);
                            lv_arguments_10_0=ruleXExpression();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              								if (current==null) {
                              									current = createModelElementForParent(grammarAccess.getXConstructorCallRule());
                              								}
                              								add(
                              									current,
                              									"arguments",
                              									lv_arguments_10_0,
                              									"org.eclipse.xtext.xbase.Xbase.XExpression");
                              								afterParserOrEnumRuleCall();
                              							
                            }

                            }


                            }

                            // InternalTableDSL.g:9567:6: (otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) ) )*
                            loop136:
                            do {
                                int alt136=2;
                                int LA136_0 = input.LA(1);

                                if ( (LA136_0==101) ) {
                                    alt136=1;
                                }


                                switch (alt136) {
                            	case 1 :
                            	    // InternalTableDSL.g:9568:7: otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) )
                            	    {
                            	    otherlv_11=(Token)match(input,101,FOLLOW_65); if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      							newLeafNode(otherlv_11, grammarAccess.getXConstructorCallAccess().getCommaKeyword_4_1_1_1_0());
                            	      						
                            	    }
                            	    // InternalTableDSL.g:9572:7: ( (lv_arguments_12_0= ruleXExpression ) )
                            	    // InternalTableDSL.g:9573:8: (lv_arguments_12_0= ruleXExpression )
                            	    {
                            	    // InternalTableDSL.g:9573:8: (lv_arguments_12_0= ruleXExpression )
                            	    // InternalTableDSL.g:9574:9: lv_arguments_12_0= ruleXExpression
                            	    {
                            	    if ( state.backtracking==0 ) {

                            	      									newCompositeNode(grammarAccess.getXConstructorCallAccess().getArgumentsXExpressionParserRuleCall_4_1_1_1_1_0());
                            	      								
                            	    }
                            	    pushFollow(FOLLOW_62);
                            	    lv_arguments_12_0=ruleXExpression();

                            	    state._fsp--;
                            	    if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      									if (current==null) {
                            	      										current = createModelElementForParent(grammarAccess.getXConstructorCallRule());
                            	      									}
                            	      									add(
                            	      										current,
                            	      										"arguments",
                            	      										lv_arguments_12_0,
                            	      										"org.eclipse.xtext.xbase.Xbase.XExpression");
                            	      									afterParserOrEnumRuleCall();
                            	      								
                            	    }

                            	    }


                            	    }


                            	    }
                            	    break;

                            	default :
                            	    break loop136;
                                }
                            } while (true);


                            }


                            }
                            break;

                    }

                    otherlv_13=(Token)match(input,102,FOLLOW_121); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_13, grammarAccess.getXConstructorCallAccess().getRightParenthesisKeyword_4_2());
                      			
                    }

                    }
                    break;

            }

            // InternalTableDSL.g:9599:3: ( ( ( () '[' ) )=> (lv_arguments_14_0= ruleXClosure ) )?
            int alt139=2;
            alt139 = dfa139.predict(input);
            switch (alt139) {
                case 1 :
                    // InternalTableDSL.g:9600:4: ( ( () '[' ) )=> (lv_arguments_14_0= ruleXClosure )
                    {
                    // InternalTableDSL.g:9606:4: (lv_arguments_14_0= ruleXClosure )
                    // InternalTableDSL.g:9607:5: lv_arguments_14_0= ruleXClosure
                    {
                    if ( state.backtracking==0 ) {

                      					newCompositeNode(grammarAccess.getXConstructorCallAccess().getArgumentsXClosureParserRuleCall_5_0());
                      				
                    }
                    pushFollow(FOLLOW_2);
                    lv_arguments_14_0=ruleXClosure();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					if (current==null) {
                      						current = createModelElementForParent(grammarAccess.getXConstructorCallRule());
                      					}
                      					add(
                      						current,
                      						"arguments",
                      						lv_arguments_14_0,
                      						"org.eclipse.xtext.xbase.Xbase.XClosure");
                      					afterParserOrEnumRuleCall();
                      				
                    }

                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXConstructorCall"


    // $ANTLR start "entryRuleXBooleanLiteral"
    // InternalTableDSL.g:9628:1: entryRuleXBooleanLiteral returns [EObject current=null] : iv_ruleXBooleanLiteral= ruleXBooleanLiteral EOF ;
    public final EObject entryRuleXBooleanLiteral() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXBooleanLiteral = null;


        try {
            // InternalTableDSL.g:9628:56: (iv_ruleXBooleanLiteral= ruleXBooleanLiteral EOF )
            // InternalTableDSL.g:9629:2: iv_ruleXBooleanLiteral= ruleXBooleanLiteral EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXBooleanLiteralRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXBooleanLiteral=ruleXBooleanLiteral();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXBooleanLiteral; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXBooleanLiteral"


    // $ANTLR start "ruleXBooleanLiteral"
    // InternalTableDSL.g:9635:1: ruleXBooleanLiteral returns [EObject current=null] : ( () (otherlv_1= 'false' | ( (lv_isTrue_2_0= 'true' ) ) ) ) ;
    public final EObject ruleXBooleanLiteral() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token lv_isTrue_2_0=null;


        	enterRule();

        try {
            // InternalTableDSL.g:9641:2: ( ( () (otherlv_1= 'false' | ( (lv_isTrue_2_0= 'true' ) ) ) ) )
            // InternalTableDSL.g:9642:2: ( () (otherlv_1= 'false' | ( (lv_isTrue_2_0= 'true' ) ) ) )
            {
            // InternalTableDSL.g:9642:2: ( () (otherlv_1= 'false' | ( (lv_isTrue_2_0= 'true' ) ) ) )
            // InternalTableDSL.g:9643:3: () (otherlv_1= 'false' | ( (lv_isTrue_2_0= 'true' ) ) )
            {
            // InternalTableDSL.g:9643:3: ()
            // InternalTableDSL.g:9644:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXBooleanLiteralAccess().getXBooleanLiteralAction_0(),
              					current);
              			
            }

            }

            // InternalTableDSL.g:9650:3: (otherlv_1= 'false' | ( (lv_isTrue_2_0= 'true' ) ) )
            int alt140=2;
            int LA140_0 = input.LA(1);

            if ( (LA140_0==151) ) {
                alt140=1;
            }
            else if ( (LA140_0==152) ) {
                alt140=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 140, 0, input);

                throw nvae;
            }
            switch (alt140) {
                case 1 :
                    // InternalTableDSL.g:9651:4: otherlv_1= 'false'
                    {
                    otherlv_1=(Token)match(input,151,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_1, grammarAccess.getXBooleanLiteralAccess().getFalseKeyword_1_0());
                      			
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:9656:4: ( (lv_isTrue_2_0= 'true' ) )
                    {
                    // InternalTableDSL.g:9656:4: ( (lv_isTrue_2_0= 'true' ) )
                    // InternalTableDSL.g:9657:5: (lv_isTrue_2_0= 'true' )
                    {
                    // InternalTableDSL.g:9657:5: (lv_isTrue_2_0= 'true' )
                    // InternalTableDSL.g:9658:6: lv_isTrue_2_0= 'true'
                    {
                    lv_isTrue_2_0=(Token)match(input,152,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						newLeafNode(lv_isTrue_2_0, grammarAccess.getXBooleanLiteralAccess().getIsTrueTrueKeyword_1_1_0());
                      					
                    }
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElement(grammarAccess.getXBooleanLiteralRule());
                      						}
                      						setWithLastConsumed(current, "isTrue", true, "true");
                      					
                    }

                    }


                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXBooleanLiteral"


    // $ANTLR start "entryRuleXNullLiteral"
    // InternalTableDSL.g:9675:1: entryRuleXNullLiteral returns [EObject current=null] : iv_ruleXNullLiteral= ruleXNullLiteral EOF ;
    public final EObject entryRuleXNullLiteral() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXNullLiteral = null;


        try {
            // InternalTableDSL.g:9675:53: (iv_ruleXNullLiteral= ruleXNullLiteral EOF )
            // InternalTableDSL.g:9676:2: iv_ruleXNullLiteral= ruleXNullLiteral EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXNullLiteralRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXNullLiteral=ruleXNullLiteral();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXNullLiteral; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXNullLiteral"


    // $ANTLR start "ruleXNullLiteral"
    // InternalTableDSL.g:9682:1: ruleXNullLiteral returns [EObject current=null] : ( () otherlv_1= 'null' ) ;
    public final EObject ruleXNullLiteral() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;


        	enterRule();

        try {
            // InternalTableDSL.g:9688:2: ( ( () otherlv_1= 'null' ) )
            // InternalTableDSL.g:9689:2: ( () otherlv_1= 'null' )
            {
            // InternalTableDSL.g:9689:2: ( () otherlv_1= 'null' )
            // InternalTableDSL.g:9690:3: () otherlv_1= 'null'
            {
            // InternalTableDSL.g:9690:3: ()
            // InternalTableDSL.g:9691:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXNullLiteralAccess().getXNullLiteralAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,153,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXNullLiteralAccess().getNullKeyword_1());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXNullLiteral"


    // $ANTLR start "entryRuleXNumberLiteral"
    // InternalTableDSL.g:9705:1: entryRuleXNumberLiteral returns [EObject current=null] : iv_ruleXNumberLiteral= ruleXNumberLiteral EOF ;
    public final EObject entryRuleXNumberLiteral() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXNumberLiteral = null;


        try {
            // InternalTableDSL.g:9705:55: (iv_ruleXNumberLiteral= ruleXNumberLiteral EOF )
            // InternalTableDSL.g:9706:2: iv_ruleXNumberLiteral= ruleXNumberLiteral EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXNumberLiteralRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXNumberLiteral=ruleXNumberLiteral();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXNumberLiteral; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXNumberLiteral"


    // $ANTLR start "ruleXNumberLiteral"
    // InternalTableDSL.g:9712:1: ruleXNumberLiteral returns [EObject current=null] : ( () ( (lv_value_1_0= ruleNumber ) ) ) ;
    public final EObject ruleXNumberLiteral() throws RecognitionException {
        EObject current = null;

        AntlrDatatypeRuleToken lv_value_1_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:9718:2: ( ( () ( (lv_value_1_0= ruleNumber ) ) ) )
            // InternalTableDSL.g:9719:2: ( () ( (lv_value_1_0= ruleNumber ) ) )
            {
            // InternalTableDSL.g:9719:2: ( () ( (lv_value_1_0= ruleNumber ) ) )
            // InternalTableDSL.g:9720:3: () ( (lv_value_1_0= ruleNumber ) )
            {
            // InternalTableDSL.g:9720:3: ()
            // InternalTableDSL.g:9721:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXNumberLiteralAccess().getXNumberLiteralAction_0(),
              					current);
              			
            }

            }

            // InternalTableDSL.g:9727:3: ( (lv_value_1_0= ruleNumber ) )
            // InternalTableDSL.g:9728:4: (lv_value_1_0= ruleNumber )
            {
            // InternalTableDSL.g:9728:4: (lv_value_1_0= ruleNumber )
            // InternalTableDSL.g:9729:5: lv_value_1_0= ruleNumber
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXNumberLiteralAccess().getValueNumberParserRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_value_1_0=ruleNumber();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXNumberLiteralRule());
              					}
              					set(
              						current,
              						"value",
              						lv_value_1_0,
              						"org.eclipse.xtext.xbase.Xbase.Number");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXNumberLiteral"


    // $ANTLR start "entryRuleXStringLiteral"
    // InternalTableDSL.g:9750:1: entryRuleXStringLiteral returns [EObject current=null] : iv_ruleXStringLiteral= ruleXStringLiteral EOF ;
    public final EObject entryRuleXStringLiteral() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXStringLiteral = null;


        try {
            // InternalTableDSL.g:9750:55: (iv_ruleXStringLiteral= ruleXStringLiteral EOF )
            // InternalTableDSL.g:9751:2: iv_ruleXStringLiteral= ruleXStringLiteral EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXStringLiteralRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXStringLiteral=ruleXStringLiteral();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXStringLiteral; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXStringLiteral"


    // $ANTLR start "ruleXStringLiteral"
    // InternalTableDSL.g:9757:1: ruleXStringLiteral returns [EObject current=null] : ( () ( (lv_value_1_0= RULE_STRING ) ) ) ;
    public final EObject ruleXStringLiteral() throws RecognitionException {
        EObject current = null;

        Token lv_value_1_0=null;


        	enterRule();

        try {
            // InternalTableDSL.g:9763:2: ( ( () ( (lv_value_1_0= RULE_STRING ) ) ) )
            // InternalTableDSL.g:9764:2: ( () ( (lv_value_1_0= RULE_STRING ) ) )
            {
            // InternalTableDSL.g:9764:2: ( () ( (lv_value_1_0= RULE_STRING ) ) )
            // InternalTableDSL.g:9765:3: () ( (lv_value_1_0= RULE_STRING ) )
            {
            // InternalTableDSL.g:9765:3: ()
            // InternalTableDSL.g:9766:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXStringLiteralAccess().getXStringLiteralAction_0(),
              					current);
              			
            }

            }

            // InternalTableDSL.g:9772:3: ( (lv_value_1_0= RULE_STRING ) )
            // InternalTableDSL.g:9773:4: (lv_value_1_0= RULE_STRING )
            {
            // InternalTableDSL.g:9773:4: (lv_value_1_0= RULE_STRING )
            // InternalTableDSL.g:9774:5: lv_value_1_0= RULE_STRING
            {
            lv_value_1_0=(Token)match(input,RULE_STRING,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(lv_value_1_0, grammarAccess.getXStringLiteralAccess().getValueSTRINGTerminalRuleCall_1_0());
              				
            }
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getXStringLiteralRule());
              					}
              					setWithLastConsumed(
              						current,
              						"value",
              						lv_value_1_0,
              						"org.eclipse.xtext.xbase.Xtype.STRING");
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXStringLiteral"


    // $ANTLR start "entryRuleXTypeLiteral"
    // InternalTableDSL.g:9794:1: entryRuleXTypeLiteral returns [EObject current=null] : iv_ruleXTypeLiteral= ruleXTypeLiteral EOF ;
    public final EObject entryRuleXTypeLiteral() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXTypeLiteral = null;


        try {
            // InternalTableDSL.g:9794:53: (iv_ruleXTypeLiteral= ruleXTypeLiteral EOF )
            // InternalTableDSL.g:9795:2: iv_ruleXTypeLiteral= ruleXTypeLiteral EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXTypeLiteralRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXTypeLiteral=ruleXTypeLiteral();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXTypeLiteral; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXTypeLiteral"


    // $ANTLR start "ruleXTypeLiteral"
    // InternalTableDSL.g:9801:1: ruleXTypeLiteral returns [EObject current=null] : ( () otherlv_1= 'typeof' otherlv_2= '(' ( ( ruleQualifiedName ) ) ( (lv_arrayDimensions_4_0= ruleArrayBrackets ) )* otherlv_5= ')' ) ;
    public final EObject ruleXTypeLiteral() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token otherlv_5=null;
        AntlrDatatypeRuleToken lv_arrayDimensions_4_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:9807:2: ( ( () otherlv_1= 'typeof' otherlv_2= '(' ( ( ruleQualifiedName ) ) ( (lv_arrayDimensions_4_0= ruleArrayBrackets ) )* otherlv_5= ')' ) )
            // InternalTableDSL.g:9808:2: ( () otherlv_1= 'typeof' otherlv_2= '(' ( ( ruleQualifiedName ) ) ( (lv_arrayDimensions_4_0= ruleArrayBrackets ) )* otherlv_5= ')' )
            {
            // InternalTableDSL.g:9808:2: ( () otherlv_1= 'typeof' otherlv_2= '(' ( ( ruleQualifiedName ) ) ( (lv_arrayDimensions_4_0= ruleArrayBrackets ) )* otherlv_5= ')' )
            // InternalTableDSL.g:9809:3: () otherlv_1= 'typeof' otherlv_2= '(' ( ( ruleQualifiedName ) ) ( (lv_arrayDimensions_4_0= ruleArrayBrackets ) )* otherlv_5= ')'
            {
            // InternalTableDSL.g:9809:3: ()
            // InternalTableDSL.g:9810:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXTypeLiteralAccess().getXTypeLiteralAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,154,FOLLOW_103); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXTypeLiteralAccess().getTypeofKeyword_1());
              		
            }
            otherlv_2=(Token)match(input,100,FOLLOW_4); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_2, grammarAccess.getXTypeLiteralAccess().getLeftParenthesisKeyword_2());
              		
            }
            // InternalTableDSL.g:9824:3: ( ( ruleQualifiedName ) )
            // InternalTableDSL.g:9825:4: ( ruleQualifiedName )
            {
            // InternalTableDSL.g:9825:4: ( ruleQualifiedName )
            // InternalTableDSL.g:9826:5: ruleQualifiedName
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getXTypeLiteralRule());
              					}
              				
            }
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXTypeLiteralAccess().getTypeJvmTypeCrossReference_3_0());
              				
            }
            pushFollow(FOLLOW_123);
            ruleQualifiedName();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:9840:3: ( (lv_arrayDimensions_4_0= ruleArrayBrackets ) )*
            loop141:
            do {
                int alt141=2;
                int LA141_0 = input.LA(1);

                if ( (LA141_0==105) ) {
                    alt141=1;
                }


                switch (alt141) {
            	case 1 :
            	    // InternalTableDSL.g:9841:4: (lv_arrayDimensions_4_0= ruleArrayBrackets )
            	    {
            	    // InternalTableDSL.g:9841:4: (lv_arrayDimensions_4_0= ruleArrayBrackets )
            	    // InternalTableDSL.g:9842:5: lv_arrayDimensions_4_0= ruleArrayBrackets
            	    {
            	    if ( state.backtracking==0 ) {

            	      					newCompositeNode(grammarAccess.getXTypeLiteralAccess().getArrayDimensionsArrayBracketsParserRuleCall_4_0());
            	      				
            	    }
            	    pushFollow(FOLLOW_123);
            	    lv_arrayDimensions_4_0=ruleArrayBrackets();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      					if (current==null) {
            	      						current = createModelElementForParent(grammarAccess.getXTypeLiteralRule());
            	      					}
            	      					add(
            	      						current,
            	      						"arrayDimensions",
            	      						lv_arrayDimensions_4_0,
            	      						"org.eclipse.xtext.xbase.Xtype.ArrayBrackets");
            	      					afterParserOrEnumRuleCall();
            	      				
            	    }

            	    }


            	    }
            	    break;

            	default :
            	    break loop141;
                }
            } while (true);

            otherlv_5=(Token)match(input,102,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_5, grammarAccess.getXTypeLiteralAccess().getRightParenthesisKeyword_5());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXTypeLiteral"


    // $ANTLR start "entryRuleXThrowExpression"
    // InternalTableDSL.g:9867:1: entryRuleXThrowExpression returns [EObject current=null] : iv_ruleXThrowExpression= ruleXThrowExpression EOF ;
    public final EObject entryRuleXThrowExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXThrowExpression = null;


        try {
            // InternalTableDSL.g:9867:57: (iv_ruleXThrowExpression= ruleXThrowExpression EOF )
            // InternalTableDSL.g:9868:2: iv_ruleXThrowExpression= ruleXThrowExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXThrowExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXThrowExpression=ruleXThrowExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXThrowExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXThrowExpression"


    // $ANTLR start "ruleXThrowExpression"
    // InternalTableDSL.g:9874:1: ruleXThrowExpression returns [EObject current=null] : ( () otherlv_1= 'throw' ( (lv_expression_2_0= ruleXExpression ) ) ) ;
    public final EObject ruleXThrowExpression() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        EObject lv_expression_2_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:9880:2: ( ( () otherlv_1= 'throw' ( (lv_expression_2_0= ruleXExpression ) ) ) )
            // InternalTableDSL.g:9881:2: ( () otherlv_1= 'throw' ( (lv_expression_2_0= ruleXExpression ) ) )
            {
            // InternalTableDSL.g:9881:2: ( () otherlv_1= 'throw' ( (lv_expression_2_0= ruleXExpression ) ) )
            // InternalTableDSL.g:9882:3: () otherlv_1= 'throw' ( (lv_expression_2_0= ruleXExpression ) )
            {
            // InternalTableDSL.g:9882:3: ()
            // InternalTableDSL.g:9883:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXThrowExpressionAccess().getXThrowExpressionAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,155,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXThrowExpressionAccess().getThrowKeyword_1());
              		
            }
            // InternalTableDSL.g:9893:3: ( (lv_expression_2_0= ruleXExpression ) )
            // InternalTableDSL.g:9894:4: (lv_expression_2_0= ruleXExpression )
            {
            // InternalTableDSL.g:9894:4: (lv_expression_2_0= ruleXExpression )
            // InternalTableDSL.g:9895:5: lv_expression_2_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXThrowExpressionAccess().getExpressionXExpressionParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_expression_2_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXThrowExpressionRule());
              					}
              					set(
              						current,
              						"expression",
              						lv_expression_2_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXThrowExpression"


    // $ANTLR start "entryRuleXReturnExpression"
    // InternalTableDSL.g:9916:1: entryRuleXReturnExpression returns [EObject current=null] : iv_ruleXReturnExpression= ruleXReturnExpression EOF ;
    public final EObject entryRuleXReturnExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXReturnExpression = null;


        try {
            // InternalTableDSL.g:9916:58: (iv_ruleXReturnExpression= ruleXReturnExpression EOF )
            // InternalTableDSL.g:9917:2: iv_ruleXReturnExpression= ruleXReturnExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXReturnExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXReturnExpression=ruleXReturnExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXReturnExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXReturnExpression"


    // $ANTLR start "ruleXReturnExpression"
    // InternalTableDSL.g:9923:1: ruleXReturnExpression returns [EObject current=null] : ( () otherlv_1= 'return' ( ( 'extends' | 'static' | 'import' | 'extension' | '!' | '-' | '+' | 'new' | '{' | 'switch' | 'synchronized' | '<' | 'super' | '#' | '[' | 'false' | 'true' | 'null' | 'typeof' | 'if' | 'for' | 'while' | 'do' | 'throw' | 'return' | 'try' | '(' | RULE_ID | RULE_HEX | RULE_INT | RULE_DECIMAL | RULE_STRING )=> (lv_expression_2_0= ruleXExpression ) )? ) ;
    public final EObject ruleXReturnExpression() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        EObject lv_expression_2_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:9929:2: ( ( () otherlv_1= 'return' ( ( 'extends' | 'static' | 'import' | 'extension' | '!' | '-' | '+' | 'new' | '{' | 'switch' | 'synchronized' | '<' | 'super' | '#' | '[' | 'false' | 'true' | 'null' | 'typeof' | 'if' | 'for' | 'while' | 'do' | 'throw' | 'return' | 'try' | '(' | RULE_ID | RULE_HEX | RULE_INT | RULE_DECIMAL | RULE_STRING )=> (lv_expression_2_0= ruleXExpression ) )? ) )
            // InternalTableDSL.g:9930:2: ( () otherlv_1= 'return' ( ( 'extends' | 'static' | 'import' | 'extension' | '!' | '-' | '+' | 'new' | '{' | 'switch' | 'synchronized' | '<' | 'super' | '#' | '[' | 'false' | 'true' | 'null' | 'typeof' | 'if' | 'for' | 'while' | 'do' | 'throw' | 'return' | 'try' | '(' | RULE_ID | RULE_HEX | RULE_INT | RULE_DECIMAL | RULE_STRING )=> (lv_expression_2_0= ruleXExpression ) )? )
            {
            // InternalTableDSL.g:9930:2: ( () otherlv_1= 'return' ( ( 'extends' | 'static' | 'import' | 'extension' | '!' | '-' | '+' | 'new' | '{' | 'switch' | 'synchronized' | '<' | 'super' | '#' | '[' | 'false' | 'true' | 'null' | 'typeof' | 'if' | 'for' | 'while' | 'do' | 'throw' | 'return' | 'try' | '(' | RULE_ID | RULE_HEX | RULE_INT | RULE_DECIMAL | RULE_STRING )=> (lv_expression_2_0= ruleXExpression ) )? )
            // InternalTableDSL.g:9931:3: () otherlv_1= 'return' ( ( 'extends' | 'static' | 'import' | 'extension' | '!' | '-' | '+' | 'new' | '{' | 'switch' | 'synchronized' | '<' | 'super' | '#' | '[' | 'false' | 'true' | 'null' | 'typeof' | 'if' | 'for' | 'while' | 'do' | 'throw' | 'return' | 'try' | '(' | RULE_ID | RULE_HEX | RULE_INT | RULE_DECIMAL | RULE_STRING )=> (lv_expression_2_0= ruleXExpression ) )?
            {
            // InternalTableDSL.g:9931:3: ()
            // InternalTableDSL.g:9932:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXReturnExpressionAccess().getXReturnExpressionAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,156,FOLLOW_124); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXReturnExpressionAccess().getReturnKeyword_1());
              		
            }
            // InternalTableDSL.g:9942:3: ( ( 'extends' | 'static' | 'import' | 'extension' | '!' | '-' | '+' | 'new' | '{' | 'switch' | 'synchronized' | '<' | 'super' | '#' | '[' | 'false' | 'true' | 'null' | 'typeof' | 'if' | 'for' | 'while' | 'do' | 'throw' | 'return' | 'try' | '(' | RULE_ID | RULE_HEX | RULE_INT | RULE_DECIMAL | RULE_STRING )=> (lv_expression_2_0= ruleXExpression ) )?
            int alt142=2;
            alt142 = dfa142.predict(input);
            switch (alt142) {
                case 1 :
                    // InternalTableDSL.g:9943:4: ( 'extends' | 'static' | 'import' | 'extension' | '!' | '-' | '+' | 'new' | '{' | 'switch' | 'synchronized' | '<' | 'super' | '#' | '[' | 'false' | 'true' | 'null' | 'typeof' | 'if' | 'for' | 'while' | 'do' | 'throw' | 'return' | 'try' | '(' | RULE_ID | RULE_HEX | RULE_INT | RULE_DECIMAL | RULE_STRING )=> (lv_expression_2_0= ruleXExpression )
                    {
                    // InternalTableDSL.g:9944:4: (lv_expression_2_0= ruleXExpression )
                    // InternalTableDSL.g:9945:5: lv_expression_2_0= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      					newCompositeNode(grammarAccess.getXReturnExpressionAccess().getExpressionXExpressionParserRuleCall_2_0());
                      				
                    }
                    pushFollow(FOLLOW_2);
                    lv_expression_2_0=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					if (current==null) {
                      						current = createModelElementForParent(grammarAccess.getXReturnExpressionRule());
                      					}
                      					set(
                      						current,
                      						"expression",
                      						lv_expression_2_0,
                      						"org.eclipse.xtext.xbase.Xbase.XExpression");
                      					afterParserOrEnumRuleCall();
                      				
                    }

                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXReturnExpression"


    // $ANTLR start "entryRuleXTryCatchFinallyExpression"
    // InternalTableDSL.g:9966:1: entryRuleXTryCatchFinallyExpression returns [EObject current=null] : iv_ruleXTryCatchFinallyExpression= ruleXTryCatchFinallyExpression EOF ;
    public final EObject entryRuleXTryCatchFinallyExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXTryCatchFinallyExpression = null;


        try {
            // InternalTableDSL.g:9966:67: (iv_ruleXTryCatchFinallyExpression= ruleXTryCatchFinallyExpression EOF )
            // InternalTableDSL.g:9967:2: iv_ruleXTryCatchFinallyExpression= ruleXTryCatchFinallyExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXTryCatchFinallyExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXTryCatchFinallyExpression=ruleXTryCatchFinallyExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXTryCatchFinallyExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXTryCatchFinallyExpression"


    // $ANTLR start "ruleXTryCatchFinallyExpression"
    // InternalTableDSL.g:9973:1: ruleXTryCatchFinallyExpression returns [EObject current=null] : ( () otherlv_1= 'try' ( (lv_expression_2_0= ruleXExpression ) ) ( ( ( ( 'catch' )=> (lv_catchClauses_3_0= ruleXCatchClause ) )+ ( ( ( 'finally' )=>otherlv_4= 'finally' ) ( (lv_finallyExpression_5_0= ruleXExpression ) ) )? ) | (otherlv_6= 'finally' ( (lv_finallyExpression_7_0= ruleXExpression ) ) ) ) ) ;
    public final EObject ruleXTryCatchFinallyExpression() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_4=null;
        Token otherlv_6=null;
        EObject lv_expression_2_0 = null;

        EObject lv_catchClauses_3_0 = null;

        EObject lv_finallyExpression_5_0 = null;

        EObject lv_finallyExpression_7_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:9979:2: ( ( () otherlv_1= 'try' ( (lv_expression_2_0= ruleXExpression ) ) ( ( ( ( 'catch' )=> (lv_catchClauses_3_0= ruleXCatchClause ) )+ ( ( ( 'finally' )=>otherlv_4= 'finally' ) ( (lv_finallyExpression_5_0= ruleXExpression ) ) )? ) | (otherlv_6= 'finally' ( (lv_finallyExpression_7_0= ruleXExpression ) ) ) ) ) )
            // InternalTableDSL.g:9980:2: ( () otherlv_1= 'try' ( (lv_expression_2_0= ruleXExpression ) ) ( ( ( ( 'catch' )=> (lv_catchClauses_3_0= ruleXCatchClause ) )+ ( ( ( 'finally' )=>otherlv_4= 'finally' ) ( (lv_finallyExpression_5_0= ruleXExpression ) ) )? ) | (otherlv_6= 'finally' ( (lv_finallyExpression_7_0= ruleXExpression ) ) ) ) )
            {
            // InternalTableDSL.g:9980:2: ( () otherlv_1= 'try' ( (lv_expression_2_0= ruleXExpression ) ) ( ( ( ( 'catch' )=> (lv_catchClauses_3_0= ruleXCatchClause ) )+ ( ( ( 'finally' )=>otherlv_4= 'finally' ) ( (lv_finallyExpression_5_0= ruleXExpression ) ) )? ) | (otherlv_6= 'finally' ( (lv_finallyExpression_7_0= ruleXExpression ) ) ) ) )
            // InternalTableDSL.g:9981:3: () otherlv_1= 'try' ( (lv_expression_2_0= ruleXExpression ) ) ( ( ( ( 'catch' )=> (lv_catchClauses_3_0= ruleXCatchClause ) )+ ( ( ( 'finally' )=>otherlv_4= 'finally' ) ( (lv_finallyExpression_5_0= ruleXExpression ) ) )? ) | (otherlv_6= 'finally' ( (lv_finallyExpression_7_0= ruleXExpression ) ) ) )
            {
            // InternalTableDSL.g:9981:3: ()
            // InternalTableDSL.g:9982:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getXTryCatchFinallyExpressionAccess().getXTryCatchFinallyExpressionAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,157,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXTryCatchFinallyExpressionAccess().getTryKeyword_1());
              		
            }
            // InternalTableDSL.g:9992:3: ( (lv_expression_2_0= ruleXExpression ) )
            // InternalTableDSL.g:9993:4: (lv_expression_2_0= ruleXExpression )
            {
            // InternalTableDSL.g:9993:4: (lv_expression_2_0= ruleXExpression )
            // InternalTableDSL.g:9994:5: lv_expression_2_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXTryCatchFinallyExpressionAccess().getExpressionXExpressionParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_125);
            lv_expression_2_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXTryCatchFinallyExpressionRule());
              					}
              					set(
              						current,
              						"expression",
              						lv_expression_2_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:10011:3: ( ( ( ( 'catch' )=> (lv_catchClauses_3_0= ruleXCatchClause ) )+ ( ( ( 'finally' )=>otherlv_4= 'finally' ) ( (lv_finallyExpression_5_0= ruleXExpression ) ) )? ) | (otherlv_6= 'finally' ( (lv_finallyExpression_7_0= ruleXExpression ) ) ) )
            int alt145=2;
            int LA145_0 = input.LA(1);

            if ( (LA145_0==160) ) {
                alt145=1;
            }
            else if ( (LA145_0==158) ) {
                alt145=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 145, 0, input);

                throw nvae;
            }
            switch (alt145) {
                case 1 :
                    // InternalTableDSL.g:10012:4: ( ( ( 'catch' )=> (lv_catchClauses_3_0= ruleXCatchClause ) )+ ( ( ( 'finally' )=>otherlv_4= 'finally' ) ( (lv_finallyExpression_5_0= ruleXExpression ) ) )? )
                    {
                    // InternalTableDSL.g:10012:4: ( ( ( 'catch' )=> (lv_catchClauses_3_0= ruleXCatchClause ) )+ ( ( ( 'finally' )=>otherlv_4= 'finally' ) ( (lv_finallyExpression_5_0= ruleXExpression ) ) )? )
                    // InternalTableDSL.g:10013:5: ( ( 'catch' )=> (lv_catchClauses_3_0= ruleXCatchClause ) )+ ( ( ( 'finally' )=>otherlv_4= 'finally' ) ( (lv_finallyExpression_5_0= ruleXExpression ) ) )?
                    {
                    // InternalTableDSL.g:10013:5: ( ( 'catch' )=> (lv_catchClauses_3_0= ruleXCatchClause ) )+
                    int cnt143=0;
                    loop143:
                    do {
                        int alt143=2;
                        int LA143_0 = input.LA(1);

                        if ( (LA143_0==160) ) {
                            int LA143_2 = input.LA(2);

                            if ( (synpred44_InternalTableDSL()) ) {
                                alt143=1;
                            }


                        }


                        switch (alt143) {
                    	case 1 :
                    	    // InternalTableDSL.g:10014:6: ( 'catch' )=> (lv_catchClauses_3_0= ruleXCatchClause )
                    	    {
                    	    // InternalTableDSL.g:10015:6: (lv_catchClauses_3_0= ruleXCatchClause )
                    	    // InternalTableDSL.g:10016:7: lv_catchClauses_3_0= ruleXCatchClause
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      							newCompositeNode(grammarAccess.getXTryCatchFinallyExpressionAccess().getCatchClausesXCatchClauseParserRuleCall_3_0_0_0());
                    	      						
                    	    }
                    	    pushFollow(FOLLOW_126);
                    	    lv_catchClauses_3_0=ruleXCatchClause();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      							if (current==null) {
                    	      								current = createModelElementForParent(grammarAccess.getXTryCatchFinallyExpressionRule());
                    	      							}
                    	      							add(
                    	      								current,
                    	      								"catchClauses",
                    	      								lv_catchClauses_3_0,
                    	      								"org.eclipse.xtext.xbase.Xbase.XCatchClause");
                    	      							afterParserOrEnumRuleCall();
                    	      						
                    	    }

                    	    }


                    	    }
                    	    break;

                    	default :
                    	    if ( cnt143 >= 1 ) break loop143;
                    	    if (state.backtracking>0) {state.failed=true; return current;}
                                EarlyExitException eee =
                                    new EarlyExitException(143, input);
                                throw eee;
                        }
                        cnt143++;
                    } while (true);

                    // InternalTableDSL.g:10033:5: ( ( ( 'finally' )=>otherlv_4= 'finally' ) ( (lv_finallyExpression_5_0= ruleXExpression ) ) )?
                    int alt144=2;
                    int LA144_0 = input.LA(1);

                    if ( (LA144_0==158) ) {
                        int LA144_1 = input.LA(2);

                        if ( (synpred45_InternalTableDSL()) ) {
                            alt144=1;
                        }
                    }
                    switch (alt144) {
                        case 1 :
                            // InternalTableDSL.g:10034:6: ( ( 'finally' )=>otherlv_4= 'finally' ) ( (lv_finallyExpression_5_0= ruleXExpression ) )
                            {
                            // InternalTableDSL.g:10034:6: ( ( 'finally' )=>otherlv_4= 'finally' )
                            // InternalTableDSL.g:10035:7: ( 'finally' )=>otherlv_4= 'finally'
                            {
                            otherlv_4=(Token)match(input,158,FOLLOW_65); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              							newLeafNode(otherlv_4, grammarAccess.getXTryCatchFinallyExpressionAccess().getFinallyKeyword_3_0_1_0());
                              						
                            }

                            }

                            // InternalTableDSL.g:10041:6: ( (lv_finallyExpression_5_0= ruleXExpression ) )
                            // InternalTableDSL.g:10042:7: (lv_finallyExpression_5_0= ruleXExpression )
                            {
                            // InternalTableDSL.g:10042:7: (lv_finallyExpression_5_0= ruleXExpression )
                            // InternalTableDSL.g:10043:8: lv_finallyExpression_5_0= ruleXExpression
                            {
                            if ( state.backtracking==0 ) {

                              								newCompositeNode(grammarAccess.getXTryCatchFinallyExpressionAccess().getFinallyExpressionXExpressionParserRuleCall_3_0_1_1_0());
                              							
                            }
                            pushFollow(FOLLOW_2);
                            lv_finallyExpression_5_0=ruleXExpression();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              								if (current==null) {
                              									current = createModelElementForParent(grammarAccess.getXTryCatchFinallyExpressionRule());
                              								}
                              								set(
                              									current,
                              									"finallyExpression",
                              									lv_finallyExpression_5_0,
                              									"org.eclipse.xtext.xbase.Xbase.XExpression");
                              								afterParserOrEnumRuleCall();
                              							
                            }

                            }


                            }


                            }
                            break;

                    }


                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:10063:4: (otherlv_6= 'finally' ( (lv_finallyExpression_7_0= ruleXExpression ) ) )
                    {
                    // InternalTableDSL.g:10063:4: (otherlv_6= 'finally' ( (lv_finallyExpression_7_0= ruleXExpression ) ) )
                    // InternalTableDSL.g:10064:5: otherlv_6= 'finally' ( (lv_finallyExpression_7_0= ruleXExpression ) )
                    {
                    otherlv_6=(Token)match(input,158,FOLLOW_65); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					newLeafNode(otherlv_6, grammarAccess.getXTryCatchFinallyExpressionAccess().getFinallyKeyword_3_1_0());
                      				
                    }
                    // InternalTableDSL.g:10068:5: ( (lv_finallyExpression_7_0= ruleXExpression ) )
                    // InternalTableDSL.g:10069:6: (lv_finallyExpression_7_0= ruleXExpression )
                    {
                    // InternalTableDSL.g:10069:6: (lv_finallyExpression_7_0= ruleXExpression )
                    // InternalTableDSL.g:10070:7: lv_finallyExpression_7_0= ruleXExpression
                    {
                    if ( state.backtracking==0 ) {

                      							newCompositeNode(grammarAccess.getXTryCatchFinallyExpressionAccess().getFinallyExpressionXExpressionParserRuleCall_3_1_1_0());
                      						
                    }
                    pushFollow(FOLLOW_2);
                    lv_finallyExpression_7_0=ruleXExpression();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      							if (current==null) {
                      								current = createModelElementForParent(grammarAccess.getXTryCatchFinallyExpressionRule());
                      							}
                      							set(
                      								current,
                      								"finallyExpression",
                      								lv_finallyExpression_7_0,
                      								"org.eclipse.xtext.xbase.Xbase.XExpression");
                      							afterParserOrEnumRuleCall();
                      						
                    }

                    }


                    }


                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXTryCatchFinallyExpression"


    // $ANTLR start "entryRuleXSynchronizedExpression"
    // InternalTableDSL.g:10093:1: entryRuleXSynchronizedExpression returns [EObject current=null] : iv_ruleXSynchronizedExpression= ruleXSynchronizedExpression EOF ;
    public final EObject entryRuleXSynchronizedExpression() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXSynchronizedExpression = null;


        try {
            // InternalTableDSL.g:10093:64: (iv_ruleXSynchronizedExpression= ruleXSynchronizedExpression EOF )
            // InternalTableDSL.g:10094:2: iv_ruleXSynchronizedExpression= ruleXSynchronizedExpression EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXSynchronizedExpressionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXSynchronizedExpression=ruleXSynchronizedExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXSynchronizedExpression; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXSynchronizedExpression"


    // $ANTLR start "ruleXSynchronizedExpression"
    // InternalTableDSL.g:10100:1: ruleXSynchronizedExpression returns [EObject current=null] : ( ( ( ( () 'synchronized' '(' ) )=> ( () otherlv_1= 'synchronized' otherlv_2= '(' ) ) ( (lv_param_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_expression_5_0= ruleXExpression ) ) ) ;
    public final EObject ruleXSynchronizedExpression() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_2=null;
        Token otherlv_4=null;
        EObject lv_param_3_0 = null;

        EObject lv_expression_5_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:10106:2: ( ( ( ( ( () 'synchronized' '(' ) )=> ( () otherlv_1= 'synchronized' otherlv_2= '(' ) ) ( (lv_param_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_expression_5_0= ruleXExpression ) ) ) )
            // InternalTableDSL.g:10107:2: ( ( ( ( () 'synchronized' '(' ) )=> ( () otherlv_1= 'synchronized' otherlv_2= '(' ) ) ( (lv_param_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_expression_5_0= ruleXExpression ) ) )
            {
            // InternalTableDSL.g:10107:2: ( ( ( ( () 'synchronized' '(' ) )=> ( () otherlv_1= 'synchronized' otherlv_2= '(' ) ) ( (lv_param_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_expression_5_0= ruleXExpression ) ) )
            // InternalTableDSL.g:10108:3: ( ( ( () 'synchronized' '(' ) )=> ( () otherlv_1= 'synchronized' otherlv_2= '(' ) ) ( (lv_param_3_0= ruleXExpression ) ) otherlv_4= ')' ( (lv_expression_5_0= ruleXExpression ) )
            {
            // InternalTableDSL.g:10108:3: ( ( ( () 'synchronized' '(' ) )=> ( () otherlv_1= 'synchronized' otherlv_2= '(' ) )
            // InternalTableDSL.g:10109:4: ( ( () 'synchronized' '(' ) )=> ( () otherlv_1= 'synchronized' otherlv_2= '(' )
            {
            // InternalTableDSL.g:10116:4: ( () otherlv_1= 'synchronized' otherlv_2= '(' )
            // InternalTableDSL.g:10117:5: () otherlv_1= 'synchronized' otherlv_2= '('
            {
            // InternalTableDSL.g:10117:5: ()
            // InternalTableDSL.g:10118:6: 
            {
            if ( state.backtracking==0 ) {

              						current = forceCreateModelElement(
              							grammarAccess.getXSynchronizedExpressionAccess().getXSynchronizedExpressionAction_0_0_0(),
              							current);
              					
            }

            }

            otherlv_1=(Token)match(input,159,FOLLOW_103); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_1, grammarAccess.getXSynchronizedExpressionAccess().getSynchronizedKeyword_0_0_1());
              				
            }
            otherlv_2=(Token)match(input,100,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					newLeafNode(otherlv_2, grammarAccess.getXSynchronizedExpressionAccess().getLeftParenthesisKeyword_0_0_2());
              				
            }

            }


            }

            // InternalTableDSL.g:10134:3: ( (lv_param_3_0= ruleXExpression ) )
            // InternalTableDSL.g:10135:4: (lv_param_3_0= ruleXExpression )
            {
            // InternalTableDSL.g:10135:4: (lv_param_3_0= ruleXExpression )
            // InternalTableDSL.g:10136:5: lv_param_3_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXSynchronizedExpressionAccess().getParamXExpressionParserRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_63);
            lv_param_3_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXSynchronizedExpressionRule());
              					}
              					set(
              						current,
              						"param",
              						lv_param_3_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            otherlv_4=(Token)match(input,102,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_4, grammarAccess.getXSynchronizedExpressionAccess().getRightParenthesisKeyword_2());
              		
            }
            // InternalTableDSL.g:10157:3: ( (lv_expression_5_0= ruleXExpression ) )
            // InternalTableDSL.g:10158:4: (lv_expression_5_0= ruleXExpression )
            {
            // InternalTableDSL.g:10158:4: (lv_expression_5_0= ruleXExpression )
            // InternalTableDSL.g:10159:5: lv_expression_5_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXSynchronizedExpressionAccess().getExpressionXExpressionParserRuleCall_3_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_expression_5_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXSynchronizedExpressionRule());
              					}
              					set(
              						current,
              						"expression",
              						lv_expression_5_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXSynchronizedExpression"


    // $ANTLR start "entryRuleXCatchClause"
    // InternalTableDSL.g:10180:1: entryRuleXCatchClause returns [EObject current=null] : iv_ruleXCatchClause= ruleXCatchClause EOF ;
    public final EObject entryRuleXCatchClause() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXCatchClause = null;


        try {
            // InternalTableDSL.g:10180:53: (iv_ruleXCatchClause= ruleXCatchClause EOF )
            // InternalTableDSL.g:10181:2: iv_ruleXCatchClause= ruleXCatchClause EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXCatchClauseRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXCatchClause=ruleXCatchClause();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXCatchClause; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXCatchClause"


    // $ANTLR start "ruleXCatchClause"
    // InternalTableDSL.g:10187:1: ruleXCatchClause returns [EObject current=null] : ( ( ( 'catch' )=>otherlv_0= 'catch' ) otherlv_1= '(' ( (lv_declaredParam_2_0= ruleFullJvmFormalParameter ) ) otherlv_3= ')' ( (lv_expression_4_0= ruleXExpression ) ) ) ;
    public final EObject ruleXCatchClause() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token otherlv_1=null;
        Token otherlv_3=null;
        EObject lv_declaredParam_2_0 = null;

        EObject lv_expression_4_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:10193:2: ( ( ( ( 'catch' )=>otherlv_0= 'catch' ) otherlv_1= '(' ( (lv_declaredParam_2_0= ruleFullJvmFormalParameter ) ) otherlv_3= ')' ( (lv_expression_4_0= ruleXExpression ) ) ) )
            // InternalTableDSL.g:10194:2: ( ( ( 'catch' )=>otherlv_0= 'catch' ) otherlv_1= '(' ( (lv_declaredParam_2_0= ruleFullJvmFormalParameter ) ) otherlv_3= ')' ( (lv_expression_4_0= ruleXExpression ) ) )
            {
            // InternalTableDSL.g:10194:2: ( ( ( 'catch' )=>otherlv_0= 'catch' ) otherlv_1= '(' ( (lv_declaredParam_2_0= ruleFullJvmFormalParameter ) ) otherlv_3= ')' ( (lv_expression_4_0= ruleXExpression ) ) )
            // InternalTableDSL.g:10195:3: ( ( 'catch' )=>otherlv_0= 'catch' ) otherlv_1= '(' ( (lv_declaredParam_2_0= ruleFullJvmFormalParameter ) ) otherlv_3= ')' ( (lv_expression_4_0= ruleXExpression ) )
            {
            // InternalTableDSL.g:10195:3: ( ( 'catch' )=>otherlv_0= 'catch' )
            // InternalTableDSL.g:10196:4: ( 'catch' )=>otherlv_0= 'catch'
            {
            otherlv_0=(Token)match(input,160,FOLLOW_103); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              				newLeafNode(otherlv_0, grammarAccess.getXCatchClauseAccess().getCatchKeyword_0());
              			
            }

            }

            otherlv_1=(Token)match(input,100,FOLLOW_78); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getXCatchClauseAccess().getLeftParenthesisKeyword_1());
              		
            }
            // InternalTableDSL.g:10206:3: ( (lv_declaredParam_2_0= ruleFullJvmFormalParameter ) )
            // InternalTableDSL.g:10207:4: (lv_declaredParam_2_0= ruleFullJvmFormalParameter )
            {
            // InternalTableDSL.g:10207:4: (lv_declaredParam_2_0= ruleFullJvmFormalParameter )
            // InternalTableDSL.g:10208:5: lv_declaredParam_2_0= ruleFullJvmFormalParameter
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXCatchClauseAccess().getDeclaredParamFullJvmFormalParameterParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_63);
            lv_declaredParam_2_0=ruleFullJvmFormalParameter();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXCatchClauseRule());
              					}
              					set(
              						current,
              						"declaredParam",
              						lv_declaredParam_2_0,
              						"org.eclipse.xtext.xbase.Xbase.FullJvmFormalParameter");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            otherlv_3=(Token)match(input,102,FOLLOW_65); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_3, grammarAccess.getXCatchClauseAccess().getRightParenthesisKeyword_3());
              		
            }
            // InternalTableDSL.g:10229:3: ( (lv_expression_4_0= ruleXExpression ) )
            // InternalTableDSL.g:10230:4: (lv_expression_4_0= ruleXExpression )
            {
            // InternalTableDSL.g:10230:4: (lv_expression_4_0= ruleXExpression )
            // InternalTableDSL.g:10231:5: lv_expression_4_0= ruleXExpression
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXCatchClauseAccess().getExpressionXExpressionParserRuleCall_4_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_expression_4_0=ruleXExpression();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXCatchClauseRule());
              					}
              					set(
              						current,
              						"expression",
              						lv_expression_4_0,
              						"org.eclipse.xtext.xbase.Xbase.XExpression");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXCatchClause"


    // $ANTLR start "entryRuleQualifiedName"
    // InternalTableDSL.g:10252:1: entryRuleQualifiedName returns [String current=null] : iv_ruleQualifiedName= ruleQualifiedName EOF ;
    public final String entryRuleQualifiedName() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleQualifiedName = null;


        try {
            // InternalTableDSL.g:10252:53: (iv_ruleQualifiedName= ruleQualifiedName EOF )
            // InternalTableDSL.g:10253:2: iv_ruleQualifiedName= ruleQualifiedName EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getQualifiedNameRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleQualifiedName=ruleQualifiedName();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleQualifiedName.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleQualifiedName"


    // $ANTLR start "ruleQualifiedName"
    // InternalTableDSL.g:10259:1: ruleQualifiedName returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (this_ValidID_0= ruleValidID ( ( ( '.' )=>kw= '.' ) this_ValidID_2= ruleValidID )* ) ;
    public final AntlrDatatypeRuleToken ruleQualifiedName() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;
        AntlrDatatypeRuleToken this_ValidID_0 = null;

        AntlrDatatypeRuleToken this_ValidID_2 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:10265:2: ( (this_ValidID_0= ruleValidID ( ( ( '.' )=>kw= '.' ) this_ValidID_2= ruleValidID )* ) )
            // InternalTableDSL.g:10266:2: (this_ValidID_0= ruleValidID ( ( ( '.' )=>kw= '.' ) this_ValidID_2= ruleValidID )* )
            {
            // InternalTableDSL.g:10266:2: (this_ValidID_0= ruleValidID ( ( ( '.' )=>kw= '.' ) this_ValidID_2= ruleValidID )* )
            // InternalTableDSL.g:10267:3: this_ValidID_0= ruleValidID ( ( ( '.' )=>kw= '.' ) this_ValidID_2= ruleValidID )*
            {
            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getQualifiedNameAccess().getValidIDParserRuleCall_0());
              		
            }
            pushFollow(FOLLOW_43);
            this_ValidID_0=ruleValidID();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current.merge(this_ValidID_0);
              		
            }
            if ( state.backtracking==0 ) {

              			afterParserOrEnumRuleCall();
              		
            }
            // InternalTableDSL.g:10277:3: ( ( ( '.' )=>kw= '.' ) this_ValidID_2= ruleValidID )*
            loop146:
            do {
                int alt146=2;
                int LA146_0 = input.LA(1);

                if ( (LA146_0==74) ) {
                    int LA146_2 = input.LA(2);

                    if ( (LA146_2==RULE_ID) ) {
                        int LA146_3 = input.LA(3);

                        if ( (synpred48_InternalTableDSL()) ) {
                            alt146=1;
                        }


                    }


                }


                switch (alt146) {
            	case 1 :
            	    // InternalTableDSL.g:10278:4: ( ( '.' )=>kw= '.' ) this_ValidID_2= ruleValidID
            	    {
            	    // InternalTableDSL.g:10278:4: ( ( '.' )=>kw= '.' )
            	    // InternalTableDSL.g:10279:5: ( '.' )=>kw= '.'
            	    {
            	    kw=(Token)match(input,74,FOLLOW_4); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      					current.merge(kw);
            	      					newLeafNode(kw, grammarAccess.getQualifiedNameAccess().getFullStopKeyword_1_0());
            	      				
            	    }

            	    }

            	    if ( state.backtracking==0 ) {

            	      				newCompositeNode(grammarAccess.getQualifiedNameAccess().getValidIDParserRuleCall_1_1());
            	      			
            	    }
            	    pushFollow(FOLLOW_43);
            	    this_ValidID_2=ruleValidID();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      				current.merge(this_ValidID_2);
            	      			
            	    }
            	    if ( state.backtracking==0 ) {

            	      				afterParserOrEnumRuleCall();
            	      			
            	    }

            	    }
            	    break;

            	default :
            	    break loop146;
                }
            } while (true);


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleQualifiedName"


    // $ANTLR start "entryRuleNumber"
    // InternalTableDSL.g:10301:1: entryRuleNumber returns [String current=null] : iv_ruleNumber= ruleNumber EOF ;
    public final String entryRuleNumber() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleNumber = null;



        	HiddenTokens myHiddenTokenState = ((XtextTokenStream)input).setHiddenTokens();

        try {
            // InternalTableDSL.g:10303:2: (iv_ruleNumber= ruleNumber EOF )
            // InternalTableDSL.g:10304:2: iv_ruleNumber= ruleNumber EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getNumberRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleNumber=ruleNumber();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleNumber.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {

            	myHiddenTokenState.restore();

        }
        return current;
    }
    // $ANTLR end "entryRuleNumber"


    // $ANTLR start "ruleNumber"
    // InternalTableDSL.g:10313:1: ruleNumber returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (this_HEX_0= RULE_HEX | ( (this_INT_1= RULE_INT | this_DECIMAL_2= RULE_DECIMAL ) (kw= '.' (this_INT_4= RULE_INT | this_DECIMAL_5= RULE_DECIMAL ) )? ) ) ;
    public final AntlrDatatypeRuleToken ruleNumber() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token this_HEX_0=null;
        Token this_INT_1=null;
        Token this_DECIMAL_2=null;
        Token kw=null;
        Token this_INT_4=null;
        Token this_DECIMAL_5=null;


        	enterRule();
        	HiddenTokens myHiddenTokenState = ((XtextTokenStream)input).setHiddenTokens();

        try {
            // InternalTableDSL.g:10320:2: ( (this_HEX_0= RULE_HEX | ( (this_INT_1= RULE_INT | this_DECIMAL_2= RULE_DECIMAL ) (kw= '.' (this_INT_4= RULE_INT | this_DECIMAL_5= RULE_DECIMAL ) )? ) ) )
            // InternalTableDSL.g:10321:2: (this_HEX_0= RULE_HEX | ( (this_INT_1= RULE_INT | this_DECIMAL_2= RULE_DECIMAL ) (kw= '.' (this_INT_4= RULE_INT | this_DECIMAL_5= RULE_DECIMAL ) )? ) )
            {
            // InternalTableDSL.g:10321:2: (this_HEX_0= RULE_HEX | ( (this_INT_1= RULE_INT | this_DECIMAL_2= RULE_DECIMAL ) (kw= '.' (this_INT_4= RULE_INT | this_DECIMAL_5= RULE_DECIMAL ) )? ) )
            int alt150=2;
            int LA150_0 = input.LA(1);

            if ( (LA150_0==RULE_HEX) ) {
                alt150=1;
            }
            else if ( (LA150_0==RULE_INT||LA150_0==RULE_DECIMAL) ) {
                alt150=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 150, 0, input);

                throw nvae;
            }
            switch (alt150) {
                case 1 :
                    // InternalTableDSL.g:10322:3: this_HEX_0= RULE_HEX
                    {
                    this_HEX_0=(Token)match(input,RULE_HEX,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current.merge(this_HEX_0);
                      		
                    }
                    if ( state.backtracking==0 ) {

                      			newLeafNode(this_HEX_0, grammarAccess.getNumberAccess().getHEXTerminalRuleCall_0());
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:10330:3: ( (this_INT_1= RULE_INT | this_DECIMAL_2= RULE_DECIMAL ) (kw= '.' (this_INT_4= RULE_INT | this_DECIMAL_5= RULE_DECIMAL ) )? )
                    {
                    // InternalTableDSL.g:10330:3: ( (this_INT_1= RULE_INT | this_DECIMAL_2= RULE_DECIMAL ) (kw= '.' (this_INT_4= RULE_INT | this_DECIMAL_5= RULE_DECIMAL ) )? )
                    // InternalTableDSL.g:10331:4: (this_INT_1= RULE_INT | this_DECIMAL_2= RULE_DECIMAL ) (kw= '.' (this_INT_4= RULE_INT | this_DECIMAL_5= RULE_DECIMAL ) )?
                    {
                    // InternalTableDSL.g:10331:4: (this_INT_1= RULE_INT | this_DECIMAL_2= RULE_DECIMAL )
                    int alt147=2;
                    int LA147_0 = input.LA(1);

                    if ( (LA147_0==RULE_INT) ) {
                        alt147=1;
                    }
                    else if ( (LA147_0==RULE_DECIMAL) ) {
                        alt147=2;
                    }
                    else {
                        if (state.backtracking>0) {state.failed=true; return current;}
                        NoViableAltException nvae =
                            new NoViableAltException("", 147, 0, input);

                        throw nvae;
                    }
                    switch (alt147) {
                        case 1 :
                            // InternalTableDSL.g:10332:5: this_INT_1= RULE_INT
                            {
                            this_INT_1=(Token)match(input,RULE_INT,FOLLOW_43); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              					current.merge(this_INT_1);
                              				
                            }
                            if ( state.backtracking==0 ) {

                              					newLeafNode(this_INT_1, grammarAccess.getNumberAccess().getINTTerminalRuleCall_1_0_0());
                              				
                            }

                            }
                            break;
                        case 2 :
                            // InternalTableDSL.g:10340:5: this_DECIMAL_2= RULE_DECIMAL
                            {
                            this_DECIMAL_2=(Token)match(input,RULE_DECIMAL,FOLLOW_43); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              					current.merge(this_DECIMAL_2);
                              				
                            }
                            if ( state.backtracking==0 ) {

                              					newLeafNode(this_DECIMAL_2, grammarAccess.getNumberAccess().getDECIMALTerminalRuleCall_1_0_1());
                              				
                            }

                            }
                            break;

                    }

                    // InternalTableDSL.g:10348:4: (kw= '.' (this_INT_4= RULE_INT | this_DECIMAL_5= RULE_DECIMAL ) )?
                    int alt149=2;
                    int LA149_0 = input.LA(1);

                    if ( (LA149_0==74) ) {
                        int LA149_1 = input.LA(2);

                        if ( (LA149_1==RULE_INT||LA149_1==RULE_DECIMAL) ) {
                            alt149=1;
                        }
                    }
                    switch (alt149) {
                        case 1 :
                            // InternalTableDSL.g:10349:5: kw= '.' (this_INT_4= RULE_INT | this_DECIMAL_5= RULE_DECIMAL )
                            {
                            kw=(Token)match(input,74,FOLLOW_127); if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              					current.merge(kw);
                              					newLeafNode(kw, grammarAccess.getNumberAccess().getFullStopKeyword_1_1_0());
                              				
                            }
                            // InternalTableDSL.g:10354:5: (this_INT_4= RULE_INT | this_DECIMAL_5= RULE_DECIMAL )
                            int alt148=2;
                            int LA148_0 = input.LA(1);

                            if ( (LA148_0==RULE_INT) ) {
                                alt148=1;
                            }
                            else if ( (LA148_0==RULE_DECIMAL) ) {
                                alt148=2;
                            }
                            else {
                                if (state.backtracking>0) {state.failed=true; return current;}
                                NoViableAltException nvae =
                                    new NoViableAltException("", 148, 0, input);

                                throw nvae;
                            }
                            switch (alt148) {
                                case 1 :
                                    // InternalTableDSL.g:10355:6: this_INT_4= RULE_INT
                                    {
                                    this_INT_4=(Token)match(input,RULE_INT,FOLLOW_2); if (state.failed) return current;
                                    if ( state.backtracking==0 ) {

                                      						current.merge(this_INT_4);
                                      					
                                    }
                                    if ( state.backtracking==0 ) {

                                      						newLeafNode(this_INT_4, grammarAccess.getNumberAccess().getINTTerminalRuleCall_1_1_1_0());
                                      					
                                    }

                                    }
                                    break;
                                case 2 :
                                    // InternalTableDSL.g:10363:6: this_DECIMAL_5= RULE_DECIMAL
                                    {
                                    this_DECIMAL_5=(Token)match(input,RULE_DECIMAL,FOLLOW_2); if (state.failed) return current;
                                    if ( state.backtracking==0 ) {

                                      						current.merge(this_DECIMAL_5);
                                      					
                                    }
                                    if ( state.backtracking==0 ) {

                                      						newLeafNode(this_DECIMAL_5, grammarAccess.getNumberAccess().getDECIMALTerminalRuleCall_1_1_1_1());
                                      					
                                    }

                                    }
                                    break;

                            }


                            }
                            break;

                    }


                    }


                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {

            	myHiddenTokenState.restore();

        }
        return current;
    }
    // $ANTLR end "ruleNumber"


    // $ANTLR start "entryRuleJvmTypeReference"
    // InternalTableDSL.g:10380:1: entryRuleJvmTypeReference returns [EObject current=null] : iv_ruleJvmTypeReference= ruleJvmTypeReference EOF ;
    public final EObject entryRuleJvmTypeReference() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleJvmTypeReference = null;


        try {
            // InternalTableDSL.g:10380:57: (iv_ruleJvmTypeReference= ruleJvmTypeReference EOF )
            // InternalTableDSL.g:10381:2: iv_ruleJvmTypeReference= ruleJvmTypeReference EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getJvmTypeReferenceRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleJvmTypeReference=ruleJvmTypeReference();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleJvmTypeReference; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleJvmTypeReference"


    // $ANTLR start "ruleJvmTypeReference"
    // InternalTableDSL.g:10387:1: ruleJvmTypeReference returns [EObject current=null] : ( (this_JvmParameterizedTypeReference_0= ruleJvmParameterizedTypeReference ( ( ( () ruleArrayBrackets ) )=> ( () ruleArrayBrackets ) )* ) | this_XFunctionTypeRef_3= ruleXFunctionTypeRef ) ;
    public final EObject ruleJvmTypeReference() throws RecognitionException {
        EObject current = null;

        EObject this_JvmParameterizedTypeReference_0 = null;

        EObject this_XFunctionTypeRef_3 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:10393:2: ( ( (this_JvmParameterizedTypeReference_0= ruleJvmParameterizedTypeReference ( ( ( () ruleArrayBrackets ) )=> ( () ruleArrayBrackets ) )* ) | this_XFunctionTypeRef_3= ruleXFunctionTypeRef ) )
            // InternalTableDSL.g:10394:2: ( (this_JvmParameterizedTypeReference_0= ruleJvmParameterizedTypeReference ( ( ( () ruleArrayBrackets ) )=> ( () ruleArrayBrackets ) )* ) | this_XFunctionTypeRef_3= ruleXFunctionTypeRef )
            {
            // InternalTableDSL.g:10394:2: ( (this_JvmParameterizedTypeReference_0= ruleJvmParameterizedTypeReference ( ( ( () ruleArrayBrackets ) )=> ( () ruleArrayBrackets ) )* ) | this_XFunctionTypeRef_3= ruleXFunctionTypeRef )
            int alt152=2;
            int LA152_0 = input.LA(1);

            if ( (LA152_0==RULE_ID) ) {
                alt152=1;
            }
            else if ( (LA152_0==100||LA152_0==125) ) {
                alt152=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 152, 0, input);

                throw nvae;
            }
            switch (alt152) {
                case 1 :
                    // InternalTableDSL.g:10395:3: (this_JvmParameterizedTypeReference_0= ruleJvmParameterizedTypeReference ( ( ( () ruleArrayBrackets ) )=> ( () ruleArrayBrackets ) )* )
                    {
                    // InternalTableDSL.g:10395:3: (this_JvmParameterizedTypeReference_0= ruleJvmParameterizedTypeReference ( ( ( () ruleArrayBrackets ) )=> ( () ruleArrayBrackets ) )* )
                    // InternalTableDSL.g:10396:4: this_JvmParameterizedTypeReference_0= ruleJvmParameterizedTypeReference ( ( ( () ruleArrayBrackets ) )=> ( () ruleArrayBrackets ) )*
                    {
                    if ( state.backtracking==0 ) {

                      				newCompositeNode(grammarAccess.getJvmTypeReferenceAccess().getJvmParameterizedTypeReferenceParserRuleCall_0_0());
                      			
                    }
                    pushFollow(FOLLOW_121);
                    this_JvmParameterizedTypeReference_0=ruleJvmParameterizedTypeReference();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = this_JvmParameterizedTypeReference_0;
                      				afterParserOrEnumRuleCall();
                      			
                    }
                    // InternalTableDSL.g:10404:4: ( ( ( () ruleArrayBrackets ) )=> ( () ruleArrayBrackets ) )*
                    loop151:
                    do {
                        int alt151=2;
                        int LA151_0 = input.LA(1);

                        if ( (LA151_0==105) ) {
                            int LA151_2 = input.LA(2);

                            if ( (LA151_2==106) ) {
                                int LA151_3 = input.LA(3);

                                if ( (synpred49_InternalTableDSL()) ) {
                                    alt151=1;
                                }


                            }


                        }


                        switch (alt151) {
                    	case 1 :
                    	    // InternalTableDSL.g:10405:5: ( ( () ruleArrayBrackets ) )=> ( () ruleArrayBrackets )
                    	    {
                    	    // InternalTableDSL.g:10411:5: ( () ruleArrayBrackets )
                    	    // InternalTableDSL.g:10412:6: () ruleArrayBrackets
                    	    {
                    	    // InternalTableDSL.g:10412:6: ()
                    	    // InternalTableDSL.g:10413:7: 
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      							current = forceCreateModelElementAndSet(
                    	      								grammarAccess.getJvmTypeReferenceAccess().getJvmGenericArrayTypeReferenceComponentTypeAction_0_1_0_0(),
                    	      								current);
                    	      						
                    	    }

                    	    }

                    	    if ( state.backtracking==0 ) {

                    	      						newCompositeNode(grammarAccess.getJvmTypeReferenceAccess().getArrayBracketsParserRuleCall_0_1_0_1());
                    	      					
                    	    }
                    	    pushFollow(FOLLOW_121);
                    	    ruleArrayBrackets();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      						afterParserOrEnumRuleCall();
                    	      					
                    	    }

                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop151;
                        }
                    } while (true);


                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:10430:3: this_XFunctionTypeRef_3= ruleXFunctionTypeRef
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getJvmTypeReferenceAccess().getXFunctionTypeRefParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_XFunctionTypeRef_3=ruleXFunctionTypeRef();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_XFunctionTypeRef_3;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleJvmTypeReference"


    // $ANTLR start "entryRuleArrayBrackets"
    // InternalTableDSL.g:10442:1: entryRuleArrayBrackets returns [String current=null] : iv_ruleArrayBrackets= ruleArrayBrackets EOF ;
    public final String entryRuleArrayBrackets() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleArrayBrackets = null;


        try {
            // InternalTableDSL.g:10442:53: (iv_ruleArrayBrackets= ruleArrayBrackets EOF )
            // InternalTableDSL.g:10443:2: iv_ruleArrayBrackets= ruleArrayBrackets EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getArrayBracketsRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleArrayBrackets=ruleArrayBrackets();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleArrayBrackets.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleArrayBrackets"


    // $ANTLR start "ruleArrayBrackets"
    // InternalTableDSL.g:10449:1: ruleArrayBrackets returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (kw= '[' kw= ']' ) ;
    public final AntlrDatatypeRuleToken ruleArrayBrackets() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;


        	enterRule();

        try {
            // InternalTableDSL.g:10455:2: ( (kw= '[' kw= ']' ) )
            // InternalTableDSL.g:10456:2: (kw= '[' kw= ']' )
            {
            // InternalTableDSL.g:10456:2: (kw= '[' kw= ']' )
            // InternalTableDSL.g:10457:3: kw= '[' kw= ']'
            {
            kw=(Token)match(input,105,FOLLOW_100); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current.merge(kw);
              			newLeafNode(kw, grammarAccess.getArrayBracketsAccess().getLeftSquareBracketKeyword_0());
              		
            }
            kw=(Token)match(input,106,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current.merge(kw);
              			newLeafNode(kw, grammarAccess.getArrayBracketsAccess().getRightSquareBracketKeyword_1());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleArrayBrackets"


    // $ANTLR start "entryRuleXFunctionTypeRef"
    // InternalTableDSL.g:10471:1: entryRuleXFunctionTypeRef returns [EObject current=null] : iv_ruleXFunctionTypeRef= ruleXFunctionTypeRef EOF ;
    public final EObject entryRuleXFunctionTypeRef() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXFunctionTypeRef = null;


        try {
            // InternalTableDSL.g:10471:57: (iv_ruleXFunctionTypeRef= ruleXFunctionTypeRef EOF )
            // InternalTableDSL.g:10472:2: iv_ruleXFunctionTypeRef= ruleXFunctionTypeRef EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXFunctionTypeRefRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXFunctionTypeRef=ruleXFunctionTypeRef();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXFunctionTypeRef; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXFunctionTypeRef"


    // $ANTLR start "ruleXFunctionTypeRef"
    // InternalTableDSL.g:10478:1: ruleXFunctionTypeRef returns [EObject current=null] : ( (otherlv_0= '(' ( ( (lv_paramTypes_1_0= ruleJvmTypeReference ) ) (otherlv_2= ',' ( (lv_paramTypes_3_0= ruleJvmTypeReference ) ) )* )? otherlv_4= ')' )? otherlv_5= '=>' ( (lv_returnType_6_0= ruleJvmTypeReference ) ) ) ;
    public final EObject ruleXFunctionTypeRef() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        Token otherlv_2=null;
        Token otherlv_4=null;
        Token otherlv_5=null;
        EObject lv_paramTypes_1_0 = null;

        EObject lv_paramTypes_3_0 = null;

        EObject lv_returnType_6_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:10484:2: ( ( (otherlv_0= '(' ( ( (lv_paramTypes_1_0= ruleJvmTypeReference ) ) (otherlv_2= ',' ( (lv_paramTypes_3_0= ruleJvmTypeReference ) ) )* )? otherlv_4= ')' )? otherlv_5= '=>' ( (lv_returnType_6_0= ruleJvmTypeReference ) ) ) )
            // InternalTableDSL.g:10485:2: ( (otherlv_0= '(' ( ( (lv_paramTypes_1_0= ruleJvmTypeReference ) ) (otherlv_2= ',' ( (lv_paramTypes_3_0= ruleJvmTypeReference ) ) )* )? otherlv_4= ')' )? otherlv_5= '=>' ( (lv_returnType_6_0= ruleJvmTypeReference ) ) )
            {
            // InternalTableDSL.g:10485:2: ( (otherlv_0= '(' ( ( (lv_paramTypes_1_0= ruleJvmTypeReference ) ) (otherlv_2= ',' ( (lv_paramTypes_3_0= ruleJvmTypeReference ) ) )* )? otherlv_4= ')' )? otherlv_5= '=>' ( (lv_returnType_6_0= ruleJvmTypeReference ) ) )
            // InternalTableDSL.g:10486:3: (otherlv_0= '(' ( ( (lv_paramTypes_1_0= ruleJvmTypeReference ) ) (otherlv_2= ',' ( (lv_paramTypes_3_0= ruleJvmTypeReference ) ) )* )? otherlv_4= ')' )? otherlv_5= '=>' ( (lv_returnType_6_0= ruleJvmTypeReference ) )
            {
            // InternalTableDSL.g:10486:3: (otherlv_0= '(' ( ( (lv_paramTypes_1_0= ruleJvmTypeReference ) ) (otherlv_2= ',' ( (lv_paramTypes_3_0= ruleJvmTypeReference ) ) )* )? otherlv_4= ')' )?
            int alt155=2;
            int LA155_0 = input.LA(1);

            if ( (LA155_0==100) ) {
                alt155=1;
            }
            switch (alt155) {
                case 1 :
                    // InternalTableDSL.g:10487:4: otherlv_0= '(' ( ( (lv_paramTypes_1_0= ruleJvmTypeReference ) ) (otherlv_2= ',' ( (lv_paramTypes_3_0= ruleJvmTypeReference ) ) )* )? otherlv_4= ')'
                    {
                    otherlv_0=(Token)match(input,100,FOLLOW_128); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_0, grammarAccess.getXFunctionTypeRefAccess().getLeftParenthesisKeyword_0_0());
                      			
                    }
                    // InternalTableDSL.g:10491:4: ( ( (lv_paramTypes_1_0= ruleJvmTypeReference ) ) (otherlv_2= ',' ( (lv_paramTypes_3_0= ruleJvmTypeReference ) ) )* )?
                    int alt154=2;
                    int LA154_0 = input.LA(1);

                    if ( (LA154_0==RULE_ID||LA154_0==100||LA154_0==125) ) {
                        alt154=1;
                    }
                    switch (alt154) {
                        case 1 :
                            // InternalTableDSL.g:10492:5: ( (lv_paramTypes_1_0= ruleJvmTypeReference ) ) (otherlv_2= ',' ( (lv_paramTypes_3_0= ruleJvmTypeReference ) ) )*
                            {
                            // InternalTableDSL.g:10492:5: ( (lv_paramTypes_1_0= ruleJvmTypeReference ) )
                            // InternalTableDSL.g:10493:6: (lv_paramTypes_1_0= ruleJvmTypeReference )
                            {
                            // InternalTableDSL.g:10493:6: (lv_paramTypes_1_0= ruleJvmTypeReference )
                            // InternalTableDSL.g:10494:7: lv_paramTypes_1_0= ruleJvmTypeReference
                            {
                            if ( state.backtracking==0 ) {

                              							newCompositeNode(grammarAccess.getXFunctionTypeRefAccess().getParamTypesJvmTypeReferenceParserRuleCall_0_1_0_0());
                              						
                            }
                            pushFollow(FOLLOW_62);
                            lv_paramTypes_1_0=ruleJvmTypeReference();

                            state._fsp--;
                            if (state.failed) return current;
                            if ( state.backtracking==0 ) {

                              							if (current==null) {
                              								current = createModelElementForParent(grammarAccess.getXFunctionTypeRefRule());
                              							}
                              							add(
                              								current,
                              								"paramTypes",
                              								lv_paramTypes_1_0,
                              								"org.eclipse.xtext.xbase.Xtype.JvmTypeReference");
                              							afterParserOrEnumRuleCall();
                              						
                            }

                            }


                            }

                            // InternalTableDSL.g:10511:5: (otherlv_2= ',' ( (lv_paramTypes_3_0= ruleJvmTypeReference ) ) )*
                            loop153:
                            do {
                                int alt153=2;
                                int LA153_0 = input.LA(1);

                                if ( (LA153_0==101) ) {
                                    alt153=1;
                                }


                                switch (alt153) {
                            	case 1 :
                            	    // InternalTableDSL.g:10512:6: otherlv_2= ',' ( (lv_paramTypes_3_0= ruleJvmTypeReference ) )
                            	    {
                            	    otherlv_2=(Token)match(input,101,FOLLOW_78); if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      						newLeafNode(otherlv_2, grammarAccess.getXFunctionTypeRefAccess().getCommaKeyword_0_1_1_0());
                            	      					
                            	    }
                            	    // InternalTableDSL.g:10516:6: ( (lv_paramTypes_3_0= ruleJvmTypeReference ) )
                            	    // InternalTableDSL.g:10517:7: (lv_paramTypes_3_0= ruleJvmTypeReference )
                            	    {
                            	    // InternalTableDSL.g:10517:7: (lv_paramTypes_3_0= ruleJvmTypeReference )
                            	    // InternalTableDSL.g:10518:8: lv_paramTypes_3_0= ruleJvmTypeReference
                            	    {
                            	    if ( state.backtracking==0 ) {

                            	      								newCompositeNode(grammarAccess.getXFunctionTypeRefAccess().getParamTypesJvmTypeReferenceParserRuleCall_0_1_1_1_0());
                            	      							
                            	    }
                            	    pushFollow(FOLLOW_62);
                            	    lv_paramTypes_3_0=ruleJvmTypeReference();

                            	    state._fsp--;
                            	    if (state.failed) return current;
                            	    if ( state.backtracking==0 ) {

                            	      								if (current==null) {
                            	      									current = createModelElementForParent(grammarAccess.getXFunctionTypeRefRule());
                            	      								}
                            	      								add(
                            	      									current,
                            	      									"paramTypes",
                            	      									lv_paramTypes_3_0,
                            	      									"org.eclipse.xtext.xbase.Xtype.JvmTypeReference");
                            	      								afterParserOrEnumRuleCall();
                            	      							
                            	    }

                            	    }


                            	    }


                            	    }
                            	    break;

                            	default :
                            	    break loop153;
                                }
                            } while (true);


                            }
                            break;

                    }

                    otherlv_4=(Token)match(input,102,FOLLOW_129); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_4, grammarAccess.getXFunctionTypeRefAccess().getRightParenthesisKeyword_0_2());
                      			
                    }

                    }
                    break;

            }

            otherlv_5=(Token)match(input,125,FOLLOW_78); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_5, grammarAccess.getXFunctionTypeRefAccess().getEqualsSignGreaterThanSignKeyword_1());
              		
            }
            // InternalTableDSL.g:10546:3: ( (lv_returnType_6_0= ruleJvmTypeReference ) )
            // InternalTableDSL.g:10547:4: (lv_returnType_6_0= ruleJvmTypeReference )
            {
            // InternalTableDSL.g:10547:4: (lv_returnType_6_0= ruleJvmTypeReference )
            // InternalTableDSL.g:10548:5: lv_returnType_6_0= ruleJvmTypeReference
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getXFunctionTypeRefAccess().getReturnTypeJvmTypeReferenceParserRuleCall_2_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_returnType_6_0=ruleJvmTypeReference();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getXFunctionTypeRefRule());
              					}
              					set(
              						current,
              						"returnType",
              						lv_returnType_6_0,
              						"org.eclipse.xtext.xbase.Xtype.JvmTypeReference");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXFunctionTypeRef"


    // $ANTLR start "entryRuleJvmParameterizedTypeReference"
    // InternalTableDSL.g:10569:1: entryRuleJvmParameterizedTypeReference returns [EObject current=null] : iv_ruleJvmParameterizedTypeReference= ruleJvmParameterizedTypeReference EOF ;
    public final EObject entryRuleJvmParameterizedTypeReference() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleJvmParameterizedTypeReference = null;


        try {
            // InternalTableDSL.g:10569:70: (iv_ruleJvmParameterizedTypeReference= ruleJvmParameterizedTypeReference EOF )
            // InternalTableDSL.g:10570:2: iv_ruleJvmParameterizedTypeReference= ruleJvmParameterizedTypeReference EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getJvmParameterizedTypeReferenceRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleJvmParameterizedTypeReference=ruleJvmParameterizedTypeReference();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleJvmParameterizedTypeReference; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleJvmParameterizedTypeReference"


    // $ANTLR start "ruleJvmParameterizedTypeReference"
    // InternalTableDSL.g:10576:1: ruleJvmParameterizedTypeReference returns [EObject current=null] : ( ( ( ruleQualifiedName ) ) ( ( ( '<' )=>otherlv_1= '<' ) ( (lv_arguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_arguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>' ( ( ( ( () '.' ) )=> ( () otherlv_7= '.' ) ) ( ( ruleValidID ) ) ( ( ( '<' )=>otherlv_9= '<' ) ( (lv_arguments_10_0= ruleJvmArgumentTypeReference ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) ) )* otherlv_13= '>' )? )* )? ) ;
    public final EObject ruleJvmParameterizedTypeReference() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        Token otherlv_3=null;
        Token otherlv_5=null;
        Token otherlv_7=null;
        Token otherlv_9=null;
        Token otherlv_11=null;
        Token otherlv_13=null;
        EObject lv_arguments_2_0 = null;

        EObject lv_arguments_4_0 = null;

        EObject lv_arguments_10_0 = null;

        EObject lv_arguments_12_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:10582:2: ( ( ( ( ruleQualifiedName ) ) ( ( ( '<' )=>otherlv_1= '<' ) ( (lv_arguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_arguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>' ( ( ( ( () '.' ) )=> ( () otherlv_7= '.' ) ) ( ( ruleValidID ) ) ( ( ( '<' )=>otherlv_9= '<' ) ( (lv_arguments_10_0= ruleJvmArgumentTypeReference ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) ) )* otherlv_13= '>' )? )* )? ) )
            // InternalTableDSL.g:10583:2: ( ( ( ruleQualifiedName ) ) ( ( ( '<' )=>otherlv_1= '<' ) ( (lv_arguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_arguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>' ( ( ( ( () '.' ) )=> ( () otherlv_7= '.' ) ) ( ( ruleValidID ) ) ( ( ( '<' )=>otherlv_9= '<' ) ( (lv_arguments_10_0= ruleJvmArgumentTypeReference ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) ) )* otherlv_13= '>' )? )* )? )
            {
            // InternalTableDSL.g:10583:2: ( ( ( ruleQualifiedName ) ) ( ( ( '<' )=>otherlv_1= '<' ) ( (lv_arguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_arguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>' ( ( ( ( () '.' ) )=> ( () otherlv_7= '.' ) ) ( ( ruleValidID ) ) ( ( ( '<' )=>otherlv_9= '<' ) ( (lv_arguments_10_0= ruleJvmArgumentTypeReference ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) ) )* otherlv_13= '>' )? )* )? )
            // InternalTableDSL.g:10584:3: ( ( ruleQualifiedName ) ) ( ( ( '<' )=>otherlv_1= '<' ) ( (lv_arguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_arguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>' ( ( ( ( () '.' ) )=> ( () otherlv_7= '.' ) ) ( ( ruleValidID ) ) ( ( ( '<' )=>otherlv_9= '<' ) ( (lv_arguments_10_0= ruleJvmArgumentTypeReference ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) ) )* otherlv_13= '>' )? )* )?
            {
            // InternalTableDSL.g:10584:3: ( ( ruleQualifiedName ) )
            // InternalTableDSL.g:10585:4: ( ruleQualifiedName )
            {
            // InternalTableDSL.g:10585:4: ( ruleQualifiedName )
            // InternalTableDSL.g:10586:5: ruleQualifiedName
            {
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElement(grammarAccess.getJvmParameterizedTypeReferenceRule());
              					}
              				
            }
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getJvmParameterizedTypeReferenceAccess().getTypeJvmTypeCrossReference_0_0());
              				
            }
            pushFollow(FOLLOW_130);
            ruleQualifiedName();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					afterParserOrEnumRuleCall();
              				
            }

            }


            }

            // InternalTableDSL.g:10600:3: ( ( ( '<' )=>otherlv_1= '<' ) ( (lv_arguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_arguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>' ( ( ( ( () '.' ) )=> ( () otherlv_7= '.' ) ) ( ( ruleValidID ) ) ( ( ( '<' )=>otherlv_9= '<' ) ( (lv_arguments_10_0= ruleJvmArgumentTypeReference ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) ) )* otherlv_13= '>' )? )* )?
            int alt160=2;
            alt160 = dfa160.predict(input);
            switch (alt160) {
                case 1 :
                    // InternalTableDSL.g:10601:4: ( ( '<' )=>otherlv_1= '<' ) ( (lv_arguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_arguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>' ( ( ( ( () '.' ) )=> ( () otherlv_7= '.' ) ) ( ( ruleValidID ) ) ( ( ( '<' )=>otherlv_9= '<' ) ( (lv_arguments_10_0= ruleJvmArgumentTypeReference ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) ) )* otherlv_13= '>' )? )*
                    {
                    // InternalTableDSL.g:10601:4: ( ( '<' )=>otherlv_1= '<' )
                    // InternalTableDSL.g:10602:5: ( '<' )=>otherlv_1= '<'
                    {
                    otherlv_1=(Token)match(input,112,FOLLOW_90); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      					newLeafNode(otherlv_1, grammarAccess.getJvmParameterizedTypeReferenceAccess().getLessThanSignKeyword_1_0());
                      				
                    }

                    }

                    // InternalTableDSL.g:10608:4: ( (lv_arguments_2_0= ruleJvmArgumentTypeReference ) )
                    // InternalTableDSL.g:10609:5: (lv_arguments_2_0= ruleJvmArgumentTypeReference )
                    {
                    // InternalTableDSL.g:10609:5: (lv_arguments_2_0= ruleJvmArgumentTypeReference )
                    // InternalTableDSL.g:10610:6: lv_arguments_2_0= ruleJvmArgumentTypeReference
                    {
                    if ( state.backtracking==0 ) {

                      						newCompositeNode(grammarAccess.getJvmParameterizedTypeReferenceAccess().getArgumentsJvmArgumentTypeReferenceParserRuleCall_1_1_0());
                      					
                    }
                    pushFollow(FOLLOW_91);
                    lv_arguments_2_0=ruleJvmArgumentTypeReference();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      						if (current==null) {
                      							current = createModelElementForParent(grammarAccess.getJvmParameterizedTypeReferenceRule());
                      						}
                      						add(
                      							current,
                      							"arguments",
                      							lv_arguments_2_0,
                      							"org.eclipse.xtext.xbase.Xtype.JvmArgumentTypeReference");
                      						afterParserOrEnumRuleCall();
                      					
                    }

                    }


                    }

                    // InternalTableDSL.g:10627:4: (otherlv_3= ',' ( (lv_arguments_4_0= ruleJvmArgumentTypeReference ) ) )*
                    loop156:
                    do {
                        int alt156=2;
                        int LA156_0 = input.LA(1);

                        if ( (LA156_0==101) ) {
                            alt156=1;
                        }


                        switch (alt156) {
                    	case 1 :
                    	    // InternalTableDSL.g:10628:5: otherlv_3= ',' ( (lv_arguments_4_0= ruleJvmArgumentTypeReference ) )
                    	    {
                    	    otherlv_3=(Token)match(input,101,FOLLOW_90); if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      					newLeafNode(otherlv_3, grammarAccess.getJvmParameterizedTypeReferenceAccess().getCommaKeyword_1_2_0());
                    	      				
                    	    }
                    	    // InternalTableDSL.g:10632:5: ( (lv_arguments_4_0= ruleJvmArgumentTypeReference ) )
                    	    // InternalTableDSL.g:10633:6: (lv_arguments_4_0= ruleJvmArgumentTypeReference )
                    	    {
                    	    // InternalTableDSL.g:10633:6: (lv_arguments_4_0= ruleJvmArgumentTypeReference )
                    	    // InternalTableDSL.g:10634:7: lv_arguments_4_0= ruleJvmArgumentTypeReference
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      							newCompositeNode(grammarAccess.getJvmParameterizedTypeReferenceAccess().getArgumentsJvmArgumentTypeReferenceParserRuleCall_1_2_1_0());
                    	      						
                    	    }
                    	    pushFollow(FOLLOW_91);
                    	    lv_arguments_4_0=ruleJvmArgumentTypeReference();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      							if (current==null) {
                    	      								current = createModelElementForParent(grammarAccess.getJvmParameterizedTypeReferenceRule());
                    	      							}
                    	      							add(
                    	      								current,
                    	      								"arguments",
                    	      								lv_arguments_4_0,
                    	      								"org.eclipse.xtext.xbase.Xtype.JvmArgumentTypeReference");
                    	      							afterParserOrEnumRuleCall();
                    	      						
                    	    }

                    	    }


                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop156;
                        }
                    } while (true);

                    otherlv_5=(Token)match(input,113,FOLLOW_43); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				newLeafNode(otherlv_5, grammarAccess.getJvmParameterizedTypeReferenceAccess().getGreaterThanSignKeyword_1_3());
                      			
                    }
                    // InternalTableDSL.g:10656:4: ( ( ( ( () '.' ) )=> ( () otherlv_7= '.' ) ) ( ( ruleValidID ) ) ( ( ( '<' )=>otherlv_9= '<' ) ( (lv_arguments_10_0= ruleJvmArgumentTypeReference ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) ) )* otherlv_13= '>' )? )*
                    loop159:
                    do {
                        int alt159=2;
                        int LA159_0 = input.LA(1);

                        if ( (LA159_0==74) ) {
                            int LA159_2 = input.LA(2);

                            if ( (LA159_2==RULE_ID) ) {
                                int LA159_3 = input.LA(3);

                                if ( (synpred51_InternalTableDSL()) ) {
                                    alt159=1;
                                }


                            }


                        }


                        switch (alt159) {
                    	case 1 :
                    	    // InternalTableDSL.g:10657:5: ( ( ( () '.' ) )=> ( () otherlv_7= '.' ) ) ( ( ruleValidID ) ) ( ( ( '<' )=>otherlv_9= '<' ) ( (lv_arguments_10_0= ruleJvmArgumentTypeReference ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) ) )* otherlv_13= '>' )?
                    	    {
                    	    // InternalTableDSL.g:10657:5: ( ( ( () '.' ) )=> ( () otherlv_7= '.' ) )
                    	    // InternalTableDSL.g:10658:6: ( ( () '.' ) )=> ( () otherlv_7= '.' )
                    	    {
                    	    // InternalTableDSL.g:10664:6: ( () otherlv_7= '.' )
                    	    // InternalTableDSL.g:10665:7: () otherlv_7= '.'
                    	    {
                    	    // InternalTableDSL.g:10665:7: ()
                    	    // InternalTableDSL.g:10666:8: 
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      								current = forceCreateModelElementAndSet(
                    	      									grammarAccess.getJvmParameterizedTypeReferenceAccess().getJvmInnerTypeReferenceOuterAction_1_4_0_0_0(),
                    	      									current);
                    	      							
                    	    }

                    	    }

                    	    otherlv_7=(Token)match(input,74,FOLLOW_4); if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      							newLeafNode(otherlv_7, grammarAccess.getJvmParameterizedTypeReferenceAccess().getFullStopKeyword_1_4_0_0_1());
                    	      						
                    	    }

                    	    }


                    	    }

                    	    // InternalTableDSL.g:10678:5: ( ( ruleValidID ) )
                    	    // InternalTableDSL.g:10679:6: ( ruleValidID )
                    	    {
                    	    // InternalTableDSL.g:10679:6: ( ruleValidID )
                    	    // InternalTableDSL.g:10680:7: ruleValidID
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      							if (current==null) {
                    	      								current = createModelElement(grammarAccess.getJvmParameterizedTypeReferenceRule());
                    	      							}
                    	      						
                    	    }
                    	    if ( state.backtracking==0 ) {

                    	      							newCompositeNode(grammarAccess.getJvmParameterizedTypeReferenceAccess().getTypeJvmTypeCrossReference_1_4_1_0());
                    	      						
                    	    }
                    	    pushFollow(FOLLOW_131);
                    	    ruleValidID();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      							afterParserOrEnumRuleCall();
                    	      						
                    	    }

                    	    }


                    	    }

                    	    // InternalTableDSL.g:10694:5: ( ( ( '<' )=>otherlv_9= '<' ) ( (lv_arguments_10_0= ruleJvmArgumentTypeReference ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) ) )* otherlv_13= '>' )?
                    	    int alt158=2;
                    	    alt158 = dfa158.predict(input);
                    	    switch (alt158) {
                    	        case 1 :
                    	            // InternalTableDSL.g:10695:6: ( ( '<' )=>otherlv_9= '<' ) ( (lv_arguments_10_0= ruleJvmArgumentTypeReference ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) ) )* otherlv_13= '>'
                    	            {
                    	            // InternalTableDSL.g:10695:6: ( ( '<' )=>otherlv_9= '<' )
                    	            // InternalTableDSL.g:10696:7: ( '<' )=>otherlv_9= '<'
                    	            {
                    	            otherlv_9=(Token)match(input,112,FOLLOW_90); if (state.failed) return current;
                    	            if ( state.backtracking==0 ) {

                    	              							newLeafNode(otherlv_9, grammarAccess.getJvmParameterizedTypeReferenceAccess().getLessThanSignKeyword_1_4_2_0());
                    	              						
                    	            }

                    	            }

                    	            // InternalTableDSL.g:10702:6: ( (lv_arguments_10_0= ruleJvmArgumentTypeReference ) )
                    	            // InternalTableDSL.g:10703:7: (lv_arguments_10_0= ruleJvmArgumentTypeReference )
                    	            {
                    	            // InternalTableDSL.g:10703:7: (lv_arguments_10_0= ruleJvmArgumentTypeReference )
                    	            // InternalTableDSL.g:10704:8: lv_arguments_10_0= ruleJvmArgumentTypeReference
                    	            {
                    	            if ( state.backtracking==0 ) {

                    	              								newCompositeNode(grammarAccess.getJvmParameterizedTypeReferenceAccess().getArgumentsJvmArgumentTypeReferenceParserRuleCall_1_4_2_1_0());
                    	              							
                    	            }
                    	            pushFollow(FOLLOW_91);
                    	            lv_arguments_10_0=ruleJvmArgumentTypeReference();

                    	            state._fsp--;
                    	            if (state.failed) return current;
                    	            if ( state.backtracking==0 ) {

                    	              								if (current==null) {
                    	              									current = createModelElementForParent(grammarAccess.getJvmParameterizedTypeReferenceRule());
                    	              								}
                    	              								add(
                    	              									current,
                    	              									"arguments",
                    	              									lv_arguments_10_0,
                    	              									"org.eclipse.xtext.xbase.Xtype.JvmArgumentTypeReference");
                    	              								afterParserOrEnumRuleCall();
                    	              							
                    	            }

                    	            }


                    	            }

                    	            // InternalTableDSL.g:10721:6: (otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) ) )*
                    	            loop157:
                    	            do {
                    	                int alt157=2;
                    	                int LA157_0 = input.LA(1);

                    	                if ( (LA157_0==101) ) {
                    	                    alt157=1;
                    	                }


                    	                switch (alt157) {
                    	            	case 1 :
                    	            	    // InternalTableDSL.g:10722:7: otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) )
                    	            	    {
                    	            	    otherlv_11=(Token)match(input,101,FOLLOW_90); if (state.failed) return current;
                    	            	    if ( state.backtracking==0 ) {

                    	            	      							newLeafNode(otherlv_11, grammarAccess.getJvmParameterizedTypeReferenceAccess().getCommaKeyword_1_4_2_2_0());
                    	            	      						
                    	            	    }
                    	            	    // InternalTableDSL.g:10726:7: ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) )
                    	            	    // InternalTableDSL.g:10727:8: (lv_arguments_12_0= ruleJvmArgumentTypeReference )
                    	            	    {
                    	            	    // InternalTableDSL.g:10727:8: (lv_arguments_12_0= ruleJvmArgumentTypeReference )
                    	            	    // InternalTableDSL.g:10728:9: lv_arguments_12_0= ruleJvmArgumentTypeReference
                    	            	    {
                    	            	    if ( state.backtracking==0 ) {

                    	            	      									newCompositeNode(grammarAccess.getJvmParameterizedTypeReferenceAccess().getArgumentsJvmArgumentTypeReferenceParserRuleCall_1_4_2_2_1_0());
                    	            	      								
                    	            	    }
                    	            	    pushFollow(FOLLOW_91);
                    	            	    lv_arguments_12_0=ruleJvmArgumentTypeReference();

                    	            	    state._fsp--;
                    	            	    if (state.failed) return current;
                    	            	    if ( state.backtracking==0 ) {

                    	            	      									if (current==null) {
                    	            	      										current = createModelElementForParent(grammarAccess.getJvmParameterizedTypeReferenceRule());
                    	            	      									}
                    	            	      									add(
                    	            	      										current,
                    	            	      										"arguments",
                    	            	      										lv_arguments_12_0,
                    	            	      										"org.eclipse.xtext.xbase.Xtype.JvmArgumentTypeReference");
                    	            	      									afterParserOrEnumRuleCall();
                    	            	      								
                    	            	    }

                    	            	    }


                    	            	    }


                    	            	    }
                    	            	    break;

                    	            	default :
                    	            	    break loop157;
                    	                }
                    	            } while (true);

                    	            otherlv_13=(Token)match(input,113,FOLLOW_43); if (state.failed) return current;
                    	            if ( state.backtracking==0 ) {

                    	              						newLeafNode(otherlv_13, grammarAccess.getJvmParameterizedTypeReferenceAccess().getGreaterThanSignKeyword_1_4_2_3());
                    	              					
                    	            }

                    	            }
                    	            break;

                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop159;
                        }
                    } while (true);


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleJvmParameterizedTypeReference"


    // $ANTLR start "entryRuleJvmArgumentTypeReference"
    // InternalTableDSL.g:10757:1: entryRuleJvmArgumentTypeReference returns [EObject current=null] : iv_ruleJvmArgumentTypeReference= ruleJvmArgumentTypeReference EOF ;
    public final EObject entryRuleJvmArgumentTypeReference() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleJvmArgumentTypeReference = null;


        try {
            // InternalTableDSL.g:10757:65: (iv_ruleJvmArgumentTypeReference= ruleJvmArgumentTypeReference EOF )
            // InternalTableDSL.g:10758:2: iv_ruleJvmArgumentTypeReference= ruleJvmArgumentTypeReference EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getJvmArgumentTypeReferenceRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleJvmArgumentTypeReference=ruleJvmArgumentTypeReference();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleJvmArgumentTypeReference; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleJvmArgumentTypeReference"


    // $ANTLR start "ruleJvmArgumentTypeReference"
    // InternalTableDSL.g:10764:1: ruleJvmArgumentTypeReference returns [EObject current=null] : (this_JvmTypeReference_0= ruleJvmTypeReference | this_JvmWildcardTypeReference_1= ruleJvmWildcardTypeReference ) ;
    public final EObject ruleJvmArgumentTypeReference() throws RecognitionException {
        EObject current = null;

        EObject this_JvmTypeReference_0 = null;

        EObject this_JvmWildcardTypeReference_1 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:10770:2: ( (this_JvmTypeReference_0= ruleJvmTypeReference | this_JvmWildcardTypeReference_1= ruleJvmWildcardTypeReference ) )
            // InternalTableDSL.g:10771:2: (this_JvmTypeReference_0= ruleJvmTypeReference | this_JvmWildcardTypeReference_1= ruleJvmWildcardTypeReference )
            {
            // InternalTableDSL.g:10771:2: (this_JvmTypeReference_0= ruleJvmTypeReference | this_JvmWildcardTypeReference_1= ruleJvmWildcardTypeReference )
            int alt161=2;
            int LA161_0 = input.LA(1);

            if ( (LA161_0==RULE_ID||LA161_0==100||LA161_0==125) ) {
                alt161=1;
            }
            else if ( (LA161_0==161) ) {
                alt161=2;
            }
            else {
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 161, 0, input);

                throw nvae;
            }
            switch (alt161) {
                case 1 :
                    // InternalTableDSL.g:10772:3: this_JvmTypeReference_0= ruleJvmTypeReference
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getJvmArgumentTypeReferenceAccess().getJvmTypeReferenceParserRuleCall_0());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_JvmTypeReference_0=ruleJvmTypeReference();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_JvmTypeReference_0;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:10781:3: this_JvmWildcardTypeReference_1= ruleJvmWildcardTypeReference
                    {
                    if ( state.backtracking==0 ) {

                      			newCompositeNode(grammarAccess.getJvmArgumentTypeReferenceAccess().getJvmWildcardTypeReferenceParserRuleCall_1());
                      		
                    }
                    pushFollow(FOLLOW_2);
                    this_JvmWildcardTypeReference_1=ruleJvmWildcardTypeReference();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      			current = this_JvmWildcardTypeReference_1;
                      			afterParserOrEnumRuleCall();
                      		
                    }

                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleJvmArgumentTypeReference"


    // $ANTLR start "entryRuleJvmWildcardTypeReference"
    // InternalTableDSL.g:10793:1: entryRuleJvmWildcardTypeReference returns [EObject current=null] : iv_ruleJvmWildcardTypeReference= ruleJvmWildcardTypeReference EOF ;
    public final EObject entryRuleJvmWildcardTypeReference() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleJvmWildcardTypeReference = null;


        try {
            // InternalTableDSL.g:10793:65: (iv_ruleJvmWildcardTypeReference= ruleJvmWildcardTypeReference EOF )
            // InternalTableDSL.g:10794:2: iv_ruleJvmWildcardTypeReference= ruleJvmWildcardTypeReference EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getJvmWildcardTypeReferenceRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleJvmWildcardTypeReference=ruleJvmWildcardTypeReference();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleJvmWildcardTypeReference; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleJvmWildcardTypeReference"


    // $ANTLR start "ruleJvmWildcardTypeReference"
    // InternalTableDSL.g:10800:1: ruleJvmWildcardTypeReference returns [EObject current=null] : ( () otherlv_1= '?' ( ( ( (lv_constraints_2_0= ruleJvmUpperBound ) ) ( (lv_constraints_3_0= ruleJvmUpperBoundAnded ) )* ) | ( ( (lv_constraints_4_0= ruleJvmLowerBound ) ) ( (lv_constraints_5_0= ruleJvmLowerBoundAnded ) )* ) )? ) ;
    public final EObject ruleJvmWildcardTypeReference() throws RecognitionException {
        EObject current = null;

        Token otherlv_1=null;
        EObject lv_constraints_2_0 = null;

        EObject lv_constraints_3_0 = null;

        EObject lv_constraints_4_0 = null;

        EObject lv_constraints_5_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:10806:2: ( ( () otherlv_1= '?' ( ( ( (lv_constraints_2_0= ruleJvmUpperBound ) ) ( (lv_constraints_3_0= ruleJvmUpperBoundAnded ) )* ) | ( ( (lv_constraints_4_0= ruleJvmLowerBound ) ) ( (lv_constraints_5_0= ruleJvmLowerBoundAnded ) )* ) )? ) )
            // InternalTableDSL.g:10807:2: ( () otherlv_1= '?' ( ( ( (lv_constraints_2_0= ruleJvmUpperBound ) ) ( (lv_constraints_3_0= ruleJvmUpperBoundAnded ) )* ) | ( ( (lv_constraints_4_0= ruleJvmLowerBound ) ) ( (lv_constraints_5_0= ruleJvmLowerBoundAnded ) )* ) )? )
            {
            // InternalTableDSL.g:10807:2: ( () otherlv_1= '?' ( ( ( (lv_constraints_2_0= ruleJvmUpperBound ) ) ( (lv_constraints_3_0= ruleJvmUpperBoundAnded ) )* ) | ( ( (lv_constraints_4_0= ruleJvmLowerBound ) ) ( (lv_constraints_5_0= ruleJvmLowerBoundAnded ) )* ) )? )
            // InternalTableDSL.g:10808:3: () otherlv_1= '?' ( ( ( (lv_constraints_2_0= ruleJvmUpperBound ) ) ( (lv_constraints_3_0= ruleJvmUpperBoundAnded ) )* ) | ( ( (lv_constraints_4_0= ruleJvmLowerBound ) ) ( (lv_constraints_5_0= ruleJvmLowerBoundAnded ) )* ) )?
            {
            // InternalTableDSL.g:10808:3: ()
            // InternalTableDSL.g:10809:4: 
            {
            if ( state.backtracking==0 ) {

              				current = forceCreateModelElement(
              					grammarAccess.getJvmWildcardTypeReferenceAccess().getJvmWildcardTypeReferenceAction_0(),
              					current);
              			
            }

            }

            otherlv_1=(Token)match(input,161,FOLLOW_132); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_1, grammarAccess.getJvmWildcardTypeReferenceAccess().getQuestionMarkKeyword_1());
              		
            }
            // InternalTableDSL.g:10819:3: ( ( ( (lv_constraints_2_0= ruleJvmUpperBound ) ) ( (lv_constraints_3_0= ruleJvmUpperBoundAnded ) )* ) | ( ( (lv_constraints_4_0= ruleJvmLowerBound ) ) ( (lv_constraints_5_0= ruleJvmLowerBoundAnded ) )* ) )?
            int alt164=3;
            int LA164_0 = input.LA(1);

            if ( (LA164_0==148) ) {
                alt164=1;
            }
            else if ( (LA164_0==149) ) {
                alt164=2;
            }
            switch (alt164) {
                case 1 :
                    // InternalTableDSL.g:10820:4: ( ( (lv_constraints_2_0= ruleJvmUpperBound ) ) ( (lv_constraints_3_0= ruleJvmUpperBoundAnded ) )* )
                    {
                    // InternalTableDSL.g:10820:4: ( ( (lv_constraints_2_0= ruleJvmUpperBound ) ) ( (lv_constraints_3_0= ruleJvmUpperBoundAnded ) )* )
                    // InternalTableDSL.g:10821:5: ( (lv_constraints_2_0= ruleJvmUpperBound ) ) ( (lv_constraints_3_0= ruleJvmUpperBoundAnded ) )*
                    {
                    // InternalTableDSL.g:10821:5: ( (lv_constraints_2_0= ruleJvmUpperBound ) )
                    // InternalTableDSL.g:10822:6: (lv_constraints_2_0= ruleJvmUpperBound )
                    {
                    // InternalTableDSL.g:10822:6: (lv_constraints_2_0= ruleJvmUpperBound )
                    // InternalTableDSL.g:10823:7: lv_constraints_2_0= ruleJvmUpperBound
                    {
                    if ( state.backtracking==0 ) {

                      							newCompositeNode(grammarAccess.getJvmWildcardTypeReferenceAccess().getConstraintsJvmUpperBoundParserRuleCall_2_0_0_0());
                      						
                    }
                    pushFollow(FOLLOW_133);
                    lv_constraints_2_0=ruleJvmUpperBound();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      							if (current==null) {
                      								current = createModelElementForParent(grammarAccess.getJvmWildcardTypeReferenceRule());
                      							}
                      							add(
                      								current,
                      								"constraints",
                      								lv_constraints_2_0,
                      								"org.eclipse.xtext.xbase.Xtype.JvmUpperBound");
                      							afterParserOrEnumRuleCall();
                      						
                    }

                    }


                    }

                    // InternalTableDSL.g:10840:5: ( (lv_constraints_3_0= ruleJvmUpperBoundAnded ) )*
                    loop162:
                    do {
                        int alt162=2;
                        int LA162_0 = input.LA(1);

                        if ( (LA162_0==162) ) {
                            alt162=1;
                        }


                        switch (alt162) {
                    	case 1 :
                    	    // InternalTableDSL.g:10841:6: (lv_constraints_3_0= ruleJvmUpperBoundAnded )
                    	    {
                    	    // InternalTableDSL.g:10841:6: (lv_constraints_3_0= ruleJvmUpperBoundAnded )
                    	    // InternalTableDSL.g:10842:7: lv_constraints_3_0= ruleJvmUpperBoundAnded
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      							newCompositeNode(grammarAccess.getJvmWildcardTypeReferenceAccess().getConstraintsJvmUpperBoundAndedParserRuleCall_2_0_1_0());
                    	      						
                    	    }
                    	    pushFollow(FOLLOW_133);
                    	    lv_constraints_3_0=ruleJvmUpperBoundAnded();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      							if (current==null) {
                    	      								current = createModelElementForParent(grammarAccess.getJvmWildcardTypeReferenceRule());
                    	      							}
                    	      							add(
                    	      								current,
                    	      								"constraints",
                    	      								lv_constraints_3_0,
                    	      								"org.eclipse.xtext.xbase.Xtype.JvmUpperBoundAnded");
                    	      							afterParserOrEnumRuleCall();
                    	      						
                    	    }

                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop162;
                        }
                    } while (true);


                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:10861:4: ( ( (lv_constraints_4_0= ruleJvmLowerBound ) ) ( (lv_constraints_5_0= ruleJvmLowerBoundAnded ) )* )
                    {
                    // InternalTableDSL.g:10861:4: ( ( (lv_constraints_4_0= ruleJvmLowerBound ) ) ( (lv_constraints_5_0= ruleJvmLowerBoundAnded ) )* )
                    // InternalTableDSL.g:10862:5: ( (lv_constraints_4_0= ruleJvmLowerBound ) ) ( (lv_constraints_5_0= ruleJvmLowerBoundAnded ) )*
                    {
                    // InternalTableDSL.g:10862:5: ( (lv_constraints_4_0= ruleJvmLowerBound ) )
                    // InternalTableDSL.g:10863:6: (lv_constraints_4_0= ruleJvmLowerBound )
                    {
                    // InternalTableDSL.g:10863:6: (lv_constraints_4_0= ruleJvmLowerBound )
                    // InternalTableDSL.g:10864:7: lv_constraints_4_0= ruleJvmLowerBound
                    {
                    if ( state.backtracking==0 ) {

                      							newCompositeNode(grammarAccess.getJvmWildcardTypeReferenceAccess().getConstraintsJvmLowerBoundParserRuleCall_2_1_0_0());
                      						
                    }
                    pushFollow(FOLLOW_133);
                    lv_constraints_4_0=ruleJvmLowerBound();

                    state._fsp--;
                    if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      							if (current==null) {
                      								current = createModelElementForParent(grammarAccess.getJvmWildcardTypeReferenceRule());
                      							}
                      							add(
                      								current,
                      								"constraints",
                      								lv_constraints_4_0,
                      								"org.eclipse.xtext.xbase.Xtype.JvmLowerBound");
                      							afterParserOrEnumRuleCall();
                      						
                    }

                    }


                    }

                    // InternalTableDSL.g:10881:5: ( (lv_constraints_5_0= ruleJvmLowerBoundAnded ) )*
                    loop163:
                    do {
                        int alt163=2;
                        int LA163_0 = input.LA(1);

                        if ( (LA163_0==162) ) {
                            alt163=1;
                        }


                        switch (alt163) {
                    	case 1 :
                    	    // InternalTableDSL.g:10882:6: (lv_constraints_5_0= ruleJvmLowerBoundAnded )
                    	    {
                    	    // InternalTableDSL.g:10882:6: (lv_constraints_5_0= ruleJvmLowerBoundAnded )
                    	    // InternalTableDSL.g:10883:7: lv_constraints_5_0= ruleJvmLowerBoundAnded
                    	    {
                    	    if ( state.backtracking==0 ) {

                    	      							newCompositeNode(grammarAccess.getJvmWildcardTypeReferenceAccess().getConstraintsJvmLowerBoundAndedParserRuleCall_2_1_1_0());
                    	      						
                    	    }
                    	    pushFollow(FOLLOW_133);
                    	    lv_constraints_5_0=ruleJvmLowerBoundAnded();

                    	    state._fsp--;
                    	    if (state.failed) return current;
                    	    if ( state.backtracking==0 ) {

                    	      							if (current==null) {
                    	      								current = createModelElementForParent(grammarAccess.getJvmWildcardTypeReferenceRule());
                    	      							}
                    	      							add(
                    	      								current,
                    	      								"constraints",
                    	      								lv_constraints_5_0,
                    	      								"org.eclipse.xtext.xbase.Xtype.JvmLowerBoundAnded");
                    	      							afterParserOrEnumRuleCall();
                    	      						
                    	    }

                    	    }


                    	    }
                    	    break;

                    	default :
                    	    break loop163;
                        }
                    } while (true);


                    }


                    }
                    break;

            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleJvmWildcardTypeReference"


    // $ANTLR start "entryRuleJvmUpperBound"
    // InternalTableDSL.g:10906:1: entryRuleJvmUpperBound returns [EObject current=null] : iv_ruleJvmUpperBound= ruleJvmUpperBound EOF ;
    public final EObject entryRuleJvmUpperBound() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleJvmUpperBound = null;


        try {
            // InternalTableDSL.g:10906:54: (iv_ruleJvmUpperBound= ruleJvmUpperBound EOF )
            // InternalTableDSL.g:10907:2: iv_ruleJvmUpperBound= ruleJvmUpperBound EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getJvmUpperBoundRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleJvmUpperBound=ruleJvmUpperBound();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleJvmUpperBound; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleJvmUpperBound"


    // $ANTLR start "ruleJvmUpperBound"
    // InternalTableDSL.g:10913:1: ruleJvmUpperBound returns [EObject current=null] : (otherlv_0= 'extends' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) ) ;
    public final EObject ruleJvmUpperBound() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        EObject lv_typeReference_1_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:10919:2: ( (otherlv_0= 'extends' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) ) )
            // InternalTableDSL.g:10920:2: (otherlv_0= 'extends' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) )
            {
            // InternalTableDSL.g:10920:2: (otherlv_0= 'extends' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) )
            // InternalTableDSL.g:10921:3: otherlv_0= 'extends' ( (lv_typeReference_1_0= ruleJvmTypeReference ) )
            {
            otherlv_0=(Token)match(input,148,FOLLOW_78); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getJvmUpperBoundAccess().getExtendsKeyword_0());
              		
            }
            // InternalTableDSL.g:10925:3: ( (lv_typeReference_1_0= ruleJvmTypeReference ) )
            // InternalTableDSL.g:10926:4: (lv_typeReference_1_0= ruleJvmTypeReference )
            {
            // InternalTableDSL.g:10926:4: (lv_typeReference_1_0= ruleJvmTypeReference )
            // InternalTableDSL.g:10927:5: lv_typeReference_1_0= ruleJvmTypeReference
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getJvmUpperBoundAccess().getTypeReferenceJvmTypeReferenceParserRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_typeReference_1_0=ruleJvmTypeReference();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getJvmUpperBoundRule());
              					}
              					set(
              						current,
              						"typeReference",
              						lv_typeReference_1_0,
              						"org.eclipse.xtext.xbase.Xtype.JvmTypeReference");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleJvmUpperBound"


    // $ANTLR start "entryRuleJvmUpperBoundAnded"
    // InternalTableDSL.g:10948:1: entryRuleJvmUpperBoundAnded returns [EObject current=null] : iv_ruleJvmUpperBoundAnded= ruleJvmUpperBoundAnded EOF ;
    public final EObject entryRuleJvmUpperBoundAnded() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleJvmUpperBoundAnded = null;


        try {
            // InternalTableDSL.g:10948:59: (iv_ruleJvmUpperBoundAnded= ruleJvmUpperBoundAnded EOF )
            // InternalTableDSL.g:10949:2: iv_ruleJvmUpperBoundAnded= ruleJvmUpperBoundAnded EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getJvmUpperBoundAndedRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleJvmUpperBoundAnded=ruleJvmUpperBoundAnded();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleJvmUpperBoundAnded; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleJvmUpperBoundAnded"


    // $ANTLR start "ruleJvmUpperBoundAnded"
    // InternalTableDSL.g:10955:1: ruleJvmUpperBoundAnded returns [EObject current=null] : (otherlv_0= '&' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) ) ;
    public final EObject ruleJvmUpperBoundAnded() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        EObject lv_typeReference_1_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:10961:2: ( (otherlv_0= '&' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) ) )
            // InternalTableDSL.g:10962:2: (otherlv_0= '&' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) )
            {
            // InternalTableDSL.g:10962:2: (otherlv_0= '&' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) )
            // InternalTableDSL.g:10963:3: otherlv_0= '&' ( (lv_typeReference_1_0= ruleJvmTypeReference ) )
            {
            otherlv_0=(Token)match(input,162,FOLLOW_78); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getJvmUpperBoundAndedAccess().getAmpersandKeyword_0());
              		
            }
            // InternalTableDSL.g:10967:3: ( (lv_typeReference_1_0= ruleJvmTypeReference ) )
            // InternalTableDSL.g:10968:4: (lv_typeReference_1_0= ruleJvmTypeReference )
            {
            // InternalTableDSL.g:10968:4: (lv_typeReference_1_0= ruleJvmTypeReference )
            // InternalTableDSL.g:10969:5: lv_typeReference_1_0= ruleJvmTypeReference
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getJvmUpperBoundAndedAccess().getTypeReferenceJvmTypeReferenceParserRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_typeReference_1_0=ruleJvmTypeReference();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getJvmUpperBoundAndedRule());
              					}
              					set(
              						current,
              						"typeReference",
              						lv_typeReference_1_0,
              						"org.eclipse.xtext.xbase.Xtype.JvmTypeReference");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleJvmUpperBoundAnded"


    // $ANTLR start "entryRuleJvmLowerBound"
    // InternalTableDSL.g:10990:1: entryRuleJvmLowerBound returns [EObject current=null] : iv_ruleJvmLowerBound= ruleJvmLowerBound EOF ;
    public final EObject entryRuleJvmLowerBound() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleJvmLowerBound = null;


        try {
            // InternalTableDSL.g:10990:54: (iv_ruleJvmLowerBound= ruleJvmLowerBound EOF )
            // InternalTableDSL.g:10991:2: iv_ruleJvmLowerBound= ruleJvmLowerBound EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getJvmLowerBoundRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleJvmLowerBound=ruleJvmLowerBound();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleJvmLowerBound; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleJvmLowerBound"


    // $ANTLR start "ruleJvmLowerBound"
    // InternalTableDSL.g:10997:1: ruleJvmLowerBound returns [EObject current=null] : (otherlv_0= 'super' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) ) ;
    public final EObject ruleJvmLowerBound() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        EObject lv_typeReference_1_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:11003:2: ( (otherlv_0= 'super' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) ) )
            // InternalTableDSL.g:11004:2: (otherlv_0= 'super' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) )
            {
            // InternalTableDSL.g:11004:2: (otherlv_0= 'super' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) )
            // InternalTableDSL.g:11005:3: otherlv_0= 'super' ( (lv_typeReference_1_0= ruleJvmTypeReference ) )
            {
            otherlv_0=(Token)match(input,149,FOLLOW_78); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getJvmLowerBoundAccess().getSuperKeyword_0());
              		
            }
            // InternalTableDSL.g:11009:3: ( (lv_typeReference_1_0= ruleJvmTypeReference ) )
            // InternalTableDSL.g:11010:4: (lv_typeReference_1_0= ruleJvmTypeReference )
            {
            // InternalTableDSL.g:11010:4: (lv_typeReference_1_0= ruleJvmTypeReference )
            // InternalTableDSL.g:11011:5: lv_typeReference_1_0= ruleJvmTypeReference
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getJvmLowerBoundAccess().getTypeReferenceJvmTypeReferenceParserRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_typeReference_1_0=ruleJvmTypeReference();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getJvmLowerBoundRule());
              					}
              					set(
              						current,
              						"typeReference",
              						lv_typeReference_1_0,
              						"org.eclipse.xtext.xbase.Xtype.JvmTypeReference");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleJvmLowerBound"


    // $ANTLR start "entryRuleJvmLowerBoundAnded"
    // InternalTableDSL.g:11032:1: entryRuleJvmLowerBoundAnded returns [EObject current=null] : iv_ruleJvmLowerBoundAnded= ruleJvmLowerBoundAnded EOF ;
    public final EObject entryRuleJvmLowerBoundAnded() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleJvmLowerBoundAnded = null;


        try {
            // InternalTableDSL.g:11032:59: (iv_ruleJvmLowerBoundAnded= ruleJvmLowerBoundAnded EOF )
            // InternalTableDSL.g:11033:2: iv_ruleJvmLowerBoundAnded= ruleJvmLowerBoundAnded EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getJvmLowerBoundAndedRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleJvmLowerBoundAnded=ruleJvmLowerBoundAnded();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleJvmLowerBoundAnded; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleJvmLowerBoundAnded"


    // $ANTLR start "ruleJvmLowerBoundAnded"
    // InternalTableDSL.g:11039:1: ruleJvmLowerBoundAnded returns [EObject current=null] : (otherlv_0= '&' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) ) ;
    public final EObject ruleJvmLowerBoundAnded() throws RecognitionException {
        EObject current = null;

        Token otherlv_0=null;
        EObject lv_typeReference_1_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:11045:2: ( (otherlv_0= '&' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) ) )
            // InternalTableDSL.g:11046:2: (otherlv_0= '&' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) )
            {
            // InternalTableDSL.g:11046:2: (otherlv_0= '&' ( (lv_typeReference_1_0= ruleJvmTypeReference ) ) )
            // InternalTableDSL.g:11047:3: otherlv_0= '&' ( (lv_typeReference_1_0= ruleJvmTypeReference ) )
            {
            otherlv_0=(Token)match(input,162,FOLLOW_78); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			newLeafNode(otherlv_0, grammarAccess.getJvmLowerBoundAndedAccess().getAmpersandKeyword_0());
              		
            }
            // InternalTableDSL.g:11051:3: ( (lv_typeReference_1_0= ruleJvmTypeReference ) )
            // InternalTableDSL.g:11052:4: (lv_typeReference_1_0= ruleJvmTypeReference )
            {
            // InternalTableDSL.g:11052:4: (lv_typeReference_1_0= ruleJvmTypeReference )
            // InternalTableDSL.g:11053:5: lv_typeReference_1_0= ruleJvmTypeReference
            {
            if ( state.backtracking==0 ) {

              					newCompositeNode(grammarAccess.getJvmLowerBoundAndedAccess().getTypeReferenceJvmTypeReferenceParserRuleCall_1_0());
              				
            }
            pushFollow(FOLLOW_2);
            lv_typeReference_1_0=ruleJvmTypeReference();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              					if (current==null) {
              						current = createModelElementForParent(grammarAccess.getJvmLowerBoundAndedRule());
              					}
              					set(
              						current,
              						"typeReference",
              						lv_typeReference_1_0,
              						"org.eclipse.xtext.xbase.Xtype.JvmTypeReference");
              					afterParserOrEnumRuleCall();
              				
            }

            }


            }


            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleJvmLowerBoundAnded"


    // $ANTLR start "entryRuleQualifiedNameWithWildcard"
    // InternalTableDSL.g:11074:1: entryRuleQualifiedNameWithWildcard returns [String current=null] : iv_ruleQualifiedNameWithWildcard= ruleQualifiedNameWithWildcard EOF ;
    public final String entryRuleQualifiedNameWithWildcard() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleQualifiedNameWithWildcard = null;


        try {
            // InternalTableDSL.g:11074:65: (iv_ruleQualifiedNameWithWildcard= ruleQualifiedNameWithWildcard EOF )
            // InternalTableDSL.g:11075:2: iv_ruleQualifiedNameWithWildcard= ruleQualifiedNameWithWildcard EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getQualifiedNameWithWildcardRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleQualifiedNameWithWildcard=ruleQualifiedNameWithWildcard();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleQualifiedNameWithWildcard.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleQualifiedNameWithWildcard"


    // $ANTLR start "ruleQualifiedNameWithWildcard"
    // InternalTableDSL.g:11081:1: ruleQualifiedNameWithWildcard returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (this_QualifiedName_0= ruleQualifiedName kw= '.' kw= '*' ) ;
    public final AntlrDatatypeRuleToken ruleQualifiedNameWithWildcard() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;
        AntlrDatatypeRuleToken this_QualifiedName_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:11087:2: ( (this_QualifiedName_0= ruleQualifiedName kw= '.' kw= '*' ) )
            // InternalTableDSL.g:11088:2: (this_QualifiedName_0= ruleQualifiedName kw= '.' kw= '*' )
            {
            // InternalTableDSL.g:11088:2: (this_QualifiedName_0= ruleQualifiedName kw= '.' kw= '*' )
            // InternalTableDSL.g:11089:3: this_QualifiedName_0= ruleQualifiedName kw= '.' kw= '*'
            {
            if ( state.backtracking==0 ) {

              			newCompositeNode(grammarAccess.getQualifiedNameWithWildcardAccess().getQualifiedNameParserRuleCall_0());
              		
            }
            pushFollow(FOLLOW_134);
            this_QualifiedName_0=ruleQualifiedName();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current.merge(this_QualifiedName_0);
              		
            }
            if ( state.backtracking==0 ) {

              			afterParserOrEnumRuleCall();
              		
            }
            kw=(Token)match(input,74,FOLLOW_135); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current.merge(kw);
              			newLeafNode(kw, grammarAccess.getQualifiedNameWithWildcardAccess().getFullStopKeyword_1());
              		
            }
            kw=(Token)match(input,96,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              			current.merge(kw);
              			newLeafNode(kw, grammarAccess.getQualifiedNameWithWildcardAccess().getAsteriskKeyword_2());
              		
            }

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleQualifiedNameWithWildcard"


    // $ANTLR start "entryRuleValidID"
    // InternalTableDSL.g:11113:1: entryRuleValidID returns [String current=null] : iv_ruleValidID= ruleValidID EOF ;
    public final String entryRuleValidID() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleValidID = null;


        try {
            // InternalTableDSL.g:11113:47: (iv_ruleValidID= ruleValidID EOF )
            // InternalTableDSL.g:11114:2: iv_ruleValidID= ruleValidID EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getValidIDRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleValidID=ruleValidID();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleValidID.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleValidID"


    // $ANTLR start "ruleValidID"
    // InternalTableDSL.g:11120:1: ruleValidID returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : this_ID_0= RULE_ID ;
    public final AntlrDatatypeRuleToken ruleValidID() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token this_ID_0=null;


        	enterRule();

        try {
            // InternalTableDSL.g:11126:2: (this_ID_0= RULE_ID )
            // InternalTableDSL.g:11127:2: this_ID_0= RULE_ID
            {
            this_ID_0=(Token)match(input,RULE_ID,FOLLOW_2); if (state.failed) return current;
            if ( state.backtracking==0 ) {

              		current.merge(this_ID_0);
              	
            }
            if ( state.backtracking==0 ) {

              		newLeafNode(this_ID_0, grammarAccess.getValidIDAccess().getIDTerminalRuleCall());
              	
            }

            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleValidID"


    // $ANTLR start "entryRuleXImportSection"
    // InternalTableDSL.g:11137:1: entryRuleXImportSection returns [EObject current=null] : iv_ruleXImportSection= ruleXImportSection EOF ;
    public final EObject entryRuleXImportSection() throws RecognitionException {
        EObject current = null;

        EObject iv_ruleXImportSection = null;


        try {
            // InternalTableDSL.g:11137:55: (iv_ruleXImportSection= ruleXImportSection EOF )
            // InternalTableDSL.g:11138:2: iv_ruleXImportSection= ruleXImportSection EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getXImportSectionRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleXImportSection=ruleXImportSection();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleXImportSection; 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleXImportSection"


    // $ANTLR start "ruleXImportSection"
    // InternalTableDSL.g:11144:1: ruleXImportSection returns [EObject current=null] : ( (lv_importDeclarations_0_0= ruleXImportDeclaration ) )+ ;
    public final EObject ruleXImportSection() throws RecognitionException {
        EObject current = null;

        EObject lv_importDeclarations_0_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:11150:2: ( ( (lv_importDeclarations_0_0= ruleXImportDeclaration ) )+ )
            // InternalTableDSL.g:11151:2: ( (lv_importDeclarations_0_0= ruleXImportDeclaration ) )+
            {
            // InternalTableDSL.g:11151:2: ( (lv_importDeclarations_0_0= ruleXImportDeclaration ) )+
            int cnt165=0;
            loop165:
            do {
                int alt165=2;
                int LA165_0 = input.LA(1);

                if ( (LA165_0==93) ) {
                    alt165=1;
                }


                switch (alt165) {
            	case 1 :
            	    // InternalTableDSL.g:11152:3: (lv_importDeclarations_0_0= ruleXImportDeclaration )
            	    {
            	    // InternalTableDSL.g:11152:3: (lv_importDeclarations_0_0= ruleXImportDeclaration )
            	    // InternalTableDSL.g:11153:4: lv_importDeclarations_0_0= ruleXImportDeclaration
            	    {
            	    if ( state.backtracking==0 ) {

            	      				newCompositeNode(grammarAccess.getXImportSectionAccess().getImportDeclarationsXImportDeclarationParserRuleCall_0());
            	      			
            	    }
            	    pushFollow(FOLLOW_136);
            	    lv_importDeclarations_0_0=ruleXImportDeclaration();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      				if (current==null) {
            	      					current = createModelElementForParent(grammarAccess.getXImportSectionRule());
            	      				}
            	      				add(
            	      					current,
            	      					"importDeclarations",
            	      					lv_importDeclarations_0_0,
            	      					"org.eclipse.osbp.xtext.oxtype.OXtype.XImportDeclaration");
            	      				afterParserOrEnumRuleCall();
            	      			
            	    }

            	    }


            	    }
            	    break;

            	default :
            	    if ( cnt165 >= 1 ) break loop165;
            	    if (state.backtracking>0) {state.failed=true; return current;}
                        EarlyExitException eee =
                            new EarlyExitException(165, input);
                        throw eee;
                }
                cnt165++;
            } while (true);


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleXImportSection"


    // $ANTLR start "entryRuleQualifiedNameInStaticImport"
    // InternalTableDSL.g:11173:1: entryRuleQualifiedNameInStaticImport returns [String current=null] : iv_ruleQualifiedNameInStaticImport= ruleQualifiedNameInStaticImport EOF ;
    public final String entryRuleQualifiedNameInStaticImport() throws RecognitionException {
        String current = null;

        AntlrDatatypeRuleToken iv_ruleQualifiedNameInStaticImport = null;


        try {
            // InternalTableDSL.g:11173:67: (iv_ruleQualifiedNameInStaticImport= ruleQualifiedNameInStaticImport EOF )
            // InternalTableDSL.g:11174:2: iv_ruleQualifiedNameInStaticImport= ruleQualifiedNameInStaticImport EOF
            {
            if ( state.backtracking==0 ) {
               newCompositeNode(grammarAccess.getQualifiedNameInStaticImportRule()); 
            }
            pushFollow(FOLLOW_1);
            iv_ruleQualifiedNameInStaticImport=ruleQualifiedNameInStaticImport();

            state._fsp--;
            if (state.failed) return current;
            if ( state.backtracking==0 ) {
               current =iv_ruleQualifiedNameInStaticImport.getText(); 
            }
            match(input,EOF,FOLLOW_2); if (state.failed) return current;

            }

        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "entryRuleQualifiedNameInStaticImport"


    // $ANTLR start "ruleQualifiedNameInStaticImport"
    // InternalTableDSL.g:11180:1: ruleQualifiedNameInStaticImport returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] : (this_ValidID_0= ruleValidID kw= '.' )+ ;
    public final AntlrDatatypeRuleToken ruleQualifiedNameInStaticImport() throws RecognitionException {
        AntlrDatatypeRuleToken current = new AntlrDatatypeRuleToken();

        Token kw=null;
        AntlrDatatypeRuleToken this_ValidID_0 = null;



        	enterRule();

        try {
            // InternalTableDSL.g:11186:2: ( (this_ValidID_0= ruleValidID kw= '.' )+ )
            // InternalTableDSL.g:11187:2: (this_ValidID_0= ruleValidID kw= '.' )+
            {
            // InternalTableDSL.g:11187:2: (this_ValidID_0= ruleValidID kw= '.' )+
            int cnt166=0;
            loop166:
            do {
                int alt166=2;
                int LA166_0 = input.LA(1);

                if ( (LA166_0==RULE_ID) ) {
                    int LA166_2 = input.LA(2);

                    if ( (LA166_2==74) ) {
                        alt166=1;
                    }


                }


                switch (alt166) {
            	case 1 :
            	    // InternalTableDSL.g:11188:3: this_ValidID_0= ruleValidID kw= '.'
            	    {
            	    if ( state.backtracking==0 ) {

            	      			newCompositeNode(grammarAccess.getQualifiedNameInStaticImportAccess().getValidIDParserRuleCall_0());
            	      		
            	    }
            	    pushFollow(FOLLOW_134);
            	    this_ValidID_0=ruleValidID();

            	    state._fsp--;
            	    if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      			current.merge(this_ValidID_0);
            	      		
            	    }
            	    if ( state.backtracking==0 ) {

            	      			afterParserOrEnumRuleCall();
            	      		
            	    }
            	    kw=(Token)match(input,74,FOLLOW_137); if (state.failed) return current;
            	    if ( state.backtracking==0 ) {

            	      			current.merge(kw);
            	      			newLeafNode(kw, grammarAccess.getQualifiedNameInStaticImportAccess().getFullStopKeyword_1());
            	      		
            	    }

            	    }
            	    break;

            	default :
            	    if ( cnt166 >= 1 ) break loop166;
            	    if (state.backtracking>0) {state.failed=true; return current;}
                        EarlyExitException eee =
                            new EarlyExitException(166, input);
                        throw eee;
                }
                cnt166++;
            } while (true);


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleQualifiedNameInStaticImport"


    // $ANTLR start "ruleStyleCompare"
    // InternalTableDSL.g:11207:1: ruleStyleCompare returns [Enumerator current=null] : ( (enumLiteral_0= 'equal' ) | (enumLiteral_1= 'greater equal' ) | (enumLiteral_2= 'greater than' ) | (enumLiteral_3= 'lower equal' ) | (enumLiteral_4= 'lower than' ) | (enumLiteral_5= 'not equal' ) ) ;
    public final Enumerator ruleStyleCompare() throws RecognitionException {
        Enumerator current = null;

        Token enumLiteral_0=null;
        Token enumLiteral_1=null;
        Token enumLiteral_2=null;
        Token enumLiteral_3=null;
        Token enumLiteral_4=null;
        Token enumLiteral_5=null;


        	enterRule();

        try {
            // InternalTableDSL.g:11213:2: ( ( (enumLiteral_0= 'equal' ) | (enumLiteral_1= 'greater equal' ) | (enumLiteral_2= 'greater than' ) | (enumLiteral_3= 'lower equal' ) | (enumLiteral_4= 'lower than' ) | (enumLiteral_5= 'not equal' ) ) )
            // InternalTableDSL.g:11214:2: ( (enumLiteral_0= 'equal' ) | (enumLiteral_1= 'greater equal' ) | (enumLiteral_2= 'greater than' ) | (enumLiteral_3= 'lower equal' ) | (enumLiteral_4= 'lower than' ) | (enumLiteral_5= 'not equal' ) )
            {
            // InternalTableDSL.g:11214:2: ( (enumLiteral_0= 'equal' ) | (enumLiteral_1= 'greater equal' ) | (enumLiteral_2= 'greater than' ) | (enumLiteral_3= 'lower equal' ) | (enumLiteral_4= 'lower than' ) | (enumLiteral_5= 'not equal' ) )
            int alt167=6;
            switch ( input.LA(1) ) {
            case 163:
                {
                alt167=1;
                }
                break;
            case 164:
                {
                alt167=2;
                }
                break;
            case 165:
                {
                alt167=3;
                }
                break;
            case 166:
                {
                alt167=4;
                }
                break;
            case 167:
                {
                alt167=5;
                }
                break;
            case 168:
                {
                alt167=6;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 167, 0, input);

                throw nvae;
            }

            switch (alt167) {
                case 1 :
                    // InternalTableDSL.g:11215:3: (enumLiteral_0= 'equal' )
                    {
                    // InternalTableDSL.g:11215:3: (enumLiteral_0= 'equal' )
                    // InternalTableDSL.g:11216:4: enumLiteral_0= 'equal'
                    {
                    enumLiteral_0=(Token)match(input,163,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getStyleCompareAccess().getEqualEnumLiteralDeclaration_0().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_0, grammarAccess.getStyleCompareAccess().getEqualEnumLiteralDeclaration_0());
                      			
                    }

                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:11223:3: (enumLiteral_1= 'greater equal' )
                    {
                    // InternalTableDSL.g:11223:3: (enumLiteral_1= 'greater equal' )
                    // InternalTableDSL.g:11224:4: enumLiteral_1= 'greater equal'
                    {
                    enumLiteral_1=(Token)match(input,164,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getStyleCompareAccess().getGreaterEqualEnumLiteralDeclaration_1().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_1, grammarAccess.getStyleCompareAccess().getGreaterEqualEnumLiteralDeclaration_1());
                      			
                    }

                    }


                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:11231:3: (enumLiteral_2= 'greater than' )
                    {
                    // InternalTableDSL.g:11231:3: (enumLiteral_2= 'greater than' )
                    // InternalTableDSL.g:11232:4: enumLiteral_2= 'greater than'
                    {
                    enumLiteral_2=(Token)match(input,165,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getStyleCompareAccess().getGreaterThanEnumLiteralDeclaration_2().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_2, grammarAccess.getStyleCompareAccess().getGreaterThanEnumLiteralDeclaration_2());
                      			
                    }

                    }


                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:11239:3: (enumLiteral_3= 'lower equal' )
                    {
                    // InternalTableDSL.g:11239:3: (enumLiteral_3= 'lower equal' )
                    // InternalTableDSL.g:11240:4: enumLiteral_3= 'lower equal'
                    {
                    enumLiteral_3=(Token)match(input,166,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getStyleCompareAccess().getLowerEqualEnumLiteralDeclaration_3().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_3, grammarAccess.getStyleCompareAccess().getLowerEqualEnumLiteralDeclaration_3());
                      			
                    }

                    }


                    }
                    break;
                case 5 :
                    // InternalTableDSL.g:11247:3: (enumLiteral_4= 'lower than' )
                    {
                    // InternalTableDSL.g:11247:3: (enumLiteral_4= 'lower than' )
                    // InternalTableDSL.g:11248:4: enumLiteral_4= 'lower than'
                    {
                    enumLiteral_4=(Token)match(input,167,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getStyleCompareAccess().getLowerThanEnumLiteralDeclaration_4().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_4, grammarAccess.getStyleCompareAccess().getLowerThanEnumLiteralDeclaration_4());
                      			
                    }

                    }


                    }
                    break;
                case 6 :
                    // InternalTableDSL.g:11255:3: (enumLiteral_5= 'not equal' )
                    {
                    // InternalTableDSL.g:11255:3: (enumLiteral_5= 'not equal' )
                    // InternalTableDSL.g:11256:4: enumLiteral_5= 'not equal'
                    {
                    enumLiteral_5=(Token)match(input,168,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getStyleCompareAccess().getNotEqualEnumLiteralDeclaration_5().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_5, grammarAccess.getStyleCompareAccess().getNotEqualEnumLiteralDeclaration_5());
                      			
                    }

                    }


                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleStyleCompare"


    // $ANTLR start "ruleTrendIconEnum"
    // InternalTableDSL.g:11266:1: ruleTrendIconEnum returns [Enumerator current=null] : ( (enumLiteral_0= 'rising' ) | (enumLiteral_1= 'bad-rising' ) | (enumLiteral_2= 'sloping' ) | (enumLiteral_3= 'good-sloping' ) | (enumLiteral_4= 'stagnating' ) ) ;
    public final Enumerator ruleTrendIconEnum() throws RecognitionException {
        Enumerator current = null;

        Token enumLiteral_0=null;
        Token enumLiteral_1=null;
        Token enumLiteral_2=null;
        Token enumLiteral_3=null;
        Token enumLiteral_4=null;


        	enterRule();

        try {
            // InternalTableDSL.g:11272:2: ( ( (enumLiteral_0= 'rising' ) | (enumLiteral_1= 'bad-rising' ) | (enumLiteral_2= 'sloping' ) | (enumLiteral_3= 'good-sloping' ) | (enumLiteral_4= 'stagnating' ) ) )
            // InternalTableDSL.g:11273:2: ( (enumLiteral_0= 'rising' ) | (enumLiteral_1= 'bad-rising' ) | (enumLiteral_2= 'sloping' ) | (enumLiteral_3= 'good-sloping' ) | (enumLiteral_4= 'stagnating' ) )
            {
            // InternalTableDSL.g:11273:2: ( (enumLiteral_0= 'rising' ) | (enumLiteral_1= 'bad-rising' ) | (enumLiteral_2= 'sloping' ) | (enumLiteral_3= 'good-sloping' ) | (enumLiteral_4= 'stagnating' ) )
            int alt168=5;
            switch ( input.LA(1) ) {
            case 169:
                {
                alt168=1;
                }
                break;
            case 170:
                {
                alt168=2;
                }
                break;
            case 171:
                {
                alt168=3;
                }
                break;
            case 172:
                {
                alt168=4;
                }
                break;
            case 173:
                {
                alt168=5;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 168, 0, input);

                throw nvae;
            }

            switch (alt168) {
                case 1 :
                    // InternalTableDSL.g:11274:3: (enumLiteral_0= 'rising' )
                    {
                    // InternalTableDSL.g:11274:3: (enumLiteral_0= 'rising' )
                    // InternalTableDSL.g:11275:4: enumLiteral_0= 'rising'
                    {
                    enumLiteral_0=(Token)match(input,169,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getTrendIconEnumAccess().getRISINGEnumLiteralDeclaration_0().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_0, grammarAccess.getTrendIconEnumAccess().getRISINGEnumLiteralDeclaration_0());
                      			
                    }

                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:11282:3: (enumLiteral_1= 'bad-rising' )
                    {
                    // InternalTableDSL.g:11282:3: (enumLiteral_1= 'bad-rising' )
                    // InternalTableDSL.g:11283:4: enumLiteral_1= 'bad-rising'
                    {
                    enumLiteral_1=(Token)match(input,170,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getTrendIconEnumAccess().getBADRISINGEnumLiteralDeclaration_1().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_1, grammarAccess.getTrendIconEnumAccess().getBADRISINGEnumLiteralDeclaration_1());
                      			
                    }

                    }


                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:11290:3: (enumLiteral_2= 'sloping' )
                    {
                    // InternalTableDSL.g:11290:3: (enumLiteral_2= 'sloping' )
                    // InternalTableDSL.g:11291:4: enumLiteral_2= 'sloping'
                    {
                    enumLiteral_2=(Token)match(input,171,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getTrendIconEnumAccess().getSLOPINGEnumLiteralDeclaration_2().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_2, grammarAccess.getTrendIconEnumAccess().getSLOPINGEnumLiteralDeclaration_2());
                      			
                    }

                    }


                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:11298:3: (enumLiteral_3= 'good-sloping' )
                    {
                    // InternalTableDSL.g:11298:3: (enumLiteral_3= 'good-sloping' )
                    // InternalTableDSL.g:11299:4: enumLiteral_3= 'good-sloping'
                    {
                    enumLiteral_3=(Token)match(input,172,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getTrendIconEnumAccess().getGOODSLOPINGEnumLiteralDeclaration_3().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_3, grammarAccess.getTrendIconEnumAccess().getGOODSLOPINGEnumLiteralDeclaration_3());
                      			
                    }

                    }


                    }
                    break;
                case 5 :
                    // InternalTableDSL.g:11306:3: (enumLiteral_4= 'stagnating' )
                    {
                    // InternalTableDSL.g:11306:3: (enumLiteral_4= 'stagnating' )
                    // InternalTableDSL.g:11307:4: enumLiteral_4= 'stagnating'
                    {
                    enumLiteral_4=(Token)match(input,173,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getTrendIconEnumAccess().getSTAGNATINGEnumLiteralDeclaration_4().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_4, grammarAccess.getTrendIconEnumAccess().getSTAGNATINGEnumLiteralDeclaration_4());
                      			
                    }

                    }


                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleTrendIconEnum"


    // $ANTLR start "ruleRowHeaderMode"
    // InternalTableDSL.g:11317:1: ruleRowHeaderMode returns [Enumerator current=null] : ( (enumLiteral_0= 'hidden' ) | (enumLiteral_1= 'explicit' ) | (enumLiteral_2= 'indexed' ) ) ;
    public final Enumerator ruleRowHeaderMode() throws RecognitionException {
        Enumerator current = null;

        Token enumLiteral_0=null;
        Token enumLiteral_1=null;
        Token enumLiteral_2=null;


        	enterRule();

        try {
            // InternalTableDSL.g:11323:2: ( ( (enumLiteral_0= 'hidden' ) | (enumLiteral_1= 'explicit' ) | (enumLiteral_2= 'indexed' ) ) )
            // InternalTableDSL.g:11324:2: ( (enumLiteral_0= 'hidden' ) | (enumLiteral_1= 'explicit' ) | (enumLiteral_2= 'indexed' ) )
            {
            // InternalTableDSL.g:11324:2: ( (enumLiteral_0= 'hidden' ) | (enumLiteral_1= 'explicit' ) | (enumLiteral_2= 'indexed' ) )
            int alt169=3;
            switch ( input.LA(1) ) {
            case 174:
                {
                alt169=1;
                }
                break;
            case 175:
                {
                alt169=2;
                }
                break;
            case 176:
                {
                alt169=3;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 169, 0, input);

                throw nvae;
            }

            switch (alt169) {
                case 1 :
                    // InternalTableDSL.g:11325:3: (enumLiteral_0= 'hidden' )
                    {
                    // InternalTableDSL.g:11325:3: (enumLiteral_0= 'hidden' )
                    // InternalTableDSL.g:11326:4: enumLiteral_0= 'hidden'
                    {
                    enumLiteral_0=(Token)match(input,174,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getRowHeaderModeAccess().getHIDDENEnumLiteralDeclaration_0().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_0, grammarAccess.getRowHeaderModeAccess().getHIDDENEnumLiteralDeclaration_0());
                      			
                    }

                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:11333:3: (enumLiteral_1= 'explicit' )
                    {
                    // InternalTableDSL.g:11333:3: (enumLiteral_1= 'explicit' )
                    // InternalTableDSL.g:11334:4: enumLiteral_1= 'explicit'
                    {
                    enumLiteral_1=(Token)match(input,175,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getRowHeaderModeAccess().getEXPLICIT_DEFAULTS_IDEnumLiteralDeclaration_1().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_1, grammarAccess.getRowHeaderModeAccess().getEXPLICIT_DEFAULTS_IDEnumLiteralDeclaration_1());
                      			
                    }

                    }


                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:11341:3: (enumLiteral_2= 'indexed' )
                    {
                    // InternalTableDSL.g:11341:3: (enumLiteral_2= 'indexed' )
                    // InternalTableDSL.g:11342:4: enumLiteral_2= 'indexed'
                    {
                    enumLiteral_2=(Token)match(input,176,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getRowHeaderModeAccess().getINDEXEnumLiteralDeclaration_2().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_2, grammarAccess.getRowHeaderModeAccess().getINDEXEnumLiteralDeclaration_2());
                      			
                    }

                    }


                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleRowHeaderMode"


    // $ANTLR start "ruleAxisEnum"
    // InternalTableDSL.g:11352:1: ruleAxisEnum returns [Enumerator current=null] : ( (enumLiteral_0= 'default' ) | (enumLiteral_1= 'columns' ) | (enumLiteral_2= 'rows' ) | (enumLiteral_3= 'pages' ) | (enumLiteral_4= 'sections' ) | (enumLiteral_5= 'chapters' ) ) ;
    public final Enumerator ruleAxisEnum() throws RecognitionException {
        Enumerator current = null;

        Token enumLiteral_0=null;
        Token enumLiteral_1=null;
        Token enumLiteral_2=null;
        Token enumLiteral_3=null;
        Token enumLiteral_4=null;
        Token enumLiteral_5=null;


        	enterRule();

        try {
            // InternalTableDSL.g:11358:2: ( ( (enumLiteral_0= 'default' ) | (enumLiteral_1= 'columns' ) | (enumLiteral_2= 'rows' ) | (enumLiteral_3= 'pages' ) | (enumLiteral_4= 'sections' ) | (enumLiteral_5= 'chapters' ) ) )
            // InternalTableDSL.g:11359:2: ( (enumLiteral_0= 'default' ) | (enumLiteral_1= 'columns' ) | (enumLiteral_2= 'rows' ) | (enumLiteral_3= 'pages' ) | (enumLiteral_4= 'sections' ) | (enumLiteral_5= 'chapters' ) )
            {
            // InternalTableDSL.g:11359:2: ( (enumLiteral_0= 'default' ) | (enumLiteral_1= 'columns' ) | (enumLiteral_2= 'rows' ) | (enumLiteral_3= 'pages' ) | (enumLiteral_4= 'sections' ) | (enumLiteral_5= 'chapters' ) )
            int alt170=6;
            switch ( input.LA(1) ) {
            case 141:
                {
                alt170=1;
                }
                break;
            case 177:
                {
                alt170=2;
                }
                break;
            case 178:
                {
                alt170=3;
                }
                break;
            case 179:
                {
                alt170=4;
                }
                break;
            case 180:
                {
                alt170=5;
                }
                break;
            case 181:
                {
                alt170=6;
                }
                break;
            default:
                if (state.backtracking>0) {state.failed=true; return current;}
                NoViableAltException nvae =
                    new NoViableAltException("", 170, 0, input);

                throw nvae;
            }

            switch (alt170) {
                case 1 :
                    // InternalTableDSL.g:11360:3: (enumLiteral_0= 'default' )
                    {
                    // InternalTableDSL.g:11360:3: (enumLiteral_0= 'default' )
                    // InternalTableDSL.g:11361:4: enumLiteral_0= 'default'
                    {
                    enumLiteral_0=(Token)match(input,141,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getAxisEnumAccess().getDEFAULTEnumLiteralDeclaration_0().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_0, grammarAccess.getAxisEnumAccess().getDEFAULTEnumLiteralDeclaration_0());
                      			
                    }

                    }


                    }
                    break;
                case 2 :
                    // InternalTableDSL.g:11368:3: (enumLiteral_1= 'columns' )
                    {
                    // InternalTableDSL.g:11368:3: (enumLiteral_1= 'columns' )
                    // InternalTableDSL.g:11369:4: enumLiteral_1= 'columns'
                    {
                    enumLiteral_1=(Token)match(input,177,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getAxisEnumAccess().getCOLUMNSEnumLiteralDeclaration_1().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_1, grammarAccess.getAxisEnumAccess().getCOLUMNSEnumLiteralDeclaration_1());
                      			
                    }

                    }


                    }
                    break;
                case 3 :
                    // InternalTableDSL.g:11376:3: (enumLiteral_2= 'rows' )
                    {
                    // InternalTableDSL.g:11376:3: (enumLiteral_2= 'rows' )
                    // InternalTableDSL.g:11377:4: enumLiteral_2= 'rows'
                    {
                    enumLiteral_2=(Token)match(input,178,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getAxisEnumAccess().getROWSEnumLiteralDeclaration_2().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_2, grammarAccess.getAxisEnumAccess().getROWSEnumLiteralDeclaration_2());
                      			
                    }

                    }


                    }
                    break;
                case 4 :
                    // InternalTableDSL.g:11384:3: (enumLiteral_3= 'pages' )
                    {
                    // InternalTableDSL.g:11384:3: (enumLiteral_3= 'pages' )
                    // InternalTableDSL.g:11385:4: enumLiteral_3= 'pages'
                    {
                    enumLiteral_3=(Token)match(input,179,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getAxisEnumAccess().getPAGESEnumLiteralDeclaration_3().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_3, grammarAccess.getAxisEnumAccess().getPAGESEnumLiteralDeclaration_3());
                      			
                    }

                    }


                    }
                    break;
                case 5 :
                    // InternalTableDSL.g:11392:3: (enumLiteral_4= 'sections' )
                    {
                    // InternalTableDSL.g:11392:3: (enumLiteral_4= 'sections' )
                    // InternalTableDSL.g:11393:4: enumLiteral_4= 'sections'
                    {
                    enumLiteral_4=(Token)match(input,180,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getAxisEnumAccess().getSECTIONSEnumLiteralDeclaration_4().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_4, grammarAccess.getAxisEnumAccess().getSECTIONSEnumLiteralDeclaration_4());
                      			
                    }

                    }


                    }
                    break;
                case 6 :
                    // InternalTableDSL.g:11400:3: (enumLiteral_5= 'chapters' )
                    {
                    // InternalTableDSL.g:11400:3: (enumLiteral_5= 'chapters' )
                    // InternalTableDSL.g:11401:4: enumLiteral_5= 'chapters'
                    {
                    enumLiteral_5=(Token)match(input,181,FOLLOW_2); if (state.failed) return current;
                    if ( state.backtracking==0 ) {

                      				current = grammarAccess.getAxisEnumAccess().getCHAPTERSEnumLiteralDeclaration_5().getEnumLiteral().getInstance();
                      				newLeafNode(enumLiteral_5, grammarAccess.getAxisEnumAccess().getCHAPTERSEnumLiteralDeclaration_5());
                      			
                    }

                    }


                    }
                    break;

            }


            }

            if ( state.backtracking==0 ) {

              	leaveRule();

            }
        }

            catch (RecognitionException re) {
                recover(input,re);
                appendSkippedTokens();
            }
        finally {
        }
        return current;
    }
    // $ANTLR end "ruleAxisEnum"

    // $ANTLR start synpred1_InternalTableDSL
    public final void synpred1_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:4583:5: ( '(' )
        // InternalTableDSL.g:4583:6: '('
        {
        match(input,100,FOLLOW_2); if (state.failed) return ;

        }
    }
    // $ANTLR end synpred1_InternalTableDSL

    // $ANTLR start synpred2_InternalTableDSL
    public final void synpred2_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:4592:7: ( ( ( ( ruleValidID ) ) '=' ) )
        // InternalTableDSL.g:4592:8: ( ( ( ruleValidID ) ) '=' )
        {
        // InternalTableDSL.g:4592:8: ( ( ( ruleValidID ) ) '=' )
        // InternalTableDSL.g:4593:8: ( ( ruleValidID ) ) '='
        {
        // InternalTableDSL.g:4593:8: ( ( ruleValidID ) )
        // InternalTableDSL.g:4594:9: ( ruleValidID )
        {
        // InternalTableDSL.g:4594:9: ( ruleValidID )
        // InternalTableDSL.g:4595:10: ruleValidID
        {
        pushFollow(FOLLOW_64);
        ruleValidID();

        state._fsp--;
        if (state.failed) return ;

        }


        }

        match(input,103,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred2_InternalTableDSL

    // $ANTLR start synpred5_InternalTableDSL
    public final void synpred5_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:4772:5: ( ( () '#' '[' ) )
        // InternalTableDSL.g:4772:6: ( () '#' '[' )
        {
        // InternalTableDSL.g:4772:6: ( () '#' '[' )
        // InternalTableDSL.g:4773:6: () '#' '['
        {
        // InternalTableDSL.g:4773:6: ()
        // InternalTableDSL.g:4774:6: 
        {
        }

        match(input,104,FOLLOW_66); if (state.failed) return ;
        match(input,105,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred5_InternalTableDSL

    // $ANTLR start synpred6_InternalTableDSL
    public final void synpred6_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:4914:5: ( ( () '#' '[' ) )
        // InternalTableDSL.g:4914:6: ( () '#' '[' )
        {
        // InternalTableDSL.g:4914:6: ( () '#' '[' )
        // InternalTableDSL.g:4915:6: () '#' '['
        {
        // InternalTableDSL.g:4915:6: ()
        // InternalTableDSL.g:4916:6: 
        {
        }

        match(input,104,FOLLOW_66); if (state.failed) return ;
        match(input,105,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred6_InternalTableDSL

    // $ANTLR start synpred7_InternalTableDSL
    public final void synpred7_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:5142:6: ( ( () ( ( ruleOpMultiAssign ) ) ) )
        // InternalTableDSL.g:5142:7: ( () ( ( ruleOpMultiAssign ) ) )
        {
        // InternalTableDSL.g:5142:7: ( () ( ( ruleOpMultiAssign ) ) )
        // InternalTableDSL.g:5143:7: () ( ( ruleOpMultiAssign ) )
        {
        // InternalTableDSL.g:5143:7: ()
        // InternalTableDSL.g:5144:7: 
        {
        }

        // InternalTableDSL.g:5145:7: ( ( ruleOpMultiAssign ) )
        // InternalTableDSL.g:5146:8: ( ruleOpMultiAssign )
        {
        // InternalTableDSL.g:5146:8: ( ruleOpMultiAssign )
        // InternalTableDSL.g:5147:9: ruleOpMultiAssign
        {
        pushFollow(FOLLOW_2);
        ruleOpMultiAssign();

        state._fsp--;
        if (state.failed) return ;

        }


        }


        }


        }
    }
    // $ANTLR end synpred7_InternalTableDSL

    // $ANTLR start synpred8_InternalTableDSL
    public final void synpred8_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:5336:5: ( ( () ( ( ruleOpOr ) ) ) )
        // InternalTableDSL.g:5336:6: ( () ( ( ruleOpOr ) ) )
        {
        // InternalTableDSL.g:5336:6: ( () ( ( ruleOpOr ) ) )
        // InternalTableDSL.g:5337:6: () ( ( ruleOpOr ) )
        {
        // InternalTableDSL.g:5337:6: ()
        // InternalTableDSL.g:5338:6: 
        {
        }

        // InternalTableDSL.g:5339:6: ( ( ruleOpOr ) )
        // InternalTableDSL.g:5340:7: ( ruleOpOr )
        {
        // InternalTableDSL.g:5340:7: ( ruleOpOr )
        // InternalTableDSL.g:5341:8: ruleOpOr
        {
        pushFollow(FOLLOW_2);
        ruleOpOr();

        state._fsp--;
        if (state.failed) return ;

        }


        }


        }


        }
    }
    // $ANTLR end synpred8_InternalTableDSL

    // $ANTLR start synpred9_InternalTableDSL
    public final void synpred9_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:5443:5: ( ( () ( ( ruleOpAnd ) ) ) )
        // InternalTableDSL.g:5443:6: ( () ( ( ruleOpAnd ) ) )
        {
        // InternalTableDSL.g:5443:6: ( () ( ( ruleOpAnd ) ) )
        // InternalTableDSL.g:5444:6: () ( ( ruleOpAnd ) )
        {
        // InternalTableDSL.g:5444:6: ()
        // InternalTableDSL.g:5445:6: 
        {
        }

        // InternalTableDSL.g:5446:6: ( ( ruleOpAnd ) )
        // InternalTableDSL.g:5447:7: ( ruleOpAnd )
        {
        // InternalTableDSL.g:5447:7: ( ruleOpAnd )
        // InternalTableDSL.g:5448:8: ruleOpAnd
        {
        pushFollow(FOLLOW_2);
        ruleOpAnd();

        state._fsp--;
        if (state.failed) return ;

        }


        }


        }


        }
    }
    // $ANTLR end synpred9_InternalTableDSL

    // $ANTLR start synpred10_InternalTableDSL
    public final void synpred10_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:5550:5: ( ( () ( ( ruleOpEquality ) ) ) )
        // InternalTableDSL.g:5550:6: ( () ( ( ruleOpEquality ) ) )
        {
        // InternalTableDSL.g:5550:6: ( () ( ( ruleOpEquality ) ) )
        // InternalTableDSL.g:5551:6: () ( ( ruleOpEquality ) )
        {
        // InternalTableDSL.g:5551:6: ()
        // InternalTableDSL.g:5552:6: 
        {
        }

        // InternalTableDSL.g:5553:6: ( ( ruleOpEquality ) )
        // InternalTableDSL.g:5554:7: ( ruleOpEquality )
        {
        // InternalTableDSL.g:5554:7: ( ruleOpEquality )
        // InternalTableDSL.g:5555:8: ruleOpEquality
        {
        pushFollow(FOLLOW_2);
        ruleOpEquality();

        state._fsp--;
        if (state.failed) return ;

        }


        }


        }


        }
    }
    // $ANTLR end synpred10_InternalTableDSL

    // $ANTLR start synpred11_InternalTableDSL
    public final void synpred11_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:5678:6: ( ( () 'instanceof' ) )
        // InternalTableDSL.g:5678:7: ( () 'instanceof' )
        {
        // InternalTableDSL.g:5678:7: ( () 'instanceof' )
        // InternalTableDSL.g:5679:7: () 'instanceof'
        {
        // InternalTableDSL.g:5679:7: ()
        // InternalTableDSL.g:5680:7: 
        {
        }

        match(input,121,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred11_InternalTableDSL

    // $ANTLR start synpred12_InternalTableDSL
    public final void synpred12_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:5721:6: ( ( () ( ( ruleOpCompare ) ) ) )
        // InternalTableDSL.g:5721:7: ( () ( ( ruleOpCompare ) ) )
        {
        // InternalTableDSL.g:5721:7: ( () ( ( ruleOpCompare ) ) )
        // InternalTableDSL.g:5722:7: () ( ( ruleOpCompare ) )
        {
        // InternalTableDSL.g:5722:7: ()
        // InternalTableDSL.g:5723:7: 
        {
        }

        // InternalTableDSL.g:5724:7: ( ( ruleOpCompare ) )
        // InternalTableDSL.g:5725:8: ( ruleOpCompare )
        {
        // InternalTableDSL.g:5725:8: ( ruleOpCompare )
        // InternalTableDSL.g:5726:9: ruleOpCompare
        {
        pushFollow(FOLLOW_2);
        ruleOpCompare();

        state._fsp--;
        if (state.failed) return ;

        }


        }


        }


        }
    }
    // $ANTLR end synpred12_InternalTableDSL

    // $ANTLR start synpred13_InternalTableDSL
    public final void synpred13_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:5856:5: ( ( () ( ( ruleOpOther ) ) ) )
        // InternalTableDSL.g:5856:6: ( () ( ( ruleOpOther ) ) )
        {
        // InternalTableDSL.g:5856:6: ( () ( ( ruleOpOther ) ) )
        // InternalTableDSL.g:5857:6: () ( ( ruleOpOther ) )
        {
        // InternalTableDSL.g:5857:6: ()
        // InternalTableDSL.g:5858:6: 
        {
        }

        // InternalTableDSL.g:5859:6: ( ( ruleOpOther ) )
        // InternalTableDSL.g:5860:7: ( ruleOpOther )
        {
        // InternalTableDSL.g:5860:7: ( ruleOpOther )
        // InternalTableDSL.g:5861:8: ruleOpOther
        {
        pushFollow(FOLLOW_2);
        ruleOpOther();

        state._fsp--;
        if (state.failed) return ;

        }


        }


        }


        }
    }
    // $ANTLR end synpred13_InternalTableDSL

    // $ANTLR start synpred14_InternalTableDSL
    public final void synpred14_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:5976:6: ( ( '>' '>' ) )
        // InternalTableDSL.g:5976:7: ( '>' '>' )
        {
        // InternalTableDSL.g:5976:7: ( '>' '>' )
        // InternalTableDSL.g:5977:7: '>' '>'
        {
        match(input,113,FOLLOW_81); if (state.failed) return ;
        match(input,113,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred14_InternalTableDSL

    // $ANTLR start synpred15_InternalTableDSL
    public final void synpred15_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:6011:6: ( ( '<' '<' ) )
        // InternalTableDSL.g:6011:7: ( '<' '<' )
        {
        // InternalTableDSL.g:6011:7: ( '<' '<' )
        // InternalTableDSL.g:6012:7: '<' '<'
        {
        match(input,112,FOLLOW_71); if (state.failed) return ;
        match(input,112,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred15_InternalTableDSL

    // $ANTLR start synpred16_InternalTableDSL
    public final void synpred16_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:6084:5: ( ( () ( ( ruleOpAdd ) ) ) )
        // InternalTableDSL.g:6084:6: ( () ( ( ruleOpAdd ) ) )
        {
        // InternalTableDSL.g:6084:6: ( () ( ( ruleOpAdd ) ) )
        // InternalTableDSL.g:6085:6: () ( ( ruleOpAdd ) )
        {
        // InternalTableDSL.g:6085:6: ()
        // InternalTableDSL.g:6086:6: 
        {
        }

        // InternalTableDSL.g:6087:6: ( ( ruleOpAdd ) )
        // InternalTableDSL.g:6088:7: ( ruleOpAdd )
        {
        // InternalTableDSL.g:6088:7: ( ruleOpAdd )
        // InternalTableDSL.g:6089:8: ruleOpAdd
        {
        pushFollow(FOLLOW_2);
        ruleOpAdd();

        state._fsp--;
        if (state.failed) return ;

        }


        }


        }


        }
    }
    // $ANTLR end synpred16_InternalTableDSL

    // $ANTLR start synpred17_InternalTableDSL
    public final void synpred17_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:6199:5: ( ( () ( ( ruleOpMulti ) ) ) )
        // InternalTableDSL.g:6199:6: ( () ( ( ruleOpMulti ) ) )
        {
        // InternalTableDSL.g:6199:6: ( () ( ( ruleOpMulti ) ) )
        // InternalTableDSL.g:6200:6: () ( ( ruleOpMulti ) )
        {
        // InternalTableDSL.g:6200:6: ()
        // InternalTableDSL.g:6201:6: 
        {
        }

        // InternalTableDSL.g:6202:6: ( ( ruleOpMulti ) )
        // InternalTableDSL.g:6203:7: ( ruleOpMulti )
        {
        // InternalTableDSL.g:6203:7: ( ruleOpMulti )
        // InternalTableDSL.g:6204:8: ruleOpMulti
        {
        pushFollow(FOLLOW_2);
        ruleOpMulti();

        state._fsp--;
        if (state.failed) return ;

        }


        }


        }


        }
    }
    // $ANTLR end synpred17_InternalTableDSL

    // $ANTLR start synpred18_InternalTableDSL
    public final void synpred18_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:6434:5: ( ( () 'as' ) )
        // InternalTableDSL.g:6434:6: ( () 'as' )
        {
        // InternalTableDSL.g:6434:6: ( () 'as' )
        // InternalTableDSL.g:6435:6: () 'as'
        {
        // InternalTableDSL.g:6435:6: ()
        // InternalTableDSL.g:6436:6: 
        {
        }

        match(input,20,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred18_InternalTableDSL

    // $ANTLR start synpred19_InternalTableDSL
    public final void synpred19_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:6502:4: ( ( () ( ( ruleOpPostfix ) ) ) )
        // InternalTableDSL.g:6502:5: ( () ( ( ruleOpPostfix ) ) )
        {
        // InternalTableDSL.g:6502:5: ( () ( ( ruleOpPostfix ) ) )
        // InternalTableDSL.g:6503:5: () ( ( ruleOpPostfix ) )
        {
        // InternalTableDSL.g:6503:5: ()
        // InternalTableDSL.g:6504:5: 
        {
        }

        // InternalTableDSL.g:6505:5: ( ( ruleOpPostfix ) )
        // InternalTableDSL.g:6506:6: ( ruleOpPostfix )
        {
        // InternalTableDSL.g:6506:6: ( ruleOpPostfix )
        // InternalTableDSL.g:6507:7: ruleOpPostfix
        {
        pushFollow(FOLLOW_2);
        ruleOpPostfix();

        state._fsp--;
        if (state.failed) return ;

        }


        }


        }


        }
    }
    // $ANTLR end synpred19_InternalTableDSL

    // $ANTLR start synpred20_InternalTableDSL
    public final void synpred20_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:6598:6: ( ( () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign ) )
        // InternalTableDSL.g:6598:7: ( () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign )
        {
        // InternalTableDSL.g:6598:7: ( () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign )
        // InternalTableDSL.g:6599:7: () ( '.' | ( ( '::' ) ) ) ( ( ruleFeatureCallID ) ) ruleOpSingleAssign
        {
        // InternalTableDSL.g:6599:7: ()
        // InternalTableDSL.g:6600:7: 
        {
        }

        // InternalTableDSL.g:6601:7: ( '.' | ( ( '::' ) ) )
        int alt171=2;
        int LA171_0 = input.LA(1);

        if ( (LA171_0==74) ) {
            alt171=1;
        }
        else if ( (LA171_0==134) ) {
            alt171=2;
        }
        else {
            if (state.backtracking>0) {state.failed=true; return ;}
            NoViableAltException nvae =
                new NoViableAltException("", 171, 0, input);

            throw nvae;
        }
        switch (alt171) {
            case 1 :
                // InternalTableDSL.g:6602:8: '.'
                {
                match(input,74,FOLLOW_88); if (state.failed) return ;

                }
                break;
            case 2 :
                // InternalTableDSL.g:6604:8: ( ( '::' ) )
                {
                // InternalTableDSL.g:6604:8: ( ( '::' ) )
                // InternalTableDSL.g:6605:9: ( '::' )
                {
                // InternalTableDSL.g:6605:9: ( '::' )
                // InternalTableDSL.g:6606:10: '::'
                {
                match(input,134,FOLLOW_88); if (state.failed) return ;

                }


                }


                }
                break;

        }

        // InternalTableDSL.g:6610:7: ( ( ruleFeatureCallID ) )
        // InternalTableDSL.g:6611:8: ( ruleFeatureCallID )
        {
        // InternalTableDSL.g:6611:8: ( ruleFeatureCallID )
        // InternalTableDSL.g:6612:9: ruleFeatureCallID
        {
        pushFollow(FOLLOW_64);
        ruleFeatureCallID();

        state._fsp--;
        if (state.failed) return ;

        }


        }

        pushFollow(FOLLOW_2);
        ruleOpSingleAssign();

        state._fsp--;
        if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred20_InternalTableDSL

    // $ANTLR start synpred21_InternalTableDSL
    public final void synpred21_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:6695:6: ( ( () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) ) ) )
        // InternalTableDSL.g:6695:7: ( () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) ) )
        {
        // InternalTableDSL.g:6695:7: ( () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) ) )
        // InternalTableDSL.g:6696:7: () ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) )
        {
        // InternalTableDSL.g:6696:7: ()
        // InternalTableDSL.g:6697:7: 
        {
        }

        // InternalTableDSL.g:6698:7: ( '.' | ( ( '?.' ) ) | ( ( '::' ) ) )
        int alt172=3;
        switch ( input.LA(1) ) {
        case 74:
            {
            alt172=1;
            }
            break;
        case 135:
            {
            alt172=2;
            }
            break;
        case 134:
            {
            alt172=3;
            }
            break;
        default:
            if (state.backtracking>0) {state.failed=true; return ;}
            NoViableAltException nvae =
                new NoViableAltException("", 172, 0, input);

            throw nvae;
        }

        switch (alt172) {
            case 1 :
                // InternalTableDSL.g:6699:8: '.'
                {
                match(input,74,FOLLOW_2); if (state.failed) return ;

                }
                break;
            case 2 :
                // InternalTableDSL.g:6701:8: ( ( '?.' ) )
                {
                // InternalTableDSL.g:6701:8: ( ( '?.' ) )
                // InternalTableDSL.g:6702:9: ( '?.' )
                {
                // InternalTableDSL.g:6702:9: ( '?.' )
                // InternalTableDSL.g:6703:10: '?.'
                {
                match(input,135,FOLLOW_2); if (state.failed) return ;

                }


                }


                }
                break;
            case 3 :
                // InternalTableDSL.g:6707:8: ( ( '::' ) )
                {
                // InternalTableDSL.g:6707:8: ( ( '::' ) )
                // InternalTableDSL.g:6708:9: ( '::' )
                {
                // InternalTableDSL.g:6708:9: ( '::' )
                // InternalTableDSL.g:6709:10: '::'
                {
                match(input,134,FOLLOW_2); if (state.failed) return ;

                }


                }


                }
                break;

        }


        }


        }
    }
    // $ANTLR end synpred21_InternalTableDSL

    // $ANTLR start synpred22_InternalTableDSL
    public final void synpred22_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:6833:7: ( ( '(' ) )
        // InternalTableDSL.g:6833:8: ( '(' )
        {
        // InternalTableDSL.g:6833:8: ( '(' )
        // InternalTableDSL.g:6834:8: '('
        {
        match(input,100,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred22_InternalTableDSL

    // $ANTLR start synpred23_InternalTableDSL
    public final void synpred23_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:6852:8: ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )
        // InternalTableDSL.g:6852:9: ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) )
        {
        // InternalTableDSL.g:6852:9: ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) )
        // InternalTableDSL.g:6853:9: () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) )
        {
        // InternalTableDSL.g:6853:9: ()
        // InternalTableDSL.g:6854:9: 
        {
        }

        // InternalTableDSL.g:6855:9: ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )?
        int alt174=2;
        int LA174_0 = input.LA(1);

        if ( (LA174_0==RULE_ID||LA174_0==100||LA174_0==125) ) {
            alt174=1;
        }
        switch (alt174) {
            case 1 :
                // InternalTableDSL.g:6856:10: ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )*
                {
                // InternalTableDSL.g:6856:10: ( ( ruleJvmFormalParameter ) )
                // InternalTableDSL.g:6857:11: ( ruleJvmFormalParameter )
                {
                // InternalTableDSL.g:6857:11: ( ruleJvmFormalParameter )
                // InternalTableDSL.g:6858:12: ruleJvmFormalParameter
                {
                pushFollow(FOLLOW_98);
                ruleJvmFormalParameter();

                state._fsp--;
                if (state.failed) return ;

                }


                }

                // InternalTableDSL.g:6861:10: ( ',' ( ( ruleJvmFormalParameter ) ) )*
                loop173:
                do {
                    int alt173=2;
                    int LA173_0 = input.LA(1);

                    if ( (LA173_0==101) ) {
                        alt173=1;
                    }


                    switch (alt173) {
                	case 1 :
                	    // InternalTableDSL.g:6862:11: ',' ( ( ruleJvmFormalParameter ) )
                	    {
                	    match(input,101,FOLLOW_78); if (state.failed) return ;
                	    // InternalTableDSL.g:6863:11: ( ( ruleJvmFormalParameter ) )
                	    // InternalTableDSL.g:6864:12: ( ruleJvmFormalParameter )
                	    {
                	    // InternalTableDSL.g:6864:12: ( ruleJvmFormalParameter )
                	    // InternalTableDSL.g:6865:13: ruleJvmFormalParameter
                	    {
                	    pushFollow(FOLLOW_98);
                	    ruleJvmFormalParameter();

                	    state._fsp--;
                	    if (state.failed) return ;

                	    }


                	    }


                	    }
                	    break;

                	default :
                	    break loop173;
                    }
                } while (true);


                }
                break;

        }

        // InternalTableDSL.g:6870:9: ( ( '|' ) )
        // InternalTableDSL.g:6871:10: ( '|' )
        {
        // InternalTableDSL.g:6871:10: ( '|' )
        // InternalTableDSL.g:6872:11: '|'
        {
        match(input,136,FOLLOW_2); if (state.failed) return ;

        }


        }


        }


        }
    }
    // $ANTLR end synpred23_InternalTableDSL

    // $ANTLR start synpred24_InternalTableDSL
    public final void synpred24_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:6949:6: ( ( () '[' ) )
        // InternalTableDSL.g:6949:7: ( () '[' )
        {
        // InternalTableDSL.g:6949:7: ( () '[' )
        // InternalTableDSL.g:6950:7: () '['
        {
        // InternalTableDSL.g:6950:7: ()
        // InternalTableDSL.g:6951:7: 
        {
        }

        match(input,105,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred24_InternalTableDSL

    // $ANTLR start synpred25_InternalTableDSL
    public final void synpred25_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:7022:4: ( ( () 'synchronized' '(' ) )
        // InternalTableDSL.g:7022:5: ( () 'synchronized' '(' )
        {
        // InternalTableDSL.g:7022:5: ( () 'synchronized' '(' )
        // InternalTableDSL.g:7023:5: () 'synchronized' '('
        {
        // InternalTableDSL.g:7023:5: ()
        // InternalTableDSL.g:7024:5: 
        {
        }

        match(input,159,FOLLOW_103); if (state.failed) return ;
        match(input,100,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred25_InternalTableDSL

    // $ANTLR start synpred26_InternalTableDSL
    public final void synpred26_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:7067:4: ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )
        // InternalTableDSL.g:7067:5: ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' )
        {
        // InternalTableDSL.g:7067:5: ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' )
        // InternalTableDSL.g:7068:5: () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':'
        {
        // InternalTableDSL.g:7068:5: ()
        // InternalTableDSL.g:7069:5: 
        {
        }

        match(input,143,FOLLOW_103); if (state.failed) return ;
        match(input,100,FOLLOW_78); if (state.failed) return ;
        // InternalTableDSL.g:7072:5: ( ( ruleJvmFormalParameter ) )
        // InternalTableDSL.g:7073:6: ( ruleJvmFormalParameter )
        {
        // InternalTableDSL.g:7073:6: ( ruleJvmFormalParameter )
        // InternalTableDSL.g:7074:7: ruleJvmFormalParameter
        {
        pushFollow(FOLLOW_106);
        ruleJvmFormalParameter();

        state._fsp--;
        if (state.failed) return ;

        }


        }

        match(input,140,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred26_InternalTableDSL

    // $ANTLR start synpred27_InternalTableDSL
    public final void synpred27_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:7181:4: ( ( () '[' ) )
        // InternalTableDSL.g:7181:5: ( () '[' )
        {
        // InternalTableDSL.g:7181:5: ( () '[' )
        // InternalTableDSL.g:7182:5: () '['
        {
        // InternalTableDSL.g:7182:5: ()
        // InternalTableDSL.g:7183:5: 
        {
        }

        match(input,105,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred27_InternalTableDSL

    // $ANTLR start synpred29_InternalTableDSL
    public final void synpred29_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:7486:4: ( ( ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )
        // InternalTableDSL.g:7486:5: ( ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) )
        {
        // InternalTableDSL.g:7486:5: ( ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) )
        // InternalTableDSL.g:7487:5: ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) )
        {
        // InternalTableDSL.g:7487:5: ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )?
        int alt176=2;
        int LA176_0 = input.LA(1);

        if ( (LA176_0==RULE_ID||LA176_0==100||LA176_0==125) ) {
            alt176=1;
        }
        switch (alt176) {
            case 1 :
                // InternalTableDSL.g:7488:6: ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )*
                {
                // InternalTableDSL.g:7488:6: ( ( ruleJvmFormalParameter ) )
                // InternalTableDSL.g:7489:7: ( ruleJvmFormalParameter )
                {
                // InternalTableDSL.g:7489:7: ( ruleJvmFormalParameter )
                // InternalTableDSL.g:7490:8: ruleJvmFormalParameter
                {
                pushFollow(FOLLOW_98);
                ruleJvmFormalParameter();

                state._fsp--;
                if (state.failed) return ;

                }


                }

                // InternalTableDSL.g:7493:6: ( ',' ( ( ruleJvmFormalParameter ) ) )*
                loop175:
                do {
                    int alt175=2;
                    int LA175_0 = input.LA(1);

                    if ( (LA175_0==101) ) {
                        alt175=1;
                    }


                    switch (alt175) {
                	case 1 :
                	    // InternalTableDSL.g:7494:7: ',' ( ( ruleJvmFormalParameter ) )
                	    {
                	    match(input,101,FOLLOW_78); if (state.failed) return ;
                	    // InternalTableDSL.g:7495:7: ( ( ruleJvmFormalParameter ) )
                	    // InternalTableDSL.g:7496:8: ( ruleJvmFormalParameter )
                	    {
                	    // InternalTableDSL.g:7496:8: ( ruleJvmFormalParameter )
                	    // InternalTableDSL.g:7497:9: ruleJvmFormalParameter
                	    {
                	    pushFollow(FOLLOW_98);
                	    ruleJvmFormalParameter();

                	    state._fsp--;
                	    if (state.failed) return ;

                	    }


                	    }


                	    }
                	    break;

                	default :
                	    break loop175;
                    }
                } while (true);


                }
                break;

        }

        // InternalTableDSL.g:7502:5: ( ( '|' ) )
        // InternalTableDSL.g:7503:6: ( '|' )
        {
        // InternalTableDSL.g:7503:6: ( '|' )
        // InternalTableDSL.g:7504:7: '|'
        {
        match(input,136,FOLLOW_2); if (state.failed) return ;

        }


        }


        }


        }
    }
    // $ANTLR end synpred29_InternalTableDSL

    // $ANTLR start synpred31_InternalTableDSL
    public final void synpred31_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:7895:5: ( 'else' )
        // InternalTableDSL.g:7895:6: 'else'
        {
        match(input,138,FOLLOW_2); if (state.failed) return ;

        }
    }
    // $ANTLR end synpred31_InternalTableDSL

    // $ANTLR start synpred32_InternalTableDSL
    public final void synpred32_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:7954:6: ( ( '(' ( ( ruleJvmFormalParameter ) ) ':' ) )
        // InternalTableDSL.g:7954:7: ( '(' ( ( ruleJvmFormalParameter ) ) ':' )
        {
        // InternalTableDSL.g:7954:7: ( '(' ( ( ruleJvmFormalParameter ) ) ':' )
        // InternalTableDSL.g:7955:7: '(' ( ( ruleJvmFormalParameter ) ) ':'
        {
        match(input,100,FOLLOW_78); if (state.failed) return ;
        // InternalTableDSL.g:7956:7: ( ( ruleJvmFormalParameter ) )
        // InternalTableDSL.g:7957:8: ( ruleJvmFormalParameter )
        {
        // InternalTableDSL.g:7957:8: ( ruleJvmFormalParameter )
        // InternalTableDSL.g:7958:9: ruleJvmFormalParameter
        {
        pushFollow(FOLLOW_106);
        ruleJvmFormalParameter();

        state._fsp--;
        if (state.failed) return ;

        }


        }

        match(input,140,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred32_InternalTableDSL

    // $ANTLR start synpred33_InternalTableDSL
    public final void synpred33_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:8021:6: ( ( ( ( ruleJvmFormalParameter ) ) ':' ) )
        // InternalTableDSL.g:8021:7: ( ( ( ruleJvmFormalParameter ) ) ':' )
        {
        // InternalTableDSL.g:8021:7: ( ( ( ruleJvmFormalParameter ) ) ':' )
        // InternalTableDSL.g:8022:7: ( ( ruleJvmFormalParameter ) ) ':'
        {
        // InternalTableDSL.g:8022:7: ( ( ruleJvmFormalParameter ) )
        // InternalTableDSL.g:8023:8: ( ruleJvmFormalParameter )
        {
        // InternalTableDSL.g:8023:8: ( ruleJvmFormalParameter )
        // InternalTableDSL.g:8024:9: ruleJvmFormalParameter
        {
        pushFollow(FOLLOW_106);
        ruleJvmFormalParameter();

        state._fsp--;
        if (state.failed) return ;

        }


        }

        match(input,140,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred33_InternalTableDSL

    // $ANTLR start synpred35_InternalTableDSL
    public final void synpred35_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:8839:5: ( ( ( ( ruleJvmTypeReference ) ) ( ( ruleValidID ) ) ) )
        // InternalTableDSL.g:8839:6: ( ( ( ruleJvmTypeReference ) ) ( ( ruleValidID ) ) )
        {
        // InternalTableDSL.g:8839:6: ( ( ( ruleJvmTypeReference ) ) ( ( ruleValidID ) ) )
        // InternalTableDSL.g:8840:6: ( ( ruleJvmTypeReference ) ) ( ( ruleValidID ) )
        {
        // InternalTableDSL.g:8840:6: ( ( ruleJvmTypeReference ) )
        // InternalTableDSL.g:8841:7: ( ruleJvmTypeReference )
        {
        // InternalTableDSL.g:8841:7: ( ruleJvmTypeReference )
        // InternalTableDSL.g:8842:8: ruleJvmTypeReference
        {
        pushFollow(FOLLOW_4);
        ruleJvmTypeReference();

        state._fsp--;
        if (state.failed) return ;

        }


        }

        // InternalTableDSL.g:8845:6: ( ( ruleValidID ) )
        // InternalTableDSL.g:8846:7: ( ruleValidID )
        {
        // InternalTableDSL.g:8846:7: ( ruleValidID )
        // InternalTableDSL.g:8847:8: ruleValidID
        {
        pushFollow(FOLLOW_2);
        ruleValidID();

        state._fsp--;
        if (state.failed) return ;

        }


        }


        }


        }
    }
    // $ANTLR end synpred35_InternalTableDSL

    // $ANTLR start synpred36_InternalTableDSL
    public final void synpred36_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:9151:5: ( ( '(' ) )
        // InternalTableDSL.g:9151:6: ( '(' )
        {
        // InternalTableDSL.g:9151:6: ( '(' )
        // InternalTableDSL.g:9152:6: '('
        {
        match(input,100,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred36_InternalTableDSL

    // $ANTLR start synpred37_InternalTableDSL
    public final void synpred37_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:9170:6: ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )
        // InternalTableDSL.g:9170:7: ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) )
        {
        // InternalTableDSL.g:9170:7: ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) )
        // InternalTableDSL.g:9171:7: () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) )
        {
        // InternalTableDSL.g:9171:7: ()
        // InternalTableDSL.g:9172:7: 
        {
        }

        // InternalTableDSL.g:9173:7: ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )?
        int alt180=2;
        int LA180_0 = input.LA(1);

        if ( (LA180_0==RULE_ID||LA180_0==100||LA180_0==125) ) {
            alt180=1;
        }
        switch (alt180) {
            case 1 :
                // InternalTableDSL.g:9174:8: ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )*
                {
                // InternalTableDSL.g:9174:8: ( ( ruleJvmFormalParameter ) )
                // InternalTableDSL.g:9175:9: ( ruleJvmFormalParameter )
                {
                // InternalTableDSL.g:9175:9: ( ruleJvmFormalParameter )
                // InternalTableDSL.g:9176:10: ruleJvmFormalParameter
                {
                pushFollow(FOLLOW_98);
                ruleJvmFormalParameter();

                state._fsp--;
                if (state.failed) return ;

                }


                }

                // InternalTableDSL.g:9179:8: ( ',' ( ( ruleJvmFormalParameter ) ) )*
                loop179:
                do {
                    int alt179=2;
                    int LA179_0 = input.LA(1);

                    if ( (LA179_0==101) ) {
                        alt179=1;
                    }


                    switch (alt179) {
                	case 1 :
                	    // InternalTableDSL.g:9180:9: ',' ( ( ruleJvmFormalParameter ) )
                	    {
                	    match(input,101,FOLLOW_78); if (state.failed) return ;
                	    // InternalTableDSL.g:9181:9: ( ( ruleJvmFormalParameter ) )
                	    // InternalTableDSL.g:9182:10: ( ruleJvmFormalParameter )
                	    {
                	    // InternalTableDSL.g:9182:10: ( ruleJvmFormalParameter )
                	    // InternalTableDSL.g:9183:11: ruleJvmFormalParameter
                	    {
                	    pushFollow(FOLLOW_98);
                	    ruleJvmFormalParameter();

                	    state._fsp--;
                	    if (state.failed) return ;

                	    }


                	    }


                	    }
                	    break;

                	default :
                	    break loop179;
                    }
                } while (true);


                }
                break;

        }

        // InternalTableDSL.g:9188:7: ( ( '|' ) )
        // InternalTableDSL.g:9189:8: ( '|' )
        {
        // InternalTableDSL.g:9189:8: ( '|' )
        // InternalTableDSL.g:9190:9: '|'
        {
        match(input,136,FOLLOW_2); if (state.failed) return ;

        }


        }


        }


        }
    }
    // $ANTLR end synpred37_InternalTableDSL

    // $ANTLR start synpred38_InternalTableDSL
    public final void synpred38_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:9267:4: ( ( () '[' ) )
        // InternalTableDSL.g:9267:5: ( () '[' )
        {
        // InternalTableDSL.g:9267:5: ( () '[' )
        // InternalTableDSL.g:9268:5: () '['
        {
        // InternalTableDSL.g:9268:5: ()
        // InternalTableDSL.g:9269:5: 
        {
        }

        match(input,105,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred38_InternalTableDSL

    // $ANTLR start synpred39_InternalTableDSL
    public final void synpred39_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:9427:5: ( '<' )
        // InternalTableDSL.g:9427:6: '<'
        {
        match(input,112,FOLLOW_2); if (state.failed) return ;

        }
    }
    // $ANTLR end synpred39_InternalTableDSL

    // $ANTLR start synpred40_InternalTableDSL
    public final void synpred40_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:9484:5: ( ( '(' ) )
        // InternalTableDSL.g:9484:6: ( '(' )
        {
        // InternalTableDSL.g:9484:6: ( '(' )
        // InternalTableDSL.g:9485:6: '('
        {
        match(input,100,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred40_InternalTableDSL

    // $ANTLR start synpred41_InternalTableDSL
    public final void synpred41_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:9503:6: ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )
        // InternalTableDSL.g:9503:7: ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) )
        {
        // InternalTableDSL.g:9503:7: ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) )
        // InternalTableDSL.g:9504:7: () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) )
        {
        // InternalTableDSL.g:9504:7: ()
        // InternalTableDSL.g:9505:7: 
        {
        }

        // InternalTableDSL.g:9506:7: ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )?
        int alt182=2;
        int LA182_0 = input.LA(1);

        if ( (LA182_0==RULE_ID||LA182_0==100||LA182_0==125) ) {
            alt182=1;
        }
        switch (alt182) {
            case 1 :
                // InternalTableDSL.g:9507:8: ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )*
                {
                // InternalTableDSL.g:9507:8: ( ( ruleJvmFormalParameter ) )
                // InternalTableDSL.g:9508:9: ( ruleJvmFormalParameter )
                {
                // InternalTableDSL.g:9508:9: ( ruleJvmFormalParameter )
                // InternalTableDSL.g:9509:10: ruleJvmFormalParameter
                {
                pushFollow(FOLLOW_98);
                ruleJvmFormalParameter();

                state._fsp--;
                if (state.failed) return ;

                }


                }

                // InternalTableDSL.g:9512:8: ( ',' ( ( ruleJvmFormalParameter ) ) )*
                loop181:
                do {
                    int alt181=2;
                    int LA181_0 = input.LA(1);

                    if ( (LA181_0==101) ) {
                        alt181=1;
                    }


                    switch (alt181) {
                	case 1 :
                	    // InternalTableDSL.g:9513:9: ',' ( ( ruleJvmFormalParameter ) )
                	    {
                	    match(input,101,FOLLOW_78); if (state.failed) return ;
                	    // InternalTableDSL.g:9514:9: ( ( ruleJvmFormalParameter ) )
                	    // InternalTableDSL.g:9515:10: ( ruleJvmFormalParameter )
                	    {
                	    // InternalTableDSL.g:9515:10: ( ruleJvmFormalParameter )
                	    // InternalTableDSL.g:9516:11: ruleJvmFormalParameter
                	    {
                	    pushFollow(FOLLOW_98);
                	    ruleJvmFormalParameter();

                	    state._fsp--;
                	    if (state.failed) return ;

                	    }


                	    }


                	    }
                	    break;

                	default :
                	    break loop181;
                    }
                } while (true);


                }
                break;

        }

        // InternalTableDSL.g:9521:7: ( ( '|' ) )
        // InternalTableDSL.g:9522:8: ( '|' )
        {
        // InternalTableDSL.g:9522:8: ( '|' )
        // InternalTableDSL.g:9523:9: '|'
        {
        match(input,136,FOLLOW_2); if (state.failed) return ;

        }


        }


        }


        }
    }
    // $ANTLR end synpred41_InternalTableDSL

    // $ANTLR start synpred42_InternalTableDSL
    public final void synpred42_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:9600:4: ( ( () '[' ) )
        // InternalTableDSL.g:9600:5: ( () '[' )
        {
        // InternalTableDSL.g:9600:5: ( () '[' )
        // InternalTableDSL.g:9601:5: () '['
        {
        // InternalTableDSL.g:9601:5: ()
        // InternalTableDSL.g:9602:5: 
        {
        }

        match(input,105,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred42_InternalTableDSL

    // $ANTLR start synpred43_InternalTableDSL
    public final void synpred43_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:9943:4: ( 'extends' | 'static' | 'import' | 'extension' | '!' | '-' | '+' | 'new' | '{' | 'switch' | 'synchronized' | '<' | 'super' | '#' | '[' | 'false' | 'true' | 'null' | 'typeof' | 'if' | 'for' | 'while' | 'do' | 'throw' | 'return' | 'try' | '(' | RULE_ID | RULE_HEX | RULE_INT | RULE_DECIMAL | RULE_STRING )
        // InternalTableDSL.g:
        {
        if ( (input.LA(1)>=RULE_ID && input.LA(1)<=RULE_STRING)||(input.LA(1)>=RULE_INT && input.LA(1)<=RULE_DECIMAL)||input.LA(1)==16||(input.LA(1)>=91 && input.LA(1)<=95)||input.LA(1)==100||(input.LA(1)>=104 && input.LA(1)<=105)||input.LA(1)==112||input.LA(1)==131||input.LA(1)==137||input.LA(1)==139||(input.LA(1)>=143 && input.LA(1)<=145)||(input.LA(1)>=148 && input.LA(1)<=157)||input.LA(1)==159 ) {
            input.consume();
            state.errorRecovery=false;state.failed=false;
        }
        else {
            if (state.backtracking>0) {state.failed=true; return ;}
            MismatchedSetException mse = new MismatchedSetException(null,input);
            throw mse;
        }


        }
    }
    // $ANTLR end synpred43_InternalTableDSL

    // $ANTLR start synpred44_InternalTableDSL
    public final void synpred44_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:10014:6: ( 'catch' )
        // InternalTableDSL.g:10014:7: 'catch'
        {
        match(input,160,FOLLOW_2); if (state.failed) return ;

        }
    }
    // $ANTLR end synpred44_InternalTableDSL

    // $ANTLR start synpred45_InternalTableDSL
    public final void synpred45_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:10035:7: ( 'finally' )
        // InternalTableDSL.g:10035:8: 'finally'
        {
        match(input,158,FOLLOW_2); if (state.failed) return ;

        }
    }
    // $ANTLR end synpred45_InternalTableDSL

    // $ANTLR start synpred48_InternalTableDSL
    public final void synpred48_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:10279:5: ( '.' )
        // InternalTableDSL.g:10279:6: '.'
        {
        match(input,74,FOLLOW_2); if (state.failed) return ;

        }
    }
    // $ANTLR end synpred48_InternalTableDSL

    // $ANTLR start synpred49_InternalTableDSL
    public final void synpred49_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:10405:5: ( ( () ruleArrayBrackets ) )
        // InternalTableDSL.g:10405:6: ( () ruleArrayBrackets )
        {
        // InternalTableDSL.g:10405:6: ( () ruleArrayBrackets )
        // InternalTableDSL.g:10406:6: () ruleArrayBrackets
        {
        // InternalTableDSL.g:10406:6: ()
        // InternalTableDSL.g:10407:6: 
        {
        }

        pushFollow(FOLLOW_2);
        ruleArrayBrackets();

        state._fsp--;
        if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred49_InternalTableDSL

    // $ANTLR start synpred50_InternalTableDSL
    public final void synpred50_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:10602:5: ( '<' )
        // InternalTableDSL.g:10602:6: '<'
        {
        match(input,112,FOLLOW_2); if (state.failed) return ;

        }
    }
    // $ANTLR end synpred50_InternalTableDSL

    // $ANTLR start synpred51_InternalTableDSL
    public final void synpred51_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:10658:6: ( ( () '.' ) )
        // InternalTableDSL.g:10658:7: ( () '.' )
        {
        // InternalTableDSL.g:10658:7: ( () '.' )
        // InternalTableDSL.g:10659:7: () '.'
        {
        // InternalTableDSL.g:10659:7: ()
        // InternalTableDSL.g:10660:7: 
        {
        }

        match(input,74,FOLLOW_2); if (state.failed) return ;

        }


        }
    }
    // $ANTLR end synpred51_InternalTableDSL

    // $ANTLR start synpred52_InternalTableDSL
    public final void synpred52_InternalTableDSL_fragment() throws RecognitionException {   
        // InternalTableDSL.g:10696:7: ( '<' )
        // InternalTableDSL.g:10696:8: '<'
        {
        match(input,112,FOLLOW_2); if (state.failed) return ;

        }
    }
    // $ANTLR end synpred52_InternalTableDSL

    // Delegated rules

    public final boolean synpred48_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred48_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred18_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred18_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred13_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred13_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred43_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred43_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred14_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred14_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred27_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred27_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred8_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred8_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred19_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred19_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred49_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred49_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred51_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred51_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred2_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred2_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred21_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred21_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred36_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred36_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred9_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred9_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred12_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred12_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred15_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred15_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred42_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred42_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred33_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred33_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred1_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred1_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred37_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred37_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred5_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred5_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred20_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred20_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred50_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred50_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred11_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred11_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred29_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred29_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred24_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred24_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred41_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred41_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred16_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred16_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred38_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred38_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred40_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred40_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred45_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred45_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred25_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred25_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred32_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred32_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred6_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred6_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred17_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred17_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred23_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred23_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred31_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred31_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred10_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred10_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred44_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred44_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred7_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred7_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred26_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred26_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred52_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred52_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred39_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred39_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred22_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred22_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }
    public final boolean synpred35_InternalTableDSL() {
        state.backtracking++;
        int start = input.mark();
        try {
            synpred35_InternalTableDSL_fragment(); // can never throw exception
        } catch (RecognitionException re) {
            System.err.println("impossible: "+re);
        }
        boolean success = !state.failed;
        input.rewind(start);
        state.backtracking--;
        state.failed=false;
        return success;
    }


    protected DFA46 dfa46 = new DFA46(this);
    protected DFA49 dfa49 = new DFA49(this);
    protected DFA55 dfa55 = new DFA55(this);
    protected DFA58 dfa58 = new DFA58(this);
    protected DFA60 dfa60 = new DFA60(this);
    protected DFA70 dfa70 = new DFA70(this);
    protected DFA73 dfa73 = new DFA73(this);
    protected DFA89 dfa89 = new DFA89(this);
    protected DFA88 dfa88 = new DFA88(this);
    protected DFA90 dfa90 = new DFA90(this);
    protected DFA92 dfa92 = new DFA92(this);
    protected DFA101 dfa101 = new DFA101(this);
    protected DFA108 dfa108 = new DFA108(this);
    protected DFA107 dfa107 = new DFA107(this);
    protected DFA130 dfa130 = new DFA130(this);
    protected DFA129 dfa129 = new DFA129(this);
    protected DFA131 dfa131 = new DFA131(this);
    protected DFA135 dfa135 = new DFA135(this);
    protected DFA138 dfa138 = new DFA138(this);
    protected DFA137 dfa137 = new DFA137(this);
    protected DFA139 dfa139 = new DFA139(this);
    protected DFA142 dfa142 = new DFA142(this);
    protected DFA160 dfa160 = new DFA160(this);
    protected DFA158 dfa158 = new DFA158(this);
    static final String dfa_1s = "\10\uffff";
    static final String dfa_2s = "\2\uffff\1\5\4\uffff\1\5";
    static final String dfa_3s = "\1\4\1\uffff\1\17\1\uffff\1\4\2\uffff\1\17";
    static final String dfa_4s = "\1\141\1\uffff\1\142\1\uffff\1\140\2\uffff\1\142";
    static final String dfa_5s = "\1\uffff\1\1\1\uffff\1\4\1\uffff\1\2\1\3\1\uffff";
    static final String dfa_6s = "\10\uffff}>";
    static final String[] dfa_7s = {
            "\1\2\131\uffff\1\1\2\uffff\1\3",
            "",
            "\1\5\72\uffff\1\4\22\uffff\1\5\4\uffff\1\5",
            "",
            "\1\7\133\uffff\1\6",
            "",
            "",
            "\1\5\72\uffff\1\4\22\uffff\1\5\4\uffff\1\5"
    };

    static final short[] dfa_1 = DFA.unpackEncodedString(dfa_1s);
    static final short[] dfa_2 = DFA.unpackEncodedString(dfa_2s);
    static final char[] dfa_3 = DFA.unpackEncodedStringToUnsignedChars(dfa_3s);
    static final char[] dfa_4 = DFA.unpackEncodedStringToUnsignedChars(dfa_4s);
    static final short[] dfa_5 = DFA.unpackEncodedString(dfa_5s);
    static final short[] dfa_6 = DFA.unpackEncodedString(dfa_6s);
    static final short[][] dfa_7 = unpackEncodedStringArray(dfa_7s);

    class DFA46 extends DFA {

        public DFA46(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 46;
            this.eot = dfa_1;
            this.eof = dfa_2;
            this.min = dfa_3;
            this.max = dfa_4;
            this.accept = dfa_5;
            this.special = dfa_6;
            this.transition = dfa_7;
        }
        public String getDescription() {
            return "4372:3: ( ( ( (lv_static_2_0= 'static' ) ) ( (lv_extension_3_0= 'extension' ) )? ( ( ruleQualifiedNameInStaticImport ) ) ( ( (lv_wildcard_5_0= '*' ) ) | ( (lv_memberName_6_0= ruleValidID ) ) ) ) | ( ( ruleQualifiedName ) ) | ( (lv_importedNamespace_8_0= ruleQualifiedNameWithWildcard ) ) | ( ( (lv_fqnImport_9_0= 'ns' ) ) ( (lv_importedFullyQualifiedName_10_0= ruleQualifiedName ) ) ) )";
        }
    }
    static final String dfa_8s = "\44\uffff";
    static final String dfa_9s = "\1\4\1\0\42\uffff";
    static final String dfa_10s = "\1\u009f\1\0\42\uffff";
    static final String dfa_11s = "\2\uffff\1\2\37\uffff\1\3\1\1";
    static final String dfa_12s = "\1\uffff\1\0\42\uffff}>";
    static final String[] dfa_13s = {
            "\1\1\1\2\1\uffff\3\2\6\uffff\1\2\112\uffff\5\2\3\uffff\2\2\1\uffff\1\42\1\uffff\2\2\6\uffff\1\2\22\uffff\1\2\5\uffff\1\2\1\uffff\1\2\3\uffff\3\2\2\uffff\12\2\1\uffff\1\2",
            "\1\uffff",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            ""
    };

    static final short[] dfa_8 = DFA.unpackEncodedString(dfa_8s);
    static final char[] dfa_9 = DFA.unpackEncodedStringToUnsignedChars(dfa_9s);
    static final char[] dfa_10 = DFA.unpackEncodedStringToUnsignedChars(dfa_10s);
    static final short[] dfa_11 = DFA.unpackEncodedString(dfa_11s);
    static final short[] dfa_12 = DFA.unpackEncodedString(dfa_12s);
    static final short[][] dfa_13 = unpackEncodedStringArray(dfa_13s);

    class DFA49 extends DFA {

        public DFA49(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 49;
            this.eot = dfa_8;
            this.eof = dfa_8;
            this.min = dfa_9;
            this.max = dfa_10;
            this.accept = dfa_11;
            this.special = dfa_12;
            this.transition = dfa_13;
        }
        public String getDescription() {
            return "4589:4: ( ( ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_4_0= ruleXAnnotationElementValuePair ) ) (otherlv_5= ',' ( ( ( ( ( ruleValidID ) ) '=' ) )=> (lv_elementValuePairs_6_0= ruleXAnnotationElementValuePair ) ) )* ) | ( (lv_value_7_0= ruleXAnnotationElementValueOrCommaList ) ) )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA49_1 = input.LA(1);

                         
                        int index49_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred2_InternalTableDSL()) ) {s = 35;}

                        else if ( (true) ) {s = 2;}

                         
                        input.seek(index49_1);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 49, _s, input);
            error(nvae);
            throw nvae;
        }
    }
    static final String dfa_14s = "\43\uffff";
    static final String dfa_15s = "\1\4\1\0\41\uffff";
    static final String dfa_16s = "\1\u009f\1\0\41\uffff";
    static final String dfa_17s = "\2\uffff\1\2\37\uffff\1\1";
    static final String dfa_18s = "\1\uffff\1\0\41\uffff}>";
    static final String[] dfa_19s = {
            "\2\2\1\uffff\3\2\6\uffff\1\2\112\uffff\5\2\3\uffff\2\2\3\uffff\1\1\1\2\6\uffff\1\2\22\uffff\1\2\5\uffff\1\2\1\uffff\1\2\3\uffff\3\2\2\uffff\12\2\1\uffff\1\2",
            "\1\uffff",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            ""
    };

    static final short[] dfa_14 = DFA.unpackEncodedString(dfa_14s);
    static final char[] dfa_15 = DFA.unpackEncodedStringToUnsignedChars(dfa_15s);
    static final char[] dfa_16 = DFA.unpackEncodedStringToUnsignedChars(dfa_16s);
    static final short[] dfa_17 = DFA.unpackEncodedString(dfa_17s);
    static final short[] dfa_18 = DFA.unpackEncodedString(dfa_18s);
    static final short[][] dfa_19 = unpackEncodedStringArray(dfa_19s);

    class DFA55 extends DFA {

        public DFA55(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 55;
            this.eot = dfa_14;
            this.eof = dfa_14;
            this.min = dfa_15;
            this.max = dfa_16;
            this.accept = dfa_17;
            this.special = dfa_18;
            this.transition = dfa_19;
        }
        public String getDescription() {
            return "4769:2: ( ( ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']' ) | (this_XAnnotationOrExpression_7= ruleXAnnotationOrExpression ( () (otherlv_9= ',' ( (lv_elements_10_0= ruleXAnnotationOrExpression ) ) )+ )? ) )";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA55_1 = input.LA(1);

                         
                        int index55_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred5_InternalTableDSL()) ) {s = 34;}

                        else if ( (true) ) {s = 2;}

                         
                        input.seek(index55_1);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 55, _s, input);
            error(nvae);
            throw nvae;
        }
    }

    class DFA58 extends DFA {

        public DFA58(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 58;
            this.eot = dfa_14;
            this.eof = dfa_14;
            this.min = dfa_15;
            this.max = dfa_16;
            this.accept = dfa_17;
            this.special = dfa_18;
            this.transition = dfa_19;
        }
        public String getDescription() {
            return "4911:2: ( ( ( ( ( () '#' '[' ) )=> ( () otherlv_1= '#' otherlv_2= '[' ) ) ( ( (lv_elements_3_0= ruleXAnnotationOrExpression ) ) (otherlv_4= ',' ( (lv_elements_5_0= ruleXAnnotationOrExpression ) ) )* )? otherlv_6= ']' ) | this_XAnnotationOrExpression_7= ruleXAnnotationOrExpression )";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA58_1 = input.LA(1);

                         
                        int index58_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred6_InternalTableDSL()) ) {s = 34;}

                        else if ( (true) ) {s = 2;}

                         
                        input.seek(index58_1);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 58, _s, input);
            error(nvae);
            throw nvae;
        }
    }
    static final String dfa_20s = "\12\uffff";
    static final String dfa_21s = "\1\10\11\uffff";
    static final String dfa_22s = "\1\4\7\0\2\uffff";
    static final String dfa_23s = "\1\u00a0\7\0\2\uffff";
    static final String dfa_24s = "\10\uffff\1\2\1\1";
    static final String dfa_25s = "\1\uffff\1\1\1\2\1\3\1\4\1\5\1\0\1\6\2\uffff}>";
    static final String[] dfa_26s = {
            "\2\10\1\uffff\3\10\6\uffff\2\10\2\uffff\1\10\65\uffff\1\10\20\uffff\6\10\1\uffff\1\10\1\uffff\3\10\1\uffff\3\10\1\1\1\2\1\3\1\4\1\5\1\6\1\7\26\10\1\uffff\30\10",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "",
            ""
    };

    static final short[] dfa_20 = DFA.unpackEncodedString(dfa_20s);
    static final short[] dfa_21 = DFA.unpackEncodedString(dfa_21s);
    static final char[] dfa_22 = DFA.unpackEncodedStringToUnsignedChars(dfa_22s);
    static final char[] dfa_23 = DFA.unpackEncodedStringToUnsignedChars(dfa_23s);
    static final short[] dfa_24 = DFA.unpackEncodedString(dfa_24s);
    static final short[] dfa_25 = DFA.unpackEncodedString(dfa_25s);
    static final short[][] dfa_26 = unpackEncodedStringArray(dfa_26s);

    class DFA60 extends DFA {

        public DFA60(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 60;
            this.eot = dfa_20;
            this.eof = dfa_21;
            this.min = dfa_22;
            this.max = dfa_23;
            this.accept = dfa_24;
            this.special = dfa_25;
            this.transition = dfa_26;
        }
        public String getDescription() {
            return "5140:4: ( ( ( ( () ( ( ruleOpMultiAssign ) ) ) )=> ( () ( ( ruleOpMultiAssign ) ) ) ) ( (lv_rightOperand_7_0= ruleXAssignment ) ) )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA60_6 = input.LA(1);

                         
                        int index60_6 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred7_InternalTableDSL()) ) {s = 9;}

                        else if ( (true) ) {s = 8;}

                         
                        input.seek(index60_6);
                        if ( s>=0 ) return s;
                        break;
                    case 1 : 
                        int LA60_1 = input.LA(1);

                         
                        int index60_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred7_InternalTableDSL()) ) {s = 9;}

                        else if ( (true) ) {s = 8;}

                         
                        input.seek(index60_1);
                        if ( s>=0 ) return s;
                        break;
                    case 2 : 
                        int LA60_2 = input.LA(1);

                         
                        int index60_2 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred7_InternalTableDSL()) ) {s = 9;}

                        else if ( (true) ) {s = 8;}

                         
                        input.seek(index60_2);
                        if ( s>=0 ) return s;
                        break;
                    case 3 : 
                        int LA60_3 = input.LA(1);

                         
                        int index60_3 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred7_InternalTableDSL()) ) {s = 9;}

                        else if ( (true) ) {s = 8;}

                         
                        input.seek(index60_3);
                        if ( s>=0 ) return s;
                        break;
                    case 4 : 
                        int LA60_4 = input.LA(1);

                         
                        int index60_4 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred7_InternalTableDSL()) ) {s = 9;}

                        else if ( (true) ) {s = 8;}

                         
                        input.seek(index60_4);
                        if ( s>=0 ) return s;
                        break;
                    case 5 : 
                        int LA60_5 = input.LA(1);

                         
                        int index60_5 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred7_InternalTableDSL()) ) {s = 9;}

                        else if ( (true) ) {s = 8;}

                         
                        input.seek(index60_5);
                        if ( s>=0 ) return s;
                        break;
                    case 6 : 
                        int LA60_7 = input.LA(1);

                         
                        int index60_7 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred7_InternalTableDSL()) ) {s = 9;}

                        else if ( (true) ) {s = 8;}

                         
                        input.seek(index60_7);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 60, _s, input);
            error(nvae);
            throw nvae;
        }
    }
    static final String dfa_27s = "\13\uffff";
    static final String dfa_28s = "\1\1\12\uffff";
    static final String dfa_29s = "\1\4\1\uffff\10\0\1\uffff";
    static final String dfa_30s = "\1\u00a0\1\uffff\10\0\1\uffff";
    static final String dfa_31s = "\1\uffff\1\2\10\uffff\1\1";
    static final String dfa_32s = "\2\uffff\1\0\1\4\1\2\1\3\1\1\1\5\1\6\1\7\1\uffff}>";
    static final String[] dfa_33s = {
            "\2\1\1\uffff\3\1\6\uffff\2\1\2\uffff\1\1\65\uffff\1\1\20\uffff\6\1\1\uffff\1\1\1\uffff\3\1\1\uffff\10\1\1\2\1\3\10\1\1\4\1\5\1\6\1\7\1\10\1\11\10\1\1\uffff\30\1",
            "",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            ""
    };

    static final short[] dfa_27 = DFA.unpackEncodedString(dfa_27s);
    static final short[] dfa_28 = DFA.unpackEncodedString(dfa_28s);
    static final char[] dfa_29 = DFA.unpackEncodedStringToUnsignedChars(dfa_29s);
    static final char[] dfa_30 = DFA.unpackEncodedStringToUnsignedChars(dfa_30s);
    static final short[] dfa_31 = DFA.unpackEncodedString(dfa_31s);
    static final short[] dfa_32 = DFA.unpackEncodedString(dfa_32s);
    static final short[][] dfa_33 = unpackEncodedStringArray(dfa_33s);

    class DFA70 extends DFA {

        public DFA70(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 70;
            this.eot = dfa_27;
            this.eof = dfa_28;
            this.min = dfa_29;
            this.max = dfa_30;
            this.accept = dfa_31;
            this.special = dfa_32;
            this.transition = dfa_33;
        }
        public String getDescription() {
            return "()* loopback of 5854:3: ( ( ( ( () ( ( ruleOpOther ) ) ) )=> ( () ( ( ruleOpOther ) ) ) ) ( (lv_rightOperand_3_0= ruleXAdditiveExpression ) ) )*";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA70_2 = input.LA(1);

                         
                        int index70_2 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred13_InternalTableDSL()) ) {s = 10;}

                        else if ( (true) ) {s = 1;}

                         
                        input.seek(index70_2);
                        if ( s>=0 ) return s;
                        break;
                    case 1 : 
                        int LA70_6 = input.LA(1);

                         
                        int index70_6 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred13_InternalTableDSL()) ) {s = 10;}

                        else if ( (true) ) {s = 1;}

                         
                        input.seek(index70_6);
                        if ( s>=0 ) return s;
                        break;
                    case 2 : 
                        int LA70_4 = input.LA(1);

                         
                        int index70_4 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred13_InternalTableDSL()) ) {s = 10;}

                        else if ( (true) ) {s = 1;}

                         
                        input.seek(index70_4);
                        if ( s>=0 ) return s;
                        break;
                    case 3 : 
                        int LA70_5 = input.LA(1);

                         
                        int index70_5 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred13_InternalTableDSL()) ) {s = 10;}

                        else if ( (true) ) {s = 1;}

                         
                        input.seek(index70_5);
                        if ( s>=0 ) return s;
                        break;
                    case 4 : 
                        int LA70_3 = input.LA(1);

                         
                        int index70_3 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred13_InternalTableDSL()) ) {s = 10;}

                        else if ( (true) ) {s = 1;}

                         
                        input.seek(index70_3);
                        if ( s>=0 ) return s;
                        break;
                    case 5 : 
                        int LA70_7 = input.LA(1);

                         
                        int index70_7 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred13_InternalTableDSL()) ) {s = 10;}

                        else if ( (true) ) {s = 1;}

                         
                        input.seek(index70_7);
                        if ( s>=0 ) return s;
                        break;
                    case 6 : 
                        int LA70_8 = input.LA(1);

                         
                        int index70_8 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred13_InternalTableDSL()) ) {s = 10;}

                        else if ( (true) ) {s = 1;}

                         
                        input.seek(index70_8);
                        if ( s>=0 ) return s;
                        break;
                    case 7 : 
                        int LA70_9 = input.LA(1);

                         
                        int index70_9 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred13_InternalTableDSL()) ) {s = 10;}

                        else if ( (true) ) {s = 1;}

                         
                        input.seek(index70_9);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 70, _s, input);
            error(nvae);
            throw nvae;
        }
    }
    static final String dfa_34s = "\1\160\2\uffff\1\161\7\uffff";
    static final String dfa_35s = "\1\177\2\uffff\1\174\7\uffff";
    static final String dfa_36s = "\1\uffff\1\1\1\2\1\uffff\1\4\1\5\1\7\1\10\1\11\1\3\1\6";
    static final String dfa_37s = "\13\uffff}>";
    static final String[] dfa_38s = {
            "\1\6\1\3\10\uffff\1\1\1\2\1\4\1\5\1\7\1\10",
            "",
            "",
            "\1\12\12\uffff\1\11",
            "",
            "",
            "",
            "",
            "",
            "",
            ""
    };
    static final char[] dfa_34 = DFA.unpackEncodedStringToUnsignedChars(dfa_34s);
    static final char[] dfa_35 = DFA.unpackEncodedStringToUnsignedChars(dfa_35s);
    static final short[] dfa_36 = DFA.unpackEncodedString(dfa_36s);
    static final short[] dfa_37 = DFA.unpackEncodedString(dfa_37s);
    static final short[][] dfa_38 = unpackEncodedStringArray(dfa_38s);

    class DFA73 extends DFA {

        public DFA73(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 73;
            this.eot = dfa_27;
            this.eof = dfa_27;
            this.min = dfa_34;
            this.max = dfa_35;
            this.accept = dfa_36;
            this.special = dfa_37;
            this.transition = dfa_38;
        }
        public String getDescription() {
            return "5930:2: (kw= '->' | kw= '..<' | (kw= '>' kw= '..' ) | kw= '..' | kw= '=>' | (kw= '>' ( ( ( ( '>' '>' ) )=> (kw= '>' kw= '>' ) ) | kw= '>' ) ) | (kw= '<' ( ( ( ( '<' '<' ) )=> (kw= '<' kw= '<' ) ) | kw= '<' | kw= '=>' ) ) | kw= '<>' | kw= '?:' )";
        }
    }
    static final String dfa_39s = "\116\uffff";
    static final String dfa_40s = "\1\2\115\uffff";
    static final String dfa_41s = "\1\4\1\0\114\uffff";
    static final String dfa_42s = "\1\u00a0\1\0\114\uffff";
    static final String dfa_43s = "\2\uffff\1\2\112\uffff\1\1";
    static final String dfa_44s = "\1\uffff\1\0\114\uffff}>";
    static final String[] dfa_45s = {
            "\2\2\1\uffff\3\2\6\uffff\2\2\2\uffff\1\2\65\uffff\1\2\20\uffff\6\2\1\uffff\1\2\1\uffff\1\1\2\2\1\uffff\40\2\1\uffff\30\2",
            "\1\uffff",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            ""
    };

    static final short[] dfa_39 = DFA.unpackEncodedString(dfa_39s);
    static final short[] dfa_40 = DFA.unpackEncodedString(dfa_40s);
    static final char[] dfa_41 = DFA.unpackEncodedStringToUnsignedChars(dfa_41s);
    static final char[] dfa_42 = DFA.unpackEncodedStringToUnsignedChars(dfa_42s);
    static final short[] dfa_43 = DFA.unpackEncodedString(dfa_43s);
    static final short[] dfa_44 = DFA.unpackEncodedString(dfa_44s);
    static final short[][] dfa_45 = unpackEncodedStringArray(dfa_45s);

    class DFA89 extends DFA {

        public DFA89(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 89;
            this.eot = dfa_39;
            this.eof = dfa_40;
            this.min = dfa_41;
            this.max = dfa_42;
            this.accept = dfa_43;
            this.special = dfa_44;
            this.transition = dfa_45;
        }
        public String getDescription() {
            return "6831:5: ( ( ( ( '(' ) )=> (lv_explicitOperationCall_17_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) ) | ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* ) )? otherlv_22= ')' )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA89_1 = input.LA(1);

                         
                        int index89_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred22_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 2;}

                         
                        input.seek(index89_1);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 89, _s, input);
            error(nvae);
            throw nvae;
        }
    }
    static final String dfa_46s = "\1\4\2\0\41\uffff";
    static final String dfa_47s = "\1\u009f\2\0\41\uffff";
    static final String dfa_48s = "\3\uffff\2\1\1\2\35\uffff\1\3";
    static final String dfa_49s = "\1\0\1\1\1\2\41\uffff}>";
    static final String[] dfa_50s = {
            "\1\1\1\5\1\uffff\3\5\6\uffff\1\5\112\uffff\5\5\4\uffff\1\2\1\uffff\1\43\1\uffff\2\5\6\uffff\1\5\14\uffff\1\3\5\uffff\1\5\4\uffff\1\4\1\5\1\uffff\1\5\3\uffff\3\5\2\uffff\12\5\1\uffff\1\5",
            "\1\uffff",
            "\1\uffff",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            ""
    };
    static final char[] dfa_46 = DFA.unpackEncodedStringToUnsignedChars(dfa_46s);
    static final char[] dfa_47 = DFA.unpackEncodedStringToUnsignedChars(dfa_47s);
    static final short[] dfa_48 = DFA.unpackEncodedString(dfa_48s);
    static final short[] dfa_49 = DFA.unpackEncodedString(dfa_49s);
    static final short[][] dfa_50 = unpackEncodedStringArray(dfa_50s);

    class DFA88 extends DFA {

        public DFA88(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 88;
            this.eot = dfa_8;
            this.eof = dfa_8;
            this.min = dfa_46;
            this.max = dfa_47;
            this.accept = dfa_48;
            this.special = dfa_49;
            this.transition = dfa_50;
        }
        public String getDescription() {
            return "6850:6: ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_memberCallArguments_18_0= ruleXShortClosure ) ) | ( ( (lv_memberCallArguments_19_0= ruleXExpression ) ) (otherlv_20= ',' ( (lv_memberCallArguments_21_0= ruleXExpression ) ) )* ) )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA88_0 = input.LA(1);

                         
                        int index88_0 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (LA88_0==RULE_ID) ) {s = 1;}

                        else if ( (LA88_0==100) ) {s = 2;}

                        else if ( (LA88_0==125) && (synpred23_InternalTableDSL())) {s = 3;}

                        else if ( (LA88_0==136) && (synpred23_InternalTableDSL())) {s = 4;}

                        else if ( (LA88_0==RULE_STRING||(LA88_0>=RULE_INT && LA88_0<=RULE_DECIMAL)||LA88_0==16||(LA88_0>=91 && LA88_0<=95)||(LA88_0>=104 && LA88_0<=105)||LA88_0==112||LA88_0==131||LA88_0==137||LA88_0==139||(LA88_0>=143 && LA88_0<=145)||(LA88_0>=148 && LA88_0<=157)||LA88_0==159) ) {s = 5;}

                        else if ( (LA88_0==102) ) {s = 35;}

                         
                        input.seek(index88_0);
                        if ( s>=0 ) return s;
                        break;
                    case 1 : 
                        int LA88_1 = input.LA(1);

                         
                        int index88_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred23_InternalTableDSL()) ) {s = 4;}

                        else if ( (true) ) {s = 5;}

                         
                        input.seek(index88_1);
                        if ( s>=0 ) return s;
                        break;
                    case 2 : 
                        int LA88_2 = input.LA(1);

                         
                        int index88_2 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred23_InternalTableDSL()) ) {s = 4;}

                        else if ( (true) ) {s = 5;}

                         
                        input.seek(index88_2);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 88, _s, input);
            error(nvae);
            throw nvae;
        }
    }
    static final String[] dfa_51s = {
            "\2\2\1\uffff\3\2\6\uffff\2\2\2\uffff\1\2\65\uffff\1\2\20\uffff\6\2\1\uffff\1\2\1\uffff\3\2\1\uffff\1\2\1\1\36\2\1\uffff\30\2",
            "\1\uffff",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            ""
    };
    static final short[][] dfa_51 = unpackEncodedStringArray(dfa_51s);

    class DFA90 extends DFA {

        public DFA90(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 90;
            this.eot = dfa_39;
            this.eof = dfa_40;
            this.min = dfa_41;
            this.max = dfa_42;
            this.accept = dfa_43;
            this.special = dfa_44;
            this.transition = dfa_51;
        }
        public String getDescription() {
            return "6948:5: ( ( ( () '[' ) )=> (lv_memberCallArguments_23_0= ruleXClosure ) )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA90_1 = input.LA(1);

                         
                        int index90_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred24_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 2;}

                         
                        input.seek(index90_1);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 90, _s, input);
            error(nvae);
            throw nvae;
        }
    }
    static final String dfa_52s = "\40\uffff";
    static final String dfa_53s = "\1\4\26\uffff\1\0\10\uffff";
    static final String dfa_54s = "\1\u009f\26\uffff\1\0\10\uffff";
    static final String dfa_55s = "\1\uffff\1\1\1\2\1\3\1\4\1\5\6\uffff\1\6\11\uffff\1\7\1\uffff\1\12\1\13\1\14\1\15\1\16\1\17\1\10\1\11";
    static final String dfa_56s = "\1\0\26\uffff\1\1\10\uffff}>";
    static final String[] dfa_57s = {
            "\1\5\1\14\1\uffff\3\14\6\uffff\1\2\114\uffff\3\5\4\uffff\1\35\3\uffff\2\14\6\uffff\1\5\30\uffff\1\26\1\uffff\1\3\3\uffff\1\27\1\30\1\31\2\uffff\2\5\1\1\4\14\1\32\1\33\1\34\1\uffff\1\4",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "\1\uffff",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            ""
    };

    static final short[] dfa_52 = DFA.unpackEncodedString(dfa_52s);
    static final char[] dfa_53 = DFA.unpackEncodedStringToUnsignedChars(dfa_53s);
    static final char[] dfa_54 = DFA.unpackEncodedStringToUnsignedChars(dfa_54s);
    static final short[] dfa_55 = DFA.unpackEncodedString(dfa_55s);
    static final short[] dfa_56 = DFA.unpackEncodedString(dfa_56s);
    static final short[][] dfa_57 = unpackEncodedStringArray(dfa_57s);

    class DFA92 extends DFA {

        public DFA92(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 92;
            this.eot = dfa_52;
            this.eof = dfa_52;
            this.min = dfa_53;
            this.max = dfa_54;
            this.accept = dfa_55;
            this.special = dfa_56;
            this.transition = dfa_57;
        }
        public String getDescription() {
            return "6993:2: (this_XConstructorCall_0= ruleXConstructorCall | this_XBlockExpression_1= ruleXBlockExpression | this_XSwitchExpression_2= ruleXSwitchExpression | ( ( ( () 'synchronized' '(' ) )=>this_XSynchronizedExpression_3= ruleXSynchronizedExpression ) | this_XFeatureCall_4= ruleXFeatureCall | this_XLiteral_5= ruleXLiteral | this_XIfExpression_6= ruleXIfExpression | ( ( ( () 'for' '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=>this_XForLoopExpression_7= ruleXForLoopExpression ) | this_XBasicForLoopExpression_8= ruleXBasicForLoopExpression | this_XWhileExpression_9= ruleXWhileExpression | this_XDoWhileExpression_10= ruleXDoWhileExpression | this_XThrowExpression_11= ruleXThrowExpression | this_XReturnExpression_12= ruleXReturnExpression | this_XTryCatchFinallyExpression_13= ruleXTryCatchFinallyExpression | this_XParenthesizedExpression_14= ruleXParenthesizedExpression )";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA92_0 = input.LA(1);

                         
                        int index92_0 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (LA92_0==150) ) {s = 1;}

                        else if ( (LA92_0==16) ) {s = 2;}

                        else if ( (LA92_0==139) ) {s = 3;}

                        else if ( (LA92_0==159) && (synpred25_InternalTableDSL())) {s = 4;}

                        else if ( (LA92_0==RULE_ID||(LA92_0>=93 && LA92_0<=95)||LA92_0==112||(LA92_0>=148 && LA92_0<=149)) ) {s = 5;}

                        else if ( (LA92_0==RULE_STRING||(LA92_0>=RULE_INT && LA92_0<=RULE_DECIMAL)||(LA92_0>=104 && LA92_0<=105)||(LA92_0>=151 && LA92_0<=154)) ) {s = 12;}

                        else if ( (LA92_0==137) ) {s = 22;}

                        else if ( (LA92_0==143) ) {s = 23;}

                        else if ( (LA92_0==144) ) {s = 24;}

                        else if ( (LA92_0==145) ) {s = 25;}

                        else if ( (LA92_0==155) ) {s = 26;}

                        else if ( (LA92_0==156) ) {s = 27;}

                        else if ( (LA92_0==157) ) {s = 28;}

                        else if ( (LA92_0==100) ) {s = 29;}

                         
                        input.seek(index92_0);
                        if ( s>=0 ) return s;
                        break;
                    case 1 : 
                        int LA92_23 = input.LA(1);

                         
                        int index92_23 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred26_InternalTableDSL()) ) {s = 30;}

                        else if ( (true) ) {s = 31;}

                         
                        input.seek(index92_23);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 92, _s, input);
            error(nvae);
            throw nvae;
        }
    }
    static final String dfa_58s = "\46\uffff";
    static final String dfa_59s = "\1\4\2\0\43\uffff";
    static final String dfa_60s = "\1\u009f\2\0\43\uffff";
    static final String dfa_61s = "\3\uffff\2\1\1\2\40\uffff";
    static final String dfa_62s = "\1\0\1\1\1\2\43\uffff}>";
    static final String[] dfa_63s = {
            "\1\1\1\5\1\uffff\3\5\6\uffff\1\5\112\uffff\5\5\4\uffff\1\2\3\uffff\3\5\5\uffff\1\5\14\uffff\1\3\5\uffff\1\5\4\uffff\1\4\1\5\1\uffff\1\5\3\uffff\17\5\1\uffff\1\5",
            "\1\uffff",
            "\1\uffff",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            ""
    };

    static final short[] dfa_58 = DFA.unpackEncodedString(dfa_58s);
    static final char[] dfa_59 = DFA.unpackEncodedStringToUnsignedChars(dfa_59s);
    static final char[] dfa_60 = DFA.unpackEncodedStringToUnsignedChars(dfa_60s);
    static final short[] dfa_61 = DFA.unpackEncodedString(dfa_61s);
    static final short[] dfa_62 = DFA.unpackEncodedString(dfa_62s);
    static final short[][] dfa_63 = unpackEncodedStringArray(dfa_63s);

    class DFA101 extends DFA {

        public DFA101(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 101;
            this.eot = dfa_58;
            this.eof = dfa_58;
            this.min = dfa_59;
            this.max = dfa_60;
            this.accept = dfa_61;
            this.special = dfa_62;
            this.transition = dfa_63;
        }
        public String getDescription() {
            return "7485:3: ( ( ( ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> ( ( ( (lv_declaredFormalParameters_2_0= ruleJvmFormalParameter ) ) (otherlv_3= ',' ( (lv_declaredFormalParameters_4_0= ruleJvmFormalParameter ) ) )* )? ( (lv_explicitSyntax_5_0= '|' ) ) ) )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA101_0 = input.LA(1);

                         
                        int index101_0 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (LA101_0==RULE_ID) ) {s = 1;}

                        else if ( (LA101_0==100) ) {s = 2;}

                        else if ( (LA101_0==125) && (synpred29_InternalTableDSL())) {s = 3;}

                        else if ( (LA101_0==136) && (synpred29_InternalTableDSL())) {s = 4;}

                        else if ( (LA101_0==RULE_STRING||(LA101_0>=RULE_INT && LA101_0<=RULE_DECIMAL)||LA101_0==16||(LA101_0>=91 && LA101_0<=95)||(LA101_0>=104 && LA101_0<=106)||LA101_0==112||LA101_0==131||LA101_0==137||LA101_0==139||(LA101_0>=143 && LA101_0<=157)||LA101_0==159) ) {s = 5;}

                         
                        input.seek(index101_0);
                        if ( s>=0 ) return s;
                        break;
                    case 1 : 
                        int LA101_1 = input.LA(1);

                         
                        int index101_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred29_InternalTableDSL()) ) {s = 4;}

                        else if ( (true) ) {s = 5;}

                         
                        input.seek(index101_1);
                        if ( s>=0 ) return s;
                        break;
                    case 2 : 
                        int LA101_2 = input.LA(1);

                         
                        int index101_2 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred29_InternalTableDSL()) ) {s = 4;}

                        else if ( (true) ) {s = 5;}

                         
                        input.seek(index101_2);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 101, _s, input);
            error(nvae);
            throw nvae;
        }
    }
    static final String[] dfa_64s = {
            "\2\2\1\uffff\3\2\6\uffff\1\2\112\uffff\5\2\4\uffff\1\1\3\uffff\2\2\6\uffff\1\2\14\uffff\1\2\5\uffff\1\2\5\uffff\1\2\1\uffff\1\2\3\uffff\3\2\2\uffff\12\2\1\uffff\1\2",
            "\1\uffff",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            ""
    };
    static final short[][] dfa_64 = unpackEncodedStringArray(dfa_64s);

    class DFA108 extends DFA {

        public DFA108(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 108;
            this.eot = dfa_14;
            this.eof = dfa_14;
            this.min = dfa_15;
            this.max = dfa_16;
            this.accept = dfa_17;
            this.special = dfa_18;
            this.transition = dfa_64;
        }
        public String getDescription() {
            return "7951:3: ( ( ( ( ( '(' ( ( ruleJvmFormalParameter ) ) ':' ) )=> (otherlv_2= '(' ( (lv_declaredParam_3_0= ruleJvmFormalParameter ) ) otherlv_4= ':' ) ) ( (lv_switch_5_0= ruleXExpression ) ) otherlv_6= ')' ) | ( ( ( ( ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':' ) )? ( (lv_switch_9_0= ruleXExpression ) ) ) )";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA108_1 = input.LA(1);

                         
                        int index108_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred32_InternalTableDSL()) ) {s = 34;}

                        else if ( (true) ) {s = 2;}

                         
                        input.seek(index108_1);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 108, _s, input);
            error(nvae);
            throw nvae;
        }
    }
    static final String dfa_65s = "\42\uffff";
    static final String dfa_66s = "\1\4\2\0\37\uffff";
    static final String dfa_67s = "\1\u009f\2\0\37\uffff";
    static final String dfa_68s = "\3\uffff\1\1\1\2\35\uffff";
    static final String dfa_69s = "\1\0\1\1\1\2\37\uffff}>";
    static final String[] dfa_70s = {
            "\1\1\1\4\1\uffff\3\4\6\uffff\1\4\112\uffff\5\4\4\uffff\1\2\3\uffff\2\4\6\uffff\1\4\14\uffff\1\3\5\uffff\1\4\5\uffff\1\4\1\uffff\1\4\3\uffff\3\4\2\uffff\12\4\1\uffff\1\4",
            "\1\uffff",
            "\1\uffff",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            ""
    };

    static final short[] dfa_65 = DFA.unpackEncodedString(dfa_65s);
    static final char[] dfa_66 = DFA.unpackEncodedStringToUnsignedChars(dfa_66s);
    static final char[] dfa_67 = DFA.unpackEncodedStringToUnsignedChars(dfa_67s);
    static final short[] dfa_68 = DFA.unpackEncodedString(dfa_68s);
    static final short[] dfa_69 = DFA.unpackEncodedString(dfa_69s);
    static final short[][] dfa_70 = unpackEncodedStringArray(dfa_70s);

    class DFA107 extends DFA {

        public DFA107(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 107;
            this.eot = dfa_65;
            this.eof = dfa_65;
            this.min = dfa_66;
            this.max = dfa_67;
            this.accept = dfa_68;
            this.special = dfa_69;
            this.transition = dfa_70;
        }
        public String getDescription() {
            return "8020:5: ( ( ( ( ( ruleJvmFormalParameter ) ) ':' ) )=> ( ( (lv_declaredParam_7_0= ruleJvmFormalParameter ) ) otherlv_8= ':' ) )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA107_0 = input.LA(1);

                         
                        int index107_0 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (LA107_0==RULE_ID) ) {s = 1;}

                        else if ( (LA107_0==100) ) {s = 2;}

                        else if ( (LA107_0==125) && (synpred33_InternalTableDSL())) {s = 3;}

                        else if ( (LA107_0==RULE_STRING||(LA107_0>=RULE_INT && LA107_0<=RULE_DECIMAL)||LA107_0==16||(LA107_0>=91 && LA107_0<=95)||(LA107_0>=104 && LA107_0<=105)||LA107_0==112||LA107_0==131||LA107_0==137||LA107_0==139||(LA107_0>=143 && LA107_0<=145)||(LA107_0>=148 && LA107_0<=157)||LA107_0==159) ) {s = 4;}

                         
                        input.seek(index107_0);
                        if ( s>=0 ) return s;
                        break;
                    case 1 : 
                        int LA107_1 = input.LA(1);

                         
                        int index107_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred33_InternalTableDSL()) ) {s = 3;}

                        else if ( (true) ) {s = 4;}

                         
                        input.seek(index107_1);
                        if ( s>=0 ) return s;
                        break;
                    case 2 : 
                        int LA107_2 = input.LA(1);

                         
                        int index107_2 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred33_InternalTableDSL()) ) {s = 3;}

                        else if ( (true) ) {s = 4;}

                         
                        input.seek(index107_2);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 107, _s, input);
            error(nvae);
            throw nvae;
        }
    }

    class DFA130 extends DFA {

        public DFA130(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 130;
            this.eot = dfa_39;
            this.eof = dfa_40;
            this.min = dfa_41;
            this.max = dfa_42;
            this.accept = dfa_43;
            this.special = dfa_44;
            this.transition = dfa_45;
        }
        public String getDescription() {
            return "9149:3: ( ( ( ( '(' ) )=> (lv_explicitOperationCall_7_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_featureCallArguments_8_0= ruleXShortClosure ) ) | ( ( (lv_featureCallArguments_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) ) )* ) )? otherlv_12= ')' )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA130_1 = input.LA(1);

                         
                        int index130_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred36_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 2;}

                         
                        input.seek(index130_1);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 130, _s, input);
            error(nvae);
            throw nvae;
        }
    }

    class DFA129 extends DFA {

        public DFA129(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 129;
            this.eot = dfa_8;
            this.eof = dfa_8;
            this.min = dfa_46;
            this.max = dfa_47;
            this.accept = dfa_48;
            this.special = dfa_49;
            this.transition = dfa_50;
        }
        public String getDescription() {
            return "9168:4: ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_featureCallArguments_8_0= ruleXShortClosure ) ) | ( ( (lv_featureCallArguments_9_0= ruleXExpression ) ) (otherlv_10= ',' ( (lv_featureCallArguments_11_0= ruleXExpression ) ) )* ) )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA129_0 = input.LA(1);

                         
                        int index129_0 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (LA129_0==RULE_ID) ) {s = 1;}

                        else if ( (LA129_0==100) ) {s = 2;}

                        else if ( (LA129_0==125) && (synpred37_InternalTableDSL())) {s = 3;}

                        else if ( (LA129_0==136) && (synpred37_InternalTableDSL())) {s = 4;}

                        else if ( (LA129_0==RULE_STRING||(LA129_0>=RULE_INT && LA129_0<=RULE_DECIMAL)||LA129_0==16||(LA129_0>=91 && LA129_0<=95)||(LA129_0>=104 && LA129_0<=105)||LA129_0==112||LA129_0==131||LA129_0==137||LA129_0==139||(LA129_0>=143 && LA129_0<=145)||(LA129_0>=148 && LA129_0<=157)||LA129_0==159) ) {s = 5;}

                        else if ( (LA129_0==102) ) {s = 35;}

                         
                        input.seek(index129_0);
                        if ( s>=0 ) return s;
                        break;
                    case 1 : 
                        int LA129_1 = input.LA(1);

                         
                        int index129_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred37_InternalTableDSL()) ) {s = 4;}

                        else if ( (true) ) {s = 5;}

                         
                        input.seek(index129_1);
                        if ( s>=0 ) return s;
                        break;
                    case 2 : 
                        int LA129_2 = input.LA(1);

                         
                        int index129_2 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred37_InternalTableDSL()) ) {s = 4;}

                        else if ( (true) ) {s = 5;}

                         
                        input.seek(index129_2);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 129, _s, input);
            error(nvae);
            throw nvae;
        }
    }

    class DFA131 extends DFA {

        public DFA131(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 131;
            this.eot = dfa_39;
            this.eof = dfa_40;
            this.min = dfa_41;
            this.max = dfa_42;
            this.accept = dfa_43;
            this.special = dfa_44;
            this.transition = dfa_51;
        }
        public String getDescription() {
            return "9266:3: ( ( ( () '[' ) )=> (lv_featureCallArguments_13_0= ruleXClosure ) )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA131_1 = input.LA(1);

                         
                        int index131_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred38_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 2;}

                         
                        input.seek(index131_1);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 131, _s, input);
            error(nvae);
            throw nvae;
        }
    }
    static final String[] dfa_71s = {
            "\2\2\1\uffff\3\2\6\uffff\2\2\2\uffff\1\2\65\uffff\1\2\20\uffff\6\2\1\uffff\1\2\1\uffff\3\2\1\uffff\10\2\1\1\27\2\1\uffff\30\2",
            "\1\uffff",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            ""
    };
    static final short[][] dfa_71 = unpackEncodedStringArray(dfa_71s);

    class DFA135 extends DFA {

        public DFA135(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 135;
            this.eot = dfa_39;
            this.eof = dfa_40;
            this.min = dfa_41;
            this.max = dfa_42;
            this.accept = dfa_43;
            this.special = dfa_44;
            this.transition = dfa_71;
        }
        public String getDescription() {
            return "9425:3: ( ( ( '<' )=>otherlv_3= '<' ) ( (lv_typeArguments_4_0= ruleJvmArgumentTypeReference ) ) (otherlv_5= ',' ( (lv_typeArguments_6_0= ruleJvmArgumentTypeReference ) ) )* otherlv_7= '>' )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA135_1 = input.LA(1);

                         
                        int index135_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred39_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 2;}

                         
                        input.seek(index135_1);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 135, _s, input);
            error(nvae);
            throw nvae;
        }
    }

    class DFA138 extends DFA {

        public DFA138(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 138;
            this.eot = dfa_39;
            this.eof = dfa_40;
            this.min = dfa_41;
            this.max = dfa_42;
            this.accept = dfa_43;
            this.special = dfa_44;
            this.transition = dfa_45;
        }
        public String getDescription() {
            return "9482:3: ( ( ( ( '(' ) )=> (lv_explicitConstructorCall_8_0= '(' ) ) ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_arguments_9_0= ruleXShortClosure ) ) | ( ( (lv_arguments_10_0= ruleXExpression ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) ) )* ) )? otherlv_13= ')' )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA138_1 = input.LA(1);

                         
                        int index138_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred40_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 2;}

                         
                        input.seek(index138_1);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 138, _s, input);
            error(nvae);
            throw nvae;
        }
    }

    class DFA137 extends DFA {

        public DFA137(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 137;
            this.eot = dfa_8;
            this.eof = dfa_8;
            this.min = dfa_46;
            this.max = dfa_47;
            this.accept = dfa_48;
            this.special = dfa_49;
            this.transition = dfa_50;
        }
        public String getDescription() {
            return "9501:4: ( ( ( ( () ( ( ( ruleJvmFormalParameter ) ) ( ',' ( ( ruleJvmFormalParameter ) ) )* )? ( ( '|' ) ) ) )=> (lv_arguments_9_0= ruleXShortClosure ) ) | ( ( (lv_arguments_10_0= ruleXExpression ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleXExpression ) ) )* ) )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA137_0 = input.LA(1);

                         
                        int index137_0 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (LA137_0==RULE_ID) ) {s = 1;}

                        else if ( (LA137_0==100) ) {s = 2;}

                        else if ( (LA137_0==125) && (synpred41_InternalTableDSL())) {s = 3;}

                        else if ( (LA137_0==136) && (synpred41_InternalTableDSL())) {s = 4;}

                        else if ( (LA137_0==RULE_STRING||(LA137_0>=RULE_INT && LA137_0<=RULE_DECIMAL)||LA137_0==16||(LA137_0>=91 && LA137_0<=95)||(LA137_0>=104 && LA137_0<=105)||LA137_0==112||LA137_0==131||LA137_0==137||LA137_0==139||(LA137_0>=143 && LA137_0<=145)||(LA137_0>=148 && LA137_0<=157)||LA137_0==159) ) {s = 5;}

                        else if ( (LA137_0==102) ) {s = 35;}

                         
                        input.seek(index137_0);
                        if ( s>=0 ) return s;
                        break;
                    case 1 : 
                        int LA137_1 = input.LA(1);

                         
                        int index137_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred41_InternalTableDSL()) ) {s = 4;}

                        else if ( (true) ) {s = 5;}

                         
                        input.seek(index137_1);
                        if ( s>=0 ) return s;
                        break;
                    case 2 : 
                        int LA137_2 = input.LA(1);

                         
                        int index137_2 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred41_InternalTableDSL()) ) {s = 4;}

                        else if ( (true) ) {s = 5;}

                         
                        input.seek(index137_2);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 137, _s, input);
            error(nvae);
            throw nvae;
        }
    }

    class DFA139 extends DFA {

        public DFA139(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 139;
            this.eot = dfa_39;
            this.eof = dfa_40;
            this.min = dfa_41;
            this.max = dfa_42;
            this.accept = dfa_43;
            this.special = dfa_44;
            this.transition = dfa_51;
        }
        public String getDescription() {
            return "9599:3: ( ( ( () '[' ) )=> (lv_arguments_14_0= ruleXClosure ) )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA139_1 = input.LA(1);

                         
                        int index139_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred42_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 2;}

                         
                        input.seek(index139_1);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 139, _s, input);
            error(nvae);
            throw nvae;
        }
    }
    static final String dfa_72s = "\1\41\115\uffff";
    static final String dfa_73s = "\1\4\40\0\55\uffff";
    static final String dfa_74s = "\1\u00a0\40\0\55\uffff";
    static final String dfa_75s = "\41\uffff\1\2\53\uffff\1\1";
    static final String dfa_76s = "\1\uffff\1\0\1\1\1\2\1\3\1\4\1\5\1\6\1\7\1\10\1\11\1\12\1\13\1\14\1\15\1\16\1\17\1\20\1\21\1\22\1\23\1\24\1\25\1\26\1\27\1\30\1\31\1\32\1\33\1\34\1\35\1\36\1\37\55\uffff}>";
    static final String[] dfa_77s = {
            "\1\1\1\27\1\uffff\1\24\1\23\1\25\6\uffff\1\12\1\41\2\uffff\1\41\65\uffff\1\41\20\uffff\1\10\1\7\1\4\1\3\1\5\1\41\1\uffff\1\41\1\uffff\1\40\2\41\1\uffff\1\17\1\20\6\41\1\15\22\41\1\6\4\41\1\uffff\1\31\1\41\1\13\3\41\1\32\1\33\1\34\2\41\1\2\1\16\1\11\1\21\1\22\1\26\1\30\1\35\1\36\1\37\1\41\1\14\1\41",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "\1\uffff",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            ""
    };
    static final short[] dfa_72 = DFA.unpackEncodedString(dfa_72s);
    static final char[] dfa_73 = DFA.unpackEncodedStringToUnsignedChars(dfa_73s);
    static final char[] dfa_74 = DFA.unpackEncodedStringToUnsignedChars(dfa_74s);
    static final short[] dfa_75 = DFA.unpackEncodedString(dfa_75s);
    static final short[] dfa_76 = DFA.unpackEncodedString(dfa_76s);
    static final short[][] dfa_77 = unpackEncodedStringArray(dfa_77s);

    class DFA142 extends DFA {

        public DFA142(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 142;
            this.eot = dfa_39;
            this.eof = dfa_72;
            this.min = dfa_73;
            this.max = dfa_74;
            this.accept = dfa_75;
            this.special = dfa_76;
            this.transition = dfa_77;
        }
        public String getDescription() {
            return "9942:3: ( ( 'extends' | 'static' | 'import' | 'extension' | '!' | '-' | '+' | 'new' | '{' | 'switch' | 'synchronized' | '<' | 'super' | '#' | '[' | 'false' | 'true' | 'null' | 'typeof' | 'if' | 'for' | 'while' | 'do' | 'throw' | 'return' | 'try' | '(' | RULE_ID | RULE_HEX | RULE_INT | RULE_DECIMAL | RULE_STRING )=> (lv_expression_2_0= ruleXExpression ) )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA142_1 = input.LA(1);

                         
                        int index142_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_1);
                        if ( s>=0 ) return s;
                        break;
                    case 1 : 
                        int LA142_2 = input.LA(1);

                         
                        int index142_2 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_2);
                        if ( s>=0 ) return s;
                        break;
                    case 2 : 
                        int LA142_3 = input.LA(1);

                         
                        int index142_3 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_3);
                        if ( s>=0 ) return s;
                        break;
                    case 3 : 
                        int LA142_4 = input.LA(1);

                         
                        int index142_4 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_4);
                        if ( s>=0 ) return s;
                        break;
                    case 4 : 
                        int LA142_5 = input.LA(1);

                         
                        int index142_5 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_5);
                        if ( s>=0 ) return s;
                        break;
                    case 5 : 
                        int LA142_6 = input.LA(1);

                         
                        int index142_6 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_6);
                        if ( s>=0 ) return s;
                        break;
                    case 6 : 
                        int LA142_7 = input.LA(1);

                         
                        int index142_7 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_7);
                        if ( s>=0 ) return s;
                        break;
                    case 7 : 
                        int LA142_8 = input.LA(1);

                         
                        int index142_8 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_8);
                        if ( s>=0 ) return s;
                        break;
                    case 8 : 
                        int LA142_9 = input.LA(1);

                         
                        int index142_9 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_9);
                        if ( s>=0 ) return s;
                        break;
                    case 9 : 
                        int LA142_10 = input.LA(1);

                         
                        int index142_10 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_10);
                        if ( s>=0 ) return s;
                        break;
                    case 10 : 
                        int LA142_11 = input.LA(1);

                         
                        int index142_11 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_11);
                        if ( s>=0 ) return s;
                        break;
                    case 11 : 
                        int LA142_12 = input.LA(1);

                         
                        int index142_12 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_12);
                        if ( s>=0 ) return s;
                        break;
                    case 12 : 
                        int LA142_13 = input.LA(1);

                         
                        int index142_13 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_13);
                        if ( s>=0 ) return s;
                        break;
                    case 13 : 
                        int LA142_14 = input.LA(1);

                         
                        int index142_14 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_14);
                        if ( s>=0 ) return s;
                        break;
                    case 14 : 
                        int LA142_15 = input.LA(1);

                         
                        int index142_15 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_15);
                        if ( s>=0 ) return s;
                        break;
                    case 15 : 
                        int LA142_16 = input.LA(1);

                         
                        int index142_16 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_16);
                        if ( s>=0 ) return s;
                        break;
                    case 16 : 
                        int LA142_17 = input.LA(1);

                         
                        int index142_17 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_17);
                        if ( s>=0 ) return s;
                        break;
                    case 17 : 
                        int LA142_18 = input.LA(1);

                         
                        int index142_18 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_18);
                        if ( s>=0 ) return s;
                        break;
                    case 18 : 
                        int LA142_19 = input.LA(1);

                         
                        int index142_19 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_19);
                        if ( s>=0 ) return s;
                        break;
                    case 19 : 
                        int LA142_20 = input.LA(1);

                         
                        int index142_20 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_20);
                        if ( s>=0 ) return s;
                        break;
                    case 20 : 
                        int LA142_21 = input.LA(1);

                         
                        int index142_21 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_21);
                        if ( s>=0 ) return s;
                        break;
                    case 21 : 
                        int LA142_22 = input.LA(1);

                         
                        int index142_22 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_22);
                        if ( s>=0 ) return s;
                        break;
                    case 22 : 
                        int LA142_23 = input.LA(1);

                         
                        int index142_23 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_23);
                        if ( s>=0 ) return s;
                        break;
                    case 23 : 
                        int LA142_24 = input.LA(1);

                         
                        int index142_24 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_24);
                        if ( s>=0 ) return s;
                        break;
                    case 24 : 
                        int LA142_25 = input.LA(1);

                         
                        int index142_25 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_25);
                        if ( s>=0 ) return s;
                        break;
                    case 25 : 
                        int LA142_26 = input.LA(1);

                         
                        int index142_26 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_26);
                        if ( s>=0 ) return s;
                        break;
                    case 26 : 
                        int LA142_27 = input.LA(1);

                         
                        int index142_27 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_27);
                        if ( s>=0 ) return s;
                        break;
                    case 27 : 
                        int LA142_28 = input.LA(1);

                         
                        int index142_28 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_28);
                        if ( s>=0 ) return s;
                        break;
                    case 28 : 
                        int LA142_29 = input.LA(1);

                         
                        int index142_29 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_29);
                        if ( s>=0 ) return s;
                        break;
                    case 29 : 
                        int LA142_30 = input.LA(1);

                         
                        int index142_30 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_30);
                        if ( s>=0 ) return s;
                        break;
                    case 30 : 
                        int LA142_31 = input.LA(1);

                         
                        int index142_31 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_31);
                        if ( s>=0 ) return s;
                        break;
                    case 31 : 
                        int LA142_32 = input.LA(1);

                         
                        int index142_32 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred43_InternalTableDSL()) ) {s = 77;}

                        else if ( (true) ) {s = 33;}

                         
                        input.seek(index142_32);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 142, _s, input);
            error(nvae);
            throw nvae;
        }
    }
    static final String dfa_78s = "\117\uffff";
    static final String dfa_79s = "\1\2\116\uffff";
    static final String dfa_80s = "\1\4\1\0\115\uffff";
    static final String dfa_81s = "\1\u00a2\1\0\115\uffff";
    static final String dfa_82s = "\2\uffff\1\2\113\uffff\1\1";
    static final String dfa_83s = "\1\uffff\1\0\115\uffff}>";
    static final String[] dfa_84s = {
            "\2\2\1\uffff\3\2\6\uffff\2\2\2\uffff\1\2\65\uffff\1\2\20\uffff\6\2\1\uffff\1\2\1\uffff\3\2\1\uffff\10\2\1\1\27\2\1\uffff\30\2\1\uffff\1\2",
            "\1\uffff",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            ""
    };

    static final short[] dfa_78 = DFA.unpackEncodedString(dfa_78s);
    static final short[] dfa_79 = DFA.unpackEncodedString(dfa_79s);
    static final char[] dfa_80 = DFA.unpackEncodedStringToUnsignedChars(dfa_80s);
    static final char[] dfa_81 = DFA.unpackEncodedStringToUnsignedChars(dfa_81s);
    static final short[] dfa_82 = DFA.unpackEncodedString(dfa_82s);
    static final short[] dfa_83 = DFA.unpackEncodedString(dfa_83s);
    static final short[][] dfa_84 = unpackEncodedStringArray(dfa_84s);

    class DFA160 extends DFA {

        public DFA160(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 160;
            this.eot = dfa_78;
            this.eof = dfa_79;
            this.min = dfa_80;
            this.max = dfa_81;
            this.accept = dfa_82;
            this.special = dfa_83;
            this.transition = dfa_84;
        }
        public String getDescription() {
            return "10600:3: ( ( ( '<' )=>otherlv_1= '<' ) ( (lv_arguments_2_0= ruleJvmArgumentTypeReference ) ) (otherlv_3= ',' ( (lv_arguments_4_0= ruleJvmArgumentTypeReference ) ) )* otherlv_5= '>' ( ( ( ( () '.' ) )=> ( () otherlv_7= '.' ) ) ( ( ruleValidID ) ) ( ( ( '<' )=>otherlv_9= '<' ) ( (lv_arguments_10_0= ruleJvmArgumentTypeReference ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) ) )* otherlv_13= '>' )? )* )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA160_1 = input.LA(1);

                         
                        int index160_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred50_InternalTableDSL()) ) {s = 78;}

                        else if ( (true) ) {s = 2;}

                         
                        input.seek(index160_1);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 160, _s, input);
            error(nvae);
            throw nvae;
        }
    }

    class DFA158 extends DFA {

        public DFA158(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 158;
            this.eot = dfa_78;
            this.eof = dfa_79;
            this.min = dfa_80;
            this.max = dfa_81;
            this.accept = dfa_82;
            this.special = dfa_83;
            this.transition = dfa_84;
        }
        public String getDescription() {
            return "10694:5: ( ( ( '<' )=>otherlv_9= '<' ) ( (lv_arguments_10_0= ruleJvmArgumentTypeReference ) ) (otherlv_11= ',' ( (lv_arguments_12_0= ruleJvmArgumentTypeReference ) ) )* otherlv_13= '>' )?";
        }
        public int specialStateTransition(int s, IntStream _input) throws NoViableAltException {
            TokenStream input = (TokenStream)_input;
        	int _s = s;
            switch ( s ) {
                    case 0 : 
                        int LA158_1 = input.LA(1);

                         
                        int index158_1 = input.index();
                        input.rewind();
                        s = -1;
                        if ( (synpred52_InternalTableDSL()) ) {s = 78;}

                        else if ( (true) ) {s = 2;}

                         
                        input.seek(index158_1);
                        if ( s>=0 ) return s;
                        break;
            }
            if (state.backtracking>0) {state.failed=true; return -1;}
            NoViableAltException nvae =
                new NoViableAltException(getDescription(), 158, _s, input);
            error(nvae);
            throw nvae;
        }
    }
 

    public static final BitSet FOLLOW_1 = new BitSet(new long[]{0x0000000000000000L});
    public static final BitSet FOLLOW_2 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_3 = new BitSet(new long[]{0x0000000000008002L});
    public static final BitSet FOLLOW_4 = new BitSet(new long[]{0x0000000000000010L});
    public static final BitSet FOLLOW_5 = new BitSet(new long[]{0x0000000000010002L});
    public static final BitSet FOLLOW_6 = new BitSet(new long[]{0x0000000000060000L});
    public static final BitSet FOLLOW_7 = new BitSet(new long[]{0x0000000000180000L});
    public static final BitSet FOLLOW_8 = new BitSet(new long[]{0x0000000000000020L});
    public static final BitSet FOLLOW_9 = new BitSet(new long[]{0x0000000000100000L});
    public static final BitSet FOLLOW_10 = new BitSet(new long[]{0x0000000040200000L,0x0000000000000040L});
    public static final BitSet FOLLOW_11 = new BitSet(new long[]{0x0000000000C00000L});
    public static final BitSet FOLLOW_12 = new BitSet(new long[]{0x000000003F000002L});
    public static final BitSet FOLLOW_13 = new BitSet(new long[]{0x0000000000000000L,0x0000000000000000L,0x0001C00000000000L});
    public static final BitSet FOLLOW_14 = new BitSet(new long[]{0x2000000000000000L});
    public static final BitSet FOLLOW_15 = new BitSet(new long[]{0x00000000BF000002L});
    public static final BitSet FOLLOW_16 = new BitSet(new long[]{0x007FC00000000000L});
    public static final BitSet FOLLOW_17 = new BitSet(new long[]{0x0000000200000002L});
    public static final BitSet FOLLOW_18 = new BitSet(new long[]{0x0000237800000002L});
    public static final BitSet FOLLOW_19 = new BitSet(new long[]{0x0000040000000000L});
    public static final BitSet FOLLOW_20 = new BitSet(new long[]{0x0000008000010000L});
    public static final BitSet FOLLOW_21 = new BitSet(new long[]{0x0000000000010000L});
    public static final BitSet FOLLOW_22 = new BitSet(new long[]{0x0380000000020000L});
    public static final BitSet FOLLOW_23 = new BitSet(new long[]{0x0000014000000002L});
    public static final BitSet FOLLOW_24 = new BitSet(new long[]{0x1E00000000020000L});
    public static final BitSet FOLLOW_25 = new BitSet(new long[]{0x0000188000000002L});
    public static final BitSet FOLLOW_26 = new BitSet(new long[]{0x0000000000000380L});
    public static final BitSet FOLLOW_27 = new BitSet(new long[]{0x0000000000000380L,0x0000000010000000L});
    public static final BitSet FOLLOW_28 = new BitSet(new long[]{0x0000001000000000L,0x000000000000003CL});
    public static final BitSet FOLLOW_29 = new BitSet(new long[]{0x0000000000000080L,0x0000000010000000L});
    public static final BitSet FOLLOW_30 = new BitSet(new long[]{0x4000000000020000L});
    public static final BitSet FOLLOW_31 = new BitSet(new long[]{0x0000000000000000L,0x0000000000000000L,0x003E000000002000L});
    public static final BitSet FOLLOW_32 = new BitSet(new long[]{0x8000000100000002L,0x0000000000000003L});
    public static final BitSet FOLLOW_33 = new BitSet(new long[]{0x0000000400020000L});
    public static final BitSet FOLLOW_34 = new BitSet(new long[]{0x0000000000000002L,0x0000000000000002L});
    public static final BitSet FOLLOW_35 = new BitSet(new long[]{0x007FC00000020000L});
    public static final BitSet FOLLOW_36 = new BitSet(new long[]{0x0000000000000000L,0x0000000000000000L,0x00003E0000000000L});
    public static final BitSet FOLLOW_37 = new BitSet(new long[]{0x0000000020000000L});
    public static final BitSet FOLLOW_38 = new BitSet(new long[]{0x0000000000000000L,0x0000000000000200L});
    public static final BitSet FOLLOW_39 = new BitSet(new long[]{0x0000000000000000L,0x0000000000000080L});
    public static final BitSet FOLLOW_40 = new BitSet(new long[]{0x0000000000000000L,0x0000000000000100L});
    public static final BitSet FOLLOW_41 = new BitSet(new long[]{0x0000000000000000L,0x000000000396E800L});
    public static final BitSet FOLLOW_42 = new BitSet(new long[]{0x0000000000020000L,0x00000000000000C0L});
    public static final BitSet FOLLOW_43 = new BitSet(new long[]{0x0000000000000002L,0x0000000000000400L});
    public static final BitSet FOLLOW_44 = new BitSet(new long[]{0x0000000000000000L,0x0000000000001000L});
    public static final BitSet FOLLOW_45 = new BitSet(new long[]{0x0000000000000000L,0x0000000000010000L});
    public static final BitSet FOLLOW_46 = new BitSet(new long[]{0x0000000000000000L,0x0000000000080000L});
    public static final BitSet FOLLOW_47 = new BitSet(new long[]{0x0000000000000080L,0x0000000018000000L});
    public static final BitSet FOLLOW_48 = new BitSet(new long[]{0x0000000000000000L,0x0000000000200000L});
    public static final BitSet FOLLOW_49 = new BitSet(new long[]{0x0000000000000000L,0x0000000000400000L});
    public static final BitSet FOLLOW_50 = new BitSet(new long[]{0x0000000000010000L,0x0000000000001000L});
    public static final BitSet FOLLOW_51 = new BitSet(new long[]{0x1800000000020000L});
    public static final BitSet FOLLOW_52 = new BitSet(new long[]{0x0000000000000000L,0x0000000000000000L,0x000001F800000000L});
    public static final BitSet FOLLOW_53 = new BitSet(new long[]{0x0000000000000000L,0x0000000004000000L});
    public static final BitSet FOLLOW_54 = new BitSet(new long[]{0x0000000000000040L});
    public static final BitSet FOLLOW_55 = new BitSet(new long[]{0x0000000000000080L});
    public static final BitSet FOLLOW_56 = new BitSet(new long[]{0x0000000000000010L,0x0000000240000000L});
    public static final BitSet FOLLOW_57 = new BitSet(new long[]{0x0000000000000010L,0x0000000080000000L});
    public static final BitSet FOLLOW_58 = new BitSet(new long[]{0x0000000000000010L,0x0000000100000000L});
    public static final BitSet FOLLOW_59 = new BitSet(new long[]{0x0000000000000002L,0x0000000400000000L});
    public static final BitSet FOLLOW_60 = new BitSet(new long[]{0x0000000000000002L,0x0000001000000000L});
    public static final BitSet FOLLOW_61 = new BitSet(new long[]{0x00000000000103B0L,0x00010358F8000000L,0x00000000BFF38A08L});
    public static final BitSet FOLLOW_62 = new BitSet(new long[]{0x0000000000000000L,0x0000006000000000L});
    public static final BitSet FOLLOW_63 = new BitSet(new long[]{0x0000000000000000L,0x0000004000000000L});
    public static final BitSet FOLLOW_64 = new BitSet(new long[]{0x0000000000000000L,0x0000008000000000L});
    public static final BitSet FOLLOW_65 = new BitSet(new long[]{0x00000000000103B0L,0x00010318F8000000L,0x00000000BFF38A08L});
    public static final BitSet FOLLOW_66 = new BitSet(new long[]{0x0000000000000000L,0x0000020000000000L});
    public static final BitSet FOLLOW_67 = new BitSet(new long[]{0x00000000000103B0L,0x00010718F8000000L,0x00000000BFF38A08L});
    public static final BitSet FOLLOW_68 = new BitSet(new long[]{0x0000000000000000L,0x0000042000000000L});
    public static final BitSet FOLLOW_69 = new BitSet(new long[]{0x0000000000000002L,0x0000002000000000L});
    public static final BitSet FOLLOW_70 = new BitSet(new long[]{0x0000000000000002L,0x0003F80000000000L});
    public static final BitSet FOLLOW_71 = new BitSet(new long[]{0x0000000000000000L,0x0001000000000000L});
    public static final BitSet FOLLOW_72 = new BitSet(new long[]{0x0000000000000000L,0x0006000000000000L});
    public static final BitSet FOLLOW_73 = new BitSet(new long[]{0x0000000000000000L,0x0004000000000000L});
    public static final BitSet FOLLOW_74 = new BitSet(new long[]{0x0000000000000002L,0x0008000000000000L});
    public static final BitSet FOLLOW_75 = new BitSet(new long[]{0x0000000000000002L,0x0010000000000000L});
    public static final BitSet FOLLOW_76 = new BitSet(new long[]{0x0000000000000002L,0x01E0000000000000L});
    public static final BitSet FOLLOW_77 = new BitSet(new long[]{0x0000000000000002L,0x0207000000000000L});
    public static final BitSet FOLLOW_78 = new BitSet(new long[]{0x0000000000000010L,0x2000001000000000L});
    public static final BitSet FOLLOW_79 = new BitSet(new long[]{0x0000000000000002L,0xFC03000000000000L});
    public static final BitSet FOLLOW_80 = new BitSet(new long[]{0x0000000000000000L,0x1000000000000000L});
    public static final BitSet FOLLOW_81 = new BitSet(new long[]{0x0000000000000000L,0x0002000000000000L});
    public static final BitSet FOLLOW_82 = new BitSet(new long[]{0x0000000000000000L,0x2001000000000000L});
    public static final BitSet FOLLOW_83 = new BitSet(new long[]{0x0000000000000002L,0x0000000018000000L});
    public static final BitSet FOLLOW_84 = new BitSet(new long[]{0x0000000000000002L,0x0000000100000000L,0x0000000000000007L});
    public static final BitSet FOLLOW_85 = new BitSet(new long[]{0x0000000000100002L});
    public static final BitSet FOLLOW_86 = new BitSet(new long[]{0x0000000000000002L,0x0000000000000000L,0x0000000000000030L});
    public static final BitSet FOLLOW_87 = new BitSet(new long[]{0x0000000000000002L,0x0000000000000400L,0x00000000000000C0L});
    public static final BitSet FOLLOW_88 = new BitSet(new long[]{0x0000000000000010L,0x00000000E0000000L,0x0000000000100000L});
    public static final BitSet FOLLOW_89 = new BitSet(new long[]{0x0000000000000010L,0x00010000E0000000L,0x0000000000300000L});
    public static final BitSet FOLLOW_90 = new BitSet(new long[]{0x0000000000000010L,0x2000001000000000L,0x0000000200000000L});
    public static final BitSet FOLLOW_91 = new BitSet(new long[]{0x0000000000000000L,0x0002002000000000L});
    public static final BitSet FOLLOW_92 = new BitSet(new long[]{0x0000000000000002L,0x0000021000000400L,0x00000000000000C0L});
    public static final BitSet FOLLOW_93 = new BitSet(new long[]{0x00000000000103B0L,0x20010358F8000000L,0x00000000BFF38B08L});
    public static final BitSet FOLLOW_94 = new BitSet(new long[]{0x0000000000000002L,0x0000020000000400L,0x00000000000000C0L});
    public static final BitSet FOLLOW_95 = new BitSet(new long[]{0x00000000000303B0L,0x00010318F8000000L,0x00000000BFF38A08L});
    public static final BitSet FOLLOW_96 = new BitSet(new long[]{0x0000000000020000L,0x0000002000000000L});
    public static final BitSet FOLLOW_97 = new BitSet(new long[]{0x00000000000103B0L,0x20010718F8000000L,0x00000000BFFF8B08L});
    public static final BitSet FOLLOW_98 = new BitSet(new long[]{0x0000000000000000L,0x0000002000000000L,0x0000000000000100L});
    public static final BitSet FOLLOW_99 = new BitSet(new long[]{0x00000000000103B0L,0x00010718F8000000L,0x00000000BFFF8A08L});
    public static final BitSet FOLLOW_100 = new BitSet(new long[]{0x0000000000000000L,0x0000040000000000L});
    public static final BitSet FOLLOW_101 = new BitSet(new long[]{0x00000000000103B2L,0x0001031CF8000000L,0x00000000BFFF8A08L});
    public static final BitSet FOLLOW_102 = new BitSet(new long[]{0x00000000000103B2L,0x00010318F8000000L,0x00000000BFFF8A08L});
    public static final BitSet FOLLOW_103 = new BitSet(new long[]{0x0000000000000000L,0x0000001000000000L});
    public static final BitSet FOLLOW_104 = new BitSet(new long[]{0x0000000000000002L,0x0000000000000000L,0x0000000000000400L});
    public static final BitSet FOLLOW_105 = new BitSet(new long[]{0x00000000000103B0L,0x20010318F8000000L,0x00000000BFF38A08L});
    public static final BitSet FOLLOW_106 = new BitSet(new long[]{0x0000000000000000L,0x0000000000000000L,0x0000000000001000L});
    public static final BitSet FOLLOW_107 = new BitSet(new long[]{0x0000000000020010L,0x2000003000000000L,0x0000000000007000L});
    public static final BitSet FOLLOW_108 = new BitSet(new long[]{0x0000000000020000L});
    public static final BitSet FOLLOW_109 = new BitSet(new long[]{0x0000000000000000L,0x0000002000000000L,0x0000000000005000L});
    public static final BitSet FOLLOW_110 = new BitSet(new long[]{0x0000000000000000L,0x0000002000000000L,0x0000000000001000L});
    public static final BitSet FOLLOW_111 = new BitSet(new long[]{0x00000000000103B0L,0x0001031CF8000000L,0x00000000BFFF8A08L});
    public static final BitSet FOLLOW_112 = new BitSet(new long[]{0x0000000000000000L,0x0000002400000000L});
    public static final BitSet FOLLOW_113 = new BitSet(new long[]{0x00000000000103B0L,0x00010318F8000000L,0x00000000BFFF8A08L});
    public static final BitSet FOLLOW_114 = new BitSet(new long[]{0x00000000000103B0L,0x0001031CF8000000L,0x00000000BFF38A08L});
    public static final BitSet FOLLOW_115 = new BitSet(new long[]{0x0000000000000000L,0x0000000400000000L});
    public static final BitSet FOLLOW_116 = new BitSet(new long[]{0x0000000000000000L,0x0000000000000000L,0x0000000000010000L});
    public static final BitSet FOLLOW_117 = new BitSet(new long[]{0x00000000000303B0L,0x00010318F8000000L,0x00000000BFFF8A08L});
    public static final BitSet FOLLOW_118 = new BitSet(new long[]{0x00000000000303B0L,0x0001031CF8000000L,0x00000000BFFF8A08L});
    public static final BitSet FOLLOW_119 = new BitSet(new long[]{0x0000000000000002L,0x0000008000000000L});
    public static final BitSet FOLLOW_120 = new BitSet(new long[]{0x0000000000000002L,0x0000021000000000L});
    public static final BitSet FOLLOW_121 = new BitSet(new long[]{0x0000000000000002L,0x0000020000000000L});
    public static final BitSet FOLLOW_122 = new BitSet(new long[]{0x0000000000000002L,0x0001021000000000L});
    public static final BitSet FOLLOW_123 = new BitSet(new long[]{0x0000000000000000L,0x0000024000000000L});
    public static final BitSet FOLLOW_124 = new BitSet(new long[]{0x00000000000103B2L,0x00010318F8000000L,0x00000000BFF38A08L});
    public static final BitSet FOLLOW_125 = new BitSet(new long[]{0x0000000000000000L,0x0000000000000000L,0x0000000140000000L});
    public static final BitSet FOLLOW_126 = new BitSet(new long[]{0x0000000000000002L,0x0000000000000000L,0x0000000140000000L});
    public static final BitSet FOLLOW_127 = new BitSet(new long[]{0x0000000000000280L});
    public static final BitSet FOLLOW_128 = new BitSet(new long[]{0x0000000000000010L,0x2000005000000000L});
    public static final BitSet FOLLOW_129 = new BitSet(new long[]{0x0000000000000000L,0x2000000000000000L});
    public static final BitSet FOLLOW_130 = new BitSet(new long[]{0x0000000000000002L,0x0001000000000000L});
    public static final BitSet FOLLOW_131 = new BitSet(new long[]{0x0000000000000002L,0x0001000000000400L});
    public static final BitSet FOLLOW_132 = new BitSet(new long[]{0x0000000000000002L,0x0000000000000000L,0x0000000000300000L});
    public static final BitSet FOLLOW_133 = new BitSet(new long[]{0x0000000000000002L,0x0000000000000000L,0x0000000400000000L});
    public static final BitSet FOLLOW_134 = new BitSet(new long[]{0x0000000000000000L,0x0000000000000400L});
    public static final BitSet FOLLOW_135 = new BitSet(new long[]{0x0000000000000000L,0x0000000100000000L});
    public static final BitSet FOLLOW_136 = new BitSet(new long[]{0x0000000000000002L,0x0000000020000000L});
    public static final BitSet FOLLOW_137 = new BitSet(new long[]{0x0000000000000012L});

}
