/**
 *                                                                            
 * Copyright (c) 2011, 2016 - Loetz GmbH&Co.KG (69115 Heidelberg, Germany)
 *                                                                            
 * All rights reserved. This program and the accompanying materials           
 * are made available under the terms of the Eclipse Public License 2.0        
 * which accompanies this distribution, and is available at                  
 * https://www.eclipse.org/legal/epl-2.0/                                 
 *                                 
 * SPDX-License-Identifier: EPL-2.0                                 
 *                                                                            
 * Contributors:   
 * Christophe Loetz (Loetz GmbH&Co.KG) - initial implementation 
 */
package org.eclipse.osbp.xtext.table.services;

import com.google.inject.Inject;
import com.google.inject.Singleton;
import java.util.List;
import org.eclipse.osbp.xtext.oxtype.services.OXtypeGrammarAccess;
import org.eclipse.xtext.Action;
import org.eclipse.xtext.Alternatives;
import org.eclipse.xtext.Assignment;
import org.eclipse.xtext.CrossReference;
import org.eclipse.xtext.EnumLiteralDeclaration;
import org.eclipse.xtext.EnumRule;
import org.eclipse.xtext.Grammar;
import org.eclipse.xtext.GrammarUtil;
import org.eclipse.xtext.Group;
import org.eclipse.xtext.Keyword;
import org.eclipse.xtext.ParserRule;
import org.eclipse.xtext.RuleCall;
import org.eclipse.xtext.TerminalRule;
import org.eclipse.xtext.UnorderedGroup;
import org.eclipse.xtext.service.AbstractElementFinder.AbstractEnumRuleElementFinder;
import org.eclipse.xtext.service.AbstractElementFinder.AbstractGrammarElementFinder;
import org.eclipse.xtext.service.GrammarProvider;
import org.eclipse.xtext.xbase.annotations.services.XbaseWithAnnotationsGrammarAccess;
import org.eclipse.xtext.xbase.services.XbaseGrammarAccess;
import org.eclipse.xtext.xbase.services.XtypeGrammarAccess;

@Singleton
public class TableDSLGrammarAccess extends AbstractGrammarElementFinder {
	
	public class TableModelElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableModel");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cImportSectionAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cImportSectionXImportSectionParserRuleCall_0_0 = (RuleCall)cImportSectionAssignment_0.eContents().get(0);
		private final Assignment cPackagesAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cPackagesTablePackageParserRuleCall_1_0 = (RuleCall)cPackagesAssignment_1.eContents().get(0);
		
		//TableModel:
		//	importSection=XImportSection?
		//	packages+=TablePackage*;
		@Override public ParserRule getRule() { return rule; }
		
		//importSection=XImportSection? packages+=TablePackage*
		public Group getGroup() { return cGroup; }
		
		//importSection=XImportSection?
		public Assignment getImportSectionAssignment_0() { return cImportSectionAssignment_0; }
		
		//XImportSection
		public RuleCall getImportSectionXImportSectionParserRuleCall_0_0() { return cImportSectionXImportSectionParserRuleCall_0_0; }
		
		//packages+=TablePackage*
		public Assignment getPackagesAssignment_1() { return cPackagesAssignment_1; }
		
		//TablePackage
		public RuleCall getPackagesTablePackageParserRuleCall_1_0() { return cPackagesTablePackageParserRuleCall_1_0; }
	}
	public class TablePackageElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TablePackage");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTablePackageAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cPackageKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cNameAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cNameQualifiedNameParserRuleCall_2_0 = (RuleCall)cNameAssignment_2.eContents().get(0);
		private final Group cGroup_3 = (Group)cGroup.eContents().get(3);
		private final Keyword cLeftCurlyBracketKeyword_3_0 = (Keyword)cGroup_3.eContents().get(0);
		private final Assignment cTablesAssignment_3_1 = (Assignment)cGroup_3.eContents().get(1);
		private final RuleCall cTablesTableParserRuleCall_3_1_0 = (RuleCall)cTablesAssignment_3_1.eContents().get(0);
		private final Keyword cRightCurlyBracketKeyword_3_2 = (Keyword)cGroup_3.eContents().get(2);
		
		//TablePackage:
		//	{TablePackage} 'package' name=QualifiedName ('{' tables+=Table* '}')?;
		@Override public ParserRule getRule() { return rule; }
		
		//{TablePackage} 'package' name=QualifiedName ('{' tables+=Table* '}')?
		public Group getGroup() { return cGroup; }
		
		//{TablePackage}
		public Action getTablePackageAction_0() { return cTablePackageAction_0; }
		
		//'package'
		public Keyword getPackageKeyword_1() { return cPackageKeyword_1; }
		
		//name=QualifiedName
		public Assignment getNameAssignment_2() { return cNameAssignment_2; }
		
		//QualifiedName
		public RuleCall getNameQualifiedNameParserRuleCall_2_0() { return cNameQualifiedNameParserRuleCall_2_0; }
		
		//('{' tables+=Table* '}')?
		public Group getGroup_3() { return cGroup_3; }
		
		//'{'
		public Keyword getLeftCurlyBracketKeyword_3_0() { return cLeftCurlyBracketKeyword_3_0; }
		
		//tables+=Table*
		public Assignment getTablesAssignment_3_1() { return cTablesAssignment_3_1; }
		
		//Table
		public RuleCall getTablesTableParserRuleCall_3_1_0() { return cTablesTableParserRuleCall_3_1_0; }
		
		//'}'
		public Keyword getRightCurlyBracketKeyword_3_2() { return cRightCurlyBracketKeyword_3_2; }
	}
	public class TableElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.Table");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cTableKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cNameAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cNameIDTerminalRuleCall_2_0 = (RuleCall)cNameAssignment_2.eContents().get(0);
		private final Group cGroup_3 = (Group)cGroup.eContents().get(3);
		private final Assignment cDescriptionAssignment_3_0 = (Assignment)cGroup_3.eContents().get(0);
		private final Keyword cDescriptionDescribedByKeyword_3_0_0 = (Keyword)cDescriptionAssignment_3_0.eContents().get(0);
		private final Assignment cDescriptionValueAssignment_3_1 = (Assignment)cGroup_3.eContents().get(1);
		private final RuleCall cDescriptionValueTRANSLATABLESTRINGParserRuleCall_3_1_0 = (RuleCall)cDescriptionValueAssignment_3_1.eContents().get(0);
		private final Keyword cAsKeyword_4 = (Keyword)cGroup.eContents().get(4);
		private final Assignment cTabletypeAssignment_5 = (Assignment)cGroup.eContents().get(5);
		private final RuleCall cTabletypeTableOptionParserRuleCall_5_0 = (RuleCall)cTabletypeAssignment_5.eContents().get(0);
		
		//Table:
		//	{Table} 'table' name=ID (description?='describedBy' descriptionValue=TRANSLATABLESTRING)?
		//	'as' tabletype=TableOption;
		@Override public ParserRule getRule() { return rule; }
		
		//{Table} 'table' name=ID (description?='describedBy' descriptionValue=TRANSLATABLESTRING)? 'as' tabletype=TableOption
		public Group getGroup() { return cGroup; }
		
		//{Table}
		public Action getTableAction_0() { return cTableAction_0; }
		
		//'table'
		public Keyword getTableKeyword_1() { return cTableKeyword_1; }
		
		//name=ID
		public Assignment getNameAssignment_2() { return cNameAssignment_2; }
		
		//ID
		public RuleCall getNameIDTerminalRuleCall_2_0() { return cNameIDTerminalRuleCall_2_0; }
		
		//(description?='describedBy' descriptionValue=TRANSLATABLESTRING)?
		public Group getGroup_3() { return cGroup_3; }
		
		//description?='describedBy'
		public Assignment getDescriptionAssignment_3_0() { return cDescriptionAssignment_3_0; }
		
		//'describedBy'
		public Keyword getDescriptionDescribedByKeyword_3_0_0() { return cDescriptionDescribedByKeyword_3_0_0; }
		
		//descriptionValue=TRANSLATABLESTRING
		public Assignment getDescriptionValueAssignment_3_1() { return cDescriptionValueAssignment_3_1; }
		
		//TRANSLATABLESTRING
		public RuleCall getDescriptionValueTRANSLATABLESTRINGParserRuleCall_3_1_0() { return cDescriptionValueTRANSLATABLESTRINGParserRuleCall_3_1_0; }
		
		//'as'
		public Keyword getAsKeyword_4() { return cAsKeyword_4; }
		
		//tabletype=TableOption
		public Assignment getTabletypeAssignment_5() { return cTabletypeAssignment_5; }
		
		//TableOption
		public RuleCall getTabletypeTableOptionParserRuleCall_5_0() { return cTabletypeTableOptionParserRuleCall_5_0; }
	}
	public class TableOptionElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableOption");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final RuleCall cTableSelectionParserRuleCall_0 = (RuleCall)cAlternatives.eContents().get(0);
		private final RuleCall cTableTableParserRuleCall_1 = (RuleCall)cAlternatives.eContents().get(1);
		private final RuleCall cTableGridParserRuleCall_2 = (RuleCall)cAlternatives.eContents().get(2);
		
		//TableOption:
		//	TableSelection | TableTable | TableGrid;
		@Override public ParserRule getRule() { return rule; }
		
		//TableSelection | TableTable | TableGrid
		public Alternatives getAlternatives() { return cAlternatives; }
		
		//TableSelection
		public RuleCall getTableSelectionParserRuleCall_0() { return cTableSelectionParserRuleCall_0; }
		
		//TableTable
		public RuleCall getTableTableParserRuleCall_1() { return cTableTableParserRuleCall_1; }
		
		//TableGrid
		public RuleCall getTableGridParserRuleCall_2() { return cTableGridParserRuleCall_2; }
	}
	public class TableSelectionElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableSelection");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableSelectionAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cSelectionKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Alternatives cAlternatives_2 = (Alternatives)cGroup.eContents().get(2);
		private final Assignment cMultiSelectionAssignment_2_0 = (Assignment)cAlternatives_2.eContents().get(0);
		private final Keyword cMultiSelectionMultipleKeyword_2_0_0 = (Keyword)cMultiSelectionAssignment_2_0.eContents().get(0);
		private final Keyword cSingleKeyword_2_1 = (Keyword)cAlternatives_2.eContents().get(1);
		private final UnorderedGroup cUnorderedGroup_3 = (UnorderedGroup)cGroup.eContents().get(3);
		private final Assignment cSelectalwaysAssignment_3_0 = (Assignment)cUnorderedGroup_3.eContents().get(0);
		private final Keyword cSelectalwaysAlwaysSelectedKeyword_3_0_0 = (Keyword)cSelectalwaysAssignment_3_0.eContents().get(0);
		private final Group cGroup_3_1 = (Group)cUnorderedGroup_3.eContents().get(1);
		private final Keyword cRowHeaderKeyword_3_1_0 = (Keyword)cGroup_3_1.eContents().get(0);
		private final Assignment cHeaderModeAssignment_3_1_1 = (Assignment)cGroup_3_1.eContents().get(1);
		private final RuleCall cHeaderModeRowHeaderModeEnumRuleCall_3_1_1_0 = (RuleCall)cHeaderModeAssignment_3_1_1.eContents().get(0);
		private final Assignment cFilteringAssignment_3_2 = (Assignment)cUnorderedGroup_3.eContents().get(2);
		private final Keyword cFilteringFilteringKeyword_3_2_0 = (Keyword)cFilteringAssignment_3_2.eContents().get(0);
		private final Assignment cEmbeddedAssignment_3_3 = (Assignment)cUnorderedGroup_3.eContents().get(3);
		private final Keyword cEmbeddedEmbeddedKeyword_3_3_0 = (Keyword)cEmbeddedAssignment_3_3.eContents().get(0);
		private final Group cGroup_3_4 = (Group)cUnorderedGroup_3.eContents().get(4);
		private final Keyword cToolbarKeyword_3_4_0 = (Keyword)cGroup_3_4.eContents().get(0);
		private final Assignment cToolbarAssignment_3_4_1 = (Assignment)cGroup_3_4.eContents().get(1);
		private final CrossReference cToolbarActionToolbarCrossReference_3_4_1_0 = (CrossReference)cToolbarAssignment_3_4_1.eContents().get(0);
		private final RuleCall cToolbarActionToolbarIDTerminalRuleCall_3_4_1_0_1 = (RuleCall)cToolbarActionToolbarCrossReference_3_4_1_0.eContents().get(1);
		private final Group cGroup_4 = (Group)cGroup.eContents().get(4);
		private final Keyword cUsingKeyword_4_0 = (Keyword)cGroup_4.eContents().get(0);
		private final Assignment cSourceAssignment_4_1 = (Assignment)cGroup_4.eContents().get(1);
		private final RuleCall cSourceTableDatamartParserRuleCall_4_1_0 = (RuleCall)cSourceAssignment_4_1.eContents().get(0);
		
		//TableSelection:
		//	{TableSelection} 'selection' (multiSelection?='multiple' | 'single') (selectalways?='alwaysSelected'? & ('rowHeader'
		//	headerMode=RowHeaderMode)? & filtering?='filtering'? & embedded?='embedded'? & ('toolbar'
		//	toolbar=[action::ActionToolbar])?) ('using' source=TableDatamart)?;
		@Override public ParserRule getRule() { return rule; }
		
		//{TableSelection} 'selection' (multiSelection?='multiple' | 'single') (selectalways?='alwaysSelected'? & ('rowHeader'
		//headerMode=RowHeaderMode)? & filtering?='filtering'? & embedded?='embedded'? & ('toolbar'
		//toolbar=[action::ActionToolbar])?) ('using' source=TableDatamart)?
		public Group getGroup() { return cGroup; }
		
		//{TableSelection}
		public Action getTableSelectionAction_0() { return cTableSelectionAction_0; }
		
		//'selection'
		public Keyword getSelectionKeyword_1() { return cSelectionKeyword_1; }
		
		//multiSelection?='multiple' | 'single'
		public Alternatives getAlternatives_2() { return cAlternatives_2; }
		
		//multiSelection?='multiple'
		public Assignment getMultiSelectionAssignment_2_0() { return cMultiSelectionAssignment_2_0; }
		
		//'multiple'
		public Keyword getMultiSelectionMultipleKeyword_2_0_0() { return cMultiSelectionMultipleKeyword_2_0_0; }
		
		//'single'
		public Keyword getSingleKeyword_2_1() { return cSingleKeyword_2_1; }
		
		//selectalways?='alwaysSelected'? & ('rowHeader' headerMode=RowHeaderMode)? & filtering?='filtering'? &
		//embedded?='embedded'? & ('toolbar' toolbar=[action::ActionToolbar])?
		public UnorderedGroup getUnorderedGroup_3() { return cUnorderedGroup_3; }
		
		//selectalways?='alwaysSelected'?
		public Assignment getSelectalwaysAssignment_3_0() { return cSelectalwaysAssignment_3_0; }
		
		//'alwaysSelected'
		public Keyword getSelectalwaysAlwaysSelectedKeyword_3_0_0() { return cSelectalwaysAlwaysSelectedKeyword_3_0_0; }
		
		//('rowHeader' headerMode=RowHeaderMode)?
		public Group getGroup_3_1() { return cGroup_3_1; }
		
		//'rowHeader'
		public Keyword getRowHeaderKeyword_3_1_0() { return cRowHeaderKeyword_3_1_0; }
		
		//headerMode=RowHeaderMode
		public Assignment getHeaderModeAssignment_3_1_1() { return cHeaderModeAssignment_3_1_1; }
		
		//RowHeaderMode
		public RuleCall getHeaderModeRowHeaderModeEnumRuleCall_3_1_1_0() { return cHeaderModeRowHeaderModeEnumRuleCall_3_1_1_0; }
		
		//filtering?='filtering'?
		public Assignment getFilteringAssignment_3_2() { return cFilteringAssignment_3_2; }
		
		//'filtering'
		public Keyword getFilteringFilteringKeyword_3_2_0() { return cFilteringFilteringKeyword_3_2_0; }
		
		//embedded?='embedded'?
		public Assignment getEmbeddedAssignment_3_3() { return cEmbeddedAssignment_3_3; }
		
		//'embedded'
		public Keyword getEmbeddedEmbeddedKeyword_3_3_0() { return cEmbeddedEmbeddedKeyword_3_3_0; }
		
		//('toolbar' toolbar=[action::ActionToolbar])?
		public Group getGroup_3_4() { return cGroup_3_4; }
		
		//'toolbar'
		public Keyword getToolbarKeyword_3_4_0() { return cToolbarKeyword_3_4_0; }
		
		//toolbar=[action::ActionToolbar]
		public Assignment getToolbarAssignment_3_4_1() { return cToolbarAssignment_3_4_1; }
		
		//[action::ActionToolbar]
		public CrossReference getToolbarActionToolbarCrossReference_3_4_1_0() { return cToolbarActionToolbarCrossReference_3_4_1_0; }
		
		//ID
		public RuleCall getToolbarActionToolbarIDTerminalRuleCall_3_4_1_0_1() { return cToolbarActionToolbarIDTerminalRuleCall_3_4_1_0_1; }
		
		//('using' source=TableDatamart)?
		public Group getGroup_4() { return cGroup_4; }
		
		//'using'
		public Keyword getUsingKeyword_4_0() { return cUsingKeyword_4_0; }
		
		//source=TableDatamart
		public Assignment getSourceAssignment_4_1() { return cSourceAssignment_4_1; }
		
		//TableDatamart
		public RuleCall getSourceTableDatamartParserRuleCall_4_1_0() { return cSourceTableDatamartParserRuleCall_4_1_0; }
	}
	public class TableTableElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableTable");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableTableAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cReadOnlyKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final UnorderedGroup cUnorderedGroup_2 = (UnorderedGroup)cGroup.eContents().get(2);
		private final Assignment cSelectalwaysAssignment_2_0 = (Assignment)cUnorderedGroup_2.eContents().get(0);
		private final Keyword cSelectalwaysAlwaysSelectedKeyword_2_0_0 = (Keyword)cSelectalwaysAssignment_2_0.eContents().get(0);
		private final Assignment cSelectByIdAssignment_2_1 = (Assignment)cUnorderedGroup_2.eContents().get(1);
		private final Keyword cSelectByIdSelectByIdKeyword_2_1_0 = (Keyword)cSelectByIdAssignment_2_1.eContents().get(0);
		private final Group cGroup_2_2 = (Group)cUnorderedGroup_2.eContents().get(2);
		private final Keyword cRowHeaderKeyword_2_2_0 = (Keyword)cGroup_2_2.eContents().get(0);
		private final Assignment cHeaderModeAssignment_2_2_1 = (Assignment)cGroup_2_2.eContents().get(1);
		private final RuleCall cHeaderModeRowHeaderModeEnumRuleCall_2_2_1_0 = (RuleCall)cHeaderModeAssignment_2_2_1.eContents().get(0);
		private final Assignment cFilteringAssignment_2_3 = (Assignment)cUnorderedGroup_2.eContents().get(3);
		private final Keyword cFilteringFilteringKeyword_2_3_0 = (Keyword)cFilteringAssignment_2_3.eContents().get(0);
		private final Assignment cEmbeddedAssignment_2_4 = (Assignment)cUnorderedGroup_2.eContents().get(4);
		private final Keyword cEmbeddedEmbeddedKeyword_2_4_0 = (Keyword)cEmbeddedAssignment_2_4.eContents().get(0);
		private final Group cGroup_2_5 = (Group)cUnorderedGroup_2.eContents().get(5);
		private final Keyword cToolbarKeyword_2_5_0 = (Keyword)cGroup_2_5.eContents().get(0);
		private final Assignment cToolbarAssignment_2_5_1 = (Assignment)cGroup_2_5.eContents().get(1);
		private final CrossReference cToolbarActionToolbarCrossReference_2_5_1_0 = (CrossReference)cToolbarAssignment_2_5_1.eContents().get(0);
		private final RuleCall cToolbarActionToolbarIDTerminalRuleCall_2_5_1_0_1 = (RuleCall)cToolbarActionToolbarCrossReference_2_5_1_0.eContents().get(1);
		private final Group cGroup_3 = (Group)cGroup.eContents().get(3);
		private final Keyword cUsingKeyword_3_0 = (Keyword)cGroup_3.eContents().get(0);
		private final Assignment cSourceAssignment_3_1 = (Assignment)cGroup_3.eContents().get(1);
		private final RuleCall cSourceTableDatamartParserRuleCall_3_1_0 = (RuleCall)cSourceAssignment_3_1.eContents().get(0);
		
		//TableTable:
		//	{TableTable} 'readOnly' (selectalways?='alwaysSelected'? & selectById?='selectById'? & ('rowHeader'
		//	headerMode=RowHeaderMode)? & filtering?='filtering'? & embedded?='embedded'? & ('toolbar'
		//	toolbar=[action::ActionToolbar])?) ('using' source=TableDatamart)?;
		@Override public ParserRule getRule() { return rule; }
		
		//{TableTable} 'readOnly' (selectalways?='alwaysSelected'? & selectById?='selectById'? & ('rowHeader'
		//headerMode=RowHeaderMode)? & filtering?='filtering'? & embedded?='embedded'? & ('toolbar'
		//toolbar=[action::ActionToolbar])?) ('using' source=TableDatamart)?
		public Group getGroup() { return cGroup; }
		
		//{TableTable}
		public Action getTableTableAction_0() { return cTableTableAction_0; }
		
		//'readOnly'
		public Keyword getReadOnlyKeyword_1() { return cReadOnlyKeyword_1; }
		
		//selectalways?='alwaysSelected'? & selectById?='selectById'? & ('rowHeader' headerMode=RowHeaderMode)? &
		//filtering?='filtering'? & embedded?='embedded'? & ('toolbar' toolbar=[action::ActionToolbar])?
		public UnorderedGroup getUnorderedGroup_2() { return cUnorderedGroup_2; }
		
		//selectalways?='alwaysSelected'?
		public Assignment getSelectalwaysAssignment_2_0() { return cSelectalwaysAssignment_2_0; }
		
		//'alwaysSelected'
		public Keyword getSelectalwaysAlwaysSelectedKeyword_2_0_0() { return cSelectalwaysAlwaysSelectedKeyword_2_0_0; }
		
		//selectById?='selectById'?
		public Assignment getSelectByIdAssignment_2_1() { return cSelectByIdAssignment_2_1; }
		
		//'selectById'
		public Keyword getSelectByIdSelectByIdKeyword_2_1_0() { return cSelectByIdSelectByIdKeyword_2_1_0; }
		
		//('rowHeader' headerMode=RowHeaderMode)?
		public Group getGroup_2_2() { return cGroup_2_2; }
		
		//'rowHeader'
		public Keyword getRowHeaderKeyword_2_2_0() { return cRowHeaderKeyword_2_2_0; }
		
		//headerMode=RowHeaderMode
		public Assignment getHeaderModeAssignment_2_2_1() { return cHeaderModeAssignment_2_2_1; }
		
		//RowHeaderMode
		public RuleCall getHeaderModeRowHeaderModeEnumRuleCall_2_2_1_0() { return cHeaderModeRowHeaderModeEnumRuleCall_2_2_1_0; }
		
		//filtering?='filtering'?
		public Assignment getFilteringAssignment_2_3() { return cFilteringAssignment_2_3; }
		
		//'filtering'
		public Keyword getFilteringFilteringKeyword_2_3_0() { return cFilteringFilteringKeyword_2_3_0; }
		
		//embedded?='embedded'?
		public Assignment getEmbeddedAssignment_2_4() { return cEmbeddedAssignment_2_4; }
		
		//'embedded'
		public Keyword getEmbeddedEmbeddedKeyword_2_4_0() { return cEmbeddedEmbeddedKeyword_2_4_0; }
		
		//('toolbar' toolbar=[action::ActionToolbar])?
		public Group getGroup_2_5() { return cGroup_2_5; }
		
		//'toolbar'
		public Keyword getToolbarKeyword_2_5_0() { return cToolbarKeyword_2_5_0; }
		
		//toolbar=[action::ActionToolbar]
		public Assignment getToolbarAssignment_2_5_1() { return cToolbarAssignment_2_5_1; }
		
		//[action::ActionToolbar]
		public CrossReference getToolbarActionToolbarCrossReference_2_5_1_0() { return cToolbarActionToolbarCrossReference_2_5_1_0; }
		
		//ID
		public RuleCall getToolbarActionToolbarIDTerminalRuleCall_2_5_1_0_1() { return cToolbarActionToolbarIDTerminalRuleCall_2_5_1_0_1; }
		
		//('using' source=TableDatamart)?
		public Group getGroup_3() { return cGroup_3; }
		
		//'using'
		public Keyword getUsingKeyword_3_0() { return cUsingKeyword_3_0; }
		
		//source=TableDatamart
		public Assignment getSourceAssignment_3_1() { return cSourceAssignment_3_1; }
		
		//TableDatamart
		public RuleCall getSourceTableDatamartParserRuleCall_3_1_0() { return cSourceTableDatamartParserRuleCall_3_1_0; }
	}
	public class TablePreorderElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TablePreorder");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTablePreorderAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cPreorderKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cColumnAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cColumnTableValueElementParserRuleCall_2_0 = (RuleCall)cColumnAssignment_2.eContents().get(0);
		private final Assignment cAscendingAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final Keyword cAscendingAscendingKeyword_3_0 = (Keyword)cAscendingAssignment_3.eContents().get(0);
		
		//TablePreorder:
		//	{TablePreorder} 'preorder' column=TableValueElement ascending?='ascending'?;
		@Override public ParserRule getRule() { return rule; }
		
		//{TablePreorder} 'preorder' column=TableValueElement ascending?='ascending'?
		public Group getGroup() { return cGroup; }
		
		//{TablePreorder}
		public Action getTablePreorderAction_0() { return cTablePreorderAction_0; }
		
		//'preorder'
		public Keyword getPreorderKeyword_1() { return cPreorderKeyword_1; }
		
		//column=TableValueElement
		public Assignment getColumnAssignment_2() { return cColumnAssignment_2; }
		
		//TableValueElement
		public RuleCall getColumnTableValueElementParserRuleCall_2_0() { return cColumnTableValueElementParserRuleCall_2_0; }
		
		//ascending?='ascending'?
		public Assignment getAscendingAssignment_3() { return cAscendingAssignment_3; }
		
		//'ascending'
		public Keyword getAscendingAscendingKeyword_3_0() { return cAscendingAscendingKeyword_3_0; }
	}
	public class TableValueElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableValue");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableValueAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cValueKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cColumnAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cColumnTableValueElementParserRuleCall_2_0 = (RuleCall)cColumnAssignment_2.eContents().get(0);
		private final UnorderedGroup cUnorderedGroup_3 = (UnorderedGroup)cGroup.eContents().get(3);
		private final Assignment cCollapsedAssignment_3_0 = (Assignment)cUnorderedGroup_3.eContents().get(0);
		private final Keyword cCollapsedCollapseKeyword_3_0_0 = (Keyword)cCollapsedAssignment_3_0.eContents().get(0);
		private final Group cGroup_3_1 = (Group)cUnorderedGroup_3.eContents().get(1);
		private final Keyword cIconKeyword_3_1_0 = (Keyword)cGroup_3_1.eContents().get(0);
		private final Assignment cIconNameAssignment_3_1_1 = (Assignment)cGroup_3_1.eContents().get(1);
		private final RuleCall cIconNameSTRINGTerminalRuleCall_3_1_1_0 = (RuleCall)cIconNameAssignment_3_1_1.eContents().get(0);
		private final Assignment cFormatterAssignment_3_2 = (Assignment)cUnorderedGroup_3.eContents().get(2);
		private final RuleCall cFormatterTableFormatterParserRuleCall_3_2_0 = (RuleCall)cFormatterAssignment_3_2.eContents().get(0);
		private final Group cGroup_3_3 = (Group)cUnorderedGroup_3.eContents().get(3);
		private final Assignment cHasImageAssignment_3_3_0 = (Assignment)cGroup_3_3.eContents().get(0);
		private final Keyword cHasImageImageKeyword_3_3_0_0 = (Keyword)cHasImageAssignment_3_3_0.eContents().get(0);
		private final Assignment cImageAssignment_3_3_1 = (Assignment)cGroup_3_3.eContents().get(1);
		private final RuleCall cImageTableImageParserRuleCall_3_3_1_0 = (RuleCall)cImageAssignment_3_3_1.eContents().get(0);
		private final Assignment cTooltipPatternAssignment_3_4 = (Assignment)cUnorderedGroup_3.eContents().get(4);
		private final RuleCall cTooltipPatternTableTooltipPatternParserRuleCall_3_4_0 = (RuleCall)cTooltipPatternAssignment_3_4.eContents().get(0);
		private final UnorderedGroup cUnorderedGroup_4 = (UnorderedGroup)cGroup.eContents().get(4);
		private final Group cGroup_4_0 = (Group)cUnorderedGroup_4.eContents().get(0);
		private final Keyword cIntervalsKeyword_4_0_0 = (Keyword)cGroup_4_0.eContents().get(0);
		private final Assignment cHideLabelIntervalAssignment_4_0_1 = (Assignment)cGroup_4_0.eContents().get(1);
		private final Keyword cHideLabelIntervalHidelabelKeyword_4_0_1_0 = (Keyword)cHideLabelIntervalAssignment_4_0_1.eContents().get(0);
		private final Keyword cLeftCurlyBracketKeyword_4_0_2 = (Keyword)cGroup_4_0.eContents().get(2);
		private final Assignment cIntervalsAssignment_4_0_3 = (Assignment)cGroup_4_0.eContents().get(3);
		private final RuleCall cIntervalsTableIntervalParserRuleCall_4_0_3_0 = (RuleCall)cIntervalsAssignment_4_0_3.eContents().get(0);
		private final Keyword cRightCurlyBracketKeyword_4_0_4 = (Keyword)cGroup_4_0.eContents().get(4);
		private final Group cGroup_4_1 = (Group)cUnorderedGroup_4.eContents().get(1);
		private final Keyword cLookupsKeyword_4_1_0 = (Keyword)cGroup_4_1.eContents().get(0);
		private final Assignment cHideLabelLookupAssignment_4_1_1 = (Assignment)cGroup_4_1.eContents().get(1);
		private final Keyword cHideLabelLookupHidelabelKeyword_4_1_1_0 = (Keyword)cHideLabelLookupAssignment_4_1_1.eContents().get(0);
		private final Keyword cLeftCurlyBracketKeyword_4_1_2 = (Keyword)cGroup_4_1.eContents().get(2);
		private final Assignment cLookupsAssignment_4_1_3 = (Assignment)cGroup_4_1.eContents().get(3);
		private final RuleCall cLookupsTableLookupParserRuleCall_4_1_3_0 = (RuleCall)cLookupsAssignment_4_1_3.eContents().get(0);
		private final Keyword cRightCurlyBracketKeyword_4_1_4 = (Keyword)cGroup_4_1.eContents().get(4);
		
		//TableValue:
		//	{TableValue} 'value' column=TableValueElement (collapsed?='collapse'? & ('icon' iconName=STRING)? &
		//	formatter=TableFormatter? & (hasImage?='image' image=TableImage)? & tooltipPattern=TableTooltipPattern?) (('intervals'
		//	hideLabelInterval?='hidelabel'? '{' intervals+=TableInterval* '}')? & ('lookups'
		//	hideLabelLookup?='hidelabel'? '{' lookups+=TableLookup* '}')?);
		@Override public ParserRule getRule() { return rule; }
		
		//{TableValue} 'value' column=TableValueElement (collapsed?='collapse'? & ('icon' iconName=STRING)? &
		//formatter=TableFormatter? & (hasImage?='image' image=TableImage)? & tooltipPattern=TableTooltipPattern?) (('intervals'
		//hideLabelInterval?='hidelabel'? '{' intervals+=TableInterval* '}')? & ('lookups' hideLabelLookup?='hidelabel'? '{'
		//lookups+=TableLookup* '}')?)
		public Group getGroup() { return cGroup; }
		
		//{TableValue}
		public Action getTableValueAction_0() { return cTableValueAction_0; }
		
		//'value'
		public Keyword getValueKeyword_1() { return cValueKeyword_1; }
		
		//column=TableValueElement
		public Assignment getColumnAssignment_2() { return cColumnAssignment_2; }
		
		//TableValueElement
		public RuleCall getColumnTableValueElementParserRuleCall_2_0() { return cColumnTableValueElementParserRuleCall_2_0; }
		
		//collapsed?='collapse'? & ('icon' iconName=STRING)? & formatter=TableFormatter? & (hasImage?='image' image=TableImage)? &
		//tooltipPattern=TableTooltipPattern?
		public UnorderedGroup getUnorderedGroup_3() { return cUnorderedGroup_3; }
		
		//collapsed?='collapse'?
		public Assignment getCollapsedAssignment_3_0() { return cCollapsedAssignment_3_0; }
		
		//'collapse'
		public Keyword getCollapsedCollapseKeyword_3_0_0() { return cCollapsedCollapseKeyword_3_0_0; }
		
		//('icon' iconName=STRING)?
		public Group getGroup_3_1() { return cGroup_3_1; }
		
		//'icon'
		public Keyword getIconKeyword_3_1_0() { return cIconKeyword_3_1_0; }
		
		//iconName=STRING
		public Assignment getIconNameAssignment_3_1_1() { return cIconNameAssignment_3_1_1; }
		
		//STRING
		public RuleCall getIconNameSTRINGTerminalRuleCall_3_1_1_0() { return cIconNameSTRINGTerminalRuleCall_3_1_1_0; }
		
		//formatter=TableFormatter?
		public Assignment getFormatterAssignment_3_2() { return cFormatterAssignment_3_2; }
		
		//TableFormatter
		public RuleCall getFormatterTableFormatterParserRuleCall_3_2_0() { return cFormatterTableFormatterParserRuleCall_3_2_0; }
		
		//(hasImage?='image' image=TableImage)?
		public Group getGroup_3_3() { return cGroup_3_3; }
		
		//hasImage?='image'
		public Assignment getHasImageAssignment_3_3_0() { return cHasImageAssignment_3_3_0; }
		
		//'image'
		public Keyword getHasImageImageKeyword_3_3_0_0() { return cHasImageImageKeyword_3_3_0_0; }
		
		//image=TableImage
		public Assignment getImageAssignment_3_3_1() { return cImageAssignment_3_3_1; }
		
		//TableImage
		public RuleCall getImageTableImageParserRuleCall_3_3_1_0() { return cImageTableImageParserRuleCall_3_3_1_0; }
		
		//tooltipPattern=TableTooltipPattern?
		public Assignment getTooltipPatternAssignment_3_4() { return cTooltipPatternAssignment_3_4; }
		
		//TableTooltipPattern
		public RuleCall getTooltipPatternTableTooltipPatternParserRuleCall_3_4_0() { return cTooltipPatternTableTooltipPatternParserRuleCall_3_4_0; }
		
		//('intervals' hideLabelInterval?='hidelabel'? '{' intervals+=TableInterval* '}')? & ('lookups'
		//hideLabelLookup?='hidelabel'? '{' lookups+=TableLookup* '}')?
		public UnorderedGroup getUnorderedGroup_4() { return cUnorderedGroup_4; }
		
		//('intervals' hideLabelInterval?='hidelabel'? '{' intervals+=TableInterval* '}')?
		public Group getGroup_4_0() { return cGroup_4_0; }
		
		//'intervals'
		public Keyword getIntervalsKeyword_4_0_0() { return cIntervalsKeyword_4_0_0; }
		
		//hideLabelInterval?='hidelabel'?
		public Assignment getHideLabelIntervalAssignment_4_0_1() { return cHideLabelIntervalAssignment_4_0_1; }
		
		//'hidelabel'
		public Keyword getHideLabelIntervalHidelabelKeyword_4_0_1_0() { return cHideLabelIntervalHidelabelKeyword_4_0_1_0; }
		
		//'{'
		public Keyword getLeftCurlyBracketKeyword_4_0_2() { return cLeftCurlyBracketKeyword_4_0_2; }
		
		//intervals+=TableInterval*
		public Assignment getIntervalsAssignment_4_0_3() { return cIntervalsAssignment_4_0_3; }
		
		//TableInterval
		public RuleCall getIntervalsTableIntervalParserRuleCall_4_0_3_0() { return cIntervalsTableIntervalParserRuleCall_4_0_3_0; }
		
		//'}'
		public Keyword getRightCurlyBracketKeyword_4_0_4() { return cRightCurlyBracketKeyword_4_0_4; }
		
		//('lookups' hideLabelLookup?='hidelabel'? '{' lookups+=TableLookup* '}')?
		public Group getGroup_4_1() { return cGroup_4_1; }
		
		//'lookups'
		public Keyword getLookupsKeyword_4_1_0() { return cLookupsKeyword_4_1_0; }
		
		//hideLabelLookup?='hidelabel'?
		public Assignment getHideLabelLookupAssignment_4_1_1() { return cHideLabelLookupAssignment_4_1_1; }
		
		//'hidelabel'
		public Keyword getHideLabelLookupHidelabelKeyword_4_1_1_0() { return cHideLabelLookupHidelabelKeyword_4_1_1_0; }
		
		//'{'
		public Keyword getLeftCurlyBracketKeyword_4_1_2() { return cLeftCurlyBracketKeyword_4_1_2; }
		
		//lookups+=TableLookup*
		public Assignment getLookupsAssignment_4_1_3() { return cLookupsAssignment_4_1_3; }
		
		//TableLookup
		public RuleCall getLookupsTableLookupParserRuleCall_4_1_3_0() { return cLookupsTableLookupParserRuleCall_4_1_3_0; }
		
		//'}'
		public Keyword getRightCurlyBracketKeyword_4_1_4() { return cRightCurlyBracketKeyword_4_1_4; }
	}
	public class TableFormatterElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableFormatter");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableFormatterAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cFormatterKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cFormatAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cFormatSTRINGTerminalRuleCall_2_0 = (RuleCall)cFormatAssignment_2.eContents().get(0);
		
		//TableFormatter:
		//	{TableFormatter} 'formatter' format=STRING;
		@Override public ParserRule getRule() { return rule; }
		
		//{TableFormatter} 'formatter' format=STRING
		public Group getGroup() { return cGroup; }
		
		//{TableFormatter}
		public Action getTableFormatterAction_0() { return cTableFormatterAction_0; }
		
		//'formatter'
		public Keyword getFormatterKeyword_1() { return cFormatterKeyword_1; }
		
		//format=STRING
		public Assignment getFormatAssignment_2() { return cFormatAssignment_2; }
		
		//STRING
		public RuleCall getFormatSTRINGTerminalRuleCall_2_0() { return cFormatSTRINGTerminalRuleCall_2_0; }
	}
	public class TableImageElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableImage");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableImageAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cPathKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cImagePathPatternAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cImagePathPatternSTRINGTerminalRuleCall_2_0 = (RuleCall)cImagePathPatternAssignment_2.eContents().get(0);
		private final UnorderedGroup cUnorderedGroup_3 = (UnorderedGroup)cGroup.eContents().get(3);
		private final Assignment cHasParameterAssignment_3_0 = (Assignment)cUnorderedGroup_3.eContents().get(0);
		private final Keyword cHasParameterDynamicKeyword_3_0_0 = (Keyword)cHasParameterAssignment_3_0.eContents().get(0);
		private final Assignment cHideImageLabelAssignment_3_1 = (Assignment)cUnorderedGroup_3.eContents().get(1);
		private final Keyword cHideImageLabelHidelabelKeyword_3_1_0 = (Keyword)cHideImageLabelAssignment_3_1.eContents().get(0);
		private final Group cGroup_3_2 = (Group)cUnorderedGroup_3.eContents().get(2);
		private final Assignment cResizeAssignment_3_2_0 = (Assignment)cGroup_3_2.eContents().get(0);
		private final Keyword cResizeResizeKeyword_3_2_0_0 = (Keyword)cResizeAssignment_3_2_0.eContents().get(0);
		private final Assignment cResizeStringAssignment_3_2_1 = (Assignment)cGroup_3_2.eContents().get(1);
		private final RuleCall cResizeStringSTRINGTerminalRuleCall_3_2_1_0 = (RuleCall)cResizeStringAssignment_3_2_1.eContents().get(0);
		
		//TableImage:
		//	{TableImage} 'path' imagePathPattern=STRING (hasParameter?='dynamic'? & hideImageLabel?='hidelabel'? &
		//	(resize?='resize' resizeString=STRING)?);
		@Override public ParserRule getRule() { return rule; }
		
		//{TableImage} 'path' imagePathPattern=STRING (hasParameter?='dynamic'? & hideImageLabel?='hidelabel'? & (resize?='resize'
		//resizeString=STRING)?)
		public Group getGroup() { return cGroup; }
		
		//{TableImage}
		public Action getTableImageAction_0() { return cTableImageAction_0; }
		
		//'path'
		public Keyword getPathKeyword_1() { return cPathKeyword_1; }
		
		//imagePathPattern=STRING
		public Assignment getImagePathPatternAssignment_2() { return cImagePathPatternAssignment_2; }
		
		//STRING
		public RuleCall getImagePathPatternSTRINGTerminalRuleCall_2_0() { return cImagePathPatternSTRINGTerminalRuleCall_2_0; }
		
		//hasParameter?='dynamic'? & hideImageLabel?='hidelabel'? & (resize?='resize' resizeString=STRING)?
		public UnorderedGroup getUnorderedGroup_3() { return cUnorderedGroup_3; }
		
		//hasParameter?='dynamic'?
		public Assignment getHasParameterAssignment_3_0() { return cHasParameterAssignment_3_0; }
		
		//'dynamic'
		public Keyword getHasParameterDynamicKeyword_3_0_0() { return cHasParameterDynamicKeyword_3_0_0; }
		
		//hideImageLabel?='hidelabel'?
		public Assignment getHideImageLabelAssignment_3_1() { return cHideImageLabelAssignment_3_1; }
		
		//'hidelabel'
		public Keyword getHideImageLabelHidelabelKeyword_3_1_0() { return cHideImageLabelHidelabelKeyword_3_1_0; }
		
		//(resize?='resize' resizeString=STRING)?
		public Group getGroup_3_2() { return cGroup_3_2; }
		
		//resize?='resize'
		public Assignment getResizeAssignment_3_2_0() { return cResizeAssignment_3_2_0; }
		
		//'resize'
		public Keyword getResizeResizeKeyword_3_2_0_0() { return cResizeResizeKeyword_3_2_0_0; }
		
		//resizeString=STRING
		public Assignment getResizeStringAssignment_3_2_1() { return cResizeStringAssignment_3_2_1; }
		
		//STRING
		public RuleCall getResizeStringSTRINGTerminalRuleCall_3_2_1_0() { return cResizeStringSTRINGTerminalRuleCall_3_2_1_0; }
	}
	public class TableTooltipPatternElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableTooltipPattern");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableTooltipPatternAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cTooltipPatternKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cTooltipPatternAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cTooltipPatternTRANSLATABLESTRINGParserRuleCall_2_0 = (RuleCall)cTooltipPatternAssignment_2.eContents().get(0);
		
		//TableTooltipPattern:
		//	{TableTooltipPattern} 'tooltipPattern' tooltipPattern=TRANSLATABLESTRING;
		@Override public ParserRule getRule() { return rule; }
		
		//{TableTooltipPattern} 'tooltipPattern' tooltipPattern=TRANSLATABLESTRING
		public Group getGroup() { return cGroup; }
		
		//{TableTooltipPattern}
		public Action getTableTooltipPatternAction_0() { return cTableTooltipPatternAction_0; }
		
		//'tooltipPattern'
		public Keyword getTooltipPatternKeyword_1() { return cTooltipPatternKeyword_1; }
		
		//tooltipPattern=TRANSLATABLESTRING
		public Assignment getTooltipPatternAssignment_2() { return cTooltipPatternAssignment_2; }
		
		//TRANSLATABLESTRING
		public RuleCall getTooltipPatternTRANSLATABLESTRINGParserRuleCall_2_0() { return cTooltipPatternTRANSLATABLESTRINGParserRuleCall_2_0; }
	}
	public class TableValueElementElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableValueElement");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final RuleCall cTableMeasureParserRuleCall_0 = (RuleCall)cAlternatives.eContents().get(0);
		private final RuleCall cTableDerivedParserRuleCall_1 = (RuleCall)cAlternatives.eContents().get(1);
		private final RuleCall cTableHierarchyParserRuleCall_2 = (RuleCall)cAlternatives.eContents().get(2);
		private final RuleCall cTableAttributeParserRuleCall_3 = (RuleCall)cAlternatives.eContents().get(3);
		private final RuleCall cTableAggregationParserRuleCall_4 = (RuleCall)cAlternatives.eContents().get(4);
		private final RuleCall cTableOrdinalParserRuleCall_5 = (RuleCall)cAlternatives.eContents().get(5);
		private final RuleCall cTableColumnParserRuleCall_6 = (RuleCall)cAlternatives.eContents().get(6);
		private final RuleCall cTableTaskParserRuleCall_7 = (RuleCall)cAlternatives.eContents().get(7);
		private final RuleCall cTableAllColumnsParserRuleCall_8 = (RuleCall)cAlternatives.eContents().get(8);
		
		//TableValueElement:
		//	TableMeasure | TableDerived | TableHierarchy | TableAttribute | TableAggregation | TableOrdinal | TableColumn |
		//	TableTask | TableAllColumns;
		@Override public ParserRule getRule() { return rule; }
		
		//TableMeasure | TableDerived | TableHierarchy | TableAttribute | TableAggregation | TableOrdinal | TableColumn |
		//TableTask | TableAllColumns
		public Alternatives getAlternatives() { return cAlternatives; }
		
		//TableMeasure
		public RuleCall getTableMeasureParserRuleCall_0() { return cTableMeasureParserRuleCall_0; }
		
		//TableDerived
		public RuleCall getTableDerivedParserRuleCall_1() { return cTableDerivedParserRuleCall_1; }
		
		//TableHierarchy
		public RuleCall getTableHierarchyParserRuleCall_2() { return cTableHierarchyParserRuleCall_2; }
		
		//TableAttribute
		public RuleCall getTableAttributeParserRuleCall_3() { return cTableAttributeParserRuleCall_3; }
		
		//TableAggregation
		public RuleCall getTableAggregationParserRuleCall_4() { return cTableAggregationParserRuleCall_4; }
		
		//TableOrdinal
		public RuleCall getTableOrdinalParserRuleCall_5() { return cTableOrdinalParserRuleCall_5; }
		
		//TableColumn
		public RuleCall getTableColumnParserRuleCall_6() { return cTableColumnParserRuleCall_6; }
		
		//TableTask
		public RuleCall getTableTaskParserRuleCall_7() { return cTableTaskParserRuleCall_7; }
		
		//TableAllColumns
		public RuleCall getTableAllColumnsParserRuleCall_8() { return cTableAllColumnsParserRuleCall_8; }
	}
	public class TableTaskElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableTask");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableTaskAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cTaskIdKeyword_1 = (Keyword)cGroup.eContents().get(1);
		
		//TableTask:
		//	{TableTask} 'taskId';
		@Override public ParserRule getRule() { return rule; }
		
		//{TableTask} 'taskId'
		public Group getGroup() { return cGroup; }
		
		//{TableTask}
		public Action getTableTaskAction_0() { return cTableTaskAction_0; }
		
		//'taskId'
		public Keyword getTaskIdKeyword_1() { return cTaskIdKeyword_1; }
	}
	public class TableAllColumnsElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableAllColumns");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableAllColumnsAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cAllColumnsKeyword_1 = (Keyword)cGroup.eContents().get(1);
		
		//TableAllColumns:
		//	{TableAllColumns} 'allColumns';
		@Override public ParserRule getRule() { return rule; }
		
		//{TableAllColumns} 'allColumns'
		public Group getGroup() { return cGroup; }
		
		//{TableAllColumns}
		public Action getTableAllColumnsAction_0() { return cTableAllColumnsAction_0; }
		
		//'allColumns'
		public Keyword getAllColumnsKeyword_1() { return cAllColumnsKeyword_1; }
	}
	public class TableOrdinalElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableOrdinal");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cOrdinalKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cValueRefAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cValueRefNumberParserRuleCall_1_0 = (RuleCall)cValueRefAssignment_1.eContents().get(0);
		
		//TableOrdinal:
		//	'ordinal' valueRef=Number;
		@Override public ParserRule getRule() { return rule; }
		
		//'ordinal' valueRef=Number
		public Group getGroup() { return cGroup; }
		
		//'ordinal'
		public Keyword getOrdinalKeyword_0() { return cOrdinalKeyword_0; }
		
		//valueRef=Number
		public Assignment getValueRefAssignment_1() { return cValueRefAssignment_1; }
		
		//Number
		public RuleCall getValueRefNumberParserRuleCall_1_0() { return cValueRefNumberParserRuleCall_1_0; }
	}
	public class TableColumnElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableColumn");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cColumnKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cValueRefAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final CrossReference cValueRefDatamartColumnCrossReference_1_0 = (CrossReference)cValueRefAssignment_1.eContents().get(0);
		private final RuleCall cValueRefDatamartColumnIDTerminalRuleCall_1_0_1 = (RuleCall)cValueRefDatamartColumnCrossReference_1_0.eContents().get(1);
		
		//TableColumn:
		//	'column' valueRef=[datamart::DatamartColumn];
		@Override public ParserRule getRule() { return rule; }
		
		//'column' valueRef=[datamart::DatamartColumn]
		public Group getGroup() { return cGroup; }
		
		//'column'
		public Keyword getColumnKeyword_0() { return cColumnKeyword_0; }
		
		//valueRef=[datamart::DatamartColumn]
		public Assignment getValueRefAssignment_1() { return cValueRefAssignment_1; }
		
		//[datamart::DatamartColumn]
		public CrossReference getValueRefDatamartColumnCrossReference_1_0() { return cValueRefDatamartColumnCrossReference_1_0; }
		
		//ID
		public RuleCall getValueRefDatamartColumnIDTerminalRuleCall_1_0_1() { return cValueRefDatamartColumnIDTerminalRuleCall_1_0_1; }
	}
	public class TableMeasureElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableMeasure");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cMeasureKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cValueRefAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final CrossReference cValueRefDatamartMeasureCrossReference_1_0 = (CrossReference)cValueRefAssignment_1.eContents().get(0);
		private final RuleCall cValueRefDatamartMeasureIDTerminalRuleCall_1_0_1 = (RuleCall)cValueRefDatamartMeasureCrossReference_1_0.eContents().get(1);
		
		//TableMeasure:
		//	'measure' valueRef=[datamart::DatamartMeasure];
		@Override public ParserRule getRule() { return rule; }
		
		//'measure' valueRef=[datamart::DatamartMeasure]
		public Group getGroup() { return cGroup; }
		
		//'measure'
		public Keyword getMeasureKeyword_0() { return cMeasureKeyword_0; }
		
		//valueRef=[datamart::DatamartMeasure]
		public Assignment getValueRefAssignment_1() { return cValueRefAssignment_1; }
		
		//[datamart::DatamartMeasure]
		public CrossReference getValueRefDatamartMeasureCrossReference_1_0() { return cValueRefDatamartMeasureCrossReference_1_0; }
		
		//ID
		public RuleCall getValueRefDatamartMeasureIDTerminalRuleCall_1_0_1() { return cValueRefDatamartMeasureIDTerminalRuleCall_1_0_1; }
	}
	public class TableDerivedElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableDerived");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cDerivedKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cValueRefAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final CrossReference cValueRefDatamartDerivedMeasureCrossReference_1_0 = (CrossReference)cValueRefAssignment_1.eContents().get(0);
		private final RuleCall cValueRefDatamartDerivedMeasureIDTerminalRuleCall_1_0_1 = (RuleCall)cValueRefDatamartDerivedMeasureCrossReference_1_0.eContents().get(1);
		
		//TableDerived:
		//	'derived' valueRef=[datamart::DatamartDerivedMeasure];
		@Override public ParserRule getRule() { return rule; }
		
		//'derived' valueRef=[datamart::DatamartDerivedMeasure]
		public Group getGroup() { return cGroup; }
		
		//'derived'
		public Keyword getDerivedKeyword_0() { return cDerivedKeyword_0; }
		
		//valueRef=[datamart::DatamartDerivedMeasure]
		public Assignment getValueRefAssignment_1() { return cValueRefAssignment_1; }
		
		//[datamart::DatamartDerivedMeasure]
		public CrossReference getValueRefDatamartDerivedMeasureCrossReference_1_0() { return cValueRefDatamartDerivedMeasureCrossReference_1_0; }
		
		//ID
		public RuleCall getValueRefDatamartDerivedMeasureIDTerminalRuleCall_1_0_1() { return cValueRefDatamartDerivedMeasureIDTerminalRuleCall_1_0_1; }
	}
	public class TableHierarchyElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableHierarchy");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cLevelKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cValueRefAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final CrossReference cValueRefCubeLevelCrossReference_1_0 = (CrossReference)cValueRefAssignment_1.eContents().get(0);
		private final RuleCall cValueRefCubeLevelIDTerminalRuleCall_1_0_1 = (RuleCall)cValueRefCubeLevelCrossReference_1_0.eContents().get(1);
		
		//TableHierarchy:
		//	'level' valueRef=[cube::CubeLevel];
		@Override public ParserRule getRule() { return rule; }
		
		//'level' valueRef=[cube::CubeLevel]
		public Group getGroup() { return cGroup; }
		
		//'level'
		public Keyword getLevelKeyword_0() { return cLevelKeyword_0; }
		
		//valueRef=[cube::CubeLevel]
		public Assignment getValueRefAssignment_1() { return cValueRefAssignment_1; }
		
		//[cube::CubeLevel]
		public CrossReference getValueRefCubeLevelCrossReference_1_0() { return cValueRefCubeLevelCrossReference_1_0; }
		
		//ID
		public RuleCall getValueRefCubeLevelIDTerminalRuleCall_1_0_1() { return cValueRefCubeLevelIDTerminalRuleCall_1_0_1; }
	}
	public class TableAttributeElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableAttribute");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableAttributeAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cPropertyKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cValueRefAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final CrossReference cValueRefDatamartAttributeCrossReference_2_0 = (CrossReference)cValueRefAssignment_2.eContents().get(0);
		private final RuleCall cValueRefDatamartAttributeIDTerminalRuleCall_2_0_1 = (RuleCall)cValueRefDatamartAttributeCrossReference_2_0.eContents().get(1);
		
		//TableAttribute:
		//	{TableAttribute} 'property' valueRef=[datamart::DatamartAttribute];
		@Override public ParserRule getRule() { return rule; }
		
		//{TableAttribute} 'property' valueRef=[datamart::DatamartAttribute]
		public Group getGroup() { return cGroup; }
		
		//{TableAttribute}
		public Action getTableAttributeAction_0() { return cTableAttributeAction_0; }
		
		//'property'
		public Keyword getPropertyKeyword_1() { return cPropertyKeyword_1; }
		
		//valueRef=[datamart::DatamartAttribute]
		public Assignment getValueRefAssignment_2() { return cValueRefAssignment_2; }
		
		//[datamart::DatamartAttribute]
		public CrossReference getValueRefDatamartAttributeCrossReference_2_0() { return cValueRefDatamartAttributeCrossReference_2_0; }
		
		//ID
		public RuleCall getValueRefDatamartAttributeIDTerminalRuleCall_2_0_1() { return cValueRefDatamartAttributeIDTerminalRuleCall_2_0_1; }
	}
	public class TableAggregationElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableAggregation");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cAggregationKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cValueRefAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final CrossReference cValueRefDatamartSetAggregationFunctionCrossReference_1_0 = (CrossReference)cValueRefAssignment_1.eContents().get(0);
		private final RuleCall cValueRefDatamartSetAggregationFunctionIDTerminalRuleCall_1_0_1 = (RuleCall)cValueRefDatamartSetAggregationFunctionCrossReference_1_0.eContents().get(1);
		
		//TableAggregation:
		//	'aggregation' valueRef=[datamart::DatamartSetAggregationFunction];
		@Override public ParserRule getRule() { return rule; }
		
		//'aggregation' valueRef=[datamart::DatamartSetAggregationFunction]
		public Group getGroup() { return cGroup; }
		
		//'aggregation'
		public Keyword getAggregationKeyword_0() { return cAggregationKeyword_0; }
		
		//valueRef=[datamart::DatamartSetAggregationFunction]
		public Assignment getValueRefAssignment_1() { return cValueRefAssignment_1; }
		
		//[datamart::DatamartSetAggregationFunction]
		public CrossReference getValueRefDatamartSetAggregationFunctionCrossReference_1_0() { return cValueRefDatamartSetAggregationFunctionCrossReference_1_0; }
		
		//ID
		public RuleCall getValueRefDatamartSetAggregationFunctionIDTerminalRuleCall_1_0_1() { return cValueRefDatamartSetAggregationFunctionIDTerminalRuleCall_1_0_1; }
	}
	public class TableIntervalElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableInterval");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final RuleCall cTableNumberIntervalParserRuleCall_0 = (RuleCall)cAlternatives.eContents().get(0);
		private final RuleCall cTableIntIntervalParserRuleCall_1 = (RuleCall)cAlternatives.eContents().get(1);
		private final RuleCall cTableDateDayIntervalParserRuleCall_2 = (RuleCall)cAlternatives.eContents().get(2);
		
		//TableInterval:
		//	TableNumberInterval | TableIntInterval | TableDateDayInterval;
		@Override public ParserRule getRule() { return rule; }
		
		//TableNumberInterval | TableIntInterval | TableDateDayInterval
		public Alternatives getAlternatives() { return cAlternatives; }
		
		//TableNumberInterval
		public RuleCall getTableNumberIntervalParserRuleCall_0() { return cTableNumberIntervalParserRuleCall_0; }
		
		//TableIntInterval
		public RuleCall getTableIntIntervalParserRuleCall_1() { return cTableIntIntervalParserRuleCall_1; }
		
		//TableDateDayInterval
		public RuleCall getTableDateDayIntervalParserRuleCall_2() { return cTableDateDayIntervalParserRuleCall_2; }
	}
	public class TableNumberIntervalElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableNumberInterval");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableNumberIntervalAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cUpToNumberKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cNumberIntervalValueAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cNumberIntervalValueSignedNumberParserRuleCall_2_0 = (RuleCall)cNumberIntervalValueAssignment_2.eContents().get(0);
		private final Assignment cNumberRangeAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cNumberRangeTableRangeElementParserRuleCall_3_0 = (RuleCall)cNumberRangeAssignment_3.eContents().get(0);
		
		//TableNumberInterval:
		//	{TableNumberInterval} 'upToNumber' numberIntervalValue=SignedNumber numberRange=TableRangeElement;
		@Override public ParserRule getRule() { return rule; }
		
		//{TableNumberInterval} 'upToNumber' numberIntervalValue=SignedNumber numberRange=TableRangeElement
		public Group getGroup() { return cGroup; }
		
		//{TableNumberInterval}
		public Action getTableNumberIntervalAction_0() { return cTableNumberIntervalAction_0; }
		
		//'upToNumber'
		public Keyword getUpToNumberKeyword_1() { return cUpToNumberKeyword_1; }
		
		//numberIntervalValue=SignedNumber
		public Assignment getNumberIntervalValueAssignment_2() { return cNumberIntervalValueAssignment_2; }
		
		//SignedNumber
		public RuleCall getNumberIntervalValueSignedNumberParserRuleCall_2_0() { return cNumberIntervalValueSignedNumberParserRuleCall_2_0; }
		
		//numberRange=TableRangeElement
		public Assignment getNumberRangeAssignment_3() { return cNumberRangeAssignment_3; }
		
		//TableRangeElement
		public RuleCall getNumberRangeTableRangeElementParserRuleCall_3_0() { return cNumberRangeTableRangeElementParserRuleCall_3_0; }
	}
	public class TableIntIntervalElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableIntInterval");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableIntIntervalAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cUpToIntegerKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cIntIntervalValueAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cIntIntervalValueSignedIntParserRuleCall_2_0 = (RuleCall)cIntIntervalValueAssignment_2.eContents().get(0);
		private final Assignment cIntRangeAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cIntRangeTableRangeElementParserRuleCall_3_0 = (RuleCall)cIntRangeAssignment_3.eContents().get(0);
		
		//TableIntInterval:
		//	{TableIntInterval} 'upToInteger' intIntervalValue=SignedInt intRange=TableRangeElement;
		@Override public ParserRule getRule() { return rule; }
		
		//{TableIntInterval} 'upToInteger' intIntervalValue=SignedInt intRange=TableRangeElement
		public Group getGroup() { return cGroup; }
		
		//{TableIntInterval}
		public Action getTableIntIntervalAction_0() { return cTableIntIntervalAction_0; }
		
		//'upToInteger'
		public Keyword getUpToIntegerKeyword_1() { return cUpToIntegerKeyword_1; }
		
		//intIntervalValue=SignedInt
		public Assignment getIntIntervalValueAssignment_2() { return cIntIntervalValueAssignment_2; }
		
		//SignedInt
		public RuleCall getIntIntervalValueSignedIntParserRuleCall_2_0() { return cIntIntervalValueSignedIntParserRuleCall_2_0; }
		
		//intRange=TableRangeElement
		public Assignment getIntRangeAssignment_3() { return cIntRangeAssignment_3; }
		
		//TableRangeElement
		public RuleCall getIntRangeTableRangeElementParserRuleCall_3_0() { return cIntRangeTableRangeElementParserRuleCall_3_0; }
	}
	public class TableDateDayIntervalElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableDateDayInterval");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableDateDayIntervalAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cDaysInPastKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cDateIntervalValueAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cDateIntervalValueSignedIntParserRuleCall_2_0 = (RuleCall)cDateIntervalValueAssignment_2.eContents().get(0);
		private final Assignment cDateRangeAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cDateRangeTableRangeElementParserRuleCall_3_0 = (RuleCall)cDateRangeAssignment_3.eContents().get(0);
		
		//TableDateDayInterval:
		//	{TableDateDayInterval} 'daysInPast' dateIntervalValue=SignedInt dateRange=TableRangeElement;
		@Override public ParserRule getRule() { return rule; }
		
		//{TableDateDayInterval} 'daysInPast' dateIntervalValue=SignedInt dateRange=TableRangeElement
		public Group getGroup() { return cGroup; }
		
		//{TableDateDayInterval}
		public Action getTableDateDayIntervalAction_0() { return cTableDateDayIntervalAction_0; }
		
		//'daysInPast'
		public Keyword getDaysInPastKeyword_1() { return cDaysInPastKeyword_1; }
		
		//dateIntervalValue=SignedInt
		public Assignment getDateIntervalValueAssignment_2() { return cDateIntervalValueAssignment_2; }
		
		//SignedInt
		public RuleCall getDateIntervalValueSignedIntParserRuleCall_2_0() { return cDateIntervalValueSignedIntParserRuleCall_2_0; }
		
		//dateRange=TableRangeElement
		public Assignment getDateRangeAssignment_3() { return cDateRangeAssignment_3; }
		
		//TableRangeElement
		public RuleCall getDateRangeTableRangeElementParserRuleCall_3_0() { return cDateRangeTableRangeElementParserRuleCall_3_0; }
	}
	public class TableLookupElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableLookup");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final RuleCall cTableNumberLookupParserRuleCall_0 = (RuleCall)cAlternatives.eContents().get(0);
		private final RuleCall cTableIntLookupParserRuleCall_1 = (RuleCall)cAlternatives.eContents().get(1);
		private final RuleCall cTableStringLookupParserRuleCall_2 = (RuleCall)cAlternatives.eContents().get(2);
		private final RuleCall cTableDateDayLookupParserRuleCall_3 = (RuleCall)cAlternatives.eContents().get(3);
		
		//TableLookup:
		//	TableNumberLookup | TableIntLookup | TableStringLookup | TableDateDayLookup;
		@Override public ParserRule getRule() { return rule; }
		
		//TableNumberLookup | TableIntLookup | TableStringLookup | TableDateDayLookup
		public Alternatives getAlternatives() { return cAlternatives; }
		
		//TableNumberLookup
		public RuleCall getTableNumberLookupParserRuleCall_0() { return cTableNumberLookupParserRuleCall_0; }
		
		//TableIntLookup
		public RuleCall getTableIntLookupParserRuleCall_1() { return cTableIntLookupParserRuleCall_1; }
		
		//TableStringLookup
		public RuleCall getTableStringLookupParserRuleCall_2() { return cTableStringLookupParserRuleCall_2; }
		
		//TableDateDayLookup
		public RuleCall getTableDateDayLookupParserRuleCall_3() { return cTableDateDayLookupParserRuleCall_3; }
	}
	public class TableIntLookupElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableIntLookup");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableIntLookupAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cIntegerKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cLookupValueAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cLookupValueSignedIntParserRuleCall_2_0 = (RuleCall)cLookupValueAssignment_2.eContents().get(0);
		private final Assignment cDiscreteAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cDiscreteTableRangeElementParserRuleCall_3_0 = (RuleCall)cDiscreteAssignment_3.eContents().get(0);
		
		//TableIntLookup:
		//	{TableIntLookup} 'integer' lookupValue=SignedInt discrete=TableRangeElement;
		@Override public ParserRule getRule() { return rule; }
		
		//{TableIntLookup} 'integer' lookupValue=SignedInt discrete=TableRangeElement
		public Group getGroup() { return cGroup; }
		
		//{TableIntLookup}
		public Action getTableIntLookupAction_0() { return cTableIntLookupAction_0; }
		
		//'integer'
		public Keyword getIntegerKeyword_1() { return cIntegerKeyword_1; }
		
		//lookupValue=SignedInt
		public Assignment getLookupValueAssignment_2() { return cLookupValueAssignment_2; }
		
		//SignedInt
		public RuleCall getLookupValueSignedIntParserRuleCall_2_0() { return cLookupValueSignedIntParserRuleCall_2_0; }
		
		//discrete=TableRangeElement
		public Assignment getDiscreteAssignment_3() { return cDiscreteAssignment_3; }
		
		//TableRangeElement
		public RuleCall getDiscreteTableRangeElementParserRuleCall_3_0() { return cDiscreteTableRangeElementParserRuleCall_3_0; }
	}
	public class TableNumberLookupElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableNumberLookup");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableNumberLookupAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cNumberKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cLookupValueAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cLookupValueSignedNumberParserRuleCall_2_0 = (RuleCall)cLookupValueAssignment_2.eContents().get(0);
		private final Assignment cDiscreteAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cDiscreteTableRangeElementParserRuleCall_3_0 = (RuleCall)cDiscreteAssignment_3.eContents().get(0);
		
		//TableNumberLookup:
		//	{TableNumberLookup} 'number' lookupValue=SignedNumber discrete=TableRangeElement;
		@Override public ParserRule getRule() { return rule; }
		
		//{TableNumberLookup} 'number' lookupValue=SignedNumber discrete=TableRangeElement
		public Group getGroup() { return cGroup; }
		
		//{TableNumberLookup}
		public Action getTableNumberLookupAction_0() { return cTableNumberLookupAction_0; }
		
		//'number'
		public Keyword getNumberKeyword_1() { return cNumberKeyword_1; }
		
		//lookupValue=SignedNumber
		public Assignment getLookupValueAssignment_2() { return cLookupValueAssignment_2; }
		
		//SignedNumber
		public RuleCall getLookupValueSignedNumberParserRuleCall_2_0() { return cLookupValueSignedNumberParserRuleCall_2_0; }
		
		//discrete=TableRangeElement
		public Assignment getDiscreteAssignment_3() { return cDiscreteAssignment_3; }
		
		//TableRangeElement
		public RuleCall getDiscreteTableRangeElementParserRuleCall_3_0() { return cDiscreteTableRangeElementParserRuleCall_3_0; }
	}
	public class TableStringLookupElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableStringLookup");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableStringLookupAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cStringKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cLookupValueAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cLookupValueSTRINGTerminalRuleCall_2_0 = (RuleCall)cLookupValueAssignment_2.eContents().get(0);
		private final Assignment cDiscreteAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cDiscreteTableRangeElementParserRuleCall_3_0 = (RuleCall)cDiscreteAssignment_3.eContents().get(0);
		
		//TableStringLookup:
		//	{TableStringLookup} 'string' lookupValue=STRING discrete=TableRangeElement;
		@Override public ParserRule getRule() { return rule; }
		
		//{TableStringLookup} 'string' lookupValue=STRING discrete=TableRangeElement
		public Group getGroup() { return cGroup; }
		
		//{TableStringLookup}
		public Action getTableStringLookupAction_0() { return cTableStringLookupAction_0; }
		
		//'string'
		public Keyword getStringKeyword_1() { return cStringKeyword_1; }
		
		//lookupValue=STRING
		public Assignment getLookupValueAssignment_2() { return cLookupValueAssignment_2; }
		
		//STRING
		public RuleCall getLookupValueSTRINGTerminalRuleCall_2_0() { return cLookupValueSTRINGTerminalRuleCall_2_0; }
		
		//discrete=TableRangeElement
		public Assignment getDiscreteAssignment_3() { return cDiscreteAssignment_3; }
		
		//TableRangeElement
		public RuleCall getDiscreteTableRangeElementParserRuleCall_3_0() { return cDiscreteTableRangeElementParserRuleCall_3_0; }
	}
	public class TableDateDayLookupElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableDateDayLookup");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableDateDayLookupAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cDaysInPastKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cLookupValueAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cLookupValueSignedIntParserRuleCall_2_0 = (RuleCall)cLookupValueAssignment_2.eContents().get(0);
		private final Assignment cDiscreteAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cDiscreteTableRangeElementParserRuleCall_3_0 = (RuleCall)cDiscreteAssignment_3.eContents().get(0);
		
		//TableDateDayLookup:
		//	{TableDateDayLookup} 'daysInPast' lookupValue=SignedInt discrete=TableRangeElement;
		@Override public ParserRule getRule() { return rule; }
		
		//{TableDateDayLookup} 'daysInPast' lookupValue=SignedInt discrete=TableRangeElement
		public Group getGroup() { return cGroup; }
		
		//{TableDateDayLookup}
		public Action getTableDateDayLookupAction_0() { return cTableDateDayLookupAction_0; }
		
		//'daysInPast'
		public Keyword getDaysInPastKeyword_1() { return cDaysInPastKeyword_1; }
		
		//lookupValue=SignedInt
		public Assignment getLookupValueAssignment_2() { return cLookupValueAssignment_2; }
		
		//SignedInt
		public RuleCall getLookupValueSignedIntParserRuleCall_2_0() { return cLookupValueSignedIntParserRuleCall_2_0; }
		
		//discrete=TableRangeElement
		public Assignment getDiscreteAssignment_3() { return cDiscreteAssignment_3; }
		
		//TableRangeElement
		public RuleCall getDiscreteTableRangeElementParserRuleCall_3_0() { return cDiscreteTableRangeElementParserRuleCall_3_0; }
	}
	public class TableDatamartElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableDatamart");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cDatamartKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cDatamartRefAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final CrossReference cDatamartRefDatamartDefinitionCrossReference_1_0 = (CrossReference)cDatamartRefAssignment_1.eContents().get(0);
		private final RuleCall cDatamartRefDatamartDefinitionIDTerminalRuleCall_1_0_1 = (RuleCall)cDatamartRefDatamartDefinitionCrossReference_1_0.eContents().get(1);
		private final Group cGroup_2 = (Group)cGroup.eContents().get(2);
		private final Keyword cLeftCurlyBracketKeyword_2_0 = (Keyword)cGroup_2.eContents().get(0);
		private final Assignment cElementsAssignment_2_1 = (Assignment)cGroup_2.eContents().get(1);
		private final RuleCall cElementsTableElementParserRuleCall_2_1_0 = (RuleCall)cElementsAssignment_2_1.eContents().get(0);
		private final Keyword cRightCurlyBracketKeyword_2_2 = (Keyword)cGroup_2.eContents().get(2);
		
		//TableDatamart:
		//	'datamart' datamartRef=[datamart::DatamartDefinition] ('{' elements+=TableElement* '}')?;
		@Override public ParserRule getRule() { return rule; }
		
		//'datamart' datamartRef=[datamart::DatamartDefinition] ('{' elements+=TableElement* '}')?
		public Group getGroup() { return cGroup; }
		
		//'datamart'
		public Keyword getDatamartKeyword_0() { return cDatamartKeyword_0; }
		
		//datamartRef=[datamart::DatamartDefinition]
		public Assignment getDatamartRefAssignment_1() { return cDatamartRefAssignment_1; }
		
		//[datamart::DatamartDefinition]
		public CrossReference getDatamartRefDatamartDefinitionCrossReference_1_0() { return cDatamartRefDatamartDefinitionCrossReference_1_0; }
		
		//ID
		public RuleCall getDatamartRefDatamartDefinitionIDTerminalRuleCall_1_0_1() { return cDatamartRefDatamartDefinitionIDTerminalRuleCall_1_0_1; }
		
		//('{' elements+=TableElement* '}')?
		public Group getGroup_2() { return cGroup_2; }
		
		//'{'
		public Keyword getLeftCurlyBracketKeyword_2_0() { return cLeftCurlyBracketKeyword_2_0; }
		
		//elements+=TableElement*
		public Assignment getElementsAssignment_2_1() { return cElementsAssignment_2_1; }
		
		//TableElement
		public RuleCall getElementsTableElementParserRuleCall_2_1_0() { return cElementsTableElementParserRuleCall_2_1_0; }
		
		//'}'
		public Keyword getRightCurlyBracketKeyword_2_2() { return cRightCurlyBracketKeyword_2_2; }
	}
	public class TableElementElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableElement");
		private final RuleCall cTableAxisParserRuleCall = (RuleCall)rule.eContents().get(1);
		
		//TableElement:
		//	TableAxis;
		@Override public ParserRule getRule() { return rule; }
		
		//TableAxis
		public RuleCall getTableAxisParserRuleCall() { return cTableAxisParserRuleCall; }
	}
	public class TableEventElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableEvent");
		private final Assignment cSourceAssignment = (Assignment)rule.eContents().get(1);
		private final RuleCall cSourceTableValueElementParserRuleCall_0 = (RuleCall)cSourceAssignment.eContents().get(0);
		
		//TableEvent:
		//	source=TableValueElement;
		@Override public ParserRule getRule() { return rule; }
		
		//source=TableValueElement
		public Assignment getSourceAssignment() { return cSourceAssignment; }
		
		//TableValueElement
		public RuleCall getSourceTableValueElementParserRuleCall_0() { return cSourceTableValueElementParserRuleCall_0; }
	}
	public class TableAxisElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableAxis");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cAxisKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cAxisAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cAxisAxisEnumEnumRuleCall_1_0 = (RuleCall)cAxisAssignment_1.eContents().get(0);
		private final UnorderedGroup cUnorderedGroup_2 = (UnorderedGroup)cGroup.eContents().get(2);
		private final Group cGroup_2_0 = (Group)cUnorderedGroup_2.eContents().get(0);
		private final Assignment cHasRowHeightAssignment_2_0_0 = (Assignment)cGroup_2_0.eContents().get(0);
		private final Keyword cHasRowHeightRowheightKeyword_2_0_0_0 = (Keyword)cHasRowHeightAssignment_2_0_0.eContents().get(0);
		private final Assignment cRowHeightAssignment_2_0_1 = (Assignment)cGroup_2_0.eContents().get(1);
		private final RuleCall cRowHeightNumberParserRuleCall_2_0_1_0 = (RuleCall)cRowHeightAssignment_2_0_1.eContents().get(0);
		private final Assignment cPreOrderAssignment_2_1 = (Assignment)cUnorderedGroup_2.eContents().get(1);
		private final RuleCall cPreOrderTablePreorderParserRuleCall_2_1_0 = (RuleCall)cPreOrderAssignment_2_1.eContents().get(0);
		private final Group cGroup_3 = (Group)cGroup.eContents().get(3);
		private final Assignment cHasDetailsAssignment_3_0 = (Assignment)cGroup_3.eContents().get(0);
		private final Keyword cHasDetailsDetailsKeyword_3_0_0 = (Keyword)cHasDetailsAssignment_3_0.eContents().get(0);
		private final Keyword cLeftCurlyBracketKeyword_3_1 = (Keyword)cGroup_3.eContents().get(1);
		private final Assignment cValuesAssignment_3_2 = (Assignment)cGroup_3.eContents().get(2);
		private final RuleCall cValuesTableValueParserRuleCall_3_2_0 = (RuleCall)cValuesAssignment_3_2.eContents().get(0);
		private final Keyword cRightCurlyBracketKeyword_3_3 = (Keyword)cGroup_3.eContents().get(3);
		private final Group cGroup_4 = (Group)cGroup.eContents().get(4);
		private final Assignment cHasEventsAssignment_4_0 = (Assignment)cGroup_4.eContents().get(0);
		private final Keyword cHasEventsNotifyOnSelectKeyword_4_0_0 = (Keyword)cHasEventsAssignment_4_0.eContents().get(0);
		private final Keyword cLeftCurlyBracketKeyword_4_1 = (Keyword)cGroup_4.eContents().get(1);
		private final Assignment cEventsAssignment_4_2 = (Assignment)cGroup_4.eContents().get(2);
		private final RuleCall cEventsTableEventParserRuleCall_4_2_0 = (RuleCall)cEventsAssignment_4_2.eContents().get(0);
		private final Keyword cRightCurlyBracketKeyword_4_3 = (Keyword)cGroup_4.eContents().get(3);
		
		//TableAxis:
		//	'axis' axis=AxisEnum ((hasRowHeight?='rowheight' rowHeight=Number)? & preOrder=TablePreorder?) (hasDetails?='details'
		//	'{' values+=TableValue* '}')? (hasEvents?='notifyOnSelect' '{' events+=TableEvent* '}')?;
		@Override public ParserRule getRule() { return rule; }
		
		//'axis' axis=AxisEnum ((hasRowHeight?='rowheight' rowHeight=Number)? & preOrder=TablePreorder?) (hasDetails?='details'
		//'{' values+=TableValue* '}')? (hasEvents?='notifyOnSelect' '{' events+=TableEvent* '}')?
		public Group getGroup() { return cGroup; }
		
		//'axis'
		public Keyword getAxisKeyword_0() { return cAxisKeyword_0; }
		
		//axis=AxisEnum
		public Assignment getAxisAssignment_1() { return cAxisAssignment_1; }
		
		//AxisEnum
		public RuleCall getAxisAxisEnumEnumRuleCall_1_0() { return cAxisAxisEnumEnumRuleCall_1_0; }
		
		//(hasRowHeight?='rowheight' rowHeight=Number)? & preOrder=TablePreorder?
		public UnorderedGroup getUnorderedGroup_2() { return cUnorderedGroup_2; }
		
		//(hasRowHeight?='rowheight' rowHeight=Number)?
		public Group getGroup_2_0() { return cGroup_2_0; }
		
		//hasRowHeight?='rowheight'
		public Assignment getHasRowHeightAssignment_2_0_0() { return cHasRowHeightAssignment_2_0_0; }
		
		//'rowheight'
		public Keyword getHasRowHeightRowheightKeyword_2_0_0_0() { return cHasRowHeightRowheightKeyword_2_0_0_0; }
		
		//rowHeight=Number
		public Assignment getRowHeightAssignment_2_0_1() { return cRowHeightAssignment_2_0_1; }
		
		//Number
		public RuleCall getRowHeightNumberParserRuleCall_2_0_1_0() { return cRowHeightNumberParserRuleCall_2_0_1_0; }
		
		//preOrder=TablePreorder?
		public Assignment getPreOrderAssignment_2_1() { return cPreOrderAssignment_2_1; }
		
		//TablePreorder
		public RuleCall getPreOrderTablePreorderParserRuleCall_2_1_0() { return cPreOrderTablePreorderParserRuleCall_2_1_0; }
		
		//(hasDetails?='details' '{' values+=TableValue* '}')?
		public Group getGroup_3() { return cGroup_3; }
		
		//hasDetails?='details'
		public Assignment getHasDetailsAssignment_3_0() { return cHasDetailsAssignment_3_0; }
		
		//'details'
		public Keyword getHasDetailsDetailsKeyword_3_0_0() { return cHasDetailsDetailsKeyword_3_0_0; }
		
		//'{'
		public Keyword getLeftCurlyBracketKeyword_3_1() { return cLeftCurlyBracketKeyword_3_1; }
		
		//values+=TableValue*
		public Assignment getValuesAssignment_3_2() { return cValuesAssignment_3_2; }
		
		//TableValue
		public RuleCall getValuesTableValueParserRuleCall_3_2_0() { return cValuesTableValueParserRuleCall_3_2_0; }
		
		//'}'
		public Keyword getRightCurlyBracketKeyword_3_3() { return cRightCurlyBracketKeyword_3_3; }
		
		//(hasEvents?='notifyOnSelect' '{' events+=TableEvent* '}')?
		public Group getGroup_4() { return cGroup_4; }
		
		//hasEvents?='notifyOnSelect'
		public Assignment getHasEventsAssignment_4_0() { return cHasEventsAssignment_4_0; }
		
		//'notifyOnSelect'
		public Keyword getHasEventsNotifyOnSelectKeyword_4_0_0() { return cHasEventsNotifyOnSelectKeyword_4_0_0; }
		
		//'{'
		public Keyword getLeftCurlyBracketKeyword_4_1() { return cLeftCurlyBracketKeyword_4_1; }
		
		//events+=TableEvent*
		public Assignment getEventsAssignment_4_2() { return cEventsAssignment_4_2; }
		
		//TableEvent
		public RuleCall getEventsTableEventParserRuleCall_4_2_0() { return cEventsTableEventParserRuleCall_4_2_0; }
		
		//'}'
		public Keyword getRightCurlyBracketKeyword_4_3() { return cRightCurlyBracketKeyword_4_3; }
	}
	public class TableRangeElementElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableRangeElement");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final RuleCall cTableTextColorParserRuleCall_0 = (RuleCall)cAlternatives.eContents().get(0);
		private final RuleCall cTableCellColorParserRuleCall_1 = (RuleCall)cAlternatives.eContents().get(1);
		private final RuleCall cTableIconParserRuleCall_2 = (RuleCall)cAlternatives.eContents().get(2);
		private final RuleCall cTableTrendParserRuleCall_3 = (RuleCall)cAlternatives.eContents().get(3);
		private final RuleCall cTableTooltipParserRuleCall_4 = (RuleCall)cAlternatives.eContents().get(4);
		
		//TableRangeElement:
		//	TableTextColor | TableCellColor | TableIcon | TableTrend | TableTooltip;
		@Override public ParserRule getRule() { return rule; }
		
		//TableTextColor | TableCellColor | TableIcon | TableTrend | TableTooltip
		public Alternatives getAlternatives() { return cAlternatives; }
		
		//TableTextColor
		public RuleCall getTableTextColorParserRuleCall_0() { return cTableTextColorParserRuleCall_0; }
		
		//TableCellColor
		public RuleCall getTableCellColorParserRuleCall_1() { return cTableCellColorParserRuleCall_1; }
		
		//TableIcon
		public RuleCall getTableIconParserRuleCall_2() { return cTableIconParserRuleCall_2; }
		
		//TableTrend
		public RuleCall getTableTrendParserRuleCall_3() { return cTableTrendParserRuleCall_3; }
		
		//TableTooltip
		public RuleCall getTableTooltipParserRuleCall_4() { return cTableTooltipParserRuleCall_4; }
	}
	public class TableTextColorElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableTextColor");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cTextcolorKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cRgbAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cRgbSTRINGTerminalRuleCall_1_0 = (RuleCall)cRgbAssignment_1.eContents().get(0);
		
		//TableTextColor:
		//	'textcolor' rgb=STRING;
		@Override public ParserRule getRule() { return rule; }
		
		//'textcolor' rgb=STRING
		public Group getGroup() { return cGroup; }
		
		//'textcolor'
		public Keyword getTextcolorKeyword_0() { return cTextcolorKeyword_0; }
		
		//rgb=STRING
		public Assignment getRgbAssignment_1() { return cRgbAssignment_1; }
		
		//STRING
		public RuleCall getRgbSTRINGTerminalRuleCall_1_0() { return cRgbSTRINGTerminalRuleCall_1_0; }
	}
	public class TableCellColorElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableCellColor");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cCellcolorKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cRgbAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cRgbSTRINGTerminalRuleCall_1_0 = (RuleCall)cRgbAssignment_1.eContents().get(0);
		
		//TableCellColor:
		//	'cellcolor' rgb=STRING;
		@Override public ParserRule getRule() { return rule; }
		
		//'cellcolor' rgb=STRING
		public Group getGroup() { return cGroup; }
		
		//'cellcolor'
		public Keyword getCellcolorKeyword_0() { return cCellcolorKeyword_0; }
		
		//rgb=STRING
		public Assignment getRgbAssignment_1() { return cRgbAssignment_1; }
		
		//STRING
		public RuleCall getRgbSTRINGTerminalRuleCall_1_0() { return cRgbSTRINGTerminalRuleCall_1_0; }
	}
	public class TableIconElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableIcon");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cIconKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cIconAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cIconSTRINGTerminalRuleCall_1_0 = (RuleCall)cIconAssignment_1.eContents().get(0);
		
		//TableIcon:
		//	'icon' icon=STRING;
		@Override public ParserRule getRule() { return rule; }
		
		//'icon' icon=STRING
		public Group getGroup() { return cGroup; }
		
		//'icon'
		public Keyword getIconKeyword_0() { return cIconKeyword_0; }
		
		//icon=STRING
		public Assignment getIconAssignment_1() { return cIconAssignment_1; }
		
		//STRING
		public RuleCall getIconSTRINGTerminalRuleCall_1_0() { return cIconSTRINGTerminalRuleCall_1_0; }
	}
	public class TableTrendElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableTrend");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cTrendKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cIconAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cIconTrendIconEnumEnumRuleCall_1_0 = (RuleCall)cIconAssignment_1.eContents().get(0);
		
		//TableTrend:
		//	'trend' icon=TrendIconEnum;
		@Override public ParserRule getRule() { return rule; }
		
		//'trend' icon=TrendIconEnum
		public Group getGroup() { return cGroup; }
		
		//'trend'
		public Keyword getTrendKeyword_0() { return cTrendKeyword_0; }
		
		//icon=TrendIconEnum
		public Assignment getIconAssignment_1() { return cIconAssignment_1; }
		
		//TrendIconEnum
		public RuleCall getIconTrendIconEnumEnumRuleCall_1_0() { return cIconTrendIconEnumEnumRuleCall_1_0; }
	}
	public class TableTooltipElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableTooltip");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cTooltipKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cTooltipAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cTooltipTRANSLATABLESTRINGParserRuleCall_1_0 = (RuleCall)cTooltipAssignment_1.eContents().get(0);
		
		//TableTooltip:
		//	'tooltip' tooltip=TRANSLATABLESTRING;
		@Override public ParserRule getRule() { return rule; }
		
		//'tooltip' tooltip=TRANSLATABLESTRING
		public Group getGroup() { return cGroup; }
		
		//'tooltip'
		public Keyword getTooltipKeyword_0() { return cTooltipKeyword_0; }
		
		//tooltip=TRANSLATABLESTRING
		public Assignment getTooltipAssignment_1() { return cTooltipAssignment_1; }
		
		//TRANSLATABLESTRING
		public RuleCall getTooltipTRANSLATABLESTRINGParserRuleCall_1_0() { return cTooltipTRANSLATABLESTRINGParserRuleCall_1_0; }
	}
	public class TableGridElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableGrid");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cTableGridAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cEditableKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Keyword cUsingKeyword_2 = (Keyword)cGroup.eContents().get(2);
		private final Assignment cSourceAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cSourceTableDtoDatasourceParserRuleCall_3_0 = (RuleCall)cSourceAssignment_3.eContents().get(0);
		
		//// ----------------------------- grid --------------------------------------
		//TableGrid:
		//	{TableGrid} 'editable' 'using' source=TableDtoDatasource;
		@Override public ParserRule getRule() { return rule; }
		
		//{TableGrid} 'editable' 'using' source=TableDtoDatasource
		public Group getGroup() { return cGroup; }
		
		//{TableGrid}
		public Action getTableGridAction_0() { return cTableGridAction_0; }
		
		//'editable'
		public Keyword getEditableKeyword_1() { return cEditableKeyword_1; }
		
		//'using'
		public Keyword getUsingKeyword_2() { return cUsingKeyword_2; }
		
		//source=TableDtoDatasource
		public Assignment getSourceAssignment_3() { return cSourceAssignment_3; }
		
		//TableDtoDatasource
		public RuleCall getSourceTableDtoDatasourceParserRuleCall_3_0() { return cSourceTableDtoDatasourceParserRuleCall_3_0; }
	}
	public class PropertyElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.Property");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cEditableAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cEditableEditableKeyword_0_0 = (Keyword)cEditableAssignment_0.eContents().get(0);
		private final Keyword cPropKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cPathAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cPathNestedFieldParserRuleCall_2_0 = (RuleCall)cPathAssignment_2.eContents().get(0);
		private final Keyword cStyleKeyword_3 = (Keyword)cGroup.eContents().get(3);
		private final Assignment cStyleAssignment_4 = (Assignment)cGroup.eContents().get(4);
		private final RuleCall cStylePropertyStyleParserRuleCall_4_0 = (RuleCall)cStyleAssignment_4.eContents().get(0);
		
		//Property CxGridProperty:
		//	editable?='editable'? 'prop' path=NestedField 'style' style=PropertyStyle;
		@Override public ParserRule getRule() { return rule; }
		
		//editable?='editable'? 'prop' path=NestedField 'style' style=PropertyStyle
		public Group getGroup() { return cGroup; }
		
		//editable?='editable'?
		public Assignment getEditableAssignment_0() { return cEditableAssignment_0; }
		
		//'editable'
		public Keyword getEditableEditableKeyword_0_0() { return cEditableEditableKeyword_0_0; }
		
		//'prop'
		public Keyword getPropKeyword_1() { return cPropKeyword_1; }
		
		//path=NestedField
		public Assignment getPathAssignment_2() { return cPathAssignment_2; }
		
		//NestedField
		public RuleCall getPathNestedFieldParserRuleCall_2_0() { return cPathNestedFieldParserRuleCall_2_0; }
		
		//'style'
		public Keyword getStyleKeyword_3() { return cStyleKeyword_3; }
		
		//style=PropertyStyle
		public Assignment getStyleAssignment_4() { return cStyleAssignment_4; }
		
		//PropertyStyle
		public RuleCall getStylePropertyStyleParserRuleCall_4_0() { return cStylePropertyStyleParserRuleCall_4_0; }
	}
	public class TableDtoDatasourceElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TableDtoDatasource");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cDtoKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cDtoSourceAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final CrossReference cDtoSourceLDtoCrossReference_1_0 = (CrossReference)cDtoSourceAssignment_1.eContents().get(0);
		private final RuleCall cDtoSourceLDtoIDTerminalRuleCall_1_0_1 = (RuleCall)cDtoSourceLDtoCrossReference_1_0.eContents().get(1);
		private final Group cGroup_2 = (Group)cGroup.eContents().get(2);
		private final Keyword cLeftCurlyBracketKeyword_2_0 = (Keyword)cGroup_2.eContents().get(0);
		private final Assignment cPropertiesAssignment_2_1 = (Assignment)cGroup_2.eContents().get(1);
		private final RuleCall cPropertiesPropertyParserRuleCall_2_1_0 = (RuleCall)cPropertiesAssignment_2_1.eContents().get(0);
		private final Keyword cRightCurlyBracketKeyword_2_2 = (Keyword)cGroup_2.eContents().get(2);
		
		//TableDtoDatasource:
		//	'dto' dtoSource=[dto::LDto] ('{' properties+=Property* '}')?;
		@Override public ParserRule getRule() { return rule; }
		
		//'dto' dtoSource=[dto::LDto] ('{' properties+=Property* '}')?
		public Group getGroup() { return cGroup; }
		
		//'dto'
		public Keyword getDtoKeyword_0() { return cDtoKeyword_0; }
		
		//dtoSource=[dto::LDto]
		public Assignment getDtoSourceAssignment_1() { return cDtoSourceAssignment_1; }
		
		//[dto::LDto]
		public CrossReference getDtoSourceLDtoCrossReference_1_0() { return cDtoSourceLDtoCrossReference_1_0; }
		
		//ID
		public RuleCall getDtoSourceLDtoIDTerminalRuleCall_1_0_1() { return cDtoSourceLDtoIDTerminalRuleCall_1_0_1; }
		
		//('{' properties+=Property* '}')?
		public Group getGroup_2() { return cGroup_2; }
		
		//'{'
		public Keyword getLeftCurlyBracketKeyword_2_0() { return cLeftCurlyBracketKeyword_2_0; }
		
		//properties+=Property*
		public Assignment getPropertiesAssignment_2_1() { return cPropertiesAssignment_2_1; }
		
		//Property
		public RuleCall getPropertiesPropertyParserRuleCall_2_1_0() { return cPropertiesPropertyParserRuleCall_2_1_0; }
		
		//'}'
		public Keyword getRightCurlyBracketKeyword_2_2() { return cRightCurlyBracketKeyword_2_2; }
	}
	public class NestedFieldElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.NestedField");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cCxGridNestedFieldAction_0 = (Action)cGroup.eContents().get(0);
		private final Assignment cFieldAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final CrossReference cFieldJvmOperationCrossReference_1_0 = (CrossReference)cFieldAssignment_1.eContents().get(0);
		private final RuleCall cFieldJvmOperationIDTerminalRuleCall_1_0_1 = (RuleCall)cFieldJvmOperationCrossReference_1_0.eContents().get(1);
		private final Assignment cPathAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cPathNestedPathParserRuleCall_2_0 = (RuleCall)cPathAssignment_2.eContents().get(0);
		
		//NestedField CxGridNestedField:
		//	{CxGridNestedField} field=[JvmOperation] path=NestedPath?;
		@Override public ParserRule getRule() { return rule; }
		
		//{CxGridNestedField} field=[JvmOperation] path=NestedPath?
		public Group getGroup() { return cGroup; }
		
		//{CxGridNestedField}
		public Action getCxGridNestedFieldAction_0() { return cCxGridNestedFieldAction_0; }
		
		//field=[JvmOperation]
		public Assignment getFieldAssignment_1() { return cFieldAssignment_1; }
		
		//[JvmOperation]
		public CrossReference getFieldJvmOperationCrossReference_1_0() { return cFieldJvmOperationCrossReference_1_0; }
		
		//ID
		public RuleCall getFieldJvmOperationIDTerminalRuleCall_1_0_1() { return cFieldJvmOperationIDTerminalRuleCall_1_0_1; }
		
		//path=NestedPath?
		public Assignment getPathAssignment_2() { return cPathAssignment_2; }
		
		//NestedPath
		public RuleCall getPathNestedPathParserRuleCall_2_0() { return cPathNestedPathParserRuleCall_2_0; }
	}
	public class NestedPathElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.NestedPath");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cCxGridNestedPathAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cFullStopKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cFieldAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final CrossReference cFieldJvmOperationCrossReference_2_0 = (CrossReference)cFieldAssignment_2.eContents().get(0);
		private final RuleCall cFieldJvmOperationIDTerminalRuleCall_2_0_1 = (RuleCall)cFieldJvmOperationCrossReference_2_0.eContents().get(1);
		private final Assignment cPathAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cPathNestedPathParserRuleCall_3_0 = (RuleCall)cPathAssignment_3.eContents().get(0);
		
		//NestedPath CxGridNestedPath:
		//	{CxGridNestedPath}
		//	'.' field=[JvmOperation] path=NestedPath?;
		@Override public ParserRule getRule() { return rule; }
		
		//{CxGridNestedPath} '.' field=[JvmOperation] path=NestedPath?
		public Group getGroup() { return cGroup; }
		
		//{CxGridNestedPath}
		public Action getCxGridNestedPathAction_0() { return cCxGridNestedPathAction_0; }
		
		//'.'
		public Keyword getFullStopKeyword_1() { return cFullStopKeyword_1; }
		
		//field=[JvmOperation]
		public Assignment getFieldAssignment_2() { return cFieldAssignment_2; }
		
		//[JvmOperation]
		public CrossReference getFieldJvmOperationCrossReference_2_0() { return cFieldJvmOperationCrossReference_2_0; }
		
		//ID
		public RuleCall getFieldJvmOperationIDTerminalRuleCall_2_0_1() { return cFieldJvmOperationIDTerminalRuleCall_2_0_1; }
		
		//path=NestedPath?
		public Assignment getPathAssignment_3() { return cPathAssignment_3; }
		
		//NestedPath
		public RuleCall getPathNestedPathParserRuleCall_3_0() { return cPathNestedPathParserRuleCall_3_0; }
	}
	public class PropertyStyleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.PropertyStyle");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final RuleCall cPropertyButtonStyleParserRuleCall_0 = (RuleCall)cAlternatives.eContents().get(0);
		private final RuleCall cPropertyHtmlStyleParserRuleCall_1 = (RuleCall)cAlternatives.eContents().get(1);
		private final RuleCall cPropertyProgressbarStyleParserRuleCall_2 = (RuleCall)cAlternatives.eContents().get(2);
		private final RuleCall cPropertyTextStyleParserRuleCall_3 = (RuleCall)cAlternatives.eContents().get(3);
		private final RuleCall cPropertyBooleanStyleParserRuleCall_4 = (RuleCall)cAlternatives.eContents().get(4);
		private final RuleCall cPropertyDateStyleParserRuleCall_5 = (RuleCall)cAlternatives.eContents().get(5);
		private final RuleCall cPropertyNumberStyleParserRuleCall_6 = (RuleCall)cAlternatives.eContents().get(6);
		private final RuleCall cPropertyImageStyleParserRuleCall_7 = (RuleCall)cAlternatives.eContents().get(7);
		private final RuleCall cPropertyBlobImageStyleParserRuleCall_8 = (RuleCall)cAlternatives.eContents().get(8);
		private final RuleCall cGridPropIndicatorStyleParserRuleCall_9 = (RuleCall)cAlternatives.eContents().get(9);
		
		//PropertyStyle style::CxGridPropStyle:
		//	PropertyButtonStyle | PropertyHtmlStyle | PropertyProgressbarStyle | PropertyTextStyle | PropertyBooleanStyle |
		//	PropertyDateStyle | PropertyNumberStyle | PropertyImageStyle | PropertyBlobImageStyle | GridPropIndicatorStyle /*|
		//	PropertyPriceStyle | PropertyQuantityStyle */;
		@Override public ParserRule getRule() { return rule; }
		
		//PropertyButtonStyle | PropertyHtmlStyle | PropertyProgressbarStyle | PropertyTextStyle | PropertyBooleanStyle |
		//PropertyDateStyle | PropertyNumberStyle | PropertyImageStyle | PropertyBlobImageStyle | GridPropIndicatorStyle
		public Alternatives getAlternatives() { return cAlternatives; }
		
		//PropertyButtonStyle
		public RuleCall getPropertyButtonStyleParserRuleCall_0() { return cPropertyButtonStyleParserRuleCall_0; }
		
		//PropertyHtmlStyle
		public RuleCall getPropertyHtmlStyleParserRuleCall_1() { return cPropertyHtmlStyleParserRuleCall_1; }
		
		//PropertyProgressbarStyle
		public RuleCall getPropertyProgressbarStyleParserRuleCall_2() { return cPropertyProgressbarStyleParserRuleCall_2; }
		
		//PropertyTextStyle
		public RuleCall getPropertyTextStyleParserRuleCall_3() { return cPropertyTextStyleParserRuleCall_3; }
		
		//PropertyBooleanStyle
		public RuleCall getPropertyBooleanStyleParserRuleCall_4() { return cPropertyBooleanStyleParserRuleCall_4; }
		
		//PropertyDateStyle
		public RuleCall getPropertyDateStyleParserRuleCall_5() { return cPropertyDateStyleParserRuleCall_5; }
		
		//PropertyNumberStyle
		public RuleCall getPropertyNumberStyleParserRuleCall_6() { return cPropertyNumberStyleParserRuleCall_6; }
		
		//PropertyImageStyle
		public RuleCall getPropertyImageStyleParserRuleCall_7() { return cPropertyImageStyleParserRuleCall_7; }
		
		//PropertyBlobImageStyle
		public RuleCall getPropertyBlobImageStyleParserRuleCall_8() { return cPropertyBlobImageStyleParserRuleCall_8; }
		
		//GridPropIndicatorStyle
		public RuleCall getGridPropIndicatorStyleParserRuleCall_9() { return cGridPropIndicatorStyleParserRuleCall_9; }
	}
	public class PropertyButtonStyleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.PropertyButtonStyle");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cCxGridPropButtonStyleAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cButtonStyleKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Keyword cEventTopicKeyword_2 = (Keyword)cGroup.eContents().get(2);
		private final Assignment cEventTopicAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cEventTopicSTRINGTerminalRuleCall_3_0 = (RuleCall)cEventTopicAssignment_3.eContents().get(0);
		
		//PropertyButtonStyle style::CxGridPropButtonStyle:
		//	{style::CxGridPropButtonStyle}
		//	'buttonStyle' 'eventTopic' eventTopic=STRING;
		@Override public ParserRule getRule() { return rule; }
		
		//{style::CxGridPropButtonStyle} 'buttonStyle' 'eventTopic' eventTopic=STRING
		public Group getGroup() { return cGroup; }
		
		//{style::CxGridPropButtonStyle}
		public Action getCxGridPropButtonStyleAction_0() { return cCxGridPropButtonStyleAction_0; }
		
		//'buttonStyle'
		public Keyword getButtonStyleKeyword_1() { return cButtonStyleKeyword_1; }
		
		//'eventTopic'
		public Keyword getEventTopicKeyword_2() { return cEventTopicKeyword_2; }
		
		//eventTopic=STRING
		public Assignment getEventTopicAssignment_3() { return cEventTopicAssignment_3; }
		
		//STRING
		public RuleCall getEventTopicSTRINGTerminalRuleCall_3_0() { return cEventTopicSTRINGTerminalRuleCall_3_0; }
	}
	public class PropertyHtmlStyleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.PropertyHtmlStyle");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cCxGridPropHtmlStyleAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cHtmlStyleKeyword_1 = (Keyword)cGroup.eContents().get(1);
		
		//PropertyHtmlStyle style::CxGridPropHtmlStyle:
		//	{style::CxGridPropHtmlStyle}
		//	'htmlStyle';
		@Override public ParserRule getRule() { return rule; }
		
		//{style::CxGridPropHtmlStyle} 'htmlStyle'
		public Group getGroup() { return cGroup; }
		
		//{style::CxGridPropHtmlStyle}
		public Action getCxGridPropHtmlStyleAction_0() { return cCxGridPropHtmlStyleAction_0; }
		
		//'htmlStyle'
		public Keyword getHtmlStyleKeyword_1() { return cHtmlStyleKeyword_1; }
	}
	public class PropertyBooleanStyleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.PropertyBooleanStyle");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cCxGridPropBooleanStyleAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cBoolStyleKeyword_1 = (Keyword)cGroup.eContents().get(1);
		
		//PropertyBooleanStyle style::CxGridPropBooleanStyle:
		//	{style::CxGridPropBooleanStyle}
		//	'boolStyle';
		@Override public ParserRule getRule() { return rule; }
		
		//{style::CxGridPropBooleanStyle} 'boolStyle'
		public Group getGroup() { return cGroup; }
		
		//{style::CxGridPropBooleanStyle}
		public Action getCxGridPropBooleanStyleAction_0() { return cCxGridPropBooleanStyleAction_0; }
		
		//'boolStyle'
		public Keyword getBoolStyleKeyword_1() { return cBoolStyleKeyword_1; }
	}
	public class PropertyDateStyleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.PropertyDateStyle");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cCxGridPropDateStyleAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cDateStyleKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Keyword cFormatKeyword_2 = (Keyword)cGroup.eContents().get(2);
		private final Assignment cDateFormatAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cDateFormatSTRINGTerminalRuleCall_3_0 = (RuleCall)cDateFormatAssignment_3.eContents().get(0);
		
		//PropertyDateStyle style::CxGridPropDateStyle:
		//	{style::CxGridPropDateStyle}
		//	'dateStyle' 'format' dateFormat=STRING;
		@Override public ParserRule getRule() { return rule; }
		
		//{style::CxGridPropDateStyle} 'dateStyle' 'format' dateFormat=STRING
		public Group getGroup() { return cGroup; }
		
		//{style::CxGridPropDateStyle}
		public Action getCxGridPropDateStyleAction_0() { return cCxGridPropDateStyleAction_0; }
		
		//'dateStyle'
		public Keyword getDateStyleKeyword_1() { return cDateStyleKeyword_1; }
		
		//'format'
		public Keyword getFormatKeyword_2() { return cFormatKeyword_2; }
		
		//dateFormat=STRING
		public Assignment getDateFormatAssignment_3() { return cDateFormatAssignment_3; }
		
		//STRING
		public RuleCall getDateFormatSTRINGTerminalRuleCall_3_0() { return cDateFormatSTRINGTerminalRuleCall_3_0; }
	}
	public class PropertyNumberStyleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.PropertyNumberStyle");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cCxGridPropNumberStyleAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cNumberStyleKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Keyword cFormatKeyword_2 = (Keyword)cGroup.eContents().get(2);
		private final Assignment cNumberFormatAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cNumberFormatSTRINGTerminalRuleCall_3_0 = (RuleCall)cNumberFormatAssignment_3.eContents().get(0);
		
		//PropertyNumberStyle style::CxGridPropNumberStyle:
		//	{style::CxGridPropNumberStyle}
		//	'numberStyle' 'format' numberFormat=STRING;
		@Override public ParserRule getRule() { return rule; }
		
		//{style::CxGridPropNumberStyle} 'numberStyle' 'format' numberFormat=STRING
		public Group getGroup() { return cGroup; }
		
		//{style::CxGridPropNumberStyle}
		public Action getCxGridPropNumberStyleAction_0() { return cCxGridPropNumberStyleAction_0; }
		
		//'numberStyle'
		public Keyword getNumberStyleKeyword_1() { return cNumberStyleKeyword_1; }
		
		//'format'
		public Keyword getFormatKeyword_2() { return cFormatKeyword_2; }
		
		//numberFormat=STRING
		public Assignment getNumberFormatAssignment_3() { return cNumberFormatAssignment_3; }
		
		//STRING
		public RuleCall getNumberFormatSTRINGTerminalRuleCall_3_0() { return cNumberFormatSTRINGTerminalRuleCall_3_0; }
	}
	public class PropertyProgressbarStyleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.PropertyProgressbarStyle");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cCxGridPropProgressbarStyleAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cProgressbarStyleKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Keyword cMaxKeyword_2 = (Keyword)cGroup.eContents().get(2);
		private final Assignment cMaxValueAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cMaxValueLDoubleParserRuleCall_3_0 = (RuleCall)cMaxValueAssignment_3.eContents().get(0);
		
		//PropertyProgressbarStyle style::CxGridPropProgressbarStyle:
		//	{style::CxGridPropProgressbarStyle}
		//	'progressbarStyle' 'max' maxValue=LDouble;
		@Override public ParserRule getRule() { return rule; }
		
		//{style::CxGridPropProgressbarStyle} 'progressbarStyle' 'max' maxValue=LDouble
		public Group getGroup() { return cGroup; }
		
		//{style::CxGridPropProgressbarStyle}
		public Action getCxGridPropProgressbarStyleAction_0() { return cCxGridPropProgressbarStyleAction_0; }
		
		//'progressbarStyle'
		public Keyword getProgressbarStyleKeyword_1() { return cProgressbarStyleKeyword_1; }
		
		//'max'
		public Keyword getMaxKeyword_2() { return cMaxKeyword_2; }
		
		//maxValue=LDouble
		public Assignment getMaxValueAssignment_3() { return cMaxValueAssignment_3; }
		
		//LDouble
		public RuleCall getMaxValueLDoubleParserRuleCall_3_0() { return cMaxValueLDoubleParserRuleCall_3_0; }
	}
	public class GridPropIndicatorStyleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.GridPropIndicatorStyle");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cCxGridPropIndicatorStyleAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cIndicatorStyleKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Keyword cGreenFromKeyword_2 = (Keyword)cGroup.eContents().get(2);
		private final Assignment cGreenStartsAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cGreenStartsLDoubleParserRuleCall_3_0 = (RuleCall)cGreenStartsAssignment_3.eContents().get(0);
		private final Keyword cRedUntilKeyword_4 = (Keyword)cGroup.eContents().get(4);
		private final Assignment cRedEndsAssignment_5 = (Assignment)cGroup.eContents().get(5);
		private final RuleCall cRedEndsLDoubleParserRuleCall_5_0 = (RuleCall)cRedEndsAssignment_5.eContents().get(0);
		
		//GridPropIndicatorStyle style::CxGridPropIndicatorStyle:
		//	{style::CxGridPropIndicatorStyle}
		//	'indicatorStyle' 'greenFrom' greenStarts=LDouble 'redUntil' redEnds=LDouble;
		@Override public ParserRule getRule() { return rule; }
		
		//{style::CxGridPropIndicatorStyle} 'indicatorStyle' 'greenFrom' greenStarts=LDouble 'redUntil' redEnds=LDouble
		public Group getGroup() { return cGroup; }
		
		//{style::CxGridPropIndicatorStyle}
		public Action getCxGridPropIndicatorStyleAction_0() { return cCxGridPropIndicatorStyleAction_0; }
		
		//'indicatorStyle'
		public Keyword getIndicatorStyleKeyword_1() { return cIndicatorStyleKeyword_1; }
		
		//'greenFrom'
		public Keyword getGreenFromKeyword_2() { return cGreenFromKeyword_2; }
		
		//greenStarts=LDouble
		public Assignment getGreenStartsAssignment_3() { return cGreenStartsAssignment_3; }
		
		//LDouble
		public RuleCall getGreenStartsLDoubleParserRuleCall_3_0() { return cGreenStartsLDoubleParserRuleCall_3_0; }
		
		//'redUntil'
		public Keyword getRedUntilKeyword_4() { return cRedUntilKeyword_4; }
		
		//redEnds=LDouble
		public Assignment getRedEndsAssignment_5() { return cRedEndsAssignment_5; }
		
		//LDouble
		public RuleCall getRedEndsLDoubleParserRuleCall_5_0() { return cRedEndsLDoubleParserRuleCall_5_0; }
	}
	public class PropertyQuantityStyleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.PropertyQuantityStyle");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cCxGridPropQuantityStyleAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cQuantityStyleKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cHtmlPatternAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cHtmlPatternSTRINGTerminalRuleCall_2_0 = (RuleCall)cHtmlPatternAssignment_2.eContents().get(0);
		private final Keyword cValueKeyword_3 = (Keyword)cGroup.eContents().get(3);
		private final Keyword cEqualsSignKeyword_4 = (Keyword)cGroup.eContents().get(4);
		private final Assignment cValuePropertyPathAssignment_5 = (Assignment)cGroup.eContents().get(5);
		private final RuleCall cValuePropertyPathNestedFieldParserRuleCall_5_0 = (RuleCall)cValuePropertyPathAssignment_5.eContents().get(0);
		private final Group cGroup_6 = (Group)cGroup.eContents().get(6);
		private final Keyword cLeftParenthesisKeyword_6_0 = (Keyword)cGroup_6.eContents().get(0);
		private final Keyword cFormatKeyword_6_1 = (Keyword)cGroup_6.eContents().get(1);
		private final Assignment cValueNumberFormatAssignment_6_2 = (Assignment)cGroup_6.eContents().get(2);
		private final RuleCall cValueNumberFormatSTRINGTerminalRuleCall_6_2_0 = (RuleCall)cValueNumberFormatAssignment_6_2.eContents().get(0);
		private final Keyword cRightParenthesisKeyword_6_3 = (Keyword)cGroup_6.eContents().get(3);
		private final Keyword cUomKeyword_7 = (Keyword)cGroup.eContents().get(7);
		private final Keyword cEqualsSignKeyword_8 = (Keyword)cGroup.eContents().get(8);
		private final Assignment cUomPropertyPathAssignment_9 = (Assignment)cGroup.eContents().get(9);
		private final RuleCall cUomPropertyPathNestedFieldParserRuleCall_9_0 = (RuleCall)cUomPropertyPathAssignment_9.eContents().get(0);
		
		//PropertyQuantityStyle style::CxGridPropQuantityStyle:
		//	{style::CxGridPropQuantityStyle}
		//	'quantityStyle' htmlPattern=STRING? 'value' '=' valuePropertyPath=NestedField ('(' 'format' valueNumberFormat=STRING
		//	')')? 'uom' '='
		//	uomPropertyPath=NestedField;
		@Override public ParserRule getRule() { return rule; }
		
		//{style::CxGridPropQuantityStyle} 'quantityStyle' htmlPattern=STRING? 'value' '=' valuePropertyPath=NestedField ('('
		//'format' valueNumberFormat=STRING ')')? 'uom' '=' uomPropertyPath=NestedField
		public Group getGroup() { return cGroup; }
		
		//{style::CxGridPropQuantityStyle}
		public Action getCxGridPropQuantityStyleAction_0() { return cCxGridPropQuantityStyleAction_0; }
		
		//'quantityStyle'
		public Keyword getQuantityStyleKeyword_1() { return cQuantityStyleKeyword_1; }
		
		//htmlPattern=STRING?
		public Assignment getHtmlPatternAssignment_2() { return cHtmlPatternAssignment_2; }
		
		//STRING
		public RuleCall getHtmlPatternSTRINGTerminalRuleCall_2_0() { return cHtmlPatternSTRINGTerminalRuleCall_2_0; }
		
		//'value'
		public Keyword getValueKeyword_3() { return cValueKeyword_3; }
		
		//'='
		public Keyword getEqualsSignKeyword_4() { return cEqualsSignKeyword_4; }
		
		//valuePropertyPath=NestedField
		public Assignment getValuePropertyPathAssignment_5() { return cValuePropertyPathAssignment_5; }
		
		//NestedField
		public RuleCall getValuePropertyPathNestedFieldParserRuleCall_5_0() { return cValuePropertyPathNestedFieldParserRuleCall_5_0; }
		
		//('(' 'format' valueNumberFormat=STRING ')')?
		public Group getGroup_6() { return cGroup_6; }
		
		//'('
		public Keyword getLeftParenthesisKeyword_6_0() { return cLeftParenthesisKeyword_6_0; }
		
		//'format'
		public Keyword getFormatKeyword_6_1() { return cFormatKeyword_6_1; }
		
		//valueNumberFormat=STRING
		public Assignment getValueNumberFormatAssignment_6_2() { return cValueNumberFormatAssignment_6_2; }
		
		//STRING
		public RuleCall getValueNumberFormatSTRINGTerminalRuleCall_6_2_0() { return cValueNumberFormatSTRINGTerminalRuleCall_6_2_0; }
		
		//')'
		public Keyword getRightParenthesisKeyword_6_3() { return cRightParenthesisKeyword_6_3; }
		
		//'uom'
		public Keyword getUomKeyword_7() { return cUomKeyword_7; }
		
		//'='
		public Keyword getEqualsSignKeyword_8() { return cEqualsSignKeyword_8; }
		
		//uomPropertyPath=NestedField
		public Assignment getUomPropertyPathAssignment_9() { return cUomPropertyPathAssignment_9; }
		
		//NestedField
		public RuleCall getUomPropertyPathNestedFieldParserRuleCall_9_0() { return cUomPropertyPathNestedFieldParserRuleCall_9_0; }
	}
	public class PropertyPriceStyleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.PropertyPriceStyle");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cCxGridPropPriceStyleAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cPriceStyleKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cHtmlPatternAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cHtmlPatternSTRINGTerminalRuleCall_2_0 = (RuleCall)cHtmlPatternAssignment_2.eContents().get(0);
		private final Keyword cValueKeyword_3 = (Keyword)cGroup.eContents().get(3);
		private final Keyword cEqualsSignKeyword_4 = (Keyword)cGroup.eContents().get(4);
		private final Assignment cValuePropertyPathAssignment_5 = (Assignment)cGroup.eContents().get(5);
		private final RuleCall cValuePropertyPathNestedFieldParserRuleCall_5_0 = (RuleCall)cValuePropertyPathAssignment_5.eContents().get(0);
		private final Group cGroup_6 = (Group)cGroup.eContents().get(6);
		private final Keyword cLeftParenthesisKeyword_6_0 = (Keyword)cGroup_6.eContents().get(0);
		private final Keyword cFormatKeyword_6_1 = (Keyword)cGroup_6.eContents().get(1);
		private final Assignment cValueNumberFormatAssignment_6_2 = (Assignment)cGroup_6.eContents().get(2);
		private final RuleCall cValueNumberFormatSTRINGTerminalRuleCall_6_2_0 = (RuleCall)cValueNumberFormatAssignment_6_2.eContents().get(0);
		private final Keyword cRightParenthesisKeyword_6_3 = (Keyword)cGroup_6.eContents().get(3);
		private final Keyword cCurrencyKeyword_7 = (Keyword)cGroup.eContents().get(7);
		private final Keyword cEqualsSignKeyword_8 = (Keyword)cGroup.eContents().get(8);
		private final Assignment cCurrencyPropertyPathAssignment_9 = (Assignment)cGroup.eContents().get(9);
		private final RuleCall cCurrencyPropertyPathNestedFieldParserRuleCall_9_0 = (RuleCall)cCurrencyPropertyPathAssignment_9.eContents().get(0);
		
		//PropertyPriceStyle style::CxGridPropPriceStyle:
		//	{style::CxGridPropPriceStyle}
		//	'priceStyle' htmlPattern=STRING? 'value' '=' valuePropertyPath=NestedField ('(' 'format' valueNumberFormat=STRING
		//	')')? 'currency' '='
		//	currencyPropertyPath=NestedField;
		@Override public ParserRule getRule() { return rule; }
		
		//{style::CxGridPropPriceStyle} 'priceStyle' htmlPattern=STRING? 'value' '=' valuePropertyPath=NestedField ('(' 'format'
		//valueNumberFormat=STRING ')')? 'currency' '=' currencyPropertyPath=NestedField
		public Group getGroup() { return cGroup; }
		
		//{style::CxGridPropPriceStyle}
		public Action getCxGridPropPriceStyleAction_0() { return cCxGridPropPriceStyleAction_0; }
		
		//'priceStyle'
		public Keyword getPriceStyleKeyword_1() { return cPriceStyleKeyword_1; }
		
		//htmlPattern=STRING?
		public Assignment getHtmlPatternAssignment_2() { return cHtmlPatternAssignment_2; }
		
		//STRING
		public RuleCall getHtmlPatternSTRINGTerminalRuleCall_2_0() { return cHtmlPatternSTRINGTerminalRuleCall_2_0; }
		
		//'value'
		public Keyword getValueKeyword_3() { return cValueKeyword_3; }
		
		//'='
		public Keyword getEqualsSignKeyword_4() { return cEqualsSignKeyword_4; }
		
		//valuePropertyPath=NestedField
		public Assignment getValuePropertyPathAssignment_5() { return cValuePropertyPathAssignment_5; }
		
		//NestedField
		public RuleCall getValuePropertyPathNestedFieldParserRuleCall_5_0() { return cValuePropertyPathNestedFieldParserRuleCall_5_0; }
		
		//('(' 'format' valueNumberFormat=STRING ')')?
		public Group getGroup_6() { return cGroup_6; }
		
		//'('
		public Keyword getLeftParenthesisKeyword_6_0() { return cLeftParenthesisKeyword_6_0; }
		
		//'format'
		public Keyword getFormatKeyword_6_1() { return cFormatKeyword_6_1; }
		
		//valueNumberFormat=STRING
		public Assignment getValueNumberFormatAssignment_6_2() { return cValueNumberFormatAssignment_6_2; }
		
		//STRING
		public RuleCall getValueNumberFormatSTRINGTerminalRuleCall_6_2_0() { return cValueNumberFormatSTRINGTerminalRuleCall_6_2_0; }
		
		//')'
		public Keyword getRightParenthesisKeyword_6_3() { return cRightParenthesisKeyword_6_3; }
		
		//'currency'
		public Keyword getCurrencyKeyword_7() { return cCurrencyKeyword_7; }
		
		//'='
		public Keyword getEqualsSignKeyword_8() { return cEqualsSignKeyword_8; }
		
		//currencyPropertyPath=NestedField
		public Assignment getCurrencyPropertyPathAssignment_9() { return cCurrencyPropertyPathAssignment_9; }
		
		//NestedField
		public RuleCall getCurrencyPropertyPathNestedFieldParserRuleCall_9_0() { return cCurrencyPropertyPathNestedFieldParserRuleCall_9_0; }
	}
	public class PropertyTextStyleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.PropertyTextStyle");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cCxGridPropTextStyleAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cTextStyleKeyword_1 = (Keyword)cGroup.eContents().get(1);
		
		//PropertyTextStyle style::CxGridPropTextStyle:
		//	{style::CxGridPropTextStyle}
		//	'textStyle';
		@Override public ParserRule getRule() { return rule; }
		
		//{style::CxGridPropTextStyle} 'textStyle'
		public Group getGroup() { return cGroup; }
		
		//{style::CxGridPropTextStyle}
		public Action getCxGridPropTextStyleAction_0() { return cCxGridPropTextStyleAction_0; }
		
		//'textStyle'
		public Keyword getTextStyleKeyword_1() { return cTextStyleKeyword_1; }
	}
	public class PropertyBlobImageStyleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.PropertyBlobImageStyle");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cCxGridPropBlobImageStyleAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cBlobImageStyleKeyword_1 = (Keyword)cGroup.eContents().get(1);
		
		//PropertyBlobImageStyle style::CxGridPropBlobImageStyle:
		//	{style::CxGridPropBlobImageStyle}
		//	'blobImageStyle';
		@Override public ParserRule getRule() { return rule; }
		
		//{style::CxGridPropBlobImageStyle} 'blobImageStyle'
		public Group getGroup() { return cGroup; }
		
		//{style::CxGridPropBlobImageStyle}
		public Action getCxGridPropBlobImageStyleAction_0() { return cCxGridPropBlobImageStyleAction_0; }
		
		//'blobImageStyle'
		public Keyword getBlobImageStyleKeyword_1() { return cBlobImageStyleKeyword_1; }
	}
	public class PropertyImageStyleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.PropertyImageStyle");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Action cCxGridPropImageStyleAction_0 = (Action)cGroup.eContents().get(0);
		private final Keyword cImageStyleKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Group cGroup_2 = (Group)cGroup.eContents().get(2);
		private final Keyword cEventTopicKeyword_2_0 = (Keyword)cGroup_2.eContents().get(0);
		private final Assignment cEventTopicAssignment_2_1 = (Assignment)cGroup_2.eContents().get(1);
		private final RuleCall cEventTopicSTRINGTerminalRuleCall_2_1_0 = (RuleCall)cEventTopicAssignment_2_1.eContents().get(0);
		private final Keyword cLeftCurlyBracketKeyword_3 = (Keyword)cGroup.eContents().get(3);
		private final Assignment cConfigsAssignment_4 = (Assignment)cGroup.eContents().get(4);
		private final RuleCall cConfigsStyleConfigParserRuleCall_4_0 = (RuleCall)cConfigsAssignment_4.eContents().get(0);
		private final Keyword cRightCurlyBracketKeyword_5 = (Keyword)cGroup.eContents().get(5);
		
		//PropertyImageStyle style::CxGridPropImageStyle:
		//	{style::CxGridPropImageStyle}
		//	'imageStyle' ('eventTopic' eventTopic=STRING)? '{'
		//	configs+=StyleConfig*
		//	'}';
		@Override public ParserRule getRule() { return rule; }
		
		//{style::CxGridPropImageStyle} 'imageStyle' ('eventTopic' eventTopic=STRING)? '{' configs+=StyleConfig* '}'
		public Group getGroup() { return cGroup; }
		
		//{style::CxGridPropImageStyle}
		public Action getCxGridPropImageStyleAction_0() { return cCxGridPropImageStyleAction_0; }
		
		//'imageStyle'
		public Keyword getImageStyleKeyword_1() { return cImageStyleKeyword_1; }
		
		//('eventTopic' eventTopic=STRING)?
		public Group getGroup_2() { return cGroup_2; }
		
		//'eventTopic'
		public Keyword getEventTopicKeyword_2_0() { return cEventTopicKeyword_2_0; }
		
		//eventTopic=STRING
		public Assignment getEventTopicAssignment_2_1() { return cEventTopicAssignment_2_1; }
		
		//STRING
		public RuleCall getEventTopicSTRINGTerminalRuleCall_2_1_0() { return cEventTopicSTRINGTerminalRuleCall_2_1_0; }
		
		//'{'
		public Keyword getLeftCurlyBracketKeyword_3() { return cLeftCurlyBracketKeyword_3; }
		
		//configs+=StyleConfig*
		public Assignment getConfigsAssignment_4() { return cConfigsAssignment_4; }
		
		//StyleConfig
		public RuleCall getConfigsStyleConfigParserRuleCall_4_0() { return cConfigsStyleConfigParserRuleCall_4_0; }
		
		//'}'
		public Keyword getRightCurlyBracketKeyword_5() { return cRightCurlyBracketKeyword_5; }
	}
	public class StyleConfigElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.StyleConfig");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final RuleCall cNumericToResourceStyleConfigParserRuleCall_0 = (RuleCall)cAlternatives.eContents().get(0);
		private final RuleCall cStringToResourceStyleConfigParserRuleCall_1 = (RuleCall)cAlternatives.eContents().get(1);
		
		//StyleConfig style::CxGridStyleConfig:
		//	NumericToResourceStyleConfig | StringToResourceStyleConfig;
		@Override public ParserRule getRule() { return rule; }
		
		//NumericToResourceStyleConfig | StringToResourceStyleConfig
		public Alternatives getAlternatives() { return cAlternatives; }
		
		//NumericToResourceStyleConfig
		public RuleCall getNumericToResourceStyleConfigParserRuleCall_0() { return cNumericToResourceStyleConfigParserRuleCall_0; }
		
		//StringToResourceStyleConfig
		public RuleCall getStringToResourceStyleConfigParserRuleCall_1() { return cStringToResourceStyleConfigParserRuleCall_1; }
	}
	public class NumericToResourceStyleConfigElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.NumericToResourceStyleConfig");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cNumberKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cCompareAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cCompareStyleCompareEnumRuleCall_1_0 = (RuleCall)cCompareAssignment_1.eContents().get(0);
		private final Assignment cValueAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cValueLDoubleParserRuleCall_2_0 = (RuleCall)cValueAssignment_2.eContents().get(0);
		private final Keyword cThenKeyword_3 = (Keyword)cGroup.eContents().get(3);
		private final Assignment cResourceThemePathAssignment_4 = (Assignment)cGroup.eContents().get(4);
		private final RuleCall cResourceThemePathTHEME_RESOURCETerminalRuleCall_4_0 = (RuleCall)cResourceThemePathAssignment_4.eContents().get(0);
		
		//NumericToResourceStyleConfig style::CxGridStyleConfigNumericToResource:
		//	'number' compare=StyleCompare value=LDouble 'then' resourceThemePath=THEME_RESOURCE;
		@Override public ParserRule getRule() { return rule; }
		
		//'number' compare=StyleCompare value=LDouble 'then' resourceThemePath=THEME_RESOURCE
		public Group getGroup() { return cGroup; }
		
		//'number'
		public Keyword getNumberKeyword_0() { return cNumberKeyword_0; }
		
		//compare=StyleCompare
		public Assignment getCompareAssignment_1() { return cCompareAssignment_1; }
		
		//StyleCompare
		public RuleCall getCompareStyleCompareEnumRuleCall_1_0() { return cCompareStyleCompareEnumRuleCall_1_0; }
		
		//value=LDouble
		public Assignment getValueAssignment_2() { return cValueAssignment_2; }
		
		//LDouble
		public RuleCall getValueLDoubleParserRuleCall_2_0() { return cValueLDoubleParserRuleCall_2_0; }
		
		//'then'
		public Keyword getThenKeyword_3() { return cThenKeyword_3; }
		
		//resourceThemePath=THEME_RESOURCE
		public Assignment getResourceThemePathAssignment_4() { return cResourceThemePathAssignment_4; }
		
		//THEME_RESOURCE
		public RuleCall getResourceThemePathTHEME_RESOURCETerminalRuleCall_4_0() { return cResourceThemePathTHEME_RESOURCETerminalRuleCall_4_0; }
	}
	public class StringToResourceStyleConfigElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.StringToResourceStyleConfig");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cStringKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cCompareAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cCompareStyleCompareEnumRuleCall_1_0 = (RuleCall)cCompareAssignment_1.eContents().get(0);
		private final Assignment cValueAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cValueSTRINGTerminalRuleCall_2_0 = (RuleCall)cValueAssignment_2.eContents().get(0);
		private final Keyword cThenKeyword_3 = (Keyword)cGroup.eContents().get(3);
		private final Assignment cResourceThemePathAssignment_4 = (Assignment)cGroup.eContents().get(4);
		private final RuleCall cResourceThemePathTHEME_RESOURCETerminalRuleCall_4_0 = (RuleCall)cResourceThemePathAssignment_4.eContents().get(0);
		
		//StringToResourceStyleConfig style::CxGridStyleConfigStringToResource:
		//	'string' compare=StyleCompare value=STRING 'then' resourceThemePath=THEME_RESOURCE;
		@Override public ParserRule getRule() { return rule; }
		
		//'string' compare=StyleCompare value=STRING 'then' resourceThemePath=THEME_RESOURCE
		public Group getGroup() { return cGroup; }
		
		//'string'
		public Keyword getStringKeyword_0() { return cStringKeyword_0; }
		
		//compare=StyleCompare
		public Assignment getCompareAssignment_1() { return cCompareAssignment_1; }
		
		//StyleCompare
		public RuleCall getCompareStyleCompareEnumRuleCall_1_0() { return cCompareStyleCompareEnumRuleCall_1_0; }
		
		//value=STRING
		public Assignment getValueAssignment_2() { return cValueAssignment_2; }
		
		//STRING
		public RuleCall getValueSTRINGTerminalRuleCall_2_0() { return cValueSTRINGTerminalRuleCall_2_0; }
		
		//'then'
		public Keyword getThenKeyword_3() { return cThenKeyword_3; }
		
		//resourceThemePath=THEME_RESOURCE
		public Assignment getResourceThemePathAssignment_4() { return cResourceThemePathAssignment_4; }
		
		//THEME_RESOURCE
		public RuleCall getResourceThemePathTHEME_RESOURCETerminalRuleCall_4_0() { return cResourceThemePathTHEME_RESOURCETerminalRuleCall_4_0; }
	}
	public class LIntElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.LInt");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Alternatives cAlternatives_0 = (Alternatives)cGroup.eContents().get(0);
		private final Keyword cPlusSignKeyword_0_0 = (Keyword)cAlternatives_0.eContents().get(0);
		private final Keyword cHyphenMinusKeyword_0_1 = (Keyword)cAlternatives_0.eContents().get(1);
		private final RuleCall cINTTerminalRuleCall_1 = (RuleCall)cGroup.eContents().get(1);
		
		//LInt ecore::EInt:
		//	('+' | '-')? INT;
		@Override public ParserRule getRule() { return rule; }
		
		//('+' | '-')? INT
		public Group getGroup() { return cGroup; }
		
		//('+' | '-')?
		public Alternatives getAlternatives_0() { return cAlternatives_0; }
		
		//'+'
		public Keyword getPlusSignKeyword_0_0() { return cPlusSignKeyword_0_0; }
		
		//'-'
		public Keyword getHyphenMinusKeyword_0_1() { return cHyphenMinusKeyword_0_1; }
		
		//INT
		public RuleCall getINTTerminalRuleCall_1() { return cINTTerminalRuleCall_1; }
	}
	public class LDoubleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.LDouble");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final RuleCall cLIntParserRuleCall_0 = (RuleCall)cGroup.eContents().get(0);
		private final Group cGroup_1 = (Group)cGroup.eContents().get(1);
		private final Keyword cFullStopKeyword_1_0 = (Keyword)cGroup_1.eContents().get(0);
		private final RuleCall cINTTerminalRuleCall_1_1 = (RuleCall)cGroup_1.eContents().get(1);
		
		//LDouble ecore::EDouble:
		//	LInt ('.' INT)?;
		@Override public ParserRule getRule() { return rule; }
		
		//LInt ('.' INT)?
		public Group getGroup() { return cGroup; }
		
		//LInt
		public RuleCall getLIntParserRuleCall_0() { return cLIntParserRuleCall_0; }
		
		//('.' INT)?
		public Group getGroup_1() { return cGroup_1; }
		
		//'.'
		public Keyword getFullStopKeyword_1_0() { return cFullStopKeyword_1_0; }
		
		//INT
		public RuleCall getINTTerminalRuleCall_1_1() { return cINTTerminalRuleCall_1_1; }
	}
	public class SignedNumberElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.SignedNumber");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cHyphenMinusKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final RuleCall cNumberParserRuleCall_1 = (RuleCall)cGroup.eContents().get(1);
		
		////  ----------------- grid ends ------------------------
		//SignedNumber ecore::EDouble:
		//	'-'? Number;
		@Override public ParserRule getRule() { return rule; }
		
		//'-'? Number
		public Group getGroup() { return cGroup; }
		
		//'-'?
		public Keyword getHyphenMinusKeyword_0() { return cHyphenMinusKeyword_0; }
		
		//Number
		public RuleCall getNumberParserRuleCall_1() { return cNumberParserRuleCall_1; }
	}
	public class SignedIntElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.SignedInt");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cHyphenMinusKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final RuleCall cINTTerminalRuleCall_1 = (RuleCall)cGroup.eContents().get(1);
		
		//SignedInt ecore::EInt:
		//	'-'? INT;
		@Override public ParserRule getRule() { return rule; }
		
		//'-'? INT
		public Group getGroup() { return cGroup; }
		
		//'-'?
		public Keyword getHyphenMinusKeyword_0() { return cHyphenMinusKeyword_0; }
		
		//INT
		public RuleCall getINTTerminalRuleCall_1() { return cINTTerminalRuleCall_1; }
	}
	public class TRANSLATABLESTRINGElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TRANSLATABLESTRING");
		private final RuleCall cSTRINGTerminalRuleCall = (RuleCall)rule.eContents().get(1);
		
		//TRANSLATABLESTRING:
		//	STRING;
		@Override public ParserRule getRule() { return rule; }
		
		//STRING
		public RuleCall getSTRINGTerminalRuleCall() { return cSTRINGTerminalRuleCall; }
	}
	public class TRANSLATABLEIDElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TRANSLATABLEID");
		private final RuleCall cIDTerminalRuleCall = (RuleCall)rule.eContents().get(1);
		
		//TRANSLATABLEID:
		//	ID;
		@Override public ParserRule getRule() { return rule; }
		
		//ID
		public RuleCall getIDTerminalRuleCall() { return cIDTerminalRuleCall; }
	}
	
	public class StyleCompareElements extends AbstractEnumRuleElementFinder {
		private final EnumRule rule = (EnumRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.StyleCompare");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final EnumLiteralDeclaration cEqualEnumLiteralDeclaration_0 = (EnumLiteralDeclaration)cAlternatives.eContents().get(0);
		private final Keyword cEqualEqualKeyword_0_0 = (Keyword)cEqualEnumLiteralDeclaration_0.eContents().get(0);
		private final EnumLiteralDeclaration cGreaterEqualEnumLiteralDeclaration_1 = (EnumLiteralDeclaration)cAlternatives.eContents().get(1);
		private final Keyword cGreaterEqualGreaterEqualKeyword_1_0 = (Keyword)cGreaterEqualEnumLiteralDeclaration_1.eContents().get(0);
		private final EnumLiteralDeclaration cGreaterThanEnumLiteralDeclaration_2 = (EnumLiteralDeclaration)cAlternatives.eContents().get(2);
		private final Keyword cGreaterThanGreaterThanKeyword_2_0 = (Keyword)cGreaterThanEnumLiteralDeclaration_2.eContents().get(0);
		private final EnumLiteralDeclaration cLowerEqualEnumLiteralDeclaration_3 = (EnumLiteralDeclaration)cAlternatives.eContents().get(3);
		private final Keyword cLowerEqualLowerEqualKeyword_3_0 = (Keyword)cLowerEqualEnumLiteralDeclaration_3.eContents().get(0);
		private final EnumLiteralDeclaration cLowerThanEnumLiteralDeclaration_4 = (EnumLiteralDeclaration)cAlternatives.eContents().get(4);
		private final Keyword cLowerThanLowerThanKeyword_4_0 = (Keyword)cLowerThanEnumLiteralDeclaration_4.eContents().get(0);
		private final EnumLiteralDeclaration cNotEqualEnumLiteralDeclaration_5 = (EnumLiteralDeclaration)cAlternatives.eContents().get(5);
		private final Keyword cNotEqualNotEqualKeyword_5_0 = (Keyword)cNotEqualEnumLiteralDeclaration_5.eContents().get(0);
		
		//enum StyleCompare returns style::CxGridCompare:
		//	Equal="equal" | GreaterEqual="greater equal" | GreaterThan="greater than" | LowerEqual="lower equal" |
		//	LowerThan="lower than" | NotEqual="not equal";
		public EnumRule getRule() { return rule; }
		
		//Equal="equal" | GreaterEqual="greater equal" | GreaterThan="greater than" | LowerEqual="lower equal" |
		//LowerThan="lower than" | NotEqual="not equal"
		public Alternatives getAlternatives() { return cAlternatives; }
		
		//Equal="equal"
		public EnumLiteralDeclaration getEqualEnumLiteralDeclaration_0() { return cEqualEnumLiteralDeclaration_0; }
		
		//"equal"
		public Keyword getEqualEqualKeyword_0_0() { return cEqualEqualKeyword_0_0; }
		
		//GreaterEqual="greater equal"
		public EnumLiteralDeclaration getGreaterEqualEnumLiteralDeclaration_1() { return cGreaterEqualEnumLiteralDeclaration_1; }
		
		//"greater equal"
		public Keyword getGreaterEqualGreaterEqualKeyword_1_0() { return cGreaterEqualGreaterEqualKeyword_1_0; }
		
		//GreaterThan="greater than"
		public EnumLiteralDeclaration getGreaterThanEnumLiteralDeclaration_2() { return cGreaterThanEnumLiteralDeclaration_2; }
		
		//"greater than"
		public Keyword getGreaterThanGreaterThanKeyword_2_0() { return cGreaterThanGreaterThanKeyword_2_0; }
		
		//LowerEqual="lower equal"
		public EnumLiteralDeclaration getLowerEqualEnumLiteralDeclaration_3() { return cLowerEqualEnumLiteralDeclaration_3; }
		
		//"lower equal"
		public Keyword getLowerEqualLowerEqualKeyword_3_0() { return cLowerEqualLowerEqualKeyword_3_0; }
		
		//LowerThan="lower than"
		public EnumLiteralDeclaration getLowerThanEnumLiteralDeclaration_4() { return cLowerThanEnumLiteralDeclaration_4; }
		
		//"lower than"
		public Keyword getLowerThanLowerThanKeyword_4_0() { return cLowerThanLowerThanKeyword_4_0; }
		
		//NotEqual="not equal"
		public EnumLiteralDeclaration getNotEqualEnumLiteralDeclaration_5() { return cNotEqualEnumLiteralDeclaration_5; }
		
		//"not equal"
		public Keyword getNotEqualNotEqualKeyword_5_0() { return cNotEqualNotEqualKeyword_5_0; }
	}
	public class TrendIconEnumElements extends AbstractEnumRuleElementFinder {
		private final EnumRule rule = (EnumRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.TrendIconEnum");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final EnumLiteralDeclaration cRISINGEnumLiteralDeclaration_0 = (EnumLiteralDeclaration)cAlternatives.eContents().get(0);
		private final Keyword cRISINGRisingKeyword_0_0 = (Keyword)cRISINGEnumLiteralDeclaration_0.eContents().get(0);
		private final EnumLiteralDeclaration cBADRISINGEnumLiteralDeclaration_1 = (EnumLiteralDeclaration)cAlternatives.eContents().get(1);
		private final Keyword cBADRISINGBadRisingKeyword_1_0 = (Keyword)cBADRISINGEnumLiteralDeclaration_1.eContents().get(0);
		private final EnumLiteralDeclaration cSLOPINGEnumLiteralDeclaration_2 = (EnumLiteralDeclaration)cAlternatives.eContents().get(2);
		private final Keyword cSLOPINGSlopingKeyword_2_0 = (Keyword)cSLOPINGEnumLiteralDeclaration_2.eContents().get(0);
		private final EnumLiteralDeclaration cGOODSLOPINGEnumLiteralDeclaration_3 = (EnumLiteralDeclaration)cAlternatives.eContents().get(3);
		private final Keyword cGOODSLOPINGGoodSlopingKeyword_3_0 = (Keyword)cGOODSLOPINGEnumLiteralDeclaration_3.eContents().get(0);
		private final EnumLiteralDeclaration cSTAGNATINGEnumLiteralDeclaration_4 = (EnumLiteralDeclaration)cAlternatives.eContents().get(4);
		private final Keyword cSTAGNATINGStagnatingKeyword_4_0 = (Keyword)cSTAGNATINGEnumLiteralDeclaration_4.eContents().get(0);
		
		//enum TrendIconEnum:
		//	RISING='rising' | BADRISING='bad-rising' | SLOPING='sloping' | GOODSLOPING='good-sloping' | STAGNATING='stagnating';
		public EnumRule getRule() { return rule; }
		
		//RISING='rising' | BADRISING='bad-rising' | SLOPING='sloping' | GOODSLOPING='good-sloping' | STAGNATING='stagnating'
		public Alternatives getAlternatives() { return cAlternatives; }
		
		//RISING='rising'
		public EnumLiteralDeclaration getRISINGEnumLiteralDeclaration_0() { return cRISINGEnumLiteralDeclaration_0; }
		
		//'rising'
		public Keyword getRISINGRisingKeyword_0_0() { return cRISINGRisingKeyword_0_0; }
		
		//BADRISING='bad-rising'
		public EnumLiteralDeclaration getBADRISINGEnumLiteralDeclaration_1() { return cBADRISINGEnumLiteralDeclaration_1; }
		
		//'bad-rising'
		public Keyword getBADRISINGBadRisingKeyword_1_0() { return cBADRISINGBadRisingKeyword_1_0; }
		
		//SLOPING='sloping'
		public EnumLiteralDeclaration getSLOPINGEnumLiteralDeclaration_2() { return cSLOPINGEnumLiteralDeclaration_2; }
		
		//'sloping'
		public Keyword getSLOPINGSlopingKeyword_2_0() { return cSLOPINGSlopingKeyword_2_0; }
		
		//GOODSLOPING='good-sloping'
		public EnumLiteralDeclaration getGOODSLOPINGEnumLiteralDeclaration_3() { return cGOODSLOPINGEnumLiteralDeclaration_3; }
		
		//'good-sloping'
		public Keyword getGOODSLOPINGGoodSlopingKeyword_3_0() { return cGOODSLOPINGGoodSlopingKeyword_3_0; }
		
		//STAGNATING='stagnating'
		public EnumLiteralDeclaration getSTAGNATINGEnumLiteralDeclaration_4() { return cSTAGNATINGEnumLiteralDeclaration_4; }
		
		//'stagnating'
		public Keyword getSTAGNATINGStagnatingKeyword_4_0() { return cSTAGNATINGStagnatingKeyword_4_0; }
	}
	public class RowHeaderModeElements extends AbstractEnumRuleElementFinder {
		private final EnumRule rule = (EnumRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.RowHeaderMode");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final EnumLiteralDeclaration cHIDDENEnumLiteralDeclaration_0 = (EnumLiteralDeclaration)cAlternatives.eContents().get(0);
		private final Keyword cHIDDENHiddenKeyword_0_0 = (Keyword)cHIDDENEnumLiteralDeclaration_0.eContents().get(0);
		private final EnumLiteralDeclaration cEXPLICIT_DEFAULTS_IDEnumLiteralDeclaration_1 = (EnumLiteralDeclaration)cAlternatives.eContents().get(1);
		private final Keyword cEXPLICIT_DEFAULTS_IDExplicitKeyword_1_0 = (Keyword)cEXPLICIT_DEFAULTS_IDEnumLiteralDeclaration_1.eContents().get(0);
		private final EnumLiteralDeclaration cINDEXEnumLiteralDeclaration_2 = (EnumLiteralDeclaration)cAlternatives.eContents().get(2);
		private final Keyword cINDEXIndexedKeyword_2_0 = (Keyword)cINDEXEnumLiteralDeclaration_2.eContents().get(0);
		
		//enum RowHeaderMode:
		//	HIDDEN='hidden' | EXPLICIT_DEFAULTS_ID='explicit' | INDEX='indexed';
		public EnumRule getRule() { return rule; }
		
		//HIDDEN='hidden' | EXPLICIT_DEFAULTS_ID='explicit' | INDEX='indexed'
		public Alternatives getAlternatives() { return cAlternatives; }
		
		//HIDDEN='hidden'
		public EnumLiteralDeclaration getHIDDENEnumLiteralDeclaration_0() { return cHIDDENEnumLiteralDeclaration_0; }
		
		//'hidden'
		public Keyword getHIDDENHiddenKeyword_0_0() { return cHIDDENHiddenKeyword_0_0; }
		
		//EXPLICIT_DEFAULTS_ID='explicit'
		public EnumLiteralDeclaration getEXPLICIT_DEFAULTS_IDEnumLiteralDeclaration_1() { return cEXPLICIT_DEFAULTS_IDEnumLiteralDeclaration_1; }
		
		//'explicit'
		public Keyword getEXPLICIT_DEFAULTS_IDExplicitKeyword_1_0() { return cEXPLICIT_DEFAULTS_IDExplicitKeyword_1_0; }
		
		//INDEX='indexed'
		public EnumLiteralDeclaration getINDEXEnumLiteralDeclaration_2() { return cINDEXEnumLiteralDeclaration_2; }
		
		//'indexed'
		public Keyword getINDEXIndexedKeyword_2_0() { return cINDEXIndexedKeyword_2_0; }
	}
	public class AxisEnumElements extends AbstractEnumRuleElementFinder {
		private final EnumRule rule = (EnumRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.AxisEnum");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final EnumLiteralDeclaration cDEFAULTEnumLiteralDeclaration_0 = (EnumLiteralDeclaration)cAlternatives.eContents().get(0);
		private final Keyword cDEFAULTDefaultKeyword_0_0 = (Keyword)cDEFAULTEnumLiteralDeclaration_0.eContents().get(0);
		private final EnumLiteralDeclaration cCOLUMNSEnumLiteralDeclaration_1 = (EnumLiteralDeclaration)cAlternatives.eContents().get(1);
		private final Keyword cCOLUMNSColumnsKeyword_1_0 = (Keyword)cCOLUMNSEnumLiteralDeclaration_1.eContents().get(0);
		private final EnumLiteralDeclaration cROWSEnumLiteralDeclaration_2 = (EnumLiteralDeclaration)cAlternatives.eContents().get(2);
		private final Keyword cROWSRowsKeyword_2_0 = (Keyword)cROWSEnumLiteralDeclaration_2.eContents().get(0);
		private final EnumLiteralDeclaration cPAGESEnumLiteralDeclaration_3 = (EnumLiteralDeclaration)cAlternatives.eContents().get(3);
		private final Keyword cPAGESPagesKeyword_3_0 = (Keyword)cPAGESEnumLiteralDeclaration_3.eContents().get(0);
		private final EnumLiteralDeclaration cSECTIONSEnumLiteralDeclaration_4 = (EnumLiteralDeclaration)cAlternatives.eContents().get(4);
		private final Keyword cSECTIONSSectionsKeyword_4_0 = (Keyword)cSECTIONSEnumLiteralDeclaration_4.eContents().get(0);
		private final EnumLiteralDeclaration cCHAPTERSEnumLiteralDeclaration_5 = (EnumLiteralDeclaration)cAlternatives.eContents().get(5);
		private final Keyword cCHAPTERSChaptersKeyword_5_0 = (Keyword)cCHAPTERSEnumLiteralDeclaration_5.eContents().get(0);
		
		//enum AxisEnum returns datamart::AxisEnum:
		//	DEFAULT='default' | COLUMNS='columns' | ROWS='rows' | PAGES='pages' | SECTIONS='sections' | CHAPTERS='chapters'
		//	/* | AXIS(<index>)*/;
		public EnumRule getRule() { return rule; }
		
		//DEFAULT='default' | COLUMNS='columns' | ROWS='rows' | PAGES='pages' | SECTIONS='sections' | CHAPTERS='chapters'
		public Alternatives getAlternatives() { return cAlternatives; }
		
		//DEFAULT='default'
		public EnumLiteralDeclaration getDEFAULTEnumLiteralDeclaration_0() { return cDEFAULTEnumLiteralDeclaration_0; }
		
		//'default'
		public Keyword getDEFAULTDefaultKeyword_0_0() { return cDEFAULTDefaultKeyword_0_0; }
		
		//COLUMNS='columns'
		public EnumLiteralDeclaration getCOLUMNSEnumLiteralDeclaration_1() { return cCOLUMNSEnumLiteralDeclaration_1; }
		
		//'columns'
		public Keyword getCOLUMNSColumnsKeyword_1_0() { return cCOLUMNSColumnsKeyword_1_0; }
		
		//ROWS='rows'
		public EnumLiteralDeclaration getROWSEnumLiteralDeclaration_2() { return cROWSEnumLiteralDeclaration_2; }
		
		//'rows'
		public Keyword getROWSRowsKeyword_2_0() { return cROWSRowsKeyword_2_0; }
		
		//PAGES='pages'
		public EnumLiteralDeclaration getPAGESEnumLiteralDeclaration_3() { return cPAGESEnumLiteralDeclaration_3; }
		
		//'pages'
		public Keyword getPAGESPagesKeyword_3_0() { return cPAGESPagesKeyword_3_0; }
		
		//SECTIONS='sections'
		public EnumLiteralDeclaration getSECTIONSEnumLiteralDeclaration_4() { return cSECTIONSEnumLiteralDeclaration_4; }
		
		//'sections'
		public Keyword getSECTIONSSectionsKeyword_4_0() { return cSECTIONSSectionsKeyword_4_0; }
		
		//CHAPTERS='chapters'
		public EnumLiteralDeclaration getCHAPTERSEnumLiteralDeclaration_5() { return cCHAPTERSEnumLiteralDeclaration_5; }
		
		//'chapters'
		public Keyword getCHAPTERSChaptersKeyword_5_0() { return cCHAPTERSChaptersKeyword_5_0; }
	}
	
	private final TableModelElements pTableModel;
	private final TablePackageElements pTablePackage;
	private final TableElements pTable;
	private final TableOptionElements pTableOption;
	private final TableSelectionElements pTableSelection;
	private final TableTableElements pTableTable;
	private final TablePreorderElements pTablePreorder;
	private final TableValueElements pTableValue;
	private final TableFormatterElements pTableFormatter;
	private final TableImageElements pTableImage;
	private final TableTooltipPatternElements pTableTooltipPattern;
	private final TableValueElementElements pTableValueElement;
	private final TableTaskElements pTableTask;
	private final TableAllColumnsElements pTableAllColumns;
	private final TableOrdinalElements pTableOrdinal;
	private final TableColumnElements pTableColumn;
	private final TableMeasureElements pTableMeasure;
	private final TableDerivedElements pTableDerived;
	private final TableHierarchyElements pTableHierarchy;
	private final TableAttributeElements pTableAttribute;
	private final TableAggregationElements pTableAggregation;
	private final TableIntervalElements pTableInterval;
	private final TableNumberIntervalElements pTableNumberInterval;
	private final TableIntIntervalElements pTableIntInterval;
	private final TableDateDayIntervalElements pTableDateDayInterval;
	private final TableLookupElements pTableLookup;
	private final TableIntLookupElements pTableIntLookup;
	private final TableNumberLookupElements pTableNumberLookup;
	private final TableStringLookupElements pTableStringLookup;
	private final TableDateDayLookupElements pTableDateDayLookup;
	private final TableDatamartElements pTableDatamart;
	private final TableElementElements pTableElement;
	private final TableEventElements pTableEvent;
	private final TableAxisElements pTableAxis;
	private final TableRangeElementElements pTableRangeElement;
	private final TableTextColorElements pTableTextColor;
	private final TableCellColorElements pTableCellColor;
	private final TableIconElements pTableIcon;
	private final TableTrendElements pTableTrend;
	private final TableTooltipElements pTableTooltip;
	private final TableGridElements pTableGrid;
	private final PropertyElements pProperty;
	private final TableDtoDatasourceElements pTableDtoDatasource;
	private final NestedFieldElements pNestedField;
	private final NestedPathElements pNestedPath;
	private final PropertyStyleElements pPropertyStyle;
	private final PropertyButtonStyleElements pPropertyButtonStyle;
	private final PropertyHtmlStyleElements pPropertyHtmlStyle;
	private final PropertyBooleanStyleElements pPropertyBooleanStyle;
	private final PropertyDateStyleElements pPropertyDateStyle;
	private final PropertyNumberStyleElements pPropertyNumberStyle;
	private final PropertyProgressbarStyleElements pPropertyProgressbarStyle;
	private final GridPropIndicatorStyleElements pGridPropIndicatorStyle;
	private final PropertyQuantityStyleElements pPropertyQuantityStyle;
	private final PropertyPriceStyleElements pPropertyPriceStyle;
	private final PropertyTextStyleElements pPropertyTextStyle;
	private final PropertyBlobImageStyleElements pPropertyBlobImageStyle;
	private final PropertyImageStyleElements pPropertyImageStyle;
	private final StyleConfigElements pStyleConfig;
	private final NumericToResourceStyleConfigElements pNumericToResourceStyleConfig;
	private final StringToResourceStyleConfigElements pStringToResourceStyleConfig;
	private final StyleCompareElements eStyleCompare;
	private final TerminalRule tTHEME_RESOURCE;
	private final LIntElements pLInt;
	private final LDoubleElements pLDouble;
	private final TerminalRule tEVENT_TOPIC;
	private final SignedNumberElements pSignedNumber;
	private final SignedIntElements pSignedInt;
	private final TRANSLATABLESTRINGElements pTRANSLATABLESTRING;
	private final TRANSLATABLEIDElements pTRANSLATABLEID;
	private final TrendIconEnumElements eTrendIconEnum;
	private final RowHeaderModeElements eRowHeaderMode;
	private final AxisEnumElements eAxisEnum;
	
	private final Grammar grammar;
	
	private final OXtypeGrammarAccess gaOXtype;
	
	private final XbaseWithAnnotationsGrammarAccess gaXbaseWithAnnotations;
	
	private final XbaseGrammarAccess gaXbase;
	
	private final XtypeGrammarAccess gaXtype;

	@Inject
	public TableDSLGrammarAccess(GrammarProvider grammarProvider,
			OXtypeGrammarAccess gaOXtype,
			XbaseWithAnnotationsGrammarAccess gaXbaseWithAnnotations,
			XbaseGrammarAccess gaXbase,
			XtypeGrammarAccess gaXtype) {
		this.grammar = internalFindGrammar(grammarProvider);
		this.gaOXtype = gaOXtype;
		this.gaXbaseWithAnnotations = gaXbaseWithAnnotations;
		this.gaXbase = gaXbase;
		this.gaXtype = gaXtype;
		this.pTableModel = new TableModelElements();
		this.pTablePackage = new TablePackageElements();
		this.pTable = new TableElements();
		this.pTableOption = new TableOptionElements();
		this.pTableSelection = new TableSelectionElements();
		this.pTableTable = new TableTableElements();
		this.pTablePreorder = new TablePreorderElements();
		this.pTableValue = new TableValueElements();
		this.pTableFormatter = new TableFormatterElements();
		this.pTableImage = new TableImageElements();
		this.pTableTooltipPattern = new TableTooltipPatternElements();
		this.pTableValueElement = new TableValueElementElements();
		this.pTableTask = new TableTaskElements();
		this.pTableAllColumns = new TableAllColumnsElements();
		this.pTableOrdinal = new TableOrdinalElements();
		this.pTableColumn = new TableColumnElements();
		this.pTableMeasure = new TableMeasureElements();
		this.pTableDerived = new TableDerivedElements();
		this.pTableHierarchy = new TableHierarchyElements();
		this.pTableAttribute = new TableAttributeElements();
		this.pTableAggregation = new TableAggregationElements();
		this.pTableInterval = new TableIntervalElements();
		this.pTableNumberInterval = new TableNumberIntervalElements();
		this.pTableIntInterval = new TableIntIntervalElements();
		this.pTableDateDayInterval = new TableDateDayIntervalElements();
		this.pTableLookup = new TableLookupElements();
		this.pTableIntLookup = new TableIntLookupElements();
		this.pTableNumberLookup = new TableNumberLookupElements();
		this.pTableStringLookup = new TableStringLookupElements();
		this.pTableDateDayLookup = new TableDateDayLookupElements();
		this.pTableDatamart = new TableDatamartElements();
		this.pTableElement = new TableElementElements();
		this.pTableEvent = new TableEventElements();
		this.pTableAxis = new TableAxisElements();
		this.pTableRangeElement = new TableRangeElementElements();
		this.pTableTextColor = new TableTextColorElements();
		this.pTableCellColor = new TableCellColorElements();
		this.pTableIcon = new TableIconElements();
		this.pTableTrend = new TableTrendElements();
		this.pTableTooltip = new TableTooltipElements();
		this.pTableGrid = new TableGridElements();
		this.pProperty = new PropertyElements();
		this.pTableDtoDatasource = new TableDtoDatasourceElements();
		this.pNestedField = new NestedFieldElements();
		this.pNestedPath = new NestedPathElements();
		this.pPropertyStyle = new PropertyStyleElements();
		this.pPropertyButtonStyle = new PropertyButtonStyleElements();
		this.pPropertyHtmlStyle = new PropertyHtmlStyleElements();
		this.pPropertyBooleanStyle = new PropertyBooleanStyleElements();
		this.pPropertyDateStyle = new PropertyDateStyleElements();
		this.pPropertyNumberStyle = new PropertyNumberStyleElements();
		this.pPropertyProgressbarStyle = new PropertyProgressbarStyleElements();
		this.pGridPropIndicatorStyle = new GridPropIndicatorStyleElements();
		this.pPropertyQuantityStyle = new PropertyQuantityStyleElements();
		this.pPropertyPriceStyle = new PropertyPriceStyleElements();
		this.pPropertyTextStyle = new PropertyTextStyleElements();
		this.pPropertyBlobImageStyle = new PropertyBlobImageStyleElements();
		this.pPropertyImageStyle = new PropertyImageStyleElements();
		this.pStyleConfig = new StyleConfigElements();
		this.pNumericToResourceStyleConfig = new NumericToResourceStyleConfigElements();
		this.pStringToResourceStyleConfig = new StringToResourceStyleConfigElements();
		this.eStyleCompare = new StyleCompareElements();
		this.tTHEME_RESOURCE = (TerminalRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.THEME_RESOURCE");
		this.pLInt = new LIntElements();
		this.pLDouble = new LDoubleElements();
		this.tEVENT_TOPIC = (TerminalRule) GrammarUtil.findRuleForName(getGrammar(), "org.eclipse.osbp.xtext.table.TableDSL.EVENT_TOPIC");
		this.pSignedNumber = new SignedNumberElements();
		this.pSignedInt = new SignedIntElements();
		this.pTRANSLATABLESTRING = new TRANSLATABLESTRINGElements();
		this.pTRANSLATABLEID = new TRANSLATABLEIDElements();
		this.eTrendIconEnum = new TrendIconEnumElements();
		this.eRowHeaderMode = new RowHeaderModeElements();
		this.eAxisEnum = new AxisEnumElements();
	}
	
	protected Grammar internalFindGrammar(GrammarProvider grammarProvider) {
		Grammar grammar = grammarProvider.getGrammar(this);
		while (grammar != null) {
			if ("org.eclipse.osbp.xtext.table.TableDSL".equals(grammar.getName())) {
				return grammar;
			}
			List<Grammar> grammars = grammar.getUsedGrammars();
			if (!grammars.isEmpty()) {
				grammar = grammars.iterator().next();
			} else {
				return null;
			}
		}
		return grammar;
	}
	
	@Override
	public Grammar getGrammar() {
		return grammar;
	}
	
	
	public OXtypeGrammarAccess getOXtypeGrammarAccess() {
		return gaOXtype;
	}
	
	public XbaseWithAnnotationsGrammarAccess getXbaseWithAnnotationsGrammarAccess() {
		return gaXbaseWithAnnotations;
	}
	
	public XbaseGrammarAccess getXbaseGrammarAccess() {
		return gaXbase;
	}
	
	public XtypeGrammarAccess getXtypeGrammarAccess() {
		return gaXtype;
	}

	
	//TableModel:
	//	importSection=XImportSection?
	//	packages+=TablePackage*;
	public TableModelElements getTableModelAccess() {
		return pTableModel;
	}
	
	public ParserRule getTableModelRule() {
		return getTableModelAccess().getRule();
	}
	
	//TablePackage:
	//	{TablePackage} 'package' name=QualifiedName ('{' tables+=Table* '}')?;
	public TablePackageElements getTablePackageAccess() {
		return pTablePackage;
	}
	
	public ParserRule getTablePackageRule() {
		return getTablePackageAccess().getRule();
	}
	
	//Table:
	//	{Table} 'table' name=ID (description?='describedBy' descriptionValue=TRANSLATABLESTRING)?
	//	'as' tabletype=TableOption;
	public TableElements getTableAccess() {
		return pTable;
	}
	
	public ParserRule getTableRule() {
		return getTableAccess().getRule();
	}
	
	//TableOption:
	//	TableSelection | TableTable | TableGrid;
	public TableOptionElements getTableOptionAccess() {
		return pTableOption;
	}
	
	public ParserRule getTableOptionRule() {
		return getTableOptionAccess().getRule();
	}
	
	//TableSelection:
	//	{TableSelection} 'selection' (multiSelection?='multiple' | 'single') (selectalways?='alwaysSelected'? & ('rowHeader'
	//	headerMode=RowHeaderMode)? & filtering?='filtering'? & embedded?='embedded'? & ('toolbar'
	//	toolbar=[action::ActionToolbar])?) ('using' source=TableDatamart)?;
	public TableSelectionElements getTableSelectionAccess() {
		return pTableSelection;
	}
	
	public ParserRule getTableSelectionRule() {
		return getTableSelectionAccess().getRule();
	}
	
	//TableTable:
	//	{TableTable} 'readOnly' (selectalways?='alwaysSelected'? & selectById?='selectById'? & ('rowHeader'
	//	headerMode=RowHeaderMode)? & filtering?='filtering'? & embedded?='embedded'? & ('toolbar'
	//	toolbar=[action::ActionToolbar])?) ('using' source=TableDatamart)?;
	public TableTableElements getTableTableAccess() {
		return pTableTable;
	}
	
	public ParserRule getTableTableRule() {
		return getTableTableAccess().getRule();
	}
	
	//TablePreorder:
	//	{TablePreorder} 'preorder' column=TableValueElement ascending?='ascending'?;
	public TablePreorderElements getTablePreorderAccess() {
		return pTablePreorder;
	}
	
	public ParserRule getTablePreorderRule() {
		return getTablePreorderAccess().getRule();
	}
	
	//TableValue:
	//	{TableValue} 'value' column=TableValueElement (collapsed?='collapse'? & ('icon' iconName=STRING)? &
	//	formatter=TableFormatter? & (hasImage?='image' image=TableImage)? & tooltipPattern=TableTooltipPattern?) (('intervals'
	//	hideLabelInterval?='hidelabel'? '{' intervals+=TableInterval* '}')? & ('lookups'
	//	hideLabelLookup?='hidelabel'? '{' lookups+=TableLookup* '}')?);
	public TableValueElements getTableValueAccess() {
		return pTableValue;
	}
	
	public ParserRule getTableValueRule() {
		return getTableValueAccess().getRule();
	}
	
	//TableFormatter:
	//	{TableFormatter} 'formatter' format=STRING;
	public TableFormatterElements getTableFormatterAccess() {
		return pTableFormatter;
	}
	
	public ParserRule getTableFormatterRule() {
		return getTableFormatterAccess().getRule();
	}
	
	//TableImage:
	//	{TableImage} 'path' imagePathPattern=STRING (hasParameter?='dynamic'? & hideImageLabel?='hidelabel'? &
	//	(resize?='resize' resizeString=STRING)?);
	public TableImageElements getTableImageAccess() {
		return pTableImage;
	}
	
	public ParserRule getTableImageRule() {
		return getTableImageAccess().getRule();
	}
	
	//TableTooltipPattern:
	//	{TableTooltipPattern} 'tooltipPattern' tooltipPattern=TRANSLATABLESTRING;
	public TableTooltipPatternElements getTableTooltipPatternAccess() {
		return pTableTooltipPattern;
	}
	
	public ParserRule getTableTooltipPatternRule() {
		return getTableTooltipPatternAccess().getRule();
	}
	
	//TableValueElement:
	//	TableMeasure | TableDerived | TableHierarchy | TableAttribute | TableAggregation | TableOrdinal | TableColumn |
	//	TableTask | TableAllColumns;
	public TableValueElementElements getTableValueElementAccess() {
		return pTableValueElement;
	}
	
	public ParserRule getTableValueElementRule() {
		return getTableValueElementAccess().getRule();
	}
	
	//TableTask:
	//	{TableTask} 'taskId';
	public TableTaskElements getTableTaskAccess() {
		return pTableTask;
	}
	
	public ParserRule getTableTaskRule() {
		return getTableTaskAccess().getRule();
	}
	
	//TableAllColumns:
	//	{TableAllColumns} 'allColumns';
	public TableAllColumnsElements getTableAllColumnsAccess() {
		return pTableAllColumns;
	}
	
	public ParserRule getTableAllColumnsRule() {
		return getTableAllColumnsAccess().getRule();
	}
	
	//TableOrdinal:
	//	'ordinal' valueRef=Number;
	public TableOrdinalElements getTableOrdinalAccess() {
		return pTableOrdinal;
	}
	
	public ParserRule getTableOrdinalRule() {
		return getTableOrdinalAccess().getRule();
	}
	
	//TableColumn:
	//	'column' valueRef=[datamart::DatamartColumn];
	public TableColumnElements getTableColumnAccess() {
		return pTableColumn;
	}
	
	public ParserRule getTableColumnRule() {
		return getTableColumnAccess().getRule();
	}
	
	//TableMeasure:
	//	'measure' valueRef=[datamart::DatamartMeasure];
	public TableMeasureElements getTableMeasureAccess() {
		return pTableMeasure;
	}
	
	public ParserRule getTableMeasureRule() {
		return getTableMeasureAccess().getRule();
	}
	
	//TableDerived:
	//	'derived' valueRef=[datamart::DatamartDerivedMeasure];
	public TableDerivedElements getTableDerivedAccess() {
		return pTableDerived;
	}
	
	public ParserRule getTableDerivedRule() {
		return getTableDerivedAccess().getRule();
	}
	
	//TableHierarchy:
	//	'level' valueRef=[cube::CubeLevel];
	public TableHierarchyElements getTableHierarchyAccess() {
		return pTableHierarchy;
	}
	
	public ParserRule getTableHierarchyRule() {
		return getTableHierarchyAccess().getRule();
	}
	
	//TableAttribute:
	//	{TableAttribute} 'property' valueRef=[datamart::DatamartAttribute];
	public TableAttributeElements getTableAttributeAccess() {
		return pTableAttribute;
	}
	
	public ParserRule getTableAttributeRule() {
		return getTableAttributeAccess().getRule();
	}
	
	//TableAggregation:
	//	'aggregation' valueRef=[datamart::DatamartSetAggregationFunction];
	public TableAggregationElements getTableAggregationAccess() {
		return pTableAggregation;
	}
	
	public ParserRule getTableAggregationRule() {
		return getTableAggregationAccess().getRule();
	}
	
	//TableInterval:
	//	TableNumberInterval | TableIntInterval | TableDateDayInterval;
	public TableIntervalElements getTableIntervalAccess() {
		return pTableInterval;
	}
	
	public ParserRule getTableIntervalRule() {
		return getTableIntervalAccess().getRule();
	}
	
	//TableNumberInterval:
	//	{TableNumberInterval} 'upToNumber' numberIntervalValue=SignedNumber numberRange=TableRangeElement;
	public TableNumberIntervalElements getTableNumberIntervalAccess() {
		return pTableNumberInterval;
	}
	
	public ParserRule getTableNumberIntervalRule() {
		return getTableNumberIntervalAccess().getRule();
	}
	
	//TableIntInterval:
	//	{TableIntInterval} 'upToInteger' intIntervalValue=SignedInt intRange=TableRangeElement;
	public TableIntIntervalElements getTableIntIntervalAccess() {
		return pTableIntInterval;
	}
	
	public ParserRule getTableIntIntervalRule() {
		return getTableIntIntervalAccess().getRule();
	}
	
	//TableDateDayInterval:
	//	{TableDateDayInterval} 'daysInPast' dateIntervalValue=SignedInt dateRange=TableRangeElement;
	public TableDateDayIntervalElements getTableDateDayIntervalAccess() {
		return pTableDateDayInterval;
	}
	
	public ParserRule getTableDateDayIntervalRule() {
		return getTableDateDayIntervalAccess().getRule();
	}
	
	//TableLookup:
	//	TableNumberLookup | TableIntLookup | TableStringLookup | TableDateDayLookup;
	public TableLookupElements getTableLookupAccess() {
		return pTableLookup;
	}
	
	public ParserRule getTableLookupRule() {
		return getTableLookupAccess().getRule();
	}
	
	//TableIntLookup:
	//	{TableIntLookup} 'integer' lookupValue=SignedInt discrete=TableRangeElement;
	public TableIntLookupElements getTableIntLookupAccess() {
		return pTableIntLookup;
	}
	
	public ParserRule getTableIntLookupRule() {
		return getTableIntLookupAccess().getRule();
	}
	
	//TableNumberLookup:
	//	{TableNumberLookup} 'number' lookupValue=SignedNumber discrete=TableRangeElement;
	public TableNumberLookupElements getTableNumberLookupAccess() {
		return pTableNumberLookup;
	}
	
	public ParserRule getTableNumberLookupRule() {
		return getTableNumberLookupAccess().getRule();
	}
	
	//TableStringLookup:
	//	{TableStringLookup} 'string' lookupValue=STRING discrete=TableRangeElement;
	public TableStringLookupElements getTableStringLookupAccess() {
		return pTableStringLookup;
	}
	
	public ParserRule getTableStringLookupRule() {
		return getTableStringLookupAccess().getRule();
	}
	
	//TableDateDayLookup:
	//	{TableDateDayLookup} 'daysInPast' lookupValue=SignedInt discrete=TableRangeElement;
	public TableDateDayLookupElements getTableDateDayLookupAccess() {
		return pTableDateDayLookup;
	}
	
	public ParserRule getTableDateDayLookupRule() {
		return getTableDateDayLookupAccess().getRule();
	}
	
	//TableDatamart:
	//	'datamart' datamartRef=[datamart::DatamartDefinition] ('{' elements+=TableElement* '}')?;
	public TableDatamartElements getTableDatamartAccess() {
		return pTableDatamart;
	}
	
	public ParserRule getTableDatamartRule() {
		return getTableDatamartAccess().getRule();
	}
	
	//TableElement:
	//	TableAxis;
	public TableElementElements getTableElementAccess() {
		return pTableElement;
	}
	
	public ParserRule getTableElementRule() {
		return getTableElementAccess().getRule();
	}
	
	//TableEvent:
	//	source=TableValueElement;
	public TableEventElements getTableEventAccess() {
		return pTableEvent;
	}
	
	public ParserRule getTableEventRule() {
		return getTableEventAccess().getRule();
	}
	
	//TableAxis:
	//	'axis' axis=AxisEnum ((hasRowHeight?='rowheight' rowHeight=Number)? & preOrder=TablePreorder?) (hasDetails?='details'
	//	'{' values+=TableValue* '}')? (hasEvents?='notifyOnSelect' '{' events+=TableEvent* '}')?;
	public TableAxisElements getTableAxisAccess() {
		return pTableAxis;
	}
	
	public ParserRule getTableAxisRule() {
		return getTableAxisAccess().getRule();
	}
	
	//TableRangeElement:
	//	TableTextColor | TableCellColor | TableIcon | TableTrend | TableTooltip;
	public TableRangeElementElements getTableRangeElementAccess() {
		return pTableRangeElement;
	}
	
	public ParserRule getTableRangeElementRule() {
		return getTableRangeElementAccess().getRule();
	}
	
	//TableTextColor:
	//	'textcolor' rgb=STRING;
	public TableTextColorElements getTableTextColorAccess() {
		return pTableTextColor;
	}
	
	public ParserRule getTableTextColorRule() {
		return getTableTextColorAccess().getRule();
	}
	
	//TableCellColor:
	//	'cellcolor' rgb=STRING;
	public TableCellColorElements getTableCellColorAccess() {
		return pTableCellColor;
	}
	
	public ParserRule getTableCellColorRule() {
		return getTableCellColorAccess().getRule();
	}
	
	//TableIcon:
	//	'icon' icon=STRING;
	public TableIconElements getTableIconAccess() {
		return pTableIcon;
	}
	
	public ParserRule getTableIconRule() {
		return getTableIconAccess().getRule();
	}
	
	//TableTrend:
	//	'trend' icon=TrendIconEnum;
	public TableTrendElements getTableTrendAccess() {
		return pTableTrend;
	}
	
	public ParserRule getTableTrendRule() {
		return getTableTrendAccess().getRule();
	}
	
	//TableTooltip:
	//	'tooltip' tooltip=TRANSLATABLESTRING;
	public TableTooltipElements getTableTooltipAccess() {
		return pTableTooltip;
	}
	
	public ParserRule getTableTooltipRule() {
		return getTableTooltipAccess().getRule();
	}
	
	//// ----------------------------- grid --------------------------------------
	//TableGrid:
	//	{TableGrid} 'editable' 'using' source=TableDtoDatasource;
	public TableGridElements getTableGridAccess() {
		return pTableGrid;
	}
	
	public ParserRule getTableGridRule() {
		return getTableGridAccess().getRule();
	}
	
	//Property CxGridProperty:
	//	editable?='editable'? 'prop' path=NestedField 'style' style=PropertyStyle;
	public PropertyElements getPropertyAccess() {
		return pProperty;
	}
	
	public ParserRule getPropertyRule() {
		return getPropertyAccess().getRule();
	}
	
	//TableDtoDatasource:
	//	'dto' dtoSource=[dto::LDto] ('{' properties+=Property* '}')?;
	public TableDtoDatasourceElements getTableDtoDatasourceAccess() {
		return pTableDtoDatasource;
	}
	
	public ParserRule getTableDtoDatasourceRule() {
		return getTableDtoDatasourceAccess().getRule();
	}
	
	//NestedField CxGridNestedField:
	//	{CxGridNestedField} field=[JvmOperation] path=NestedPath?;
	public NestedFieldElements getNestedFieldAccess() {
		return pNestedField;
	}
	
	public ParserRule getNestedFieldRule() {
		return getNestedFieldAccess().getRule();
	}
	
	//NestedPath CxGridNestedPath:
	//	{CxGridNestedPath}
	//	'.' field=[JvmOperation] path=NestedPath?;
	public NestedPathElements getNestedPathAccess() {
		return pNestedPath;
	}
	
	public ParserRule getNestedPathRule() {
		return getNestedPathAccess().getRule();
	}
	
	//PropertyStyle style::CxGridPropStyle:
	//	PropertyButtonStyle | PropertyHtmlStyle | PropertyProgressbarStyle | PropertyTextStyle | PropertyBooleanStyle |
	//	PropertyDateStyle | PropertyNumberStyle | PropertyImageStyle | PropertyBlobImageStyle | GridPropIndicatorStyle /*|
	//	PropertyPriceStyle | PropertyQuantityStyle */;
	public PropertyStyleElements getPropertyStyleAccess() {
		return pPropertyStyle;
	}
	
	public ParserRule getPropertyStyleRule() {
		return getPropertyStyleAccess().getRule();
	}
	
	//PropertyButtonStyle style::CxGridPropButtonStyle:
	//	{style::CxGridPropButtonStyle}
	//	'buttonStyle' 'eventTopic' eventTopic=STRING;
	public PropertyButtonStyleElements getPropertyButtonStyleAccess() {
		return pPropertyButtonStyle;
	}
	
	public ParserRule getPropertyButtonStyleRule() {
		return getPropertyButtonStyleAccess().getRule();
	}
	
	//PropertyHtmlStyle style::CxGridPropHtmlStyle:
	//	{style::CxGridPropHtmlStyle}
	//	'htmlStyle';
	public PropertyHtmlStyleElements getPropertyHtmlStyleAccess() {
		return pPropertyHtmlStyle;
	}
	
	public ParserRule getPropertyHtmlStyleRule() {
		return getPropertyHtmlStyleAccess().getRule();
	}
	
	//PropertyBooleanStyle style::CxGridPropBooleanStyle:
	//	{style::CxGridPropBooleanStyle}
	//	'boolStyle';
	public PropertyBooleanStyleElements getPropertyBooleanStyleAccess() {
		return pPropertyBooleanStyle;
	}
	
	public ParserRule getPropertyBooleanStyleRule() {
		return getPropertyBooleanStyleAccess().getRule();
	}
	
	//PropertyDateStyle style::CxGridPropDateStyle:
	//	{style::CxGridPropDateStyle}
	//	'dateStyle' 'format' dateFormat=STRING;
	public PropertyDateStyleElements getPropertyDateStyleAccess() {
		return pPropertyDateStyle;
	}
	
	public ParserRule getPropertyDateStyleRule() {
		return getPropertyDateStyleAccess().getRule();
	}
	
	//PropertyNumberStyle style::CxGridPropNumberStyle:
	//	{style::CxGridPropNumberStyle}
	//	'numberStyle' 'format' numberFormat=STRING;
	public PropertyNumberStyleElements getPropertyNumberStyleAccess() {
		return pPropertyNumberStyle;
	}
	
	public ParserRule getPropertyNumberStyleRule() {
		return getPropertyNumberStyleAccess().getRule();
	}
	
	//PropertyProgressbarStyle style::CxGridPropProgressbarStyle:
	//	{style::CxGridPropProgressbarStyle}
	//	'progressbarStyle' 'max' maxValue=LDouble;
	public PropertyProgressbarStyleElements getPropertyProgressbarStyleAccess() {
		return pPropertyProgressbarStyle;
	}
	
	public ParserRule getPropertyProgressbarStyleRule() {
		return getPropertyProgressbarStyleAccess().getRule();
	}
	
	//GridPropIndicatorStyle style::CxGridPropIndicatorStyle:
	//	{style::CxGridPropIndicatorStyle}
	//	'indicatorStyle' 'greenFrom' greenStarts=LDouble 'redUntil' redEnds=LDouble;
	public GridPropIndicatorStyleElements getGridPropIndicatorStyleAccess() {
		return pGridPropIndicatorStyle;
	}
	
	public ParserRule getGridPropIndicatorStyleRule() {
		return getGridPropIndicatorStyleAccess().getRule();
	}
	
	//PropertyQuantityStyle style::CxGridPropQuantityStyle:
	//	{style::CxGridPropQuantityStyle}
	//	'quantityStyle' htmlPattern=STRING? 'value' '=' valuePropertyPath=NestedField ('(' 'format' valueNumberFormat=STRING
	//	')')? 'uom' '='
	//	uomPropertyPath=NestedField;
	public PropertyQuantityStyleElements getPropertyQuantityStyleAccess() {
		return pPropertyQuantityStyle;
	}
	
	public ParserRule getPropertyQuantityStyleRule() {
		return getPropertyQuantityStyleAccess().getRule();
	}
	
	//PropertyPriceStyle style::CxGridPropPriceStyle:
	//	{style::CxGridPropPriceStyle}
	//	'priceStyle' htmlPattern=STRING? 'value' '=' valuePropertyPath=NestedField ('(' 'format' valueNumberFormat=STRING
	//	')')? 'currency' '='
	//	currencyPropertyPath=NestedField;
	public PropertyPriceStyleElements getPropertyPriceStyleAccess() {
		return pPropertyPriceStyle;
	}
	
	public ParserRule getPropertyPriceStyleRule() {
		return getPropertyPriceStyleAccess().getRule();
	}
	
	//PropertyTextStyle style::CxGridPropTextStyle:
	//	{style::CxGridPropTextStyle}
	//	'textStyle';
	public PropertyTextStyleElements getPropertyTextStyleAccess() {
		return pPropertyTextStyle;
	}
	
	public ParserRule getPropertyTextStyleRule() {
		return getPropertyTextStyleAccess().getRule();
	}
	
	//PropertyBlobImageStyle style::CxGridPropBlobImageStyle:
	//	{style::CxGridPropBlobImageStyle}
	//	'blobImageStyle';
	public PropertyBlobImageStyleElements getPropertyBlobImageStyleAccess() {
		return pPropertyBlobImageStyle;
	}
	
	public ParserRule getPropertyBlobImageStyleRule() {
		return getPropertyBlobImageStyleAccess().getRule();
	}
	
	//PropertyImageStyle style::CxGridPropImageStyle:
	//	{style::CxGridPropImageStyle}
	//	'imageStyle' ('eventTopic' eventTopic=STRING)? '{'
	//	configs+=StyleConfig*
	//	'}';
	public PropertyImageStyleElements getPropertyImageStyleAccess() {
		return pPropertyImageStyle;
	}
	
	public ParserRule getPropertyImageStyleRule() {
		return getPropertyImageStyleAccess().getRule();
	}
	
	//StyleConfig style::CxGridStyleConfig:
	//	NumericToResourceStyleConfig | StringToResourceStyleConfig;
	public StyleConfigElements getStyleConfigAccess() {
		return pStyleConfig;
	}
	
	public ParserRule getStyleConfigRule() {
		return getStyleConfigAccess().getRule();
	}
	
	//NumericToResourceStyleConfig style::CxGridStyleConfigNumericToResource:
	//	'number' compare=StyleCompare value=LDouble 'then' resourceThemePath=THEME_RESOURCE;
	public NumericToResourceStyleConfigElements getNumericToResourceStyleConfigAccess() {
		return pNumericToResourceStyleConfig;
	}
	
	public ParserRule getNumericToResourceStyleConfigRule() {
		return getNumericToResourceStyleConfigAccess().getRule();
	}
	
	//StringToResourceStyleConfig style::CxGridStyleConfigStringToResource:
	//	'string' compare=StyleCompare value=STRING 'then' resourceThemePath=THEME_RESOURCE;
	public StringToResourceStyleConfigElements getStringToResourceStyleConfigAccess() {
		return pStringToResourceStyleConfig;
	}
	
	public ParserRule getStringToResourceStyleConfigRule() {
		return getStringToResourceStyleConfigAccess().getRule();
	}
	
	//enum StyleCompare returns style::CxGridCompare:
	//	Equal="equal" | GreaterEqual="greater equal" | GreaterThan="greater than" | LowerEqual="lower equal" |
	//	LowerThan="lower than" | NotEqual="not equal";
	public StyleCompareElements getStyleCompareAccess() {
		return eStyleCompare;
	}
	
	public EnumRule getStyleCompareRule() {
		return getStyleCompareAccess().getRule();
	}
	
	//terminal THEME_RESOURCE:
	//	'theme:/' ('a'..'z' | 'A'..'Z' | '$' | '_' | '.' | '/' | '0'..'9')*;
	public TerminalRule getTHEME_RESOURCERule() {
		return tTHEME_RESOURCE;
	}
	
	//LInt ecore::EInt:
	//	('+' | '-')? INT;
	public LIntElements getLIntAccess() {
		return pLInt;
	}
	
	public ParserRule getLIntRule() {
		return getLIntAccess().getRule();
	}
	
	//LDouble ecore::EDouble:
	//	LInt ('.' INT)?;
	public LDoubleElements getLDoubleAccess() {
		return pLDouble;
	}
	
	public ParserRule getLDoubleRule() {
		return getLDoubleAccess().getRule();
	}
	
	//terminal EVENT_TOPIC:
	//	"'" ID ('/' ID)* '/*'? "'";
	public TerminalRule getEVENT_TOPICRule() {
		return tEVENT_TOPIC;
	}
	
	////  ----------------- grid ends ------------------------
	//SignedNumber ecore::EDouble:
	//	'-'? Number;
	public SignedNumberElements getSignedNumberAccess() {
		return pSignedNumber;
	}
	
	public ParserRule getSignedNumberRule() {
		return getSignedNumberAccess().getRule();
	}
	
	//SignedInt ecore::EInt:
	//	'-'? INT;
	public SignedIntElements getSignedIntAccess() {
		return pSignedInt;
	}
	
	public ParserRule getSignedIntRule() {
		return getSignedIntAccess().getRule();
	}
	
	//TRANSLATABLESTRING:
	//	STRING;
	public TRANSLATABLESTRINGElements getTRANSLATABLESTRINGAccess() {
		return pTRANSLATABLESTRING;
	}
	
	public ParserRule getTRANSLATABLESTRINGRule() {
		return getTRANSLATABLESTRINGAccess().getRule();
	}
	
	//TRANSLATABLEID:
	//	ID;
	public TRANSLATABLEIDElements getTRANSLATABLEIDAccess() {
		return pTRANSLATABLEID;
	}
	
	public ParserRule getTRANSLATABLEIDRule() {
		return getTRANSLATABLEIDAccess().getRule();
	}
	
	//enum TrendIconEnum:
	//	RISING='rising' | BADRISING='bad-rising' | SLOPING='sloping' | GOODSLOPING='good-sloping' | STAGNATING='stagnating';
	public TrendIconEnumElements getTrendIconEnumAccess() {
		return eTrendIconEnum;
	}
	
	public EnumRule getTrendIconEnumRule() {
		return getTrendIconEnumAccess().getRule();
	}
	
	//enum RowHeaderMode:
	//	HIDDEN='hidden' | EXPLICIT_DEFAULTS_ID='explicit' | INDEX='indexed';
	public RowHeaderModeElements getRowHeaderModeAccess() {
		return eRowHeaderMode;
	}
	
	public EnumRule getRowHeaderModeRule() {
		return getRowHeaderModeAccess().getRule();
	}
	
	//enum AxisEnum returns datamart::AxisEnum:
	//	DEFAULT='default' | COLUMNS='columns' | ROWS='rows' | PAGES='pages' | SECTIONS='sections' | CHAPTERS='chapters'
	//	/* | AXIS(<index>)*/;
	public AxisEnumElements getAxisEnumAccess() {
		return eAxisEnum;
	}
	
	public EnumRule getAxisEnumRule() {
		return getAxisEnumAccess().getRule();
	}
	
	//@ Override XImportDeclaration OXImportDeclaration:
	//	{OXImportDeclaration}
	//	'import' (static?='static' extension?='extension'? importedType=[JvmDeclaredType|QualifiedNameInStaticImport]
	//	(wildcard?='*' | memberName=ValidID) | importedType=[JvmDeclaredType|QualifiedName] |
	//	importedNamespace=QualifiedNameWithWildcard
	//	| fqnImport?='ns' importedFullyQualifiedName=QualifiedName) ';'?;
	public OXtypeGrammarAccess.XImportDeclarationElements getXImportDeclarationAccess() {
		return gaOXtype.getXImportDeclarationAccess();
	}
	
	public ParserRule getXImportDeclarationRule() {
		return getXImportDeclarationAccess().getRule();
	}
	
	//XAnnotation:
	//	{XAnnotation}
	//	'@' annotationType=[types::JvmAnnotationType|QualifiedName] (=> '(' (elementValuePairs+=XAnnotationElementValuePair
	//	(',' elementValuePairs+=XAnnotationElementValuePair)*
	//	| value=XAnnotationElementValueOrCommaList)?
	//	')')?;
	public XbaseWithAnnotationsGrammarAccess.XAnnotationElements getXAnnotationAccess() {
		return gaXbaseWithAnnotations.getXAnnotationAccess();
	}
	
	public ParserRule getXAnnotationRule() {
		return getXAnnotationAccess().getRule();
	}
	
	//XAnnotationElementValuePair:
	//	=> (element=[types::JvmOperation|ValidID] '=') value=XAnnotationElementValue;
	public XbaseWithAnnotationsGrammarAccess.XAnnotationElementValuePairElements getXAnnotationElementValuePairAccess() {
		return gaXbaseWithAnnotations.getXAnnotationElementValuePairAccess();
	}
	
	public ParserRule getXAnnotationElementValuePairRule() {
		return getXAnnotationElementValuePairAccess().getRule();
	}
	
	//XAnnotationElementValueOrCommaList xbase::XExpression:
	//	=> ({xbase::XListLiteral} '#' '[') (elements+=XAnnotationOrExpression (',' elements+=XAnnotationOrExpression)*)? ']'
	//	| XAnnotationOrExpression ({xbase::XListLiteral.elements+=current} (',' elements+=XAnnotationOrExpression)+)?;
	public XbaseWithAnnotationsGrammarAccess.XAnnotationElementValueOrCommaListElements getXAnnotationElementValueOrCommaListAccess() {
		return gaXbaseWithAnnotations.getXAnnotationElementValueOrCommaListAccess();
	}
	
	public ParserRule getXAnnotationElementValueOrCommaListRule() {
		return getXAnnotationElementValueOrCommaListAccess().getRule();
	}
	
	//XAnnotationElementValue xbase::XExpression:
	//	=> ({xbase::XListLiteral} '#' '[') (elements+=XAnnotationOrExpression (',' elements+=XAnnotationOrExpression)*)? ']'
	//	| XAnnotationOrExpression;
	public XbaseWithAnnotationsGrammarAccess.XAnnotationElementValueElements getXAnnotationElementValueAccess() {
		return gaXbaseWithAnnotations.getXAnnotationElementValueAccess();
	}
	
	public ParserRule getXAnnotationElementValueRule() {
		return getXAnnotationElementValueAccess().getRule();
	}
	
	//XAnnotationOrExpression xbase::XExpression:
	//	XAnnotation | XExpression;
	public XbaseWithAnnotationsGrammarAccess.XAnnotationOrExpressionElements getXAnnotationOrExpressionAccess() {
		return gaXbaseWithAnnotations.getXAnnotationOrExpressionAccess();
	}
	
	public ParserRule getXAnnotationOrExpressionRule() {
		return getXAnnotationOrExpressionAccess().getRule();
	}
	
	//XExpression:
	//	XAssignment;
	public XbaseGrammarAccess.XExpressionElements getXExpressionAccess() {
		return gaXbase.getXExpressionAccess();
	}
	
	public ParserRule getXExpressionRule() {
		return getXExpressionAccess().getRule();
	}
	
	//XAssignment XExpression:
	//	{XAssignment} feature=[types::JvmIdentifiableElement|FeatureCallID] OpSingleAssign value=XAssignment | XOrExpression
	//	(=> ({XBinaryOperation.leftOperand=current} feature=[types::JvmIdentifiableElement|OpMultiAssign])
	//	rightOperand=XAssignment)?;
	public XbaseGrammarAccess.XAssignmentElements getXAssignmentAccess() {
		return gaXbase.getXAssignmentAccess();
	}
	
	public ParserRule getXAssignmentRule() {
		return getXAssignmentAccess().getRule();
	}
	
	//OpSingleAssign:
	//	'=';
	public XbaseGrammarAccess.OpSingleAssignElements getOpSingleAssignAccess() {
		return gaXbase.getOpSingleAssignAccess();
	}
	
	public ParserRule getOpSingleAssignRule() {
		return getOpSingleAssignAccess().getRule();
	}
	
	//OpMultiAssign:
	//	'+=' | '-=' | '*=' | '/=' | '%=' |
	//	'<' '<' '=' |
	//	'>' '>'? '>=';
	public XbaseGrammarAccess.OpMultiAssignElements getOpMultiAssignAccess() {
		return gaXbase.getOpMultiAssignAccess();
	}
	
	public ParserRule getOpMultiAssignRule() {
		return getOpMultiAssignAccess().getRule();
	}
	
	//XOrExpression XExpression:
	//	XAndExpression (=> ({XBinaryOperation.leftOperand=current} feature=[types::JvmIdentifiableElement|OpOr])
	//	rightOperand=XAndExpression)*;
	public XbaseGrammarAccess.XOrExpressionElements getXOrExpressionAccess() {
		return gaXbase.getXOrExpressionAccess();
	}
	
	public ParserRule getXOrExpressionRule() {
		return getXOrExpressionAccess().getRule();
	}
	
	//OpOr:
	//	'||';
	public XbaseGrammarAccess.OpOrElements getOpOrAccess() {
		return gaXbase.getOpOrAccess();
	}
	
	public ParserRule getOpOrRule() {
		return getOpOrAccess().getRule();
	}
	
	//XAndExpression XExpression:
	//	XEqualityExpression (=> ({XBinaryOperation.leftOperand=current} feature=[types::JvmIdentifiableElement|OpAnd])
	//	rightOperand=XEqualityExpression)*;
	public XbaseGrammarAccess.XAndExpressionElements getXAndExpressionAccess() {
		return gaXbase.getXAndExpressionAccess();
	}
	
	public ParserRule getXAndExpressionRule() {
		return getXAndExpressionAccess().getRule();
	}
	
	//OpAnd:
	//	'&&';
	public XbaseGrammarAccess.OpAndElements getOpAndAccess() {
		return gaXbase.getOpAndAccess();
	}
	
	public ParserRule getOpAndRule() {
		return getOpAndAccess().getRule();
	}
	
	//XEqualityExpression XExpression:
	//	XRelationalExpression (=> ({XBinaryOperation.leftOperand=current} feature=[types::JvmIdentifiableElement|OpEquality])
	//	rightOperand=XRelationalExpression)*;
	public XbaseGrammarAccess.XEqualityExpressionElements getXEqualityExpressionAccess() {
		return gaXbase.getXEqualityExpressionAccess();
	}
	
	public ParserRule getXEqualityExpressionRule() {
		return getXEqualityExpressionAccess().getRule();
	}
	
	//OpEquality:
	//	'==' | '!=' | '===' | '!==';
	public XbaseGrammarAccess.OpEqualityElements getOpEqualityAccess() {
		return gaXbase.getOpEqualityAccess();
	}
	
	public ParserRule getOpEqualityRule() {
		return getOpEqualityAccess().getRule();
	}
	
	//XRelationalExpression XExpression:
	//	XOtherOperatorExpression (=> ({XInstanceOfExpression.expression=current} 'instanceof') type=JvmTypeReference |
	//	=> ({XBinaryOperation.leftOperand=current} feature=[types::JvmIdentifiableElement|OpCompare])
	//	rightOperand=XOtherOperatorExpression)*;
	public XbaseGrammarAccess.XRelationalExpressionElements getXRelationalExpressionAccess() {
		return gaXbase.getXRelationalExpressionAccess();
	}
	
	public ParserRule getXRelationalExpressionRule() {
		return getXRelationalExpressionAccess().getRule();
	}
	
	//OpCompare:
	//	'>=' | '<' '=' | '>' | '<';
	public XbaseGrammarAccess.OpCompareElements getOpCompareAccess() {
		return gaXbase.getOpCompareAccess();
	}
	
	public ParserRule getOpCompareRule() {
		return getOpCompareAccess().getRule();
	}
	
	//XOtherOperatorExpression XExpression:
	//	XAdditiveExpression (=> ({XBinaryOperation.leftOperand=current} feature=[types::JvmIdentifiableElement|OpOther])
	//	rightOperand=XAdditiveExpression)*;
	public XbaseGrammarAccess.XOtherOperatorExpressionElements getXOtherOperatorExpressionAccess() {
		return gaXbase.getXOtherOperatorExpressionAccess();
	}
	
	public ParserRule getXOtherOperatorExpressionRule() {
		return getXOtherOperatorExpressionAccess().getRule();
	}
	
	//OpOther:
	//	'->'
	//	| '..<'
	//	| '>' '..'
	//	| '..'
	//	| '=>'
	//	| '>' (=> ('>' '>') | '>') | '<' (=> ('<' '<') | '<' | '=>') | '<>'
	//	| '?:';
	public XbaseGrammarAccess.OpOtherElements getOpOtherAccess() {
		return gaXbase.getOpOtherAccess();
	}
	
	public ParserRule getOpOtherRule() {
		return getOpOtherAccess().getRule();
	}
	
	//XAdditiveExpression XExpression:
	//	XMultiplicativeExpression (=> ({XBinaryOperation.leftOperand=current} feature=[types::JvmIdentifiableElement|OpAdd])
	//	rightOperand=XMultiplicativeExpression)*;
	public XbaseGrammarAccess.XAdditiveExpressionElements getXAdditiveExpressionAccess() {
		return gaXbase.getXAdditiveExpressionAccess();
	}
	
	public ParserRule getXAdditiveExpressionRule() {
		return getXAdditiveExpressionAccess().getRule();
	}
	
	//OpAdd:
	//	'+' | '-';
	public XbaseGrammarAccess.OpAddElements getOpAddAccess() {
		return gaXbase.getOpAddAccess();
	}
	
	public ParserRule getOpAddRule() {
		return getOpAddAccess().getRule();
	}
	
	//XMultiplicativeExpression XExpression:
	//	XUnaryOperation (=> ({XBinaryOperation.leftOperand=current} feature=[types::JvmIdentifiableElement|OpMulti])
	//	rightOperand=XUnaryOperation)*;
	public XbaseGrammarAccess.XMultiplicativeExpressionElements getXMultiplicativeExpressionAccess() {
		return gaXbase.getXMultiplicativeExpressionAccess();
	}
	
	public ParserRule getXMultiplicativeExpressionRule() {
		return getXMultiplicativeExpressionAccess().getRule();
	}
	
	//OpMulti:
	//	'*' | '**' | '/' | '%';
	public XbaseGrammarAccess.OpMultiElements getOpMultiAccess() {
		return gaXbase.getOpMultiAccess();
	}
	
	public ParserRule getOpMultiRule() {
		return getOpMultiAccess().getRule();
	}
	
	//XUnaryOperation XExpression:
	//	{XUnaryOperation} feature=[types::JvmIdentifiableElement|OpUnary] operand=XUnaryOperation
	//	| XCastedExpression;
	public XbaseGrammarAccess.XUnaryOperationElements getXUnaryOperationAccess() {
		return gaXbase.getXUnaryOperationAccess();
	}
	
	public ParserRule getXUnaryOperationRule() {
		return getXUnaryOperationAccess().getRule();
	}
	
	//OpUnary:
	//	"!" | "-" | "+";
	public XbaseGrammarAccess.OpUnaryElements getOpUnaryAccess() {
		return gaXbase.getOpUnaryAccess();
	}
	
	public ParserRule getOpUnaryRule() {
		return getOpUnaryAccess().getRule();
	}
	
	//XCastedExpression XExpression:
	//	XPostfixOperation (=> ({XCastedExpression.target=current} 'as') type=JvmTypeReference)*;
	public XbaseGrammarAccess.XCastedExpressionElements getXCastedExpressionAccess() {
		return gaXbase.getXCastedExpressionAccess();
	}
	
	public ParserRule getXCastedExpressionRule() {
		return getXCastedExpressionAccess().getRule();
	}
	
	//XPostfixOperation XExpression:
	//	XMemberFeatureCall => ({XPostfixOperation.operand=current} feature=[types::JvmIdentifiableElement|OpPostfix])?;
	public XbaseGrammarAccess.XPostfixOperationElements getXPostfixOperationAccess() {
		return gaXbase.getXPostfixOperationAccess();
	}
	
	public ParserRule getXPostfixOperationRule() {
		return getXPostfixOperationAccess().getRule();
	}
	
	//OpPostfix:
	//	"++" | "--";
	public XbaseGrammarAccess.OpPostfixElements getOpPostfixAccess() {
		return gaXbase.getOpPostfixAccess();
	}
	
	public ParserRule getOpPostfixRule() {
		return getOpPostfixAccess().getRule();
	}
	
	//XMemberFeatureCall XExpression:
	//	XPrimaryExpression (=> ({XAssignment.assignable=current} ('.' | explicitStatic?="::")
	//	feature=[types::JvmIdentifiableElement|FeatureCallID] OpSingleAssign) value=XAssignment
	//	| => ({XMemberFeatureCall.memberCallTarget=current} ("." | nullSafe?="?." | explicitStatic?="::")) ('<'
	//	typeArguments+=JvmArgumentTypeReference (',' typeArguments+=JvmArgumentTypeReference)* '>')?
	//	feature=[types::JvmIdentifiableElement|IdOrSuper] (=> explicitOperationCall?='(' (memberCallArguments+=XShortClosure
	//	| memberCallArguments+=XExpression (',' memberCallArguments+=XExpression)*)?
	//	')')?
	//	memberCallArguments+=XClosure?)*;
	public XbaseGrammarAccess.XMemberFeatureCallElements getXMemberFeatureCallAccess() {
		return gaXbase.getXMemberFeatureCallAccess();
	}
	
	public ParserRule getXMemberFeatureCallRule() {
		return getXMemberFeatureCallAccess().getRule();
	}
	
	//XPrimaryExpression XExpression:
	//	XConstructorCall | XBlockExpression | XSwitchExpression | XSynchronizedExpression | XFeatureCall | XLiteral |
	//	XIfExpression | XForLoopExpression | XBasicForLoopExpression | XWhileExpression | XDoWhileExpression |
	//	XThrowExpression | XReturnExpression | XTryCatchFinallyExpression | XParenthesizedExpression;
	public XbaseGrammarAccess.XPrimaryExpressionElements getXPrimaryExpressionAccess() {
		return gaXbase.getXPrimaryExpressionAccess();
	}
	
	public ParserRule getXPrimaryExpressionRule() {
		return getXPrimaryExpressionAccess().getRule();
	}
	
	//XLiteral XExpression:
	//	XCollectionLiteral | XClosure | XBooleanLiteral | XNumberLiteral | XNullLiteral | XStringLiteral | XTypeLiteral;
	public XbaseGrammarAccess.XLiteralElements getXLiteralAccess() {
		return gaXbase.getXLiteralAccess();
	}
	
	public ParserRule getXLiteralRule() {
		return getXLiteralAccess().getRule();
	}
	
	//XCollectionLiteral:
	//	XSetLiteral | XListLiteral;
	public XbaseGrammarAccess.XCollectionLiteralElements getXCollectionLiteralAccess() {
		return gaXbase.getXCollectionLiteralAccess();
	}
	
	public ParserRule getXCollectionLiteralRule() {
		return getXCollectionLiteralAccess().getRule();
	}
	
	//XSetLiteral:
	//	{XSetLiteral} '#' '{' (elements+=XExpression (',' elements+=XExpression)*)? '}';
	public XbaseGrammarAccess.XSetLiteralElements getXSetLiteralAccess() {
		return gaXbase.getXSetLiteralAccess();
	}
	
	public ParserRule getXSetLiteralRule() {
		return getXSetLiteralAccess().getRule();
	}
	
	//XListLiteral:
	//	{XListLiteral} '#' '[' (elements+=XExpression (',' elements+=XExpression)*)? ']';
	public XbaseGrammarAccess.XListLiteralElements getXListLiteralAccess() {
		return gaXbase.getXListLiteralAccess();
	}
	
	public ParserRule getXListLiteralRule() {
		return getXListLiteralAccess().getRule();
	}
	
	//XClosure XExpression:
	//	=> ({XClosure}
	//	'[')
	//	=> ((declaredFormalParameters+=JvmFormalParameter (',' declaredFormalParameters+=JvmFormalParameter)*)?
	//	explicitSyntax?='|')?
	//	expression=XExpressionInClosure
	//	']';
	public XbaseGrammarAccess.XClosureElements getXClosureAccess() {
		return gaXbase.getXClosureAccess();
	}
	
	public ParserRule getXClosureRule() {
		return getXClosureAccess().getRule();
	}
	
	//XExpressionInClosure XExpression:
	//	{XBlockExpression} (expressions+=XExpressionOrVarDeclaration ';'?)*;
	public XbaseGrammarAccess.XExpressionInClosureElements getXExpressionInClosureAccess() {
		return gaXbase.getXExpressionInClosureAccess();
	}
	
	public ParserRule getXExpressionInClosureRule() {
		return getXExpressionInClosureAccess().getRule();
	}
	
	//XShortClosure XExpression:
	//	=> ({XClosure} (declaredFormalParameters+=JvmFormalParameter (',' declaredFormalParameters+=JvmFormalParameter)*)?
	//	explicitSyntax?='|') expression=XExpression;
	public XbaseGrammarAccess.XShortClosureElements getXShortClosureAccess() {
		return gaXbase.getXShortClosureAccess();
	}
	
	public ParserRule getXShortClosureRule() {
		return getXShortClosureAccess().getRule();
	}
	
	//XParenthesizedExpression XExpression:
	//	'(' XExpression ')';
	public XbaseGrammarAccess.XParenthesizedExpressionElements getXParenthesizedExpressionAccess() {
		return gaXbase.getXParenthesizedExpressionAccess();
	}
	
	public ParserRule getXParenthesizedExpressionRule() {
		return getXParenthesizedExpressionAccess().getRule();
	}
	
	//XIfExpression XExpression:
	//	{XIfExpression}
	//	'if' '(' if=XExpression ')'
	//	then=XExpression (=> 'else' else=XExpression)?;
	public XbaseGrammarAccess.XIfExpressionElements getXIfExpressionAccess() {
		return gaXbase.getXIfExpressionAccess();
	}
	
	public ParserRule getXIfExpressionRule() {
		return getXIfExpressionAccess().getRule();
	}
	
	//XSwitchExpression XExpression:
	//	{XSwitchExpression}
	//	'switch' (=> ('(' declaredParam=JvmFormalParameter ':') switch=XExpression ')'
	//	| => (declaredParam=JvmFormalParameter ':')? switch=XExpression) '{'
	//	cases+=XCasePart* ('default' ':' default=XExpression)?
	//	'}';
	public XbaseGrammarAccess.XSwitchExpressionElements getXSwitchExpressionAccess() {
		return gaXbase.getXSwitchExpressionAccess();
	}
	
	public ParserRule getXSwitchExpressionRule() {
		return getXSwitchExpressionAccess().getRule();
	}
	
	//XCasePart:
	//	{XCasePart} typeGuard=JvmTypeReference? ('case' case=XExpression)? (':' then=XExpression | fallThrough?=',');
	public XbaseGrammarAccess.XCasePartElements getXCasePartAccess() {
		return gaXbase.getXCasePartAccess();
	}
	
	public ParserRule getXCasePartRule() {
		return getXCasePartAccess().getRule();
	}
	
	//XForLoopExpression XExpression:
	//	=> ({XForLoopExpression}
	//	'for' '(' declaredParam=JvmFormalParameter ':') forExpression=XExpression ')'
	//	eachExpression=XExpression;
	public XbaseGrammarAccess.XForLoopExpressionElements getXForLoopExpressionAccess() {
		return gaXbase.getXForLoopExpressionAccess();
	}
	
	public ParserRule getXForLoopExpressionRule() {
		return getXForLoopExpressionAccess().getRule();
	}
	
	//XBasicForLoopExpression XExpression:
	//	{XBasicForLoopExpression}
	//	'for' '(' (initExpressions+=XExpressionOrVarDeclaration (',' initExpressions+=XExpressionOrVarDeclaration)*)? ';'
	//	expression=XExpression? ';' (updateExpressions+=XExpression (',' updateExpressions+=XExpression)*)? ')'
	//	eachExpression=XExpression;
	public XbaseGrammarAccess.XBasicForLoopExpressionElements getXBasicForLoopExpressionAccess() {
		return gaXbase.getXBasicForLoopExpressionAccess();
	}
	
	public ParserRule getXBasicForLoopExpressionRule() {
		return getXBasicForLoopExpressionAccess().getRule();
	}
	
	//XWhileExpression XExpression:
	//	{XWhileExpression}
	//	'while' '(' predicate=XExpression ')'
	//	body=XExpression;
	public XbaseGrammarAccess.XWhileExpressionElements getXWhileExpressionAccess() {
		return gaXbase.getXWhileExpressionAccess();
	}
	
	public ParserRule getXWhileExpressionRule() {
		return getXWhileExpressionAccess().getRule();
	}
	
	//XDoWhileExpression XExpression:
	//	{XDoWhileExpression}
	//	'do'
	//	body=XExpression
	//	'while' '(' predicate=XExpression ')';
	public XbaseGrammarAccess.XDoWhileExpressionElements getXDoWhileExpressionAccess() {
		return gaXbase.getXDoWhileExpressionAccess();
	}
	
	public ParserRule getXDoWhileExpressionRule() {
		return getXDoWhileExpressionAccess().getRule();
	}
	
	//XBlockExpression XExpression:
	//	{XBlockExpression}
	//	'{' (expressions+=XExpressionOrVarDeclaration ';'?)*
	//	'}';
	public XbaseGrammarAccess.XBlockExpressionElements getXBlockExpressionAccess() {
		return gaXbase.getXBlockExpressionAccess();
	}
	
	public ParserRule getXBlockExpressionRule() {
		return getXBlockExpressionAccess().getRule();
	}
	
	//XExpressionOrVarDeclaration XExpression:
	//	XVariableDeclaration | XExpression;
	public XbaseGrammarAccess.XExpressionOrVarDeclarationElements getXExpressionOrVarDeclarationAccess() {
		return gaXbase.getXExpressionOrVarDeclarationAccess();
	}
	
	public ParserRule getXExpressionOrVarDeclarationRule() {
		return getXExpressionOrVarDeclarationAccess().getRule();
	}
	
	//XVariableDeclaration XExpression:
	//	{XVariableDeclaration} (writeable?='var' | 'val') (=> (type=JvmTypeReference name=ValidID) | name=ValidID) ('='
	//	right=XExpression)?;
	public XbaseGrammarAccess.XVariableDeclarationElements getXVariableDeclarationAccess() {
		return gaXbase.getXVariableDeclarationAccess();
	}
	
	public ParserRule getXVariableDeclarationRule() {
		return getXVariableDeclarationAccess().getRule();
	}
	
	//JvmFormalParameter types::JvmFormalParameter:
	//	parameterType=JvmTypeReference? name=ValidID;
	public XbaseGrammarAccess.JvmFormalParameterElements getJvmFormalParameterAccess() {
		return gaXbase.getJvmFormalParameterAccess();
	}
	
	public ParserRule getJvmFormalParameterRule() {
		return getJvmFormalParameterAccess().getRule();
	}
	
	//FullJvmFormalParameter types::JvmFormalParameter:
	//	parameterType=JvmTypeReference name=ValidID;
	public XbaseGrammarAccess.FullJvmFormalParameterElements getFullJvmFormalParameterAccess() {
		return gaXbase.getFullJvmFormalParameterAccess();
	}
	
	public ParserRule getFullJvmFormalParameterRule() {
		return getFullJvmFormalParameterAccess().getRule();
	}
	
	//XFeatureCall XExpression:
	//	{XFeatureCall} ('<' typeArguments+=JvmArgumentTypeReference (',' typeArguments+=JvmArgumentTypeReference)* '>')?
	//	feature=[types::JvmIdentifiableElement|IdOrSuper] (=> explicitOperationCall?='(' (featureCallArguments+=XShortClosure
	//	| featureCallArguments+=XExpression (',' featureCallArguments+=XExpression)*)?
	//	')')?
	//	featureCallArguments+=XClosure?;
	public XbaseGrammarAccess.XFeatureCallElements getXFeatureCallAccess() {
		return gaXbase.getXFeatureCallAccess();
	}
	
	public ParserRule getXFeatureCallRule() {
		return getXFeatureCallAccess().getRule();
	}
	
	//FeatureCallID:
	//	ValidID | 'extends' | 'static' | 'import' | 'extension';
	public XbaseGrammarAccess.FeatureCallIDElements getFeatureCallIDAccess() {
		return gaXbase.getFeatureCallIDAccess();
	}
	
	public ParserRule getFeatureCallIDRule() {
		return getFeatureCallIDAccess().getRule();
	}
	
	//IdOrSuper:
	//	FeatureCallID | 'super';
	public XbaseGrammarAccess.IdOrSuperElements getIdOrSuperAccess() {
		return gaXbase.getIdOrSuperAccess();
	}
	
	public ParserRule getIdOrSuperRule() {
		return getIdOrSuperAccess().getRule();
	}
	
	//XConstructorCall XExpression:
	//	{XConstructorCall}
	//	'new' constructor=[types::JvmConstructor|QualifiedName] (=> '<' typeArguments+=JvmArgumentTypeReference (','
	//	typeArguments+=JvmArgumentTypeReference)* '>')? (=> explicitConstructorCall?='(' (arguments+=XShortClosure
	//	| arguments+=XExpression (',' arguments+=XExpression)*)?
	//	')')?
	//	arguments+=XClosure?;
	public XbaseGrammarAccess.XConstructorCallElements getXConstructorCallAccess() {
		return gaXbase.getXConstructorCallAccess();
	}
	
	public ParserRule getXConstructorCallRule() {
		return getXConstructorCallAccess().getRule();
	}
	
	//XBooleanLiteral XExpression:
	//	{XBooleanLiteral} ('false' | isTrue?='true');
	public XbaseGrammarAccess.XBooleanLiteralElements getXBooleanLiteralAccess() {
		return gaXbase.getXBooleanLiteralAccess();
	}
	
	public ParserRule getXBooleanLiteralRule() {
		return getXBooleanLiteralAccess().getRule();
	}
	
	//XNullLiteral XExpression:
	//	{XNullLiteral} 'null';
	public XbaseGrammarAccess.XNullLiteralElements getXNullLiteralAccess() {
		return gaXbase.getXNullLiteralAccess();
	}
	
	public ParserRule getXNullLiteralRule() {
		return getXNullLiteralAccess().getRule();
	}
	
	//XNumberLiteral XExpression:
	//	{XNumberLiteral} value=Number;
	public XbaseGrammarAccess.XNumberLiteralElements getXNumberLiteralAccess() {
		return gaXbase.getXNumberLiteralAccess();
	}
	
	public ParserRule getXNumberLiteralRule() {
		return getXNumberLiteralAccess().getRule();
	}
	
	//XStringLiteral XExpression:
	//	{XStringLiteral} value=STRING;
	public XbaseGrammarAccess.XStringLiteralElements getXStringLiteralAccess() {
		return gaXbase.getXStringLiteralAccess();
	}
	
	public ParserRule getXStringLiteralRule() {
		return getXStringLiteralAccess().getRule();
	}
	
	//XTypeLiteral XExpression:
	//	{XTypeLiteral} 'typeof' '(' type=[types::JvmType|QualifiedName] arrayDimensions+=ArrayBrackets* ')';
	public XbaseGrammarAccess.XTypeLiteralElements getXTypeLiteralAccess() {
		return gaXbase.getXTypeLiteralAccess();
	}
	
	public ParserRule getXTypeLiteralRule() {
		return getXTypeLiteralAccess().getRule();
	}
	
	//XThrowExpression XExpression:
	//	{XThrowExpression} 'throw' expression=XExpression;
	public XbaseGrammarAccess.XThrowExpressionElements getXThrowExpressionAccess() {
		return gaXbase.getXThrowExpressionAccess();
	}
	
	public ParserRule getXThrowExpressionRule() {
		return getXThrowExpressionAccess().getRule();
	}
	
	//XReturnExpression XExpression:
	//	{XReturnExpression} 'return' -> expression=XExpression?;
	public XbaseGrammarAccess.XReturnExpressionElements getXReturnExpressionAccess() {
		return gaXbase.getXReturnExpressionAccess();
	}
	
	public ParserRule getXReturnExpressionRule() {
		return getXReturnExpressionAccess().getRule();
	}
	
	//XTryCatchFinallyExpression XExpression:
	//	{XTryCatchFinallyExpression}
	//	'try'
	//	expression=XExpression (catchClauses+=XCatchClause+ (=> 'finally' finallyExpression=XExpression)?
	//	| 'finally' finallyExpression=XExpression);
	public XbaseGrammarAccess.XTryCatchFinallyExpressionElements getXTryCatchFinallyExpressionAccess() {
		return gaXbase.getXTryCatchFinallyExpressionAccess();
	}
	
	public ParserRule getXTryCatchFinallyExpressionRule() {
		return getXTryCatchFinallyExpressionAccess().getRule();
	}
	
	//XSynchronizedExpression XExpression:
	//	=> ({XSynchronizedExpression}
	//	'synchronized' '(') param=XExpression ')' expression=XExpression;
	public XbaseGrammarAccess.XSynchronizedExpressionElements getXSynchronizedExpressionAccess() {
		return gaXbase.getXSynchronizedExpressionAccess();
	}
	
	public ParserRule getXSynchronizedExpressionRule() {
		return getXSynchronizedExpressionAccess().getRule();
	}
	
	//XCatchClause:
	//	=> 'catch' '(' declaredParam=FullJvmFormalParameter ')' expression=XExpression;
	public XbaseGrammarAccess.XCatchClauseElements getXCatchClauseAccess() {
		return gaXbase.getXCatchClauseAccess();
	}
	
	public ParserRule getXCatchClauseRule() {
		return getXCatchClauseAccess().getRule();
	}
	
	//QualifiedName:
	//	ValidID (=> '.' ValidID)*;
	public XbaseGrammarAccess.QualifiedNameElements getQualifiedNameAccess() {
		return gaXbase.getQualifiedNameAccess();
	}
	
	public ParserRule getQualifiedNameRule() {
		return getQualifiedNameAccess().getRule();
	}
	
	//Number hidden():
	//	HEX | (INT | DECIMAL) ('.' (INT | DECIMAL))?;
	public XbaseGrammarAccess.NumberElements getNumberAccess() {
		return gaXbase.getNumberAccess();
	}
	
	public ParserRule getNumberRule() {
		return getNumberAccess().getRule();
	}
	
	///**
	// * Dummy rule, for "better" downwards compatibility, since GrammarAccess generates non-static inner classes, 
	// * which makes downstream grammars break on classloading, when a rule is removed.
	// */ StaticQualifier:
	//	(ValidID '::')+;
	public XbaseGrammarAccess.StaticQualifierElements getStaticQualifierAccess() {
		return gaXbase.getStaticQualifierAccess();
	}
	
	public ParserRule getStaticQualifierRule() {
		return getStaticQualifierAccess().getRule();
	}
	
	//terminal HEX:
	//	('0x' | '0X') ('0'..'9' | 'a'..'f' | 'A'..'F' | '_')+ ('#' (('b' | 'B') ('i' | 'I') | ('l' | 'L')))?;
	public TerminalRule getHEXRule() {
		return gaXbase.getHEXRule();
	}
	
	//terminal INT returns ecore::EInt:
	//	'0'..'9' ('0'..'9' | '_')*;
	public TerminalRule getINTRule() {
		return gaXbase.getINTRule();
	}
	
	//terminal DECIMAL:
	//	INT (('e' | 'E') ('+' | '-')? INT)? (('b' | 'B') ('i' | 'I' | 'd' | 'D') | ('l' | 'L' | 'd' | 'D' | 'f' | 'F'))?;
	public TerminalRule getDECIMALRule() {
		return gaXbase.getDECIMALRule();
	}
	
	//JvmTypeReference:
	//	JvmParameterizedTypeReference => ({JvmGenericArrayTypeReference.componentType=current} ArrayBrackets)*
	//	| XFunctionTypeRef;
	public XtypeGrammarAccess.JvmTypeReferenceElements getJvmTypeReferenceAccess() {
		return gaXtype.getJvmTypeReferenceAccess();
	}
	
	public ParserRule getJvmTypeReferenceRule() {
		return getJvmTypeReferenceAccess().getRule();
	}
	
	//ArrayBrackets:
	//	'[' ']';
	public XtypeGrammarAccess.ArrayBracketsElements getArrayBracketsAccess() {
		return gaXtype.getArrayBracketsAccess();
	}
	
	public ParserRule getArrayBracketsRule() {
		return getArrayBracketsAccess().getRule();
	}
	
	//XFunctionTypeRef:
	//	('(' (paramTypes+=JvmTypeReference (',' paramTypes+=JvmTypeReference)*)? ')')? '=>' returnType=JvmTypeReference;
	public XtypeGrammarAccess.XFunctionTypeRefElements getXFunctionTypeRefAccess() {
		return gaXtype.getXFunctionTypeRefAccess();
	}
	
	public ParserRule getXFunctionTypeRefRule() {
		return getXFunctionTypeRefAccess().getRule();
	}
	
	//JvmParameterizedTypeReference:
	//	type=[JvmType|super::QualifiedName] (=> '<' arguments+=JvmArgumentTypeReference (','
	//	arguments+=JvmArgumentTypeReference)* '>' (=> ({JvmInnerTypeReference.outer=current} '.') type=[JvmType|ValidID] (=>
	//	'<' arguments+=JvmArgumentTypeReference (',' arguments+=JvmArgumentTypeReference)* '>')?)*)?;
	public XtypeGrammarAccess.JvmParameterizedTypeReferenceElements getJvmParameterizedTypeReferenceAccess() {
		return gaXtype.getJvmParameterizedTypeReferenceAccess();
	}
	
	public ParserRule getJvmParameterizedTypeReferenceRule() {
		return getJvmParameterizedTypeReferenceAccess().getRule();
	}
	
	//JvmArgumentTypeReference JvmTypeReference:
	//	JvmTypeReference | JvmWildcardTypeReference;
	public XtypeGrammarAccess.JvmArgumentTypeReferenceElements getJvmArgumentTypeReferenceAccess() {
		return gaXtype.getJvmArgumentTypeReferenceAccess();
	}
	
	public ParserRule getJvmArgumentTypeReferenceRule() {
		return getJvmArgumentTypeReferenceAccess().getRule();
	}
	
	//JvmWildcardTypeReference:
	//	{JvmWildcardTypeReference} '?' (constraints+=JvmUpperBound constraints+=JvmUpperBoundAnded*
	//	| constraints+=JvmLowerBound constraints+=JvmLowerBoundAnded*)?;
	public XtypeGrammarAccess.JvmWildcardTypeReferenceElements getJvmWildcardTypeReferenceAccess() {
		return gaXtype.getJvmWildcardTypeReferenceAccess();
	}
	
	public ParserRule getJvmWildcardTypeReferenceRule() {
		return getJvmWildcardTypeReferenceAccess().getRule();
	}
	
	//JvmUpperBound:
	//	'extends' typeReference=JvmTypeReference;
	public XtypeGrammarAccess.JvmUpperBoundElements getJvmUpperBoundAccess() {
		return gaXtype.getJvmUpperBoundAccess();
	}
	
	public ParserRule getJvmUpperBoundRule() {
		return getJvmUpperBoundAccess().getRule();
	}
	
	//JvmUpperBoundAnded JvmUpperBound:
	//	'&' typeReference=JvmTypeReference;
	public XtypeGrammarAccess.JvmUpperBoundAndedElements getJvmUpperBoundAndedAccess() {
		return gaXtype.getJvmUpperBoundAndedAccess();
	}
	
	public ParserRule getJvmUpperBoundAndedRule() {
		return getJvmUpperBoundAndedAccess().getRule();
	}
	
	//JvmLowerBound:
	//	'super' typeReference=JvmTypeReference;
	public XtypeGrammarAccess.JvmLowerBoundElements getJvmLowerBoundAccess() {
		return gaXtype.getJvmLowerBoundAccess();
	}
	
	public ParserRule getJvmLowerBoundRule() {
		return getJvmLowerBoundAccess().getRule();
	}
	
	//JvmLowerBoundAnded JvmLowerBound:
	//	'&' typeReference=JvmTypeReference;
	public XtypeGrammarAccess.JvmLowerBoundAndedElements getJvmLowerBoundAndedAccess() {
		return gaXtype.getJvmLowerBoundAndedAccess();
	}
	
	public ParserRule getJvmLowerBoundAndedRule() {
		return getJvmLowerBoundAndedAccess().getRule();
	}
	
	//JvmTypeParameter:
	//	name=ValidID (constraints+=JvmUpperBound constraints+=JvmUpperBoundAnded*)?;
	public XtypeGrammarAccess.JvmTypeParameterElements getJvmTypeParameterAccess() {
		return gaXtype.getJvmTypeParameterAccess();
	}
	
	public ParserRule getJvmTypeParameterRule() {
		return getJvmTypeParameterAccess().getRule();
	}
	
	//QualifiedNameWithWildcard:
	//	super::QualifiedName '.' '*';
	public XtypeGrammarAccess.QualifiedNameWithWildcardElements getQualifiedNameWithWildcardAccess() {
		return gaXtype.getQualifiedNameWithWildcardAccess();
	}
	
	public ParserRule getQualifiedNameWithWildcardRule() {
		return getQualifiedNameWithWildcardAccess().getRule();
	}
	
	//ValidID:
	//	ID;
	public XtypeGrammarAccess.ValidIDElements getValidIDAccess() {
		return gaXtype.getValidIDAccess();
	}
	
	public ParserRule getValidIDRule() {
		return getValidIDAccess().getRule();
	}
	
	//XImportSection:
	//	importDeclarations+=super::XImportDeclaration+;
	public XtypeGrammarAccess.XImportSectionElements getXImportSectionAccess() {
		return gaXtype.getXImportSectionAccess();
	}
	
	public ParserRule getXImportSectionRule() {
		return getXImportSectionAccess().getRule();
	}
	
	//QualifiedNameInStaticImport:
	//	(ValidID '.')+;
	public XtypeGrammarAccess.QualifiedNameInStaticImportElements getQualifiedNameInStaticImportAccess() {
		return gaXtype.getQualifiedNameInStaticImportAccess();
	}
	
	public ParserRule getQualifiedNameInStaticImportRule() {
		return getQualifiedNameInStaticImportAccess().getRule();
	}
	
	//terminal ID:
	//	'^'? ('a'..'z' | 'A'..'Z' | '$' | '_') ('a'..'z' | 'A'..'Z' | '$' | '_' | '0'..'9')*;
	public TerminalRule getIDRule() {
		return gaXtype.getIDRule();
	}
	
	//terminal STRING:
	//	'"' ('\\' . | !('\\' | '"'))* '"'? |
	//	"'" ('\\' . | !('\\' | "'"))* "'"?;
	public TerminalRule getSTRINGRule() {
		return gaXtype.getSTRINGRule();
	}
	
	//terminal ML_COMMENT:
	//	'/*'->'*/';
	public TerminalRule getML_COMMENTRule() {
		return gaXtype.getML_COMMENTRule();
	}
	
	//terminal SL_COMMENT:
	//	'//' !('\n' | '\r')* ('\r'? '\n')?;
	public TerminalRule getSL_COMMENTRule() {
		return gaXtype.getSL_COMMENTRule();
	}
	
	//terminal WS:
	//	' ' | '\t' | '\r' | '\n'+;
	public TerminalRule getWSRule() {
		return gaXtype.getWSRule();
	}
	
	//terminal ANY_OTHER:
	//	.;
	public TerminalRule getANY_OTHERRule() {
		return gaXtype.getANY_OTHERRule();
	}
}
